@@ -46,10 +46,6 @@
 #include "dotwriter.h"
 #include "static.h"
 
-// forward references
-class wxFileOutputStream;
-class wxTextOutputStream;
-
 /**
  * @class CallGraph
  * @brief Class define structure for plugin interface.
@@ -58,12 +54,12 @@ class CallGraph : public IPlugin
 {
 public:
     /**
-     * @brief Defautl constructor.
+     * @brief Default constructor.
      * @param manager
      */
     CallGraph(IManager* manager);
     /**
-     * @brief Defautl destructor.
+     * @brief Default destructor.
      */
     ~CallGraph();
     //--------------------------------------------
@@ -99,10 +95,6 @@ public:
      */
     wxString GetDotPath();
 
-    wxFileOutputStream* m_LogFile;
-
-    void LogFn(wxString s);
-
 protected:
     void MessageBox(const wxString& msg, unsigned long icon_mask);
     wxString LocateApp(const wxString& app_name);
@@ -132,18 +124,10 @@ protected:
      * @brief Pointer cgWnd type wxScrolledWindow used in tab page for display call graph picture.
      */
     wxScrolledWindow* cgWnd; // pointer cgWnd type wxScrolledWindow used in tab page for display call graph picture
-                             /**
-                              * @brief Pointer m_pInputStream type wxInputStream returned from gprof application.
-                              */
-    // wxInputStream *m_pInputStream; // pointer m_pInputStream type wxInputStream returned from gprof application
     /**
      * @brief Object confData type ConfCallGraph with stored configuration data.
      */
     ConfCallGraph confData; // object confData type ConfCallGraph with stored configuration data
-
-    // wxString        m_ProfiledBinFullName;
 };
 
-extern CallGraph* thePlugin;
-
 #endif // CallGraph
