@@ -25,10 +25,14 @@ public:
     std::shared_ptr<GenericFormatter> GetFormatterByContent(const wxString& content) const;
     size_t GetAllNames(wxArrayString* names) const;
 
+    /// Add new custom formatter
+    bool AddCustom(GenericFormatter* formatter);
+
+    /// Delete formatter by name
+    bool DeleteFormatter(const wxString& name);
+
     // do we have a formatter that can handle `filepath`?
     bool CanFormat(const wxString& filepath) const;
-    // can we format this content?
-    bool CanFormatByContent(const wxString& content) const;
 
     // serialization API
     void Load();
