@@ -25,29 +25,24 @@
 #include "codeformatter.h"
 
 #include "JSON.h"
+#include "Keyboard/clKeyboardManager.h"
+#include "SFTPClientData.hpp"
 #include "StringUtils.h"
-#include "asyncprocess.h"
-#include "clEditorConfig.h"
 #include "clEditorStateLocker.h"
 #include "clFileSystemEvent.h"
 #include "clFilesCollector.h"
-#include "clKeyboardManager.h"
 #include "clSFTPManager.hpp"
 #include "clSTCLineKeeper.h"
-#include "clWorkspaceManager.h"
 #include "codeformatterdlg.h"
 #include "codelite_events.h"
-#include "editor_config.h"
 #include "event_notifier.h"
 #include "file_logger.h"
 #include "fileutils.h"
 #include "globals.h"
+#include "macromanager.h"
 #include "macros.h"
-#include "precompiled_header.h"
-#include "procutils.h"
 #include "workspace.h"
 
-#include <algorithm>
 #include <thread>
 #include <wx/app.h> //wxInitialize/wxUnInitialize
 #include <wx/ffile.h>
@@ -56,6 +51,7 @@
 #include <wx/menu.h>
 #include <wx/msgdlg.h>
 #include <wx/progdlg.h>
+#include <wx/wupdlock.h>
 #include <wx/xrc/xmlres.h>
 
 namespace
@@ -64,19 +60,17 @@ namespace
 int ID_TOOL_SOURCE_CODE_FORMATTER = ::wxNewId();
 
 //------------------------------------------------------------------------
-CodeFormatter* theFormatter = NULL;
-
 JSONItem json_get_formatter_object(JSON* root, const wxString& formatter_name)
 {
     auto json = root->toElement();
-    if(!json.hasNamedObject("tools")) {
+    if (!json.hasNamedObject("tools")) {
         return JSONItem{ nullptr };
     }
     auto servers = json["tools"];
     int count = servers.arraySize();
-    for(int i = 0; i < count; ++i) {
+    for (int i = 0; i < count; ++i) {
         auto tool = servers[i];
-        if(tool["name"].toString() != formatter_name) {
+        if (tool["name"].toString() != formatter_name) {
             continue;
         }
         return tool;
@@ -87,14 +81,14 @@ JSONItem json_get_formatter_object(JSON* root, const wxString& formatter_name)
 thread_local std::unordered_map<wxString, size_t> ignore_map;
 bool dec_save_count_if_needed(const wxString& filepath)
 {
-    if(ignore_map.count(filepath) == 0) {
+    if (ignore_map.count(filepath) == 0) {
         return false;
     }
 
     // we caused this event, reduce the file reference count
     // and return
     ignore_map[filepath] -= 1;
-    if(ignore_map[filepath] == 0) {
+    if (ignore_map[filepath] == 0) {
         ignore_map.erase(filepath);
     }
     return true;
@@ -102,7 +96,7 @@ bool dec_save_count_if_needed(const wxString& filepath)
 
 void inc_save_count(const wxString& filepath)
 {
-    if(ignore_map.count(filepath)) {
+    if (ignore_map.count(filepath)) {
         ignore_map[filepath] += 1;
     } else {
         ignore_map[filepath] = 1;
@@ -112,13 +106,7 @@ void inc_save_count(const wxString& filepath)
 
 // Allocate the code formatter on the heap, it will be freed by
 // the application
-CL_PLUGIN_API IPlugin* CreatePlugin(IManager* manager)
-{
-    if(theFormatter == 0) {
-        theFormatter = new CodeFormatter(manager);
-    }
-    return theFormatter;
-}
+CL_PLUGIN_API IPlugin* CreatePlugin(IManager* manager) { return new CodeFormatter(manager); }
 
 CL_PLUGIN_API PluginInfo* GetPluginInfo()
 {
@@ -150,6 +138,7 @@ CodeFormatter::CodeFormatter(IManager* manager)
     EventNotifier::Get()->Bind(wxEVT_CONTEXT_MENU_FOLDER, &CodeFormatter::OnContextMenu, this);
     EventNotifier::Get()->Bind(wxEVT_WORKSPACE_LOADED, &CodeFormatter::OnWorkspaceLoaded, this);
     EventNotifier::Get()->Bind(wxEVT_WORKSPACE_CLOSED, &CodeFormatter::OnWorkspaceClosed, this);
+    EventNotifier::Get()->Bind(wxEVT_INIT_DONE, &CodeFormatter::OnInitDone, this);
 
     Bind(wxEVT_FORMAT_INPLACE_COMPELTED, &CodeFormatter::OnInplaceFormatCompleted, this);
     Bind(wxEVT_FORMAT_COMPELTED, &CodeFormatter::OnFormatCompleted, this);
@@ -166,8 +155,8 @@ void CodeFormatter::CreateToolBar(clToolBarGeneric* toolbar)
     clBitmapList* images = toolbar->GetBitmapsCreateIfNeeded();
     toolbar->AddSpacer();
     toolbar->AddTool(XRCID("format_source"), _("Format Source"), images->Add("format"), _("Format Source Code"));
-    toolbar->AddTool(XRCID("formatter_options"), _("Format Options"), images->Add("cog"),
-                     _("Source Code Formatter Options..."));
+    toolbar->AddTool(
+        XRCID("formatter_options"), _("Format Options"), images->Add("cog"), _("Source Code Formatter Options..."));
     // Connect the events to us
 
     // format the current editor
@@ -182,8 +171,8 @@ void CodeFormatter::CreatePluginMenu(wxMenu* pluginsMenu)
 {
     wxMenu* menu = new wxMenu();
     wxMenuItem* item(NULL);
-    item = new wxMenuItem(menu, XRCID("format_source"), _("Format Current Source"), _("Format Current Source"),
-                          wxITEM_NORMAL);
+    item = new wxMenuItem(
+        menu, XRCID("format_source"), _("Format Current Source"), _("Format Current Source"), wxITEM_NORMAL);
     menu->Append(item);
     menu->AppendSeparator();
     item = new wxMenuItem(menu, XRCID("formatter_options"), _("Options..."), wxEmptyString, wxITEM_NORMAL);
@@ -197,7 +186,7 @@ void CodeFormatter::OnFormatEditor(wxCommandEvent& e)
     const wxString& fileToFormat = e.GetString();
 
     // If we got a file name in the event, use it instead of the active editor
-    if(!fileToFormat.empty()) {
+    if (!fileToFormat.empty()) {
         editor = m_mgr->FindEditor(fileToFormat);
     } else {
         editor = m_mgr->GetActiveEditor();
@@ -209,16 +198,16 @@ void CodeFormatter::OnFormatEditor(wxCommandEvent& e)
 }
 std::shared_ptr<GenericFormatter> CodeFormatter::FindFormatter(const wxString& filepath, const wxString& content) const
 {
-    if(wxFileName(filepath).GetExt().IsEmpty()) {
+    if (wxFileName(filepath).GetExt().IsEmpty()) {
         // detect by content
-        if(!content.empty()) {
+        if (!content.empty()) {
             // we got content, use it
             return m_manager.GetFormatterByContent(content);
-        } else if(wxFileName::FileExists(filepath)) {
+        } else if (wxFileName::FileExists(filepath)) {
             // No content provided, but the file is a local file
             // read the content and try again
             wxString buffer;
-            if(FileUtils::ReadBufferFromFile(filepath, buffer, 4000)) {
+            if (FileUtils::ReadBufferFromFile(filepath, buffer, 4000)) {
                 return m_manager.GetFormatterByContent(content);
             }
         }
@@ -237,7 +226,7 @@ bool CodeFormatter::DoFormatEditor(IEditor* editor)
     CHECK_PTR_RET_FALSE(editor);
     bool is_remote = editor->IsRemoteFile();
     auto f = FindFormatter(editor->GetRemotePathOrLocal(), editor->GetEditorText());
-    if(!f) {
+    if (!f) {
         return false;
     }
 
@@ -245,48 +234,52 @@ bool CodeFormatter::DoFormatEditor(IEditor* editor)
     wxString file_path = editor->GetRemotePathOrLocal();
 
     // save the file formatting it
-    if(editor->IsEditorModified()) {
+    if (editor->IsEditorModified()) {
         editor->Save();
+#if USE_SFTP
+        // By default, `editor->Save()`, for remote files, will save the file in an async mode ("later"), but we need
+        // this to happen NOW. So call `clSFTPManager::Get().AwaitSaveFile`
+        if (editor->IsRemoteFile()) {
+            auto cd = editor->GetRemoteData();
+            if (cd) {
+                wxBusyCursor bc;
+                clSFTPManager::Get().AwaitSaveFile(cd->GetLocalPath(), cd->GetRemotePath(), cd->GetAccountName());
+            }
+        }
+#endif
         inc_save_count(file_path);
     }
 
-    if(is_remote) {
-        return f->FormatRemoteFile(file_path, this);
-    } else {
-        return f->FormatFile(file_path, this);
+    bool res = is_remote ? f->FormatRemoteFile(file_path, this) : f->FormatFile(file_path, this);
+    if (res) {
+        editor->ClearModifiedLines();
     }
+    return res;
 }
 
 bool CodeFormatter::DoFormatString(const wxString& content, const wxString& fileName, wxString* output)
 {
-    if(content.empty()) {
+    if (content.empty()) {
         return false;
     }
 
     auto formatter = FindFormatter(fileName, content);
-    if(!formatter) {
+    if (!formatter) {
         clDEBUG() << "Could not find suitable formatter for file:" << fileName << endl;
         return false;
     }
     return formatter->FormatString(content, fileName, output);
 }
 
-void CodeFormatter::ReloadCurrentEditor()
-{
-    // reload the current editor
-    wxCommandEvent reload_event{ wxEVT_CMD_RELOAD_EXTERNALLY_MODIFIED_NOPROMPT };
-    EventNotifier::Get()->ProcessEvent(reload_event);
-}
-
 bool CodeFormatter::DoFormatFile(const wxString& fileName, bool is_remote_format)
 {
     auto f = FindFormatter(fileName);
-    if(!f) {
+    if (!f) {
         clDEBUG() << "Could not find suitable formatter for file:" << fileName << endl;
         return false;
     }
 
-    if(is_remote_format) {
+    if (is_remote_format) {
         return f->FormatRemoteFile(fileName, this);
     } else {
         return f->FormatFile(fileName, this);
@@ -298,7 +291,7 @@ void CodeFormatter::OnSettings(wxCommandEvent& e)
     wxUnusedVar(e);
 
     CodeFormatterDlg dlg(EventNotifier::Get()->TopFrame(), m_manager);
-    if(dlg.ShowModal() == wxID_OK) {
+    if (dlg.ShowModal() == wxID_OK) {
         // save the changes to the file system
         m_manager.Save();
     } else {
@@ -327,7 +320,7 @@ void CodeFormatter::HookPopupMenu(wxMenu* menu, MenuType type)
     wxUnusedVar(type);
     wxUnusedVar(menu);
 
-    if(type == MenuTypeFileView_Project) {
+    if (type == MenuTypeFileView_Project) {
         // Project context menu
         menu->Prepend(ID_TOOL_SOURCE_CODE_FORMATTER, _("Source Code Formatter"));
     }
@@ -347,6 +340,7 @@ void CodeFormatter::UnPlug()
     EventNotifier::Get()->Unbind(wxEVT_FORMAT_FILE, &CodeFormatter::OnFormatFile, this);
     EventNotifier::Get()->Unbind(wxEVT_FILE_SAVED, &CodeFormatter::OnFileSaved, this);
     EventNotifier::Get()->Unbind(wxEVT_CONTEXT_MENU_FOLDER, &CodeFormatter::OnContextMenu, this);
+    EventNotifier::Get()->Unbind(wxEVT_INIT_DONE, &CodeFormatter::OnInitDone, this);
 
     Unbind(wxEVT_FORMAT_INPLACE_COMPELTED, &CodeFormatter::OnInplaceFormatCompleted, this);
     Unbind(wxEVT_FORMAT_COMPELTED, &CodeFormatter::OnFormatCompleted, this);
@@ -357,7 +351,7 @@ IManager* CodeFormatter::GetManager() { return m_mgr; }
 void CodeFormatter::OnFormatString(clSourceFormatEvent& e)
 {
     wxString output;
-    if(DoFormatString(e.GetInputString(), e.GetFileName(), &output)) {
+    if (DoFormatString(e.GetInputString(), e.GetFileName(), &output)) {
         e.SetFormattedString(output);
     } else {
         e.SetFormattedString(wxEmptyString);
@@ -367,7 +361,7 @@ void CodeFormatter::OnFormatString(clSourceFormatEvent& e)
 void CodeFormatter::OnFormatFile(clSourceFormatEvent& e)
 {
     e.Skip(false);
-    if(!DoFormatFile(e.GetFileName(), false)) {
+    if (!DoFormatFile(e.GetFileName(), false)) {
         // let someone else handle this
         e.Skip();
     }
@@ -385,14 +379,15 @@ void CodeFormatter::OnFormatFiles(wxCommandEvent& event)
 
             std::vector<wxString> arrfiles;
             arrfiles.reserve(files.size());
-            for(const wxFileName& f : files) {
-                if(m_manager.CanFormat(f.GetFullName())) {
+            for (const wxFileName& f : files) {
+                if (m_manager.CanFormat(f.GetFullName())) {
                     arrfiles.push_back(f.GetFullPath());
                 }
             }
             formatter->CallAfter(&CodeFormatter::OnScanFilesCompleted, arrfiles);
         },
-        m_selectedFolder, this);
+        m_selectedFolder,
+        this);
     thr.detach();
 }
 
@@ -400,7 +395,7 @@ void CodeFormatter::OnFormatProject(wxCommandEvent& event)
 {
     wxUnusedVar(event);
     TreeItemInfo selectedItem = m_mgr->GetSelectedTreeItemInfo(TreeFileView);
-    if(selectedItem.m_itemType != ProjectItem::TypeProject) {
+    if (selectedItem.m_itemType != ProjectItem::TypeProject) {
         return;
     }
 
@@ -412,8 +407,8 @@ void CodeFormatter::OnFormatProject(wxCommandEvent& event)
     std::vector<wxString> filesToFormat;
     filesToFormat.reserve(allFiles.size());
 
-    for(const auto& vt : allFiles) {
-        if(m_manager.CanFormat(vt.second->GetFilename())) {
+    for (const auto& vt : allFiles) {
+        if (m_manager.CanFormat(vt.second->GetFilename())) {
             filesToFormat.push_back(vt.second->GetFilename());
         }
     }
@@ -422,32 +417,32 @@ void CodeFormatter::OnFormatProject(wxCommandEvent& event)
 
 void CodeFormatter::BatchFormat(const std::vector<wxString>& files, bool silent)
 {
-    if(files.empty()) {
-        if(!silent) {
+    if (files.empty()) {
+        if (!silent) {
             ::wxMessageBox(_("Project contains no supported files"));
         }
         return;
     }
 
-    if(!silent) {
+    if (!silent) {
         wxString msg;
         msg << _("You are about to beautify ") << files.size() << _(" files\nContinue?");
-        if(wxYES != ::wxMessageBox(msg, _("Source Code Formatter"), wxYES_NO | wxCANCEL | wxCENTER)) {
+        if (wxYES != ::wxMessageBox(msg, _("Source Code Formatter"), wxYES_NO | wxCANCEL | wxCENTER)) {
             return;
         }
     }
 
-    for(size_t i = 0; i < files.size(); ++i) {
+    for (size_t i = 0; i < files.size(); ++i) {
         wxString msg;
         msg << "Formatting file: " << (i + 1) << "/" << files.size() << " " << files[i];
-        if(!silent) {
+        if (!silent) {
             clGetManager()->SetStatusMessage(msg, 1);
             wxSafeYield();
         }
         DoFormatFile(files[i], false);
     }
 
-    if(!silent) {
+    if (!silent) {
         clGetManager()->SetStatusMessage(wxString() << _("Successfully formatted ") << files.size() << _(" files"), 3);
         wxSafeYield();
     }
@@ -465,7 +460,7 @@ void CodeFormatter::OnWorkspaceLoaded(clWorkspaceEvent& e)
     // reset the remote commands from the previous workspace
     m_manager.ClearRemoteCommands();
 
-    if(!config) {
+    if (!config) {
         return;
     }
 
@@ -475,20 +470,33 @@ void CodeFormatter::OnWorkspaceLoaded(clWorkspaceEvent& e)
     // update the formatters with the remote command template
     // note: we do not replace macros here since some of them
     // might change per activation (e.g. $(CurrentFileRelPath))
-    for(size_t i = 0; i < all_tools.size(); ++i) {
+    for (size_t i = 0; i < all_tools.size(); ++i) {
         const wxString& tool_name = all_tools[i];
         auto json = json_get_formatter_object(config, tool_name);
-        if(!json.isOk() || (m_manager.GetFormatterByName(tool_name) == nullptr)) {
+        if (!json.isOk() || (m_manager.GetFormatterByName(tool_name) == nullptr)) {
             continue;
         }
 
-        wxString cmd = json["command"].toString();
+        // Try both array and string name
+        wxArrayString cmdArray;
+        wxString cmd;
+
+        if (json.hasNamedObject("command") && json["command"].isArray()) {
+            cmdArray = json["command"].toArrayString();
+        } else {
+            cmd = json["command"].toString();
+        }
+
+        if (!cmdArray.empty()) {
+            cmd = StringUtils::BuildCommandStringFromArray(cmdArray);
+        }
+
         wxString wd = json["working_directory"].toString();
 
         wxString remote_cmd;
-        if(m_remoteHelper->BuildRemoteCommand(cmd, {}, wd, &remote_cmd)) {
-            m_manager.GetFormatterByName(tool_name)->SetRemoteCommand(remote_cmd);
-        }
+        cmd = MacroManager::Instance()->Expand(cmd, clGetManager(), wxEmptyString);
+        wd = MacroManager::Instance()->Expand(wd, clGetManager(), wxEmptyString);
+        m_manager.GetFormatterByName(tool_name)->SetRemoteCommand(cmd, wd, {});
     }
 }
 
@@ -513,16 +521,16 @@ void CodeFormatter::OnFileSaved(clCommandEvent& e)
     CHECK_PTR_RET(editor);
 
     // is format required?
-    if(!f->IsFormatOnSave()) {
+    if (!f->IsFormatOnSave()) {
         return;
     }
 
     // did we cause the OnSave event?
-    if(dec_save_count_if_needed(filepath)) {
+    if (dec_save_count_if_needed(filepath)) {
         return;
     }
 
-    if(!DoFormatEditor(editor)) {
+    if (!DoFormatEditor(editor)) {
         return;
     }
 }
@@ -533,21 +541,23 @@ void CodeFormatter::OnFormatCompleted(clSourceFormatEvent& event)
     const wxString& filepath = event.GetFileName();
     auto editor = clGetManager()->FindEditor(filepath);
 
-    if(editor) {
+    if (editor) {
+        wxWindowUpdateLocker window_locker{ editor->GetCtrl()->GetParent() };
         editor->GetCtrl()->BeginUndoAction();
         clEditorStateLocker locker{ editor->GetCtrl() };
         editor->GetCtrl()->SetText(event.GetFormattedString());
+        editor->NotifyTextUpdated();
         editor->GetCtrl()->EndUndoAction();
         m_mgr->SetStatusMessage(_("Done"), 0);
 
-        if(editor->IsEditorModified() /* it should be.. */) {
+        if (editor->IsEditorModified() /* it should be.. */) {
             // need to set the editor back to "saved" status
             editor->Save();
             inc_save_count(filepath);
         }
     } else {
         // no editor is opened, update the file content
-        if(wxFileExists(filepath)) {
+        if (wxFileExists(filepath)) {
             FileUtils::WriteFileContent(filepath, event.GetFormattedString());
         }
     }
@@ -559,7 +569,7 @@ void CodeFormatter::OnInplaceFormatCompleted(clSourceFormatEvent& event)
     const wxString& filepath = event.GetFileName();
     auto editor = clGetManager()->FindEditor(filepath);
 
-    if(editor) {
+    if (editor) {
         // need to update the file itself
         editor->ReloadFromDisk(true);
     }
@@ -568,6 +578,20 @@ void CodeFormatter::OnInplaceFormatCompleted(clSourceFormatEvent& event)
     // we do this by firing a wxEVT_FILE_MODIFIED_EXTERNALLY event
     clFileSystemEvent event_modified{ wxEVT_FILE_MODIFIED_EXTERNALLY };
     event_modified.SetPath(filepath);
+    event_modified.SetFileName(filepath);
     event_modified.SetIsRemoteFile(!wxFileName::FileExists(filepath));
     EventNotifier::Get()->AddPendingEvent(event_modified);
 }
+
+void CodeFormatter::OnInitDone(wxCommandEvent& e)
+{
+    e.Skip();
+    // if no formatters are set, re-scan
+    wxArrayString all_names;
+    if (m_manager.GetAllNames(&all_names) == 0) {
+        wxUnusedVar(all_names);
+        wxBusyCursor bc;
+        m_manager.RestoreDefaults();
+        m_manager.Save();
+    }
+}
