@@ -1,6 +1,6 @@
 #include "fmtBlack.hpp"
 
-#include "Platform.hpp"
+#include "Platform/Platform.hpp"
 
 fmtBlack::fmtBlack()
 {
@@ -12,9 +12,10 @@ fmtBlack::fmtBlack()
     SetInplaceFormatter(true);
 
     // local command
-    wxString black_exe;
-    ThePlatform->WhichWithVersion("black", { 20, 19, 18, 17, 16, 15, 14, 13, 12 }, &black_exe);
+    wxString black_exe = "black";
+    bool enabeld = ThePlatform->WhichWithVersion("black", { 20, 19, 18, 17, 16, 15, 14, 13, 12 }, &black_exe);
     SetCommand({ black_exe, "--line-length", "80", R"#("$(CurrentFileRelPath)")#" });
+    SetEnabled(enabeld);
 }
 
 fmtBlack::~fmtBlack() {}
