@@ -1,6 +1,6 @@
 #include "fmtRustfmt.hpp"
 
-#include "Platform.hpp"
+#include "Platform/Platform.hpp"
 
 fmtRustfmt::fmtRustfmt()
 {
@@ -13,8 +13,9 @@ fmtRustfmt::fmtRustfmt()
 
     // local command
     wxString rustfmt_exe = "rustfmt";
-    ThePlatform->Which("rustfmt", &rustfmt_exe);
+    bool enabeld = ThePlatform->Which("rustfmt", &rustfmt_exe);
     SetCommand({ rustfmt_exe, "--edition", "2021", R"#("$(CurrentFileRelPath)")#" });
+    SetEnabled(enabeld);
 }
 
 fmtRustfmt::~fmtRustfmt() {}
