@@ -1,6 +1,6 @@
 #include "fmtXmlLint.hpp"
 
-#include "Platform.hpp"
+#include "Platform/Platform.hpp"
 
 fmtXmlLint::fmtXmlLint()
 {
@@ -8,9 +8,10 @@ fmtXmlLint::fmtXmlLint()
     SetFileTypes({ FileExtManager::TypeXRC, FileExtManager::TypeXml });
     SetDescription(_("xmllint - command line XML tool"));
     SetShortDescription(_("Xml formatter"));
-    wxString xml_lint_exe;
-    ThePlatform->Which("xmllint", &xml_lint_exe);
+    wxString xml_lint_exe = "xmllint";
+    bool enabeld = ThePlatform->Which("xmllint", &xml_lint_exe);
     SetCommand({ xml_lint_exe, "--format", R"#("$(CurrentFileRelPath)")#" });
+    SetEnabled(enabeld);
 }
 
 fmtXmlLint::~fmtXmlLint() {}
