@@ -1,10 +1,9 @@
 #ifndef COMPLETIONHELPER_HPP
 #define COMPLETIONHELPER_HPP
 
-#include "CxxTokenizer.h"
 #include "codelite_exports.h"
-#include "entry.h"
-#include "istorage.h"
+#include "database/entry.h"
+#include "database/istorage.h"
 
 #include <functional>
 #include <vector>
