@@ -26,14 +26,15 @@
 #ifndef ZJSONNODE_H
 #define ZJSONNODE_H
 // clang-format off
-#include "wx/vector.h"
+#include <wx/vector.h>
 #include <wx/string.h>
 #include <wx/variant.h>
 #include <wx/filename.h>
+#include <string_view>
 #include <wx/gdicmn.h>
 #include "codelite_exports.h"
 #include <map>
-#include "cJSON.h"
+#include <cJSON.h>
 #if wxUSE_GUI
 #include <wx/arrstr.h>
 #include <wx/colour.h>
@@ -52,11 +53,11 @@ class WXDLLIMPEXP_CL JSONItem
 protected:
     cJSON* m_json = nullptr;
     cJSON* m_walker = nullptr;
-    std::string m_name;
+    wxString m_properytName;
     int m_type = wxNOT_FOUND;
 
     // Values
-    std::string m_valueString;
+    wxString m_valueString;
     double m_valueNumer = 0;
 
 public:
@@ -65,33 +66,40 @@ public:
     JSONItem(const wxString& name, const std::string& val);
     JSONItem(const wxString& name, const char* pval, size_t len);
     JSONItem(const wxString& name, bool val);
+    JSONItem() {}
     virtual ~JSONItem() {}
 
     // Walkers
     JSONItem firstChild();
     JSONItem nextChild();
 
-    void SetValueNumer(double valueNumer) { this->m_valueNumer = valueNumer; }
-    double GetValueNumer() const { return m_valueNumer; }
-
-    void SetValueString(const std::string& valueString) { this->m_valueString = valueString; }
-    const std::string& GetValueString() const { return m_valueString; }
-
     // Setters
     ////////////////////////////////////////////////
-    void setName(const wxString& m_name) { this->m_name = m_name; }
     void setType(int m_type) { this->m_type = m_type; }
     int getType() const { return m_type; }
-    wxString getName() const { return m_name; }
+    const wxString& GetPropertyName() const { return m_properytName; }
+    void SetPropertyName(const wxString& name) { m_properytName = name; }
 
     // Readers
     ////////////////////////////////////////////////
     JSONItem namedObject(const wxString& name) const;
     bool hasNamedObject(const wxString& name) const;
 
+    /// If your array is big (hundred of entries) use
+    /// `GetAsVector` and iterate it instead
     JSONItem operator[](int index) const;
     JSONItem operator[](const wxString& name) const;
 
+    /// the C implementation for accessing large arrays, is the sum of an arithmetic progression.
+    /// Use this method to get an array with `O(1)` access
+    /// This call is `O(n)`
+    std::vector<JSONItem> GetAsVector() const;
+
+    /// the C implementation for accessing by name is by `O(n)`
+    /// Use this method when you have large number of items and
+    /// `O(1)` is required
+    std::unordered_map<std::string_view, JSONItem> GetAsMap() const;
+
     bool toBool(bool defaultValue = false) const;
     wxString toString(const wxString& defaultValue = wxEmptyString) const;
     wxArrayString toArrayString(const wxArrayString& defaultValue = wxArrayString()) const;
@@ -105,6 +113,7 @@ public:
     bool isString() const;
     bool isNumber() const;
     bool isArray() const;
+    bool isObject() const;
 
     wxString format(bool formatted = true) const;
     /**
@@ -114,16 +123,18 @@ public:
     char* FormatRawString(bool formatted = true) const;
     int arraySize() const;
     int toInt(int defaultVal = -1) const;
+
+    /// Convert the value into `T` from
+    template <typename T> T fromNumber(T default_value) const { return static_cast<T>(toInt((int)default_value)); }
+
     size_t toSize_t(size_t defaultVal = 0) const;
     double toDouble(double defaultVal = -1.0) const;
     wxFileName toFileName() const;
 
-#if wxUSE_GUI
     wxColour toColour(const wxColour& defaultColour = wxNullColour) const;
     wxFont toFont(const wxFont& defaultFont = wxNullFont) const;
     wxSize toSize() const;
     wxPoint toPoint() const;
-#endif
 
     wxStringMap_t toStringMap() const;
 
@@ -165,18 +176,18 @@ public:
     JSONItem& addProperty(const wxString& name, cJSON* pjson);
     JSONItem& addProperty(const wxString& name, const wxFileName& filename);
     JSONItem& addProperty(const wxString& name, const std::vector<int>& arr_int);
-    template<class T = int>
-    typename std::enable_if<!std::is_same<wxVector<T>, std::vector<T>>::value,
-                            JSONItem&>::type addProperty(const wxString& name, const wxVector<T>& arr_int) {
-	return addProperty(name, std::vector<T>(arr_int.begin(), arr_int.end()));
+    template <class T = int>
+    typename std::enable_if<!std::is_same<wxVector<T>, std::vector<T>>::value, JSONItem&>::type
+    addProperty(const wxString& name, const wxVector<T>& arr_int)
+    {
+        return addProperty(name, std::vector<T>(arr_int.begin(), arr_int.end()));
     }
 
-#if wxUSE_GUI
     JSONItem& addProperty(const wxString& name, const wxSize& sz);
     JSONItem& addProperty(const wxString& name, const wxPoint& pt);
     JSONItem& addProperty(const wxString& name, const wxColour& colour);
     JSONItem& addProperty(const wxString& name, const wxFont& font);
-#endif
+
     JSONItem& addProperty(const wxString& name, const wxArrayString& arr);
     JSONItem& addProperty(const wxString& name, const wxStringMap_t& stringMap);
     JSONItem& addProperty(const wxString& name, const JSONItem& element);
