@@ -21,7 +21,7 @@ LSP::GotoDeclarationRequest::~GotoDeclarationRequest() {}
 
 void LSP::GotoDeclarationRequest::OnResponse(const LSP::ResponseMessage& response, wxEvtHandler* owner)
 {
-    LOG_IF_TRACE { clDEBUG1() << "GotoDeclarationRequest::OnResponse() is called" << endl; }
+    LOG_IF_TRACE { LSP_TRACE() << "GotoDeclarationRequest::OnResponse() is called" << endl; }
     JSONItem result = response.Get("result");
     if(!result.isOk()) {
         return;
@@ -34,7 +34,7 @@ void LSP::GotoDeclarationRequest::OnResponse(const LSP::ResponseMessage& respons
         loc.FromJSON(result);
     }
 
-    LOG_IF_TRACE { clDEBUG1() << result.format() << endl; }
+    LOG_IF_TRACE { LSP_TRACE() << result.format() << endl; }
 
     if(!loc.GetPath().IsEmpty()) {
         if(m_for_add_missing_header) {
