@@ -28,8 +28,12 @@ protected:
     std::vector<LSP::Diagnostic> m_diagnostics;
     std::vector<LSP::SymbolInformation> m_symbolsInformation;
     std::vector<LSP::SemanticTokenRange> m_semanticTokens;
-    std::vector<LSP::Location> m_locations; // used by wxEVT_LSP_REFERENCES
+    std::vector<LSP::Location> m_locations;                             // used by wxEVT_LSP_REFERENCES
+    std::vector<LSP::Command> m_commands;                               // used by wxEVT_LSP_CODE_ACTIONS
+    std::unordered_map<wxString, std::vector<LSP::TextEdit>> m_changes; // list of changes per file
     int m_logMessageSeverity = LSP_LOG_INFO;
+    LSP::CompletionItem::eTriggerKind m_triggerKind =
+        LSP::CompletionItem::kTriggerKindInvoked; // CC response is due to 24x7 cc
 
 public:
     LSPEvent(wxEventType commandType = wxEVT_NULL, int winid = 0);
@@ -37,6 +41,9 @@ public:
     LSPEvent& operator=(const LSPEvent& other);
     virtual ~LSPEvent();
 
+    void SetTriggerKind(LSP::CompletionItem::eTriggerKind triggerKind) { this->m_triggerKind = triggerKind; }
+    LSP::CompletionItem::eTriggerKind GetTriggerKind() const { return m_triggerKind; }
+
     void SetLogMessageSeverity(int sev) { m_logMessageSeverity = sev; }
     int GetLogMessageSeverity() const { return m_logMessageSeverity; }
 
@@ -96,6 +103,14 @@ public:
     void SetLocations(const std::vector<LSP::Location>& locations) { this->m_locations = locations; }
     const std::vector<LSP::Location>& GetLocations() const { return m_locations; }
     std::vector<LSP::Location>& GetLocations() { return m_locations; }
+    void SetCommands(const std::vector<LSP::Command>& commands) { this->m_commands = commands; }
+    const std::vector<LSP::Command>& GetCommands() const { return m_commands; }
+    std::vector<LSP::Command>& GetCommands() { return m_commands; }
+    void SetChanges(const std::unordered_map<wxString, std::vector<LSP::TextEdit>>& changes)
+    {
+        this->m_changes = changes;
+    }
+    const std::unordered_map<wxString, std::vector<LSP::TextEdit>>& GetChanges() const { return m_changes; }
 };
 
 typedef void (wxEvtHandler::*LSPEventFunction)(LSPEvent&);
@@ -113,8 +128,8 @@ wxDECLARE_EXPORTED_EVENT(WXDLLIMPEXP_CL, wxEVT_LSP_REPARSE_NEEDED, LSPEvent);
 wxDECLARE_EXPORTED_EVENT(WXDLLIMPEXP_CL, wxEVT_LSP_METHOD_NOT_FOUND, LSPEvent);
 wxDECLARE_EXPORTED_EVENT(WXDLLIMPEXP_CL, wxEVT_LSP_SIGNATURE_HELP, LSPEvent);
 wxDECLARE_EXPORTED_EVENT(WXDLLIMPEXP_CL, wxEVT_LSP_HOVER, LSPEvent);
-wxDECLARE_EXPORTED_EVENT(WXDLLIMPEXP_CL, wxEVT_LSP_SET_DIAGNOSTICS, LSPEvent);
-wxDECLARE_EXPORTED_EVENT(WXDLLIMPEXP_CL, wxEVT_LSP_CLEAR_DIAGNOSTICS, LSPEvent);
+wxDECLARE_EXPORTED_EVENT(WXDLLIMPEXP_CL, wxEVT_LSP_SET_DIAGNOSTICS, LSPEvent);   // EventNotifier
+wxDECLARE_EXPORTED_EVENT(WXDLLIMPEXP_CL, wxEVT_LSP_CLEAR_DIAGNOSTICS, LSPEvent); // EventNotifier
 wxDECLARE_EXPORTED_EVENT(WXDLLIMPEXP_CL, wxEVT_LSP_OPEN_FILE, LSPEvent);
 wxDECLARE_EXPORTED_EVENT(WXDLLIMPEXP_CL, wxEVT_LSP_SEMANTICS, LSPEvent);
 wxDECLARE_EXPORTED_EVENT(WXDLLIMPEXP_CL, wxEVT_LSP_LOGMESSAGE, LSPEvent);
@@ -123,5 +138,7 @@ wxDECLARE_EXPORTED_EVENT(WXDLLIMPEXP_CL, wxEVT_LSP_SYMBOL_DECLARATION_FOUND, LSP
 wxDECLARE_EXPORTED_EVENT(WXDLLIMPEXP_CL, wxEVT_LSP_SHOW_QUICK_OUTLINE_DLG, LSPEvent);
 wxDECLARE_EXPORTED_EVENT(WXDLLIMPEXP_CL, wxEVT_LSP_REFERENCES, LSPEvent);            // EventNotifier
 wxDECLARE_EXPORTED_EVENT(WXDLLIMPEXP_CL, wxEVT_LSP_REFERENCES_INPROGRESS, LSPEvent); // EventNotifier
+wxDECLARE_EXPORTED_EVENT(WXDLLIMPEXP_CL, wxEVT_LSP_CODE_ACTIONS, LSPEvent);          // EventNotifier
+wxDECLARE_EXPORTED_EVENT(WXDLLIMPEXP_CL, wxEVT_LSP_EDIT_FILES, LSPEvent);
 
 #endif // LSPEVENT_H
