@@ -4,12 +4,22 @@
 #include "IPathConverter.hpp"
 #include "JSON.h"
 #include "JSONObject.h"
+#include "clModuleLogger.hpp"
 #include "codelite_exports.h"
 #include "fileutils.h"
 
 #include <vector>
 #include <wx/sharedptr.h>
 
+// Helper macros to be used outside of this library
+#define LSP_LOG (LSP::GetLogHandle())
+
+#define LSP_DEBUG() LOG_DEBUG(LSP_LOG)
+#define LSP_TRACE() LOG_TRACE(LSP_LOG)
+#define LSP_ERROR() LOG_ERROR(LSP_LOG)
+#define LSP_WARNING() LOG_WARNING(LSP_LOG)
+#define LSP_SYSTEM() LOG_SYSTEM(LSP_LOG)
+
 namespace LSP
 {
 enum eSymbolKind {
@@ -59,75 +69,6 @@ public:
     const wxString& GetPath() const;
     const wxString& GetUrl() const;
 };
-//===----------------------------------------------------------------------------------
-// TextDocumentContentChangeEvent
-//===----------------------------------------------------------------------------------
-class WXDLLIMPEXP_CL TextDocumentContentChangeEvent : public Serializable
-{
-    wxString m_text;
-
-public:
-    virtual JSONItem ToJSON(const wxString& name) const;
-    virtual void FromJSON(const JSONItem& json);
-
-    TextDocumentContentChangeEvent() {}
-    TextDocumentContentChangeEvent(const wxString& text)
-        : m_text(text)
-    {
-    }
-    virtual ~TextDocumentContentChangeEvent() {}
-    TextDocumentContentChangeEvent& SetText(const wxString& text);
-    const wxString& GetText() const { return m_text; }
-};
-
-//===----------------------------------------------------------------------------------
-// TextDocumentIdentifier
-//===----------------------------------------------------------------------------------
-class WXDLLIMPEXP_CL TextDocumentIdentifier : public Serializable
-{
-    URI m_filename;
-
-public:
-    virtual JSONItem ToJSON(const wxString& name) const;
-    virtual void FromJSON(const JSONItem& json);
-
-    TextDocumentIdentifier() {}
-    TextDocumentIdentifier(const wxString& filename) { URI::FromString(filename, &m_filename); }
-
-    virtual ~TextDocumentIdentifier() {}
-    TextDocumentIdentifier& SetFilename(const wxString& filename)
-    {
-        URI::FromString(filename, &m_filename);
-        return *this;
-    }
-    const wxString& GetPath() const { return m_filename.GetPath(); }
-    const wxString& GetPathAsURI() const { return m_filename.GetUrl(); }
-};
-
-//===----------------------------------------------------------------------------------
-// VersionedTextDocumentIdentifier
-//===----------------------------------------------------------------------------------
-class WXDLLIMPEXP_CL VersionedTextDocumentIdentifier : public TextDocumentIdentifier
-{
-    int m_version = 1;
-
-public:
-    virtual JSONItem ToJSON(const wxString& name) const;
-    virtual void FromJSON(const JSONItem& json);
-
-    VersionedTextDocumentIdentifier() {}
-    VersionedTextDocumentIdentifier(int version)
-        : m_version(version)
-    {
-    }
-    virtual ~VersionedTextDocumentIdentifier() {}
-    VersionedTextDocumentIdentifier& SetVersion(int version)
-    {
-        this->m_version = version;
-        return *this;
-    }
-    int GetVersion() const { return m_version; }
-};
 
 //===----------------------------------------------------------------------------------
 // Position
@@ -213,6 +154,79 @@ public:
     bool IsOk() const { return m_start.IsOk() && m_end.IsOk(); }
 };
 
+//===----------------------------------------------------------------------------------
+// TextDocumentContentChangeEvent
+//===----------------------------------------------------------------------------------
+class WXDLLIMPEXP_CL TextDocumentContentChangeEvent : public Serializable
+{
+    wxString m_text;
+    Range m_range; // Optional
+
+public:
+    virtual JSONItem ToJSON(const wxString& name) const;
+    virtual void FromJSON(const JSONItem& json);
+
+    TextDocumentContentChangeEvent() {}
+    TextDocumentContentChangeEvent(const wxString& text)
+        : m_text(text)
+    {
+    }
+    virtual ~TextDocumentContentChangeEvent() {}
+    TextDocumentContentChangeEvent& SetText(const wxString& text);
+    const wxString& GetText() const { return m_text; }
+    const Range& GetRange() const { return m_range; }
+    void SetRange(const Range& range) { m_range = range; }
+};
+
+//===----------------------------------------------------------------------------------
+// TextDocumentIdentifier
+//===----------------------------------------------------------------------------------
+class WXDLLIMPEXP_CL TextDocumentIdentifier : public Serializable
+{
+    URI m_filename;
+
+public:
+    virtual JSONItem ToJSON(const wxString& name) const;
+    virtual void FromJSON(const JSONItem& json);
+
+    TextDocumentIdentifier() {}
+    TextDocumentIdentifier(const wxString& filename) { URI::FromString(filename, &m_filename); }
+
+    virtual ~TextDocumentIdentifier() {}
+    TextDocumentIdentifier& SetFilename(const wxString& filename)
+    {
+        URI::FromString(filename, &m_filename);
+        return *this;
+    }
+    const wxString& GetPath() const { return m_filename.GetPath(); }
+    const wxString& GetPathAsURI() const { return m_filename.GetUrl(); }
+};
+
+//===----------------------------------------------------------------------------------
+// VersionedTextDocumentIdentifier
+//===----------------------------------------------------------------------------------
+class WXDLLIMPEXP_CL VersionedTextDocumentIdentifier : public TextDocumentIdentifier
+{
+    int m_version = 1;
+
+public:
+    virtual JSONItem ToJSON(const wxString& name) const;
+    virtual void FromJSON(const JSONItem& json);
+
+    VersionedTextDocumentIdentifier() {}
+    VersionedTextDocumentIdentifier(int version)
+        : m_version(version)
+    {
+    }
+    virtual ~VersionedTextDocumentIdentifier() {}
+    VersionedTextDocumentIdentifier& SetVersion(int version)
+    {
+        this->m_version = version;
+        return *this;
+    }
+    int GetVersion() const { return m_version; }
+};
+
 //===----------------------------------------------------------------------------------
 // TextEdit
 //===----------------------------------------------------------------------------------
@@ -465,10 +479,30 @@ public:
     virtual JSONItem ToJSON(const wxString& name) const;
 };
 
+enum DiagnosticSeverity {
+    /**
+     * Reports an error.
+     */
+    Error = 1,
+    /**
+     * Reports a warning.
+     */
+    Warning = 2,
+    /**
+     * Reports an information.
+     */
+    Information = 3,
+    /**
+     * Reports a hint.
+     */
+    Hint = 4,
+};
+
 class WXDLLIMPEXP_CL Diagnostic : public Serializable
 {
     Range m_range;
     wxString m_message;
+    DiagnosticSeverity m_severity = DiagnosticSeverity::Error;
 
 public:
     virtual void FromJSON(const JSONItem& json);
@@ -493,6 +527,30 @@ public:
         return *this;
     }
     const wxString& GetMessage() const { return m_message; }
+    void SetSeverity(const DiagnosticSeverity& severity) { this->m_severity = severity; }
+    const DiagnosticSeverity& GetSeverity() const { return m_severity; }
+};
+
+class WXDLLIMPEXP_CL Command : public Serializable
+{
+    wxString m_title;
+    wxString m_command;
+    wxString m_arguments;
+
+public:
+    void FromJSON(const JSONItem& json) override;
+    JSONItem ToJSON(const wxString& name) const override;
+
+    Command() {}
+    virtual ~Command() {}
+
+    void SetTitle(const wxString& title) { this->m_title = title; }
+    void SetCommand(const wxString& command) { this->m_command = command; }
+    void SetArguments(const wxString& arguments) { this->m_arguments = arguments; }
+
+    const wxString& GetTitle() const { return m_title; }
+    const wxString& GetCommand() const { return m_command; }
+    const wxString& GetArguments() const { return m_arguments; }
 };
 
 class WXDLLIMPEXP_CL DocumentSymbol : public Serializable
@@ -602,5 +660,17 @@ public:
     const wxString& GetName() const { return name; }
 };
 
+/// Initialise the library
+WXDLLIMPEXP_CL void Initialise();
+
+/// convert native file path to URI
+WXDLLIMPEXP_CL wxString FileNameToURI(const wxString& filename);
+
+/// Return the log handle of this library
+WXDLLIMPEXP_CL clModuleLogger& GetLogHandle();
+
+/// Parse the text edit from a reponse "result" field
+WXDLLIMPEXP_CL std::unordered_map<wxString, std::vector<LSP::TextEdit>> ParseWorkspaceEdit(const JSONItem& result);
+
 };     // namespace LSP
 #endif // JSONRPC_BASICTYPES_H
