@@ -1,7 +1,8 @@
 #ifndef CLCONNECTIONSTRING_H
 #define CLCONNECTIONSTRING_H
 
-#include <codelite_exports.h>
+#include "codelite_exports.h"
+
 #include <wx/string.h>
 
 class WXDLLIMPEXP_CL clConnectionString
