@@ -36,3 +36,8 @@ void StdToWX::RemoveLast(std::string& str, size_t count)
         str.erase(str.length() - count, count);
     }
 }
+
+wxArrayString StdToWX::ToArrayString(const std::vector<wxString>& vec)
+{
+    return { vec.size(), vec.data() };
+}
