@@ -25,10 +25,12 @@
 #ifndef STRINGUTILS_H
 #define STRINGUTILS_H
 
-#include "asyncprocess.h"
+#include "AsyncProcess/asyncprocess.h"
 #include "codelite_exports.h"
 
+#include <sstream>
 #include <wx/arrstr.h>
+#include <wx/combobox.h>
 #include <wx/string.h>
 
 class WXDLLIMPEXP_CL StringUtils
@@ -105,6 +107,30 @@ public:
      */
     static wxString BuildCommandStringFromArray(const wxArrayString& command_arr,
                                                 size_t flags = BuildCommandFlags::ONE_LINER);
+
+    /// If string contains space, wrap it with double quotes
+    static wxString WrapWithDoubleQuotes(const wxString& str);
+
+    /// If a string is wrapped with double quoutes -> strip them
+    static wxString StripDoubleQuotes(const wxString& str);
+
+    /// Append `str` to `arr`. If the array size exceed the truncation size, shrink it to fit
+    static wxArrayString AppendAndMakeUnique(const wxArrayString& arr, const wxString& str, size_t truncate_size = 15);
+
+    /// Given `Container` create an array with unique entries
+    template <typename Container>
+    static wxArrayString MakeUniqueArray(const Container& container)
+    {
+        wxArrayString arr;
+        std::unordered_set<wxString> unique_set;
+        arr.reserve(container.size());
+        for(const auto& str : container) {
+            if(unique_set.insert(str).second) {
+                arr.Add(str);
+            }
+        }
+        return arr;
+    }
 };
 
 #endif // STRINGUTILS_H
