@@ -1,7 +1,8 @@
 #ifndef CLSTRINGVIEW_HPP
 #define CLSTRINGVIEW_HPP
 
-#include <codelite_exports.h>
+#include "codelite_exports.h"
+
 #include <wx/string.h>
 
 class WXDLLIMPEXP_CL clStringView
