@@ -55,6 +55,7 @@ clCommandEvent& clCommandEvent::operator=(const clCommandEvent& src)
     m_oldName = src.m_oldName;
     m_lineNumber = src.m_lineNumber;
     m_selected = src.m_selected;
+    m_stringRaw = src.m_stringRaw;
 
     // Copy wxCommandEvent members here
     m_eventType = src.m_eventType;
@@ -62,6 +63,7 @@ clCommandEvent& clCommandEvent::operator=(const clCommandEvent& src)
     m_cmdString = src.m_cmdString;
     m_commandInt = src.m_commandInt;
     m_extraLong = src.m_extraLong;
+    m_sshAccount = src.m_sshAccount;
     return *this;
 }
 
@@ -186,6 +188,7 @@ clBuildEvent& clBuildEvent::operator=(const clBuildEvent& src)
     m_cleanLog = src.m_cleanLog;
     m_flags = src.m_flags;
     m_toolchain = src.m_toolchain;
+    m_buildDir = src.m_buildDir;
     return *this;
 }
 
@@ -221,7 +224,6 @@ clDebugEvent& clDebugEvent::operator=(const clDebugEvent& other)
     m_memoryBlockValue = other.m_memoryBlockValue;
     m_breakpoints = other.m_breakpoints;
     m_isSSHDebugging = other.m_isSSHDebugging;
-    m_sshAccount = other.m_sshAccount;
     m_alternateDebuggerPath = other.m_alternateDebuggerPath;
     m_uiBreakpoint = other.m_uiBreakpoint;
     return *this;
@@ -513,6 +515,31 @@ clSourceControlEvent& clSourceControlEvent::operator=(const clSourceControlEvent
 // --------------------------------------------------------------
 // Recent workspace event
 // --------------------------------------------------------------
+clEditorEvent::clEditorEvent(wxEventType commandType, int winid)
+    : clCommandEvent(commandType, winid)
+{
+}
+
+clEditorEvent::clEditorEvent(const clEditorEvent& event) { *this = event; }
+
+clEditorEvent::~clEditorEvent()
+{ /* we do not delete the user data */
+}
+
+clEditorEvent& clEditorEvent::operator=(const clEditorEvent& src)
+{
+    if(this == &src) {
+        return *this;
+    }
+
+    clCommandEvent::operator=(src);
+    m_userData = src.m_userData;
+    return *this;
+}
+
+//// --------------------------------------------------------------
+// Recent workspace event
+// --------------------------------------------------------------
 clRecentWorkspaceEvent::clRecentWorkspaceEvent(wxEventType commandType, int winid)
     : clCommandEvent(commandType, winid)
 {
