@@ -26,15 +26,15 @@
 #ifndef CLCOMMANDEVENT_H
 #define CLCOMMANDEVENT_H
 
+#include "AsyncProcess/asyncprocess.h"
 #include "LSP/CompletionItem.h"
 #include "UIBreakpoint.hpp"
-#include "asyncprocess.h"
 #include "clDebuggerBreakpoint.hpp"
 #include "clEditorConfig.h"
 #include "clGotoEntry.h"
 #include "codelite_exports.h"
-#include "entry.h"
-#include "ssh_account_info.h"
+#include "database/entry.h"
+#include "ssh/ssh_account_info.h"
 #include "wxCodeCompletionBoxEntry.hpp"
 
 #include <vector>
@@ -152,6 +152,8 @@ protected:
     bool m_allowed;
     int m_lineNumber;
     bool m_selected;
+    std::string m_stringRaw;
+    wxString m_sshAccount;
 
 public:
     clCommandEvent(wxEventType commandType = wxEVT_NULL, int winid = 0);
@@ -219,6 +221,10 @@ public:
     const wxSharedPtr<wxClientData>& GetPtr() const { return m_ptr; }
     const wxArrayString& GetStrings() const { return m_strings; }
     wxArrayString& GetStrings() { return m_strings; }
+    const std::string& GetStringRaw() const { return m_stringRaw; }
+    void SetStringRaw(const std::string& str) { m_stringRaw = str; }
+    void SetSshAccount(const wxString& sshAccount) { this->m_sshAccount = sshAccount; }
+    const wxString& GetSshAccount() const { return m_sshAccount; }
 };
 
 typedef void (wxEvtHandler::*clCommandEventFunction)(clCommandEvent&);
@@ -389,6 +395,7 @@ protected:
     bool m_cleanLog = true;
     size_t m_flags = 0;
     wxString m_toolchain;
+    wxString m_buildDir;
 
 public:
     clBuildEvent(wxEventType commandType = wxEVT_NULL, int winid = 0);
@@ -406,6 +413,9 @@ public:
         }
     }
 
+    void SetBuildDir(const wxString& buildDir) { this->m_buildDir = buildDir; }
+    const wxString& GetBuildDir() const { return m_buildDir; }
+
     void SetToolchain(const wxString& toolchain) { this->m_toolchain = toolchain; }
     const wxString& GetToolchain() const { return m_toolchain; }
     bool HasFlag(eFlags f) const { return m_flags & f; }
@@ -454,7 +464,6 @@ class WXDLLIMPEXP_CL clDebugEvent : public clCommandEvent
     size_t m_memoryBlockSize;    // wxEVT_DEBUGGER_SET_MEMORY
     clDebuggerBreakpoint::Vec_t m_breakpoints;
     bool m_isSSHDebugging = false;
-    wxString m_sshAccount;
     wxString m_alternateDebuggerPath; // Holds the path to an alternate debugger executable
     UIBreakpoint m_uiBreakpoint;
 
@@ -486,8 +495,6 @@ public:
         this->m_alternateDebuggerPath = alternateDebuggerPath;
     }
     const wxString& GetAlternateDebuggerPath() const { return m_alternateDebuggerPath; }
-    void SetSshAccount(const wxString& sshAccount) { this->m_sshAccount = sshAccount; }
-    const wxString& GetSshAccount() const { return m_sshAccount; }
     void SetIsSSHDebugging(bool isSSHDebugging) { this->m_isSSHDebugging = isSSHDebugging; }
     bool IsSSHDebugging() const { return m_isSSHDebugging; }
     void SetFeatures(size_t features) { m_features = features; }
@@ -636,6 +643,8 @@ public:
     void SetOutput(const wxString& output) { this->m_output = output; }
     void SetProcess(IProcess* process) { this->m_process = process; }
     const wxString& GetOutput() const { return m_output; }
+    void SetOutputRaw(const std::string& output) { SetStringRaw(output); }
+    const std::string& GetOutputRaw() const { return GetStringRaw(); }
     IProcess* GetProcess() { return m_process; }
 };
 
@@ -852,6 +861,26 @@ public:
 typedef void (wxEvtHandler::*clEditorConfigEventFunction)(clEditorConfigEvent&);
 #define clEditorConfigEventHandler(func) wxEVENT_HANDLER_CAST(clEditorConfigEventFunction, func)
 
+// --------------------------------------------------------------
+// clEditorEvent event
+// --------------------------------------------------------------
+class WXDLLIMPEXP_CL clEditorEvent : public clCommandEvent
+{
+    wxClientData* m_userData = nullptr;
+
+public:
+    clEditorEvent(wxEventType commandType = wxEVT_NULL, int winid = 0);
+    clEditorEvent(const clEditorEvent& event);
+    clEditorEvent& operator=(const clEditorEvent& src);
+    virtual ~clEditorEvent();
+    virtual wxEvent* Clone() const { return new clEditorEvent(*this); }
+    wxClientData* GetUserData() const { return m_userData; }
+    void SetUserData(wxClientData* d) { m_userData = d; }
+};
+
+typedef void (wxEvtHandler::*clEditorEventFunction)(clEditorEvent&);
+#define clEditorEventHandler(func) wxEVENT_HANDLER_CAST(clEditorEventFunction, func)
+
 //---------------------------------------------------------------
 // Language Server events
 //---------------------------------------------------------------
