@@ -28,14 +28,15 @@
 
 #include "codelite_exports.h"
 #include "macros.h"
+#include "wxStringHash.h"
 
 #include <vector>
 #include <wx/colour.h>
 #include <wx/ffile.h>
 #include <wx/filename.h>
+#include <wx/gdicmn.h>
 #include <wx/stopwatch.h>
 #include <wx/thread.h>
-#include <wxStringHash.h>
 
 // manipulator function
 class FileLogger;
@@ -47,10 +48,10 @@ public:
     enum { System = -1, Error = 0, Warning = 1, Dbg = 2, Developer = 3 };
 
 protected:
-    static int m_verbosity;
+    static int m_globalLogVerbosity;
     static wxString m_logfile;
-    int _requestedLogLevel;
-    FILE* m_fp;
+    int m_logEntryVersbosity;
+    FILE* m_fp = nullptr;
     wxString m_buffer;
     static std::unordered_map<wxThreadIdType, wxString> m_threads;
     static wxCriticalSection m_cs;
@@ -59,22 +60,23 @@ protected:
     static wxString GetCurrentThreadName();
 
 public:
-    FileLogger(int requestedVerbo);
+    // construct a file logger entry with a given verbosity
+    FileLogger(int verbosity);
     ~FileLogger();
 
-    FileLogger& SetRequestedLogLevel(int level)
+    FileLogger& SetLogEntryVerbosity(int verbosity)
     {
-        _requestedLogLevel = level;
+        m_logEntryVersbosity = verbosity;
         return *this;
     }
 
-    int GetRequestedLogLevel() const { return _requestedLogLevel; }
-    static int GetCurrentLogLevel() { return m_verbosity; }
+    int GetLogEntryVerbosity() const { return m_logEntryVersbosity; }
+    static int GetGlobalLogVerbosity() { return m_globalLogVerbosity; }
 
     /**
-     * @brief return true if log_level is lower than the currently set log level
+     * @brief return true if log_level is lower or equal to the global log verbosity
      */
-    static bool CanLog(int log_level) { return log_level <= GetCurrentLogLevel(); }
+    static bool CanLog(int verbo) { return verbo <= GetGlobalLogVerbosity(); }
 
     /**
      * @brief give a thread-id a unique name which will be displayed in log
@@ -94,21 +96,19 @@ public:
      * @param verbosity
      */
     void AddLogLine(const wxArrayString& arr, int verbosity);
-    static void SetVerbosity(int level);
-
-    // Set the verbosity as string
-    static void SetVerbosity(const wxString& verbosity);
 
     ///----------------------------------
-    /// Statics
+    /// log verbosity manipulation
     ///----------------------------------
+    static void SetGlobalLogVerbosity(int level);
+    static void SetGlobalLogVerbosity(const wxString& verbosity);
+    static int GetVerbosityAsNumber(const wxString& verbosity);
+    static wxString GetVerbosityAsString(int verbosity);
+
     /**
      * @brief open the log file
      */
     static void OpenLog(const wxString& fullName, int verbosity);
-    // Various util methods
-    static wxString GetVerbosityAsString(int verbosity);
-    static int GetVerbosityAsNumber(const wxString& verbosity);
 
     inline FileLogger& operator<<(FileLoggerFunction f)
     {
@@ -119,15 +119,16 @@ public:
     // special types printing
     inline FileLogger& operator<<(const std::vector<wxString>& arr)
     {
-        if(GetRequestedLogLevel() > m_verbosity) {
+        if (!FileLogger::CanLog(GetLogEntryVerbosity())) {
             return *this;
         }
-        if(!m_buffer.IsEmpty()) {
+
+        if (!m_buffer.IsEmpty()) {
             m_buffer << " ";
         }
         m_buffer << "[";
-        if(!arr.empty()) {
-            for(size_t i = 0; i < arr.size(); ++i) {
+        if (!arr.empty()) {
+            for (size_t i = 0; i < arr.size(); ++i) {
                 m_buffer << arr[i] << ", ";
             }
             m_buffer.RemoveLast(2);
@@ -138,15 +139,15 @@ public:
 
     inline FileLogger& operator<<(const wxStringSet_t& S)
     {
-        if(GetRequestedLogLevel() > m_verbosity) {
+        if (!FileLogger::CanLog(GetLogEntryVerbosity())) {
             return *this;
         }
-        if(!m_buffer.IsEmpty()) {
+        if (!m_buffer.IsEmpty()) {
             m_buffer << " ";
         }
         m_buffer << "{";
-        if(!S.empty()) {
-            for(const wxString& s : S) {
+        if (!S.empty()) {
+            for (const wxString& s : S) {
                 m_buffer << s << ", ";
             }
             m_buffer.RemoveLast(2);
@@ -157,15 +158,15 @@ public:
 
     inline FileLogger& operator<<(const wxStringMap_t& M)
     {
-        if(GetRequestedLogLevel() > m_verbosity) {
+        if (!FileLogger::CanLog(GetLogEntryVerbosity())) {
             return *this;
         }
-        if(!m_buffer.IsEmpty()) {
+        if (!m_buffer.IsEmpty()) {
             m_buffer << " ";
         }
         m_buffer << "{";
-        if(!M.empty()) {
-            for(const auto& vt : M) {
+        if (!M.empty()) {
+            for (const auto& vt : M) {
                 m_buffer << "{" << vt.first << ", " << vt.second << "}, ";
             }
             m_buffer.RemoveLast(2);
@@ -176,7 +177,7 @@ public:
 
     inline FileLogger& operator<<(const wxArrayString& arr)
     {
-        if(GetRequestedLogLevel() > m_verbosity) {
+        if (!FileLogger::CanLog(GetLogEntryVerbosity())) {
             return *this;
         }
         std::vector<wxString> v{ arr.begin(), arr.end() };
@@ -184,9 +185,45 @@ public:
         return *this;
     }
 
+    inline FileLogger& operator<<(const wxRect& rect)
+    {
+        if (!FileLogger::CanLog(GetLogEntryVerbosity())) {
+            return *this;
+        }
+
+        wxString str;
+        str << "(" << rect.x << ", " << rect.y << ", " << rect.width << ", " << rect.height << ")";
+        *this << str;
+        return *this;
+    }
+
+    inline FileLogger& operator<<(const wxPoint& point)
+    {
+        if (!FileLogger::CanLog(GetLogEntryVerbosity())) {
+            return *this;
+        }
+
+        wxString str;
+        str << "(" << point.x << ", " << point.y << ")";
+        *this << str;
+        return *this;
+    }
+
+    inline FileLogger& operator<<(const wxSize& size)
+    {
+        if (!FileLogger::CanLog(GetLogEntryVerbosity())) {
+            return *this;
+        }
+
+        wxString str;
+        str << "(" << size.x << ", " << size.y << ")";
+        *this << str;
+        return *this;
+    }
+
     inline FileLogger& operator<<(const wxColour& colour)
     {
-        if(GetRequestedLogLevel() > m_verbosity) {
+        if (!FileLogger::CanLog(GetLogEntryVerbosity())) {
             return *this;
         }
 
@@ -201,10 +238,10 @@ public:
      */
     inline FileLogger& operator<<(const wxString& str)
     {
-        if(GetRequestedLogLevel() > m_verbosity) {
+        if (!FileLogger::CanLog(GetLogEntryVerbosity())) {
             return *this;
         }
-        if(!m_buffer.IsEmpty()) {
+        if (!m_buffer.IsEmpty()) {
             m_buffer << " ";
         }
         m_buffer << str;
@@ -216,10 +253,10 @@ public:
      */
     inline FileLogger& operator<<(const wxFileName& fn)
     {
-        if(GetRequestedLogLevel() > m_verbosity) {
+        if (!FileLogger::CanLog(GetLogEntryVerbosity())) {
             return *this;
         }
-        if(!m_buffer.IsEmpty()) {
+        if (!m_buffer.IsEmpty()) {
             m_buffer << " ";
         }
         m_buffer << fn.GetFullPath();
@@ -229,12 +266,13 @@ public:
     /**
      * @brief append any type to the buffer, take log level into consideration
      */
-    template <typename T> FileLogger& Append(const T& elem, int level)
+    template <typename T>
+    FileLogger& Append(const T& elem, int level)
     {
-        if(level > m_verbosity) {
+        if (level > m_globalLogVerbosity) {
             return *this;
         }
-        if(!m_buffer.IsEmpty()) {
+        if (!m_buffer.IsEmpty()) {
             m_buffer << " ";
         }
         m_buffer << elem;
@@ -259,26 +297,28 @@ inline FileLogger& endl(FileLogger& d)
     return d;
 }
 
-template <typename T> FileLogger& operator<<(FileLogger& logger, const T& obj)
+template <typename T>
+FileLogger& operator<<(FileLogger& logger, const T& obj)
 {
-    logger.Append(obj, logger.GetRequestedLogLevel());
+    if (!FileLogger::CanLog(logger.GetLogEntryVerbosity()))
+        return logger;
+
+    logger.Append(obj, logger.GetLogEntryVerbosity());
     return logger;
 }
 
 // New API
 #define clDEBUG() FileLogger(FileLogger::Dbg) << FileLogger::Prefix(FileLogger::Dbg)
 #define clDEBUG1() FileLogger(FileLogger::Developer) << FileLogger::Prefix(FileLogger::Developer)
-
-// alias
 #define clTRACE() clDEBUG1()
 
 #define clERROR() FileLogger(FileLogger::Error) << FileLogger::Prefix(FileLogger::Error)
 #define clWARNING() FileLogger(FileLogger::Warning) << FileLogger::Prefix(FileLogger::Warning)
 #define clSYSTEM() FileLogger(FileLogger::System) << FileLogger::Prefix(FileLogger::System)
 
-#define LOG_IF_DEBUG if(FileLogger::CanLog(FileLogger::Dbg))
-#define LOG_IF_TRACE if(FileLogger::CanLog(FileLogger::Developer))
-#define LOG_IF_WARN if(FileLogger::CanLog(FileLogger::Developer))
+#define LOG_IF_DEBUG if (FileLogger::CanLog(FileLogger::Dbg))
+#define LOG_IF_TRACE if (FileLogger::CanLog(FileLogger::Developer))
+#define LOG_IF_WARN if (FileLogger::CanLog(FileLogger::Developer))
 
 // A replacement for wxLogMessage
 #define clLogMessage(msg) clDEBUG() << msg
