@@ -27,6 +27,7 @@
 
 #include "cl_standard_paths.h"
 #include "wxStringHash.h"
+
 #include <map>
 #include <set>
 #include <unordered_map>
@@ -38,38 +39,38 @@
 // wxWidgets Connect macros
 //-------------------------------------------------------
 
-#define ConnectChoice(ctrl, fn) \
+#define ConnectChoice(ctrl, fn)                                                                         \
     ctrl->Connect(ctrl->GetId(), wxEVT_COMMAND_CHOICE_SELECTED, wxCommandEventHandler(fn), NULL, this);
 
-#define ConnectButton(ctrl, fn) \
+#define ConnectButton(ctrl, fn)                                                                        \
     ctrl->Connect(ctrl->GetId(), wxEVT_COMMAND_BUTTON_CLICKED, wxCommandEventHandler(fn), NULL, this);
 
-#define ConnectListBoxDClick(ctrl, fn) \
+#define ConnectListBoxDClick(ctrl, fn)                                                                        \
     ctrl->Connect(ctrl->GetId(), wxEVT_COMMAND_LISTBOX_DOUBLECLICKED, wxCommandEventHandler(fn), NULL, this);
 
-#define ConnectCheckBox(ctrl, fn) \
+#define ConnectCheckBox(ctrl, fn)                                                                        \
     ctrl->Connect(ctrl->GetId(), wxEVT_COMMAND_CHECKBOX_CLICKED, wxCommandEventHandler(fn), NULL, this);
 
-#define ConnectListCtrlItemSelected(ctrl, fn) \
+#define ConnectListCtrlItemSelected(ctrl, fn)                                                           \
     ctrl->Connect(ctrl->GetId(), wxEVT_COMMAND_LIST_ITEM_SELECTED, wxListEventHandler(fn), NULL, this);
 
-#define ConnectListCtrlItemActivated(ctrl, fn) \
+#define ConnectListCtrlItemActivated(ctrl, fn)                                                           \
     ctrl->Connect(ctrl->GetId(), wxEVT_COMMAND_LIST_ITEM_ACTIVATED, wxListEventHandler(fn), NULL, this);
 
 #define ConnectKeyDown(ctrl, fn) ctrl->Connect(ctrl->GetId(), wxEVT_KEY_DOWN, wxKeyEventHandler(fn), NULL, this);
 
 #define ConnectCharEvent(ctrl, fn) ctrl->Connect(ctrl->GetId(), wxEVT_CHAR, wxKeyEventHandler(fn), NULL, this);
 
-#define ConnectCmdTextEntered(ctrl, fn) \
+#define ConnectCmdTextEntered(ctrl, fn)                                                            \
     ctrl->Connect(ctrl->GetId(), wxEVT_COMMAND_TEXT_ENTER, wxCommandEventHandler(fn), NULL, this);
 
-#define ConnectCmdTextUpdated(ctrl, fn) \
+#define ConnectCmdTextUpdated(ctrl, fn)                                                              \
     ctrl->Connect(ctrl->GetId(), wxEVT_COMMAND_TEXT_UPDATED, wxCommandEventHandler(fn), NULL, this);
 
-#define ConnectCombo(ctrl, fn) \
+#define ConnectCombo(ctrl, fn)                                                                            \
     ctrl->Connect(ctrl->GetId(), wxEVT_COMMAND_COMBOBOX_SELECTED, wxCommandEventHandler(fn), NULL, this);
 
-#define ConnectCheckList(ctrl, fn) \
+#define ConnectCheckList(ctrl, fn)                                                                           \
     ctrl->Connect(ctrl->GetId(), wxEVT_COMMAND_CHECKLISTBOX_TOGGLED, wxCommandEventHandler(fn), NULL, this);
 
 #define TrimString(str)        \
@@ -78,7 +79,7 @@
         str = str.Trim(false); \
     }
 
-#define IsSourceFile(ext) \
+#define IsSourceFile(ext)                                                                                \
     (ext == wxT("cpp") || ext == wxT("cxx") || ext == wxT("c") || ext == wxT("c++") || ext == wxT("cc"))
 
 #define BoolToString(b) b ? wxT("yes") : wxT("no")
@@ -91,10 +92,11 @@
 #define clCMD_EDIT _("<Edit...>")
 
 // constant message
-#define BUILD_START_MSG _("----------Build Started--------\n")
-#define BUILD_END_MSG _("----------Build Ended----------\n")
-#define BUILD_PROJECT_PREFIX _("----------Building project:[ ")
-#define CLEAN_PROJECT_PREFIX _("----------Cleaning project:[ ")
+#define BUILD_START_MSG _("==========Build Started==========\n")
+#define BUILD_END_MSG _("==========Build Ended==========\n")
+#define BUILD_PROJECT_PREFIX _("==========Building project:[ ")
+#define BUILD_PROJECT_SUFFIX _(" ]==========")
+#define CLEAN_PROJECT_PREFIX _("==========Cleaning project:[ ")
 
 // Find in files options
 #define SEARCH_IN_WORKSPACE wxTRANSLATE("<Entire Workspace>")
@@ -108,8 +110,8 @@
 
 // terminal macro
 #ifdef __WXGTK__
-#define TERMINAL_CMD                                               \
-    wxString::Format(wxT("%s/codelite_xterm '$(TITLE)' '$(CMD)'"), \
+#define TERMINAL_CMD                                                                           \
+    wxString::Format(wxT("%s/codelite_xterm '$(TITLE)' '$(CMD)'"),                             \
                      wxFileName(clStandardPaths::Get().GetExecutablePath()).GetPath().c_str())
 #elif defined(__WXMAC__)
 #define TERMINAL_CMD wxString::Format(wxT("%s/OpenTerm '$(CMD)'"), clStandardPaths::Get().GetDataDir().c_str())
@@ -135,48 +137,48 @@
 
 // Useful macros
 #define CHECK_PTR_RET(p) \
-    if(!p)               \
+    if (!p)              \
     return
 #define CHECK_PTR_RET_FALSE(p) \
-    if(!p)                     \
+    if (!p)                    \
     return false
 #define CHECK_PTR_RET_NULL(p) \
-    if(!p)                    \
+    if (!p)                   \
     return NULL
 
 #define CHECK_PTR_RET_EMPTY_STRING(p) \
-    if(!p)                            \
+    if (!p)                           \
     return wxEmptyString
 
 // If expression != expected -> return
 #define CHECK_EXPECTED_RETURN(expression, expected) \
-    if((expression) != (expected))                  \
+    if ((expression) != (expected))                 \
     return
 
 #define CHECK_COND_RET(p) \
-    if(!(p))              \
+    if (!(p))             \
     return
 #define CHECK_COND_RET_FALSE(p) \
-    if(!(p))                    \
+    if (!(p))                   \
     return false
 #define CHECK_COND_RET_NULL(p) \
-    if(!(p))                   \
+    if (!(p))                  \
     return NULL
 #define CHECK_COND_RET_EMPTY_STRING(p) \
-    if(!(p))                           \
+    if (!(p))                          \
     return wxEmptyString
 
 #define CHECK_ITEM_RET(item) \
-    if(!item.IsOk())         \
+    if (!item.IsOk())        \
     return
 #define CHECK_ITEM_RET_FALSE(item) \
-    if(!item.IsOk())               \
+    if (!item.IsOk())              \
     return false
 #define CHECK_ITEM_RET_NULL(item) \
-    if(!item.IsOk())              \
+    if (!item.IsOk())             \
     return NULL
 #define CHECK_ITEM_RET_EMPTY_STRING(item) \
-    if(!item.IsOk())                      \
+    if (!item.IsOk())                     \
     return wxEmptyString
 
 // PATH environment variable separator
@@ -186,7 +188,7 @@
 #define clPATH_SEPARATOR ":"
 #endif
 
-// ----------------------------- usefule typedefs -------------------------------
+// ----------------------------- useful typedefs -------------------------------
 typedef std::unordered_map<wxString, bool> wxStringBoolMap_t;
 typedef std::unordered_map<wxString, wxString> wxStringTable_t;
 typedef std::unordered_set<wxString> wxStringSet_t;
