@@ -31,21 +31,21 @@
 #include <sys/user.h>
 #endif
 
-#include "asyncprocess.h"
+#include "AsyncProcess/asyncprocess.h"
+#include "AsyncProcess/processreaderthread.h"
 #include "cl_command_event.h"
 #include "codelite_events.h"
 #include "file_logger.h"
 #include "fileutils.h"
-#include "processreaderthread.h"
 #include "procutils.h"
 #include "winprocess.h"
-#include "wx/tokenzr.h"
 
 #include <memory>
 #include <stdio.h>
+#include <wx/tokenzr.h>
 #ifdef __WXMSW__
-#include "wx/msw/private.h"
-#include "wx/textbuf.h"
+#include <wx/msw/private.h>
+#include <wx/textbuf.h>
 #ifndef pclose
 #define pclose _pclose
 #endif
@@ -86,7 +86,7 @@ ProcUtils::ProcUtils() {}
 
 ProcUtils::~ProcUtils() {}
 
-void ProcUtils::GetProcTree(std::map<unsigned long, bool>& parentsMap, long pid)
+std::set<unsigned long> ProcUtils::GetProcTree(long pid)
 {
 #ifdef __WXMSW__
     OSVERSIONINFO osver;
@@ -94,18 +94,18 @@ void ProcUtils::GetProcTree(std::map<unsigned long, bool>& parentsMap, long pid)
     // Check to see if were running under Windows95 or
     // Windows NT.
     osver.dwOSVersionInfoSize = sizeof(osver);
-    if(!GetVersionEx(&osver)) {
-        return;
+    if (!GetVersionEx(&osver)) {
+        return {};
     }
 
-    if(osver.dwPlatformId != VER_PLATFORM_WIN32_NT) {
-        return;
+    if (osver.dwPlatformId != VER_PLATFORM_WIN32_NT) {
+        return {};
     }
 
     // get child processes of this node
     HANDLE hProcessSnap = CreateToolhelp32Snapshot(TH32CS_SNAPPROCESS, 0);
-    if(!hProcessSnap) {
-        return;
+    if (!hProcessSnap) {
+        return {};
     }
 
     // Fill in the size of the structure before using it.
@@ -115,30 +115,31 @@ void ProcUtils::GetProcTree(std::map<unsigned long, bool>& parentsMap, long pid)
 
     // Walk the snapshot of the processes, and for each process,
     // kill it if its parent is pid.
-    if(!Process32First(hProcessSnap, &pe)) {
+    if (!Process32First(hProcessSnap, &pe)) {
         // Can't get first process.
         CloseHandle(hProcessSnap);
-        return;
+        return {};
     }
 
-    parentsMap[pid] = true;
+    std::set<unsigned long> parentsMap{ static_cast<unsigned long>(pid) };
 
     do {
-        if(parentsMap.find(pe.th32ParentProcessID) != parentsMap.end()) {
+        if (parentsMap.find(pe.th32ParentProcessID) != parentsMap.end()) {
             // get the process handle
             HANDLE hProcess = ::OpenProcess(SYNCHRONIZE | PROCESS_TERMINATE | PROCESS_QUERY_INFORMATION,
                                             FALSE, // not inheritable
                                             (DWORD)pid);
-            if(hProcess != NULL) {
+            if (hProcess != NULL) {
                 CloseHandle(hProcess);
                 // dont kill the process, just keep its ID
-                parentsMap[pe.th32ProcessID] = true;
+                parentsMap.insert(pe.th32ProcessID);
             }
         }
-    } while(Process32Next(hProcessSnap, &pe));
+    } while (Process32Next(hProcessSnap, &pe));
     CloseHandle(hProcessSnap);
+    return parentsMap;
 #else
-    parentsMap[pid] = true;
+    return { static_cast<unsigned long>(pid) };
 #endif
 }
 
@@ -165,7 +166,7 @@ PidVec_t ProcUtils::PS(const wxString& name)
 
     wxString processOutput;
     IProcess::Ptr_t p(::CreateSyncProcess(command, IProcessCreateDefault | IProcessCreateWithHiddenConsole));
-    if(p) {
+    if (p) {
         p->WaitForTerminate(processOutput);
     }
 
@@ -185,17 +186,17 @@ PidVec_t ProcUtils::PS(const wxString& name)
     //  2920    ?        Ss     0:00 ssh-agent
 
     wxArrayString lines = ::wxStringTokenize(processOutput, "\n", wxTOKEN_STRTOK);
-    for(wxString& line : lines) {
+    for (wxString& line : lines) {
         line.Trim().Trim(false);
         wxArrayString parts = ::wxStringTokenize(line, " \t", wxTOKEN_STRTOK);
-        if(parts.size() < MIN_COLUMNS_NUMBER) {
+        if (parts.size() < MIN_COLUMNS_NUMBER) {
             continue;
         }
         wxString& imageName = parts.Item(IMGNAME_COL);
         wxString& pid = parts.Item(PID_COL);
-        if(FileUtils::FuzzyMatch(name, imageName)) {
+        if (FileUtils::FuzzyMatch(name, imageName)) {
             long nPid = -1;
-            if(pid.ToCLong(&nPid)) {
+            if (pid.ToCLong(&nPid)) {
                 V.push_back({ imageName, nPid });
             }
         }
@@ -213,7 +214,7 @@ wxString ProcUtils::GetProcessNameByPid(long pid)
 
     //  Take a snapshot of all modules in the specified process.
     hModuleSnap = CreateToolhelp32Snapshot(TH32CS_SNAPMODULE, (DWORD)pid);
-    if(hModuleSnap == INVALID_HANDLE_VALUE) {
+    if (hModuleSnap == INVALID_HANDLE_VALUE) {
         return wxEmptyString;
     }
 
@@ -222,7 +223,7 @@ wxString ProcUtils::GetProcessNameByPid(long pid)
 
     //  Retrieve information about the first module,
     //  and exit if unsuccessful
-    if(!Module32First(hModuleSnap, &me32)) {
+    if (!Module32First(hModuleSnap, &me32)) {
         CloseHandle(hModuleSnap); // Must clean up the
         // snapshot object!
         return wxEmptyString;
@@ -238,10 +239,10 @@ wxString ProcUtils::GetProcessNameByPid(long pid)
     int nof_procs;
     wxString cmd;
 
-    if(!(kvd = kvm_openfiles(_PATH_DEVNULL, _PATH_DEVNULL, NULL, O_RDONLY, NULL)))
+    if (!(kvd = kvm_openfiles(_PATH_DEVNULL, _PATH_DEVNULL, NULL, O_RDONLY, NULL)))
         return wxEmptyString;
 
-    if(!(ki = kvm_getprocs(kvd, KERN_PROC_PID, pid, &nof_procs))) {
+    if (!(ki = kvm_getprocs(kvd, KERN_PROC_PID, pid, &nof_procs))) {
         kvm_close(kvd);
         return wxEmptyString;
     }
@@ -254,7 +255,7 @@ wxString ProcUtils::GetProcessNameByPid(long pid)
     wxArrayString output;
     ExecuteCommand(wxT("ps -A -o pid,command --no-heading"), output);
     // parse the output and search for our process ID
-    for(size_t i = 0; i < output.GetCount(); i++) {
+    for (size_t i = 0; i < output.GetCount(); i++) {
         wxString line = output.Item(i);
         // remove whitespaces
         line = line.Trim();
@@ -263,7 +264,7 @@ wxString ProcUtils::GetProcessNameByPid(long pid)
         wxString spid = line.BeforeFirst(wxT(' '));
         long cpid(0);
         spid.ToLong(&cpid);
-        if(cpid == pid) {
+        if (cpid == pid) {
             // we got a match, extract the command, it is in the second column
             wxString command = line.AfterFirst(wxT(' '));
             return command;
@@ -282,8 +283,8 @@ void ProcUtils::ExecuteCommand(const wxString& command, wxArrayString& output, l
     char line[512];
     memset(line, 0, sizeof(line));
     fp = popen(command.mb_str(wxConvUTF8), "r");
-    if(fp) {
-        while(fgets(line, sizeof(line), fp)) {
+    if (fp) {
+        while (fgets(line, sizeof(line), fp)) {
             output.Add(wxString(line, wxConvUTF8));
             memset(line, 0, sizeof(line));
         }
@@ -294,7 +295,7 @@ void ProcUtils::ExecuteCommand(const wxString& command, wxArrayString& output, l
 
 void ProcUtils::ExecuteInteractiveCommand(const wxString& command) { wxShell(command); }
 
-void ProcUtils::GetProcessList(std::vector<ProcessEntry>& proclist)
+std::vector<ProcessEntry> ProcUtils::GetProcessList()
 {
 #ifdef __WXMSW__
     OSVERSIONINFO osver;
@@ -302,18 +303,18 @@ void ProcUtils::GetProcessList(std::vector<ProcessEntry>& proclist)
     // Check to see if were running under Windows95 or
     // Windows NT.
     osver.dwOSVersionInfoSize = sizeof(osver);
-    if(!GetVersionEx(&osver)) {
-        return;
+    if (!GetVersionEx(&osver)) {
+        return {};
     }
 
-    if(osver.dwPlatformId != VER_PLATFORM_WIN32_NT) {
-        return;
+    if (osver.dwPlatformId != VER_PLATFORM_WIN32_NT) {
+        return {};
     }
 
     // get child processes of this node
     HANDLE hProcessSnap = CreateToolhelp32Snapshot(TH32CS_SNAPPROCESS, 0);
-    if(!hProcessSnap) {
-        return;
+    if (!hProcessSnap) {
+        return {};
     }
 
     // Fill in the size of the structure before using it.
@@ -323,18 +324,19 @@ void ProcUtils::GetProcessList(std::vector<ProcessEntry>& proclist)
 
     // Walk the snapshot of the processes, and for each process,
     // kill it if its parent is pid.
-    if(!Process32First(hProcessSnap, &pe)) {
+    if (!Process32First(hProcessSnap, &pe)) {
         // Can't get first process.
         CloseHandle(hProcessSnap);
-        return;
+        return {};
     }
 
+    std::vector<ProcessEntry> proclist;
     do {
         ProcessEntry entry;
         entry.name = pe.szExeFile;
         entry.pid = (long)pe.th32ProcessID;
         proclist.push_back(entry);
-    } while(Process32Next(hProcessSnap, &pe));
+    } while (Process32Next(hProcessSnap, &pe));
     CloseHandle(hProcessSnap);
 
 #elif defined(__FreeBSD__)
@@ -342,15 +344,16 @@ void ProcUtils::GetProcessList(std::vector<ProcessEntry>& proclist)
     struct kinfo_proc* ki;
     int nof_procs, i;
 
-    if(!(kvd = kvm_openfiles(_PATH_DEVNULL, _PATH_DEVNULL, NULL, O_RDONLY, NULL)))
-        return;
+    if (!(kvd = kvm_openfiles(_PATH_DEVNULL, _PATH_DEVNULL, NULL, O_RDONLY, NULL)))
+        return {};
 
-    if(!(ki = kvm_getprocs(kvd, KERN_PROC_PROC, 0, &nof_procs))) {
+    if (!(ki = kvm_getprocs(kvd, KERN_PROC_PROC, 0, &nof_procs))) {
         kvm_close(kvd);
-        return;
+        return {};
     }
 
-    for(i = 0; i < nof_procs; i++) {
+    std::vector<ProcessEntry> proclist;
+    for (i = 0; i < nof_procs; i++) {
         ProcessEntry entry;
         entry.pid = ki[i].ki_pid;
         entry.name = wxString(ki[i].ki_ocomm, wxConvUTF8);
@@ -367,7 +370,8 @@ void ProcUtils::GetProcessList(std::vector<ProcessEntry>& proclist)
     // Mac does not like the --no-heading...
     ExecuteCommand(wxT("ps -A -o pid,command "), output);
 #endif
-    for(size_t i = 0; i < output.GetCount(); i++) {
+    std::vector<ProcessEntry> proclist;
+    for (size_t i = 0; i < output.GetCount(); i++) {
         wxString line = output.Item(i);
         // remove whitespaces
         line = line.Trim().Trim(false);
@@ -378,7 +382,7 @@ void ProcUtils::GetProcessList(std::vector<ProcessEntry>& proclist)
         spid.ToLong(&entry.pid);
         entry.name = line.AfterFirst(wxT(' '));
 
-        if(entry.pid == 0 && i > 0) {
+        if (entry.pid == 0 && i > 0) {
             // probably this line belongs to the provious one
             ProcessEntry e = proclist.back();
             proclist.pop_back();
@@ -389,101 +393,7 @@ void ProcUtils::GetProcessList(std::vector<ProcessEntry>& proclist)
         }
     }
 #endif
-}
-
-void ProcUtils::GetChildren(long pid, std::vector<long>& proclist)
-{
-#ifdef __WXMSW__
-    OSVERSIONINFO osver;
-
-    // Check to see if were running under Windows95 or
-    // Windows NT.
-    osver.dwOSVersionInfoSize = sizeof(osver);
-    if(!GetVersionEx(&osver)) {
-        return;
-    }
-
-    if(osver.dwPlatformId != VER_PLATFORM_WIN32_NT) {
-        return;
-    }
-
-    // get child processes of this node
-    HANDLE hProcessSnap = CreateToolhelp32Snapshot(TH32CS_SNAPPROCESS, 0);
-    if(!hProcessSnap) {
-        return;
-    }
-
-    // Fill in the size of the structure before using it.
-    PROCESSENTRY32 pe;
-    memset(&pe, 0, sizeof(pe));
-    pe.dwSize = sizeof(PROCESSENTRY32);
-
-    // Walk the snapshot of the processes, and for each process,
-    // kill it if its parent is pid.
-    if(!Process32First(hProcessSnap, &pe)) {
-        // Can't get first process.
-        CloseHandle(hProcessSnap);
-        return;
-    }
-
-    // loop over all processes and collect all the processes their parent
-    // pid matches PID
-    do {
-        if((long)pe.th32ParentProcessID == pid) {
-            proclist.push_back((long)pe.th32ProcessID);
-        }
-    } while(Process32Next(hProcessSnap, &pe));
-    CloseHandle(hProcessSnap);
-
-#elif defined(__FreeBSD__)
-    kvm_t* kvd;
-    struct kinfo_proc* ki;
-    int nof_procs, i;
-
-    if(!(kvd = kvm_openfiles(_PATH_DEVNULL, _PATH_DEVNULL, NULL, O_RDONLY, NULL)))
-        return;
-
-    if(!(ki = kvm_getprocs(kvd, KERN_PROC_PROC, pid, &nof_procs))) {
-        kvm_close(kvd);
-        return;
-    }
-
-    for(i = 0; i < nof_procs; i++) {
-        if(ki[i].ki_ppid == pid)
-            proclist.push_back(ki[i].ki_pid);
-    }
-
-    kvm_close(kvd);
-
-#else
-    // GTK and other
-    wxArrayString output;
-#ifdef __WXGTK__
-    ExecuteCommand(wxT("ps -A -o pid,ppid  --no-heading"), output);
-#else
-    ExecuteCommand(wxT("ps -A -o pid,ppid "), output);
-#endif
-    // parse the output and search for our process ID
-    for(size_t i = 0; i < output.GetCount(); i++) {
-        long lpid(0);
-        long lppid(0);
-        wxString line = output.Item(i);
-
-        // remove whitespaces
-        line = line.Trim().Trim(false);
-
-        // get the process ID
-        wxString spid = line.BeforeFirst(wxT(' '));
-        spid.ToLong(&lpid);
-
-        // get the process Parent ID
-        wxString sppid = line.AfterFirst(wxT(' '));
-        sppid.ToLong(&lppid);
-        if(lppid == pid) {
-            proclist.push_back(lpid);
-        }
-    }
-#endif
+    return proclist;
 }
 
 bool ProcUtils::Shell(const wxString& programConsoleCommand)
@@ -491,7 +401,7 @@ bool ProcUtils::Shell(const wxString& programConsoleCommand)
     wxString cmd;
 #ifdef __WXMSW__
     wxChar* shell = wxGetenv(wxT("COMSPEC"));
-    if(!shell) {
+    if (!shell) {
         shell = (wxChar*)wxT("CMD.EXE");
     }
 
@@ -509,19 +419,19 @@ bool ProcUtils::Shell(const wxString& programConsoleCommand)
     wxArrayString configuredTerminal;
 
     terminal = wxT("xterm");
-    if(!programConsoleCommand.IsEmpty()) {
+    if (!programConsoleCommand.IsEmpty()) {
         tokens = wxStringTokenize(programConsoleCommand, wxT(" "), wxTOKEN_STRTOK);
-        if(!tokens.IsEmpty()) {
+        if (!tokens.IsEmpty()) {
             configuredTerminal = wxStringTokenize(tokens.Item(0), wxT("/"), wxTOKEN_STRTOK);
-            if(!configuredTerminal.IsEmpty()) {
+            if (!configuredTerminal.IsEmpty()) {
                 terminal = configuredTerminal.Last();
                 tokens.Clear();
                 configuredTerminal.Clear();
             }
         }
     }
-    if(Locate(terminal, where)) {
-        if(terminal == wxT("konsole")) {
+    if (Locate(terminal, where)) {
+        if (terminal == wxT("konsole")) {
             wxString path = wxGetCwd();
             terminal.Clear();
             terminal << where << wxT(" --workdir \"") << path << wxT("\"");
@@ -544,14 +454,14 @@ bool ProcUtils::Locate(const wxString& name, wxString& where)
     command << wxT("which \"") << name << wxT("\"");
     ProcUtils::ExecuteCommand(command, output);
 
-    if(output.IsEmpty() == false) {
+    if (output.IsEmpty() == false) {
         wxString interstingLine = output.Item(0);
 
-        if(interstingLine.Trim().Trim(false).IsEmpty()) {
+        if (interstingLine.Trim().Trim(false).IsEmpty()) {
             return false;
         }
 
-        if(!interstingLine.StartsWith(wxT("which: no "))) {
+        if (!interstingLine.StartsWith(wxT("which: no "))) {
             where = output.Item(0);
             where = where.Trim().Trim(false);
             return true;
@@ -566,7 +476,7 @@ void ProcUtils::SafeExecuteCommand(const wxString& command, wxArrayString& outpu
     wxString errMsg;
     LOG_IF_TRACE { clDEBUG1() << "executing process:" << command << endl; }
     std::unique_ptr<WinProcess> proc{ WinProcess::Execute(command, errMsg) };
-    if(!proc) {
+    if (!proc) {
         return;
     }
 
@@ -575,9 +485,9 @@ void ProcUtils::SafeExecuteCommand(const wxString& command, wxArrayString& outpu
     wxString buff;
 
     LOG_IF_TRACE { clDEBUG1() << "reading process output..." << endl; }
-    while(proc->IsAlive()) {
+    while (proc->IsAlive()) {
         tmpbuf.Clear();
-        if(proc->Read(tmpbuf)) {
+        if (proc->Read(tmpbuf)) {
             // as long as we read something, dont sleep...
             buff << tmpbuf;
         } else {
@@ -592,7 +502,7 @@ void ProcUtils::SafeExecuteCommand(const wxString& command, wxArrayString& outpu
         clDEBUG1() << "reading process output remainder..." << endl;
     }
     proc->Read(tmpbuf);
-    while(!tmpbuf.IsEmpty()) {
+    while (!tmpbuf.IsEmpty()) {
         buff << tmpbuf;
         tmpbuf.Clear();
         proc->Read(tmpbuf);
@@ -613,11 +523,11 @@ wxString ProcUtils::SafeExecuteCommand(const wxString& command)
     wxArrayString arr;
     SafeExecuteCommand(command, arr);
 
-    for(size_t i = 0; i < arr.GetCount(); ++i) {
+    for (size_t i = 0; i < arr.GetCount(); ++i) {
         strOut << arr.Item(i) << "\n";
     }
 
-    if(!strOut.IsEmpty()) {
+    if (!strOut.IsEmpty()) {
         strOut.RemoveLast();
     }
     return strOut;
@@ -626,22 +536,40 @@ wxString ProcUtils::SafeExecuteCommand(const wxString& command)
 wxString ProcUtils::GrepCommandOutput(const std::vector<wxString>& cmd, const wxString& find_what)
 {
     IProcess::Ptr_t proc(::CreateAsyncProcess(nullptr, cmd, IProcessCreateDefault | IProcessCreateSync));
-    if(!proc) {
+    if (!proc) {
         return wxEmptyString;
     }
 
     wxString output;
     proc->WaitForTerminate(output);
     auto lines = ::wxStringTokenize(output, "\n", wxTOKEN_STRTOK);
-    for(wxString& line : lines) {
+    for (wxString& line : lines) {
         line.Trim();
-        if(line.Contains(find_what)) {
+        if (line.Contains(find_what)) {
             return line;
         }
     }
     return wxEmptyString;
 }
 
+void ProcUtils::GrepCommandOutputWithCallback(const std::vector<wxString>& cmd,
+                                              std::function<bool(const wxString&)> callback)
+{
+    IProcess::Ptr_t proc(::CreateAsyncProcess(nullptr, cmd, IProcessCreateDefault | IProcessCreateSync));
+    if (!proc) {
+        return;
+    }
+
+    wxString output;
+    proc->WaitForTerminate(output);
+    auto lines = ::wxStringTokenize(output, "\n", wxTOKEN_STRTOK);
+    for (const wxString& line : lines) {
+        if (callback(line)) {
+            break;
+        }
+    }
+}
+
 namespace
 {
 class ProcessHelper : public wxProcess
@@ -668,7 +596,7 @@ public:
     // Notify about the process termination
     void OnTerminate(int pid, int status) override
     {
-        if(status == 0) {
+        if (status == 0) {
             ReadOutput();
         }
 
@@ -688,7 +616,7 @@ bool ProcUtils::ShellExecAsync(const wxString& command, long* pid, wxEvtHandler*
     wxString theCommand = wxString::Format("%s > \"%s\" 2>&1", command, filename);
     WrapInShell(theCommand);
     long rc = ::wxExecute(theCommand, wxEXEC_ASYNC | wxEXEC_HIDE_CONSOLE, new ProcessHelper(sink, filename), nullptr);
-    if(rc > 0) {
+    if (rc > 0) {
         *pid = rc;
     }
     return rc > 0;
@@ -715,11 +643,11 @@ wxString& ProcUtils::WrapInShell(wxString& cmd)
     wxString command;
 #ifdef __WXMSW__
     wxString shell = wxGetenv("COMSPEC");
-    if(shell.IsEmpty()) {
+    if (shell.IsEmpty()) {
         shell = "CMD.EXE";
     }
     command << shell << " /C ";
-    if(cmd.StartsWith("\"") && !cmd.EndsWith("\"")) {
+    if (cmd.StartsWith("\"") && !cmd.EndsWith("\"")) {
         command << "\"" << cmd << "\"";
     } else {
         command << cmd;
