@@ -25,7 +25,6 @@
 
 #include "DbViewerPanel.h"
 
-#include "AdapterSelectDlg.h"
 #include "DbExplorerFrame.h"
 #include "DbSettingDialog.h"
 #include "SqlCommandPanel.h"
@@ -129,7 +128,7 @@ void DbViewerPanel::OnItemActivate(wxTreeEvent& event)
             }
         }
 
-    } catch(DatabaseLayerException& e) {
+    } catch (const DatabaseLayerException& e) {
         ::wxMessageBox(wxString() << "Error occurred while opening SQL panel: " << e.GetErrorMessage(),
                        "Database Explorer", wxOK | wxICON_ERROR | wxCENTER);
     }
@@ -141,7 +140,7 @@ void DbViewerPanel::OnRefreshClick(wxCommandEvent& event)
     try {
         RefreshDbView();
 
-    } catch(DatabaseLayerException& e) {
+    } catch (const DatabaseLayerException& e) {
         ::wxMessageBox(e.GetErrorMessage(), "Database Explorer", wxOK | wxCENTER | wxICON_ERROR);
     }
 }
@@ -378,7 +377,7 @@ void DbViewerPanel::OnPopupClick(wxCommandEvent& evt)
                 Database* pDb = (Database*)wxDynamicCast(data->GetData(), Database);
                 if(pDb) {
                     pDb = (Database*)pDb->Clone();
-                    // NOTE: the refresh functions must be here for propper code generation (they translate views into
+                    // NOTE: the refresh functions must be here for proper code generation (they translate views into
                     // tables)
                     pDb->RefreshChildren(true);
                     pDb->RefreshChildrenDetails();
@@ -567,11 +566,11 @@ void DbViewerPanel::OnPopupClick(wxCommandEvent& evt)
         } else {
             evt.Skip();
         }
-    } catch(DatabaseLayerException& e) {
+    } catch (const DatabaseLayerException& e) {
         wxString errorMessage = wxString::Format(_("Error (%d): %s"), e.GetErrorCode(), e.GetErrorMessage().c_str());
         wxMessageDialog dlg(this, errorMessage, _("DB Error"), wxOK | wxCENTER | wxICON_ERROR);
         dlg.ShowModal();
-    } catch(...) {
+    } catch (...) {
         wxMessageDialog dlg(this, _("Unknown error."), _("DB Error"), wxOK | wxCENTER | wxICON_ERROR);
         dlg.ShowModal();
     }
@@ -614,7 +613,7 @@ bool DbViewerPanel::ImportDb(const wxString& sqlFile, Database* pDb)
         }
         pDbLayer->Commit();
         pDbLayer->Close();
-    } catch(DatabaseLayerException& e) {
+    } catch (const DatabaseLayerException& e) {
         if(pDbLayer) {
             pDbLayer->RollBack();
             pDbLayer->Close();
@@ -625,7 +624,7 @@ bool DbViewerPanel::ImportDb(const wxString& sqlFile, Database* pDb)
         dialog.AppendComment(errorMessage);
         wxMessageDialog dlg(this, errorMessage, _("DB Error"), wxOK | wxCENTER | wxICON_ERROR);
         dlg.ShowModal();
-    } catch(...) {
+    } catch (...) {
         if(pDbLayer) {
             pDbLayer->RollBack();
             pDbLayer->Close();
@@ -792,10 +791,10 @@ void DbViewerPanel::OpenSQLiteFile(const wxFileName& fileName, bool openDefaultS
             CallAfter(&DbViewerPanel::AddEditorPage, sqlpage, fileName.GetFullPath());
         }
 
-    } catch(DatabaseLayerException& e) {
+    } catch (const DatabaseLayerException& e) {
         wxString errorMessage = wxString::Format(_("Error (%d): %s"), e.GetErrorCode(), e.GetErrorMessage().c_str());
         ::wxMessageBox(errorMessage, "CodeLite", wxICON_ERROR | wxCENTER | wxOK, EventNotifier::Get()->TopFrame());
-    } catch(...) {
+    } catch (...) {
         ::wxMessageBox(_("Unknown error."), "CodeLite", wxICON_ERROR | wxCENTER | wxOK,
                        EventNotifier::Get()->TopFrame());
     }
