@@ -24,6 +24,8 @@
 //////////////////////////////////////////////////////////////////////////////
 
 #include "PostgreSqlDbAdapter.h"
+
+#include "StdToWX.h"
 #include "constraint.h"
 #include "database.h"
 #include "dbconnection.h"
@@ -60,19 +62,19 @@ void PostgreSqlDbAdapter::CloseConnection()
 
 DatabaseLayerPtr PostgreSqlDbAdapter::GetDatabaseLayer(const wxString& dbName)
 {
-    DatabaseLayer* dbLayer = NULL;
+    DatabaseLayerPtr dbLayer;
 
 #ifdef DBL_USE_POSTGRES
     if(!CanConnect())
-        return new PostgresDatabaseLayer();
+        return std::make_shared<PostgresDatabaseLayer>();
     if(m_port == 0)
         m_port = 5432;
     if(!dbName.IsEmpty())
-        dbLayer =
-            new PostgresDatabaseLayer(this->m_serverName, this->m_port, dbName, this->m_userName, this->m_password);
+        dbLayer = std::make_shared<PostgresDatabaseLayer>(this->m_serverName, this->m_port, dbName, this->m_userName,
+                                                          this->m_password);
     else
-        dbLayer = new PostgresDatabaseLayer(this->m_serverName, this->m_port, this->m_defaultDb, this->m_userName,
-                                            this->m_password);
+        dbLayer = std::make_shared<PostgresDatabaseLayer>(this->m_serverName, this->m_port, this->m_defaultDb,
+                                                          this->m_userName, this->m_password);
 #endif
     this->m_pDbLayer = dbLayer;
 
@@ -251,69 +253,42 @@ IDbType* PostgreSqlDbAdapter::GetDbTypeByName(const wxString& typeName)
 
 wxArrayString* PostgreSqlDbAdapter::GetDbTypes()
 {
-    wxArrayString* pNames = new wxArrayString();
+    return new wxArrayString(StdToWX::ToArrayString(
+        { wxT("SMALLINT"), wxT("INTEGER"), wxT("BIGINT"), wxT("DECIMAL"), wxT("NUMERIC"), wxT("REAL"),
+          wxT("DOUBLE PRECISION"), wxT("SERIAL"), wxT("BIGSERIAL"),
 
-    pNames->Add(wxT("SMALLINT"));
-    pNames->Add(wxT("INTEGER"));
-    pNames->Add(wxT("BIGINT"));
-    pNames->Add(wxT("DECIMAL"));
-    pNames->Add(wxT("NUMERIC"));
-    pNames->Add(wxT("REAL"));
-    pNames->Add(wxT("DOUBLE PRECISION"));
-    pNames->Add(wxT("SERIAL"));
-    pNames->Add(wxT("BIGSERIAL"));
+          // Monetary types
+          wxT("CHARACTER VARYING"),
 
-    // Monetary types
-    pNames->Add(wxT("CHARACTER VARYING"));
-    // Character types
-    pNames->Add(wxT("VARCHAR"));
-    pNames->Add(wxT("CHARACTER"));
-    pNames->Add(wxT("CHAR"));
-    pNames->Add(wxT("TEXT"));
+          // Character types
+          wxT("VARCHAR"), wxT("CHARACTER"), wxT("CHAR"), wxT("TEXT"),
 
-    // Binary types
-    pNames->Add(wxT("BYTEA"));
+          // Binary types
+          wxT("BYTEA"),
 
-    // Date/Time types
-    pNames->Add(wxT("TIMESTAMP"));
-    pNames->Add(wxT("DATE"));
-    pNames->Add(wxT("TIME"));
-    pNames->Add(wxT("INTERVAL"));
+          // Date/Time types
+          wxT("TIMESTAMP"), wxT("DATE"), wxT("TIME"), wxT("INTERVAL"),
 
-    // Boolean types
-    pNames->Add(wxT("BOOLEAN"));
+          // Boolean types
+          wxT("BOOLEAN"),
 
-    // Geometric types
-    pNames->Add(wxT("POINT"));
-    pNames->Add(wxT("LINE"));
-    pNames->Add(wxT("LSEG"));
-    pNames->Add(wxT("BOX"));
-    pNames->Add(wxT("PATH"));
-    pNames->Add(wxT("POLYGON"));
-    pNames->Add(wxT("CIRCLE"));
+          // Geometric types
+          wxT("POINT"), wxT("LINE"), wxT("LSEG"), wxT("BOX"), wxT("PATH"), wxT("POLYGON"), wxT("CIRCLE"),
 
-    // Network address types
-    pNames->Add(wxT("CIDR"));
-    pNames->Add(wxT("INET"));
-    pNames->Add(wxT("MACADDR"));
+          // Network address types
+          wxT("CIDR"), wxT("INET"), wxT("MACADDR"),
 
-    // Bit String types
-    pNames->Add(wxT("BIT"));
-    pNames->Add(wxT("BIT VARYING"));
+          // Bit String types
+          wxT("BIT"), wxT("BIT VARYING"),
 
-    // UUID type
-    pNames->Add(wxT("UUID"));
+          // UUID type
+          wxT("UUID"),
 
-    // XML type
-    pNames->Add(wxT("XML"));
+          // XML type
+          wxT("XML"),
 
-    // OTHER TYPES
-    pNames->Add(wxT("OID"));
-    pNames->Add(wxT("XID"));
-    pNames->Add(wxT("ARRAY"));
-    pNames->Add(wxT("REGPROX"));
-
-    return pNames;
+          // OTHER TYPES
+          wxT("OID"), wxT("XID"), wxT("ARRAY"), wxT("REGPROX") }));
 }
 wxString PostgreSqlDbAdapter::GetDefaultSelect(const wxString& dbName, const wxString& tableName)
 {
@@ -439,12 +414,12 @@ void PostgreSqlDbAdapter::GetDatabases(DbConnection* dbCon)
 
             // loading databases
             // TODO:SQL:
-            DatabaseResultSet* databaze =
+            DatabaseResultSet* database =
                 dbLayer->RunQueryWithResults(wxT("SELECT datname FROM pg_database WHERE datallowconn = 't' "));
-            while(databaze->Next()) {
-                dbCon->AddChild(new Database(this, databaze->GetResultString(1)));
+            while(database->Next()) {
+                dbCon->AddChild(new Database(this, database->GetResultString(1)));
             }
-            dbLayer->CloseResultSet(databaze);
+            dbLayer->CloseResultSet(database);
             dbLayer->Close();
         }
     }
@@ -459,7 +434,7 @@ void PostgreSqlDbAdapter::GetTables(Database* db, bool includeViews)
         if(dbLayer) {
             if(!dbLayer->IsOpen())
                 return;
-            // lading tables for database
+            // loading tables for database
             // TODO:SQL:
 
             // DatabaseResultSet *tabulky = dbLayer->RunQueryWithResults(wxString::Format(wxT("SHOW TABLES IN `%s`"),
@@ -563,7 +538,7 @@ void PostgreSqlDbAdapter::GetViews(Database* db)
         if(dbLayer) {
             if(!dbLayer->IsOpen())
                 return;
-            // lading tables for database
+            // loading tables for database
             // TODO:SQL:
 
             // DatabaseResultSet *tabulky = dbLayer->RunQueryWithResults(wxString::Format(wxT("SHOW TABLES IN `%s`"),
