@@ -26,8 +26,8 @@
 #include "SqlCommandPanel.h"
 
 #include "DbViewerPanel.h"
+#include "Keyboard/clKeyboardManager.h"
 #include "bitmap_loader.h"
-#include "clKeyboardManager.h"
 #include "clStatusBarMessage.h"
 #include "cl_aui_tool_stickness.h"
 #include "cl_defs.h"
@@ -91,7 +91,7 @@ SQLCommandPanel::SQLCommandPanel(wxWindow* parent, IDbAdapter* dbAdapter, const
     m_dbName = dbName;
     m_dbTable = dbTable;
 
-    m_editHelper.Reset(new clEditEventsHandler(m_scintillaSQL));
+    m_editHelper = std::make_unique<clEditEventsHandler>(m_scintillaSQL);
     m_scintillaSQL->AddText(wxString::Format(_(" -- selected database %s\n"), m_dbName.c_str()));
     if(!dbTable.IsEmpty()) {
         m_scintillaSQL->AddText(m_pDbAdapter->GetDefaultSelect(m_dbName, m_dbTable));
@@ -256,7 +256,7 @@ void SQLCommandPanel::ExecuteSql()
                 GetSizer()->Layout();
                 Layout();
 
-            } catch(DatabaseLayerException& e) {
+            } catch (const DatabaseLayerException& e) {
                 // for some reason an exception is thrown even if the error code is 0...
                 if(e.GetErrorCode() != 0) {
                     wxString errorMessage =
@@ -265,7 +265,7 @@ void SQLCommandPanel::ExecuteSql()
                     dlg.ShowModal();
                 }
 
-            } catch(...) {
+            } catch (...) {
                 wxMessageDialog dlg(this, _("Unknown error."), _("DB Error"), wxOK | wxCENTER | wxICON_ERROR);
                 dlg.ShowModal();
             }
@@ -307,7 +307,6 @@ void SQLCommandPanel::OnSaveClick(wxCommandEvent& event)
     }
 }
 
-void SQLCommandPanel::OnTeplatesLeftDown(wxMouseEvent& event) {}
 void SQLCommandPanel::OnTemplatesBtnClick(wxAuiToolBarEvent& event)
 {
     wxMenu menu;
