@@ -32,6 +32,7 @@
 #include "clToolBar.h"
 
 #include <map>
+#include <wx/aui/auibar.h>
 #include <wx/dblayer/include/DatabaseErrorCodes.h>
 #include <wx/dblayer/include/DatabaseLayer.h>
 #include <wx/dblayer/include/DatabaseLayerException.h>
@@ -97,7 +98,6 @@ public:
 
     virtual void OnLoadClick(wxCommandEvent& event);
     virtual void OnSaveClick(wxCommandEvent& event);
-    virtual void OnTeplatesLeftDown(wxMouseEvent& event);
     virtual void OnTemplatesBtnClick(wxAuiToolBarEvent& event);
 
     void OnPopupClick(wxCommandEvent& evt);
