@@ -24,25 +24,24 @@
 //////////////////////////////////////////////////////////////////////////////
 #include "dbgcmd.h"
 
+#include "Debugger/debuggermanager.h"
 #include "clFileName.hpp"
 #include "cl_command_event.h"
 #include "codelite_events.h"
 #include "debuggergdb.h"
-#include "debuggermanager.h"
 #include "event_notifier.h"
 #include "gdb_parser_incl.h"
-#include "gdb_result_parser.h"
 #include "gdbmi.hpp"
 #include "gdbmi_parse_thread_info.h"
 #include "precompiled_header.h"
 #include "procutils.h"
-#include "wx/buffer.h"
-#include "wx/tokenzr.h"
 
 #include <algorithm>
 #include <sstream>
 #include <unordered_map>
+#include <wx/buffer.h>
 #include <wx/regex.h>
+#include <wx/tokenzr.h>
 
 static bool IS_WINDOWNS = (wxGetOsVersion() & wxOS_WINDOWS);
 
@@ -112,12 +111,12 @@ template <typename T> wxString get_file_name(const T& node)
     wxString file_name;
     if(!node["fullname"].value.empty()) {
         file_name = node["fullname"].value;
-    } else if (!node["pending"].value.empty()) {
+    } else if(!node["pending"].value.empty()) {
         file_name = node["pending"].value;
-        if (file_name.AfterLast(':').IsNumber()) {
+        if(file_name.AfterLast(':').IsNumber()) {
             file_name = file_name.BeforeLast(':');
         }
-    } 
+    }
     // in case file is using cygwin path -> change it to Windows style
     file_name = clFileName::FromCygwin(file_name);
     return file_name;
