@@ -24,7 +24,8 @@
 //////////////////////////////////////////////////////////////////////////////
 #include "debuggergdb.h"
 
-#include "asyncprocess.h"
+#include "AsyncProcess/asyncprocess.h"
+#include "AsyncProcess/processreaderthread.h"
 #include "clFileName.hpp"
 #include "cl_command_event.h"
 #include "codelite_events.h"
@@ -37,9 +38,8 @@
 #include "file_logger.h"
 #include "fileutils.h"
 #include "globals.h"
-#include "processreaderthread.h"
 #include "procutils.h"
-#include "ssh_account_info.h"
+#include "ssh/ssh_account_info.h"
 
 #include <algorithm>
 #include <wx/ffile.h>
@@ -53,7 +53,7 @@
 
 // On Windows lower than XP, the function DebugBreakProcess does not exist
 // so we need to bind it dynamically
-typedef BOOL WINAPI (*DBG_BREAK_PROC_FUNC_PTR)(HANDLE);
+typedef BOOL(WINAPI* DBG_BREAK_PROC_FUNC_PTR)(HANDLE);
 DBG_BREAK_PROC_FUNC_PTR DebugBreakProcessFunc = NULL;
 HINSTANCE Kernel32Dll = NULL;
 
@@ -1129,12 +1129,12 @@ bool DbgGdb::DoLocateGdbExecutable(const wxString& debuggerPath, wxString& dbgEx
     gdbinit_file_content.Trim().Trim(false);
 
     // Write the content into a file
-    wxFileName gdbInitFile(wxFileName::GetHomeDir(), ".gdbinit");
+    wxFileName userGdbInitFile(wxFileName::GetHomeDir(), ".gdbinit");
     wxFileName clGdbInitFile(wxFileName::GetHomeDir(), ".codelite-gdbinit");
 
     // Read the content of the user's file
     wxString fileContent;
-    FileUtils::ReadFileContent(gdbInitFile, fileContent);
+    FileUtils::ReadFileContent(userGdbInitFile, fileContent);
     if(!fileContent.IsEmpty() && !fileContent.EndsWith("\n")) {
         fileContent << "\n";
     }
