@@ -1,23 +1,20 @@
+#include "docker.h"
+
 #include "DockerOutputPane.h"
 #include "DockerSettingsDlg.h"
 #include "bitmap_loader.h"
 #include "clDockerWorkspace.h"
 #include "clWorkspaceManager.h"
-#include "docker.h"
 #include "event_notifier.h"
+#include "imanager.h"
 #include "wxterminal.h"
-#include <imanager.h>
-#include <wx/xrc/xmlres.h>
 
-static Docker* thePlugin = NULL;
+#include <wx/xrc/xmlres.h>
 
 // Define the plugin entry point
 CL_PLUGIN_API IPlugin* CreatePlugin(IManager* manager)
 {
-    if(thePlugin == NULL) {
-        thePlugin = new Docker(manager);
-    }
-    return thePlugin;
+    return new Docker(manager);
 }
 
 CL_PLUGIN_API PluginInfo* GetPluginInfo()
@@ -43,13 +40,9 @@ Docker::Docker(IManager* manager)
     clDockerWorkspace::Initialise(this);
     clDockerWorkspace::Get(); // Make sure that the workspace instance is up and all events are hooked
 
-    Notebook* book = m_mgr->GetOutputPaneNotebook();
-    auto images = book->GetBitmaps();
-    m_outputView = new DockerOutputPane(book, m_driver);
-    book->AddPage(m_outputView, _("Docker"), false, images->Add("docker"));
-
+    m_outputView = new DockerOutputPane(m_mgr->BookGet(PaneId::BOTTOM_BAR), m_driver);
+    m_mgr->BookAddPage(PaneId::BOTTOM_BAR, m_outputView, _("Docker"));
     m_tabToggler.reset(new clTabTogglerHelper(_("Docker"), m_outputView, "", NULL));
-    m_tabToggler->SetOutputTabBmp(images->Add("docker"));
 }
 
 Docker::~Docker() {}
@@ -77,13 +70,9 @@ void Docker::CreatePluginMenu(wxMenu* pluginsMenu)
 void Docker::UnPlug()
 {
     clDockerWorkspace::Shutdown();
-
-    // before this plugin is un-plugged we must remove the tab we added
-    for(size_t i = 0; i < m_mgr->GetOutputPaneNotebook()->GetPageCount(); i++) {
-        if(m_outputView == m_mgr->GetOutputPaneNotebook()->GetPage(i)) {
-            m_mgr->GetOutputPaneNotebook()->RemovePage(i);
-            m_outputView->Destroy();
-            break;
-        }
+    if(!m_mgr->BookDeletePage(PaneId::BOTTOM_BAR, m_outputView)) {
+        // failed to delete, delete it manually
+        m_outputView->Destroy();
     }
+    m_outputView = nullptr;
 }
