@@ -1,5 +1,7 @@
 #include "ExternalToolsProcessManager.h"
-#include "asyncprocess.h"
+
+#include "AsyncProcess/asyncprocess.h"
+#include "AsyncProcess/processreaderthread.h"
 #include "dirsaver.h"
 #include "environmentconfig.h"
 #include "event_notifier.h"
@@ -7,7 +9,7 @@
 #include "globals.h"
 #include "imanager.h"
 #include "macromanager.h"
-#include "processreaderthread.h"
+
 #include <algorithm>
 #include <wx/msgdlg.h>
 #include <wx/process.h>
@@ -23,12 +25,8 @@
 class ExtToolsMyProcess : public wxProcess
 {
 public:
-    ExtToolsMyProcess()
-    {
-    }
-    virtual ~ExtToolsMyProcess()
-    {
-    }
+    ExtToolsMyProcess() {}
+    virtual ~ExtToolsMyProcess() {}
     void OnTerminate(int pid, int status)
     {
         ToolsTaskManager::Instance()->ProcessTerminated(pid);
