@@ -24,15 +24,15 @@
 //////////////////////////////////////////////////////////////////////////////
 #include "gizmos.h"
 
+#include "FileSystemWorkspace/clFileSystemWorkspace.hpp"
 #include "PluginWizard.h"
-#include "clFileSystemWorkspace.hpp"
 #include "cl_command_event.h"
 #include "cl_standard_paths.h"
 #include "codelite_events.h"
 #include "ctags_manager.h"
+#include "database/entry.h"
 #include "dirsaver.h"
 #include "editor_config.h"
-#include "entry.h"
 #include "event_notifier.h"
 #include "file_logger.h"
 #include "fileutils.h"
@@ -55,15 +55,10 @@ static wxString MI_NEW_NEW_CLASS = "Create new C++ class...";
 
 enum { ID_MI_NEW_WX_PROJECT = 9000, ID_MI_NEW_CODELITE_PLUGIN, ID_MI_NEW_NEW_CLASS };
 
-static WizardsPlugin* theGismos = NULL;
-
 // Define the plugin entry point
 CL_PLUGIN_API IPlugin* CreatePlugin(IManager* manager)
 {
-    if(theGismos == 0) {
-        theGismos = new WizardsPlugin(manager);
-    }
-    return theGismos;
+    return new WizardsPlugin(manager);
 }
 
 CL_PLUGIN_API PluginInfo* GetPluginInfo()
@@ -79,14 +74,6 @@ CL_PLUGIN_API PluginInfo* GetPluginInfo()
 
 CL_PLUGIN_API int GetPluginInterfaceVersion() { return PLUGIN_INTERFACE_VERSION; }
 
-/// Ascending sorting function
-struct ascendingSortOp {
-    bool operator()(const TagEntryPtr& rStart, const TagEntryPtr& rEnd)
-    {
-        return rEnd->GetName().Cmp(rStart->GetName()) > 0;
-    }
-};
-
 static void WriteNamespacesDeclaration(const wxArrayString& namespacesList, wxString& buffer)
 {
     for(unsigned int i = 0; i < namespacesList.Count(); i++) {
@@ -247,7 +234,7 @@ void WizardsPlugin::DoCreateNewPlugin()
         content.Replace("$(BaseFileName)", baseFileName);
         content.Replace("$(PluginShortName)", data.GetPluginName());
         content.Replace("$(PluginLongName)", data.GetPluginDescription());
-        content.Replace("$(UserName)", wxGetUserName().c_str());
+        content.Replace("$(UserName)", wxGetUserId().c_str());
 
         // Notify the formatter plugin to format the plugin source files
         clSourceFormatEvent evtFormat(wxEVT_FORMAT_STRING);
@@ -274,7 +261,7 @@ void WizardsPlugin::DoCreateNewPlugin()
         content.Replace("$(BaseFileName)", baseFileName);
         content.Replace("$(PluginShortName)", data.GetPluginName());
         content.Replace("$(PluginLongName)", data.GetPluginDescription());
-        content.Replace("$(UserName)", wxGetUserName().c_str());
+        content.Replace("$(UserName)", wxGetUserId().c_str());
 
         // format the content
         evtFormat.SetString(content);
@@ -566,37 +553,6 @@ void WizardsPlugin::OnGizmosUI(wxUpdateUIEvent& e)
     e.Enable(m_mgr->IsWorkspaceOpen());
 }
 
-void WizardsPlugin::GizmosRemoveDuplicates(std::vector<TagEntryPtr>& src, std::vector<TagEntryPtr>& target)
-{
-    std::map<wxString, TagEntryPtr> uniqueSet;
-    for(size_t i = 0; i < src.size(); i++) {
-
-        wxString signature = src.at(i)->GetSignature();
-        wxString key = m_mgr->GetTagsManager()->NormalizeFunctionSig(signature, 0);
-        int hasDefaultValues = signature.Find("=");
-
-        key.Prepend(src.at(i)->GetName());
-        if(uniqueSet.find(key) != uniqueSet.end()) {
-            // we already got an instance of this method,
-            // incase we have default values in the this Tag, keep this
-            // TagEntryPtr, otherwise keep the previous tag
-            if(hasDefaultValues != wxNOT_FOUND) {
-                uniqueSet[key] = src.at(i);
-            }
-
-        } else {
-            // First time
-            uniqueSet[key] = src.at(i);
-        }
-    }
-
-    // copy the unique set to the output vector
-    std::map<wxString, TagEntryPtr>::iterator iter = uniqueSet.begin();
-    for(; iter != uniqueSet.end(); iter++) {
-        target.push_back(iter->second);
-    }
-}
-
 void WizardsPlugin::DoPopupButtonMenu(wxPoint pt)
 {
 #ifdef __WXMSW__
@@ -644,25 +600,3 @@ void WizardsPlugin::OnFolderContentMenu(clContextMenuEvent& event)
         menu->Append(ID_MI_NEW_NEW_CLASS, _("New C++ Class"));
     }
 }
-
-bool WizardsPlugin::BulkRead(std::vector<std::pair<wxString, wxString*>>& files, const wxString& path_prefix) const
-{
-    for(size_t i = 0; i < files.size(); ++i) {
-        if(!FileUtils::ReadFileContent(path_prefix + files[i].first, *files[i].second)) {
-            return false;
-        }
-    }
-    return true;
-}
-
-bool WizardsPlugin::BulkWrite(const std::vector<std::pair<wxString, wxString>>& files,
-                              const wxString& path_prefix) const
-{
-
-    for(size_t i = 0; i < files.size(); ++i) {
-        if(!FileUtils::WriteFileContent(path_prefix + files[i].first, files[i].second)) {
-            return false;
-        }
-    }
-    return true;
-}
