@@ -24,9 +24,10 @@
 //////////////////////////////////////////////////////////////////////////////
 
 #include "newclassdlg.h"
+
+#include "FileSystemWorkspace/clFileSystemWorkspace.hpp"
+#include "FileSystemWorkspace/clFileSystemWorkspaceView.hpp"
 #include "VirtualDirectorySelectorDlg.h"
-#include "clFileSystemWorkspace.hpp"
-#include "clFileSystemWorkspaceView.hpp"
 #include "editor_config.h"
 #include "globals.h"
 #include "imanager.h"
@@ -34,12 +35,13 @@
 #include "open_resource_dialog.h"
 #include "windowattrmanager.h"
 #include "workspace.h"
-#include "wx/dir.h"
-#include "wx/xrc/xmlres.h"
+
+#include <wx/dir.h>
 #include <wx/dirdlg.h>
 #include <wx/filename.h>
 #include <wx/msgdlg.h>
 #include <wx/tokenzr.h>
+#include <wx/xrc/xmlres.h>
 
 NewClassDlg::NewClassDlg(wxWindow* parent, IManager* mgr)
     : NewClassBaseDlg(parent)
@@ -101,7 +103,9 @@ NewClassDlg::NewClassDlg(wxWindow* parent, IManager* mgr)
         m_buttonSelectVD->Disable();
         m_staticTextVD->Disable();
     }
-    ::clSetSmallDialogBestSizeAndPosition(this);
+
+    GetSizer()->Fit(this);
+    CentreOnParent();
 }
 
 NewClassDlg::~NewClassDlg() { DoSaveOptions(); }
@@ -126,7 +130,7 @@ void NewClassDlg::OnButtonOK(wxCommandEvent& e)
 bool NewClassDlg::ValidateInput()
 {
     // validate the class name
-    if(!IsValidCppIndetifier(m_textClassName->GetValue())) {
+    if(!IsValidCppIdentifier(m_textClassName->GetValue())) {
         wxString msg;
         msg << wxT("'") << m_textClassName->GetValue() << _("' is not a valid C++ qualifier");
         wxMessageBox(msg, _("CodeLite"), wxOK | wxICON_WARNING);
@@ -139,7 +143,7 @@ bool NewClassDlg::ValidateInput()
         this->GetNamespacesList(namespacesList);
         // validate each namespace
         for(unsigned int i = 0; i < namespacesList.Count(); i++) {
-            if(!IsValidCppIndetifier(namespacesList[i])) {
+            if(!IsValidCppIdentifier(namespacesList[i])) {
                 wxString msg;
                 msg << wxT("'") << namespacesList[i] << _("' is not a valid C++ qualifier");
                 wxMessageBox(msg, _("CodeLite"), wxOK | wxICON_WARNING);
@@ -200,7 +204,7 @@ void NewClassDlg::GetNewClassInfo(NewClassInfo& info) const
     info.isAssignable = this->IsCopyableClass();
     info.isMovable = this->IsMovableClass();
     info.isInheritable = this->IsInheritable();
-    info.fileName = wxFileName(GetClassFile()).GetName(); // Ommit any suffix the user might have typed in
+    info.fileName = wxFileName(GetClassFile()).GetName(); // Omit any suffix the user might have typed in
     info.isVirtualDtor = m_checkBoxVirtualDtor->IsChecked();
     info.usePragmaOnce = m_checkBoxPragmaOnce->IsChecked();
     info.virtualDirectory = m_textCtrlVD->GetValue().Trim().Trim(false);
@@ -264,9 +268,6 @@ void NewClassDlg::OnBrowseNamespace(wxCommandEvent& e)
 {
     wxUnusedVar(e);
 
-    wxArrayString kinds;
-    kinds.Add(wxT("namespace"));
-
     OpenResourceDialog dlg(this, m_mgr, "");
     if(dlg.ShowModal() == wxID_OK) {
         std::vector<OpenResourceDialogItemData*> selections = dlg.GetSelections();
@@ -383,7 +384,7 @@ void NewClassDlg::OnBlockGuardUI(wxUpdateUIEvent& event) { event.Enable(!m_check
 void NewClassDlg::DoSaveOptions()
 {
     // Save the check boxes ticked
-    size_t flags(0);
+    size_t flags = 0;
 
     if(m_checkBoxNonCopyable->IsChecked())
         flags |= NewClassDlgData::NonCopyable;
@@ -426,10 +427,6 @@ void NewClassDlg::OnBrowseParentClass(wxCommandEvent& event)
 {
     wxUnusedVar(event);
 
-    wxArrayString kinds;
-    kinds.Add(wxT("class"));
-    kinds.Add(wxT("struct"));
-
     OpenResourceDialog dlg(this, m_mgr, "");
     if(dlg.ShowModal() == wxID_OK) {
         std::vector<OpenResourceDialogItemData*> selections = dlg.GetSelections();
