@@ -26,11 +26,11 @@
 #ifndef IMANAGER_H
 #define IMANAGER_H
 
-#include "Notebook.h"
 #include "bitmap_loader.h"
 #include "clStatusBar.h"
 #include "clTab.h"
 #include "clToolBar.h"
+#include "cl_defs.h"
 #include "debugger.h"
 #include "iconfigtool.h"
 #include "ieditor.h"
@@ -38,9 +38,9 @@
 #include "optionsconfig.h"
 #include "project.h"
 #include "queuecommand.h"
-#include "wx/treectrl.h"
 
 #include <vector>
+#include <wx/aui/auibook.h>
 #include <wx/aui/framemanager.h>
 
 class clTreeCtrl;
@@ -56,6 +56,18 @@ class BuildSettingsConfig;
 class NavMgr;
 class IMacroManager;
 class wxAuiManager;
+class clInfoBar;
+class clGenericNotebook;
+class clAuiBook;
+class clNativeNotebook;
+
+#if MAINBOOK_AUIBOOK
+using MainNotebook = clAuiBook;
+#elif CL_USE_NATIVEBOOK
+using MainNotebook = clNativeNotebook;
+#else
+using MainNotebook = clGenericNotebook;
+#endif
 
 //--------------------------
 // Auxulary class
@@ -80,6 +92,13 @@ enum eOutputPaneTab { kOutputTab_Build, kOutputTab_Output };
 
 enum OF_extra { OF_None = 0x00000001, OF_AddJump = 0x00000002, OF_PlaceNextToCurrent = 0x00000004 };
 
+enum class PaneId {
+    BOTTOM_BAR,
+    SIDE_BAR,
+    DEBUG_BAR,
+    SECONDARY_SIDE_BAR,
+};
+
 //------------------------------------------------------------------
 // Defines the interface of the manager
 //------------------------------------------------------------------
@@ -115,7 +134,7 @@ public:
      */
     void AddWorkspaceTab(const wxString& tabLabel)
     {
-        if(m_workspaceTabs.Index(tabLabel) == wxNOT_FOUND) {
+        if (m_workspaceTabs.Index(tabLabel) == wxNOT_FOUND) {
             m_workspaceTabs.Add(tabLabel);
         }
     }
@@ -125,7 +144,7 @@ public:
      */
     void AddOutputTab(const wxString& tabLabel)
     {
-        if(m_outputTabs.Index(tabLabel) == wxNOT_FOUND) {
+        if (m_outputTabs.Index(tabLabel) == wxNOT_FOUND) {
             m_outputTabs.Add(tabLabel);
         }
     }
@@ -143,6 +162,37 @@ public:
      */
     virtual void ShowOutputPane(const wxString& selectWindow = "") = 0;
 
+    /**
+     * @brief toggle the sidebar pane and if provided, select 'selectedWindow'
+     * @param selectWindow tab within the 'Workspace Pane' to select, if empty don't change
+     * the selection
+     */
+    virtual void ToggleSidebarPane(const wxString& selectWindow = "") = 0;
+
+    /**
+     * @brief locate the management window `selectedWindow` and make it visible (or hide it)
+     * This function does not care where the `selectedWindow` is located
+     */
+    virtual void ShowManagementWindow(const wxString& selectedWindow, bool show) = 0;
+
+    /**
+     * @brief toggle the secondary pane and if provided, select 'selectedWindow'
+     * @param selectWindow tab within the 'Workspace Pane' to select, if empty don't change
+     * the selection
+     */
+    virtual void ToggleSecondarySidebarPane(const wxString& selectWindow = "") = 0;
+
+    /// Show / Hide pane
+    /// Possible `pane_names` are:
+    /// - "Workspace View"
+    /// - "Secondary Sidebar"
+    /// - "Output View"
+    virtual void ShowPane(const wxString& pane_name, bool show) = 0;
+
+    /// Return true if `pane_name` is shown. If `tab` is not empty, also check that it is the
+    /// selected tab
+    virtual bool IsPaneShown(const wxString& pane_name, const wxString& tab = wxEmptyString) = 0;
+
     /**
      * @brief show the toolbar. This only works when using the native toolbar
      */
@@ -167,6 +217,16 @@ public:
      */
     virtual IEditor* GetActiveEditor() = 0;
 
+    /**
+     * @brief find `editor` and select it
+     */
+    virtual bool SelectEditor(IEditor* editor) = 0;
+
+    /**
+     * @brief Convert `win` into `IEditor`. If the conversion fails, return `nullptr`
+     */
+    virtual IEditor* GetEditorFromWindow(wxWindow* win) = 0;
+
     /**
      * @brief return the main frame's status bar
      */
@@ -185,14 +245,24 @@ public:
      * @param lineno if lineno is not wxNOT_FOUD, the caret will placed on this line number
      * @return Pointer to the newly opened editor or nullptr
      */
-    virtual IEditor* OpenFile(const wxString& fileName, const wxString& projectName = wxEmptyString,
-                              int lineno = wxNOT_FOUND, OF_extra flags = OF_AddJump) = 0;
+    virtual IEditor* OpenFile(const wxString& fileName,
+                              const wxString& projectName = wxEmptyString,
+                              int lineno = wxNOT_FOUND,
+                              OF_extra flags = OF_AddJump) = 0;
 
     /**
      * @brief open a file with a given tooltip and bitmap
      */
-    virtual IEditor* OpenFile(const wxString& fileName, const wxString& bmpResourceName,
-                              const wxString& tooltip = wxEmptyString) = 0;
+    virtual IEditor*
+    OpenFile(const wxString& fileName, const wxString& bmpResourceName, const wxString& tooltip = wxEmptyString) = 0;
+
+    /**
+     * @brief load a remote file content (represented by the local_path) into an `IEdtor`
+     */
+    virtual IEditor* OpenRemoteFile(const wxString& local_path,
+                                    const wxString& remote_path,
+                                    const wxString& ssh_account,
+                                    const wxString& tooltip = wxEmptyString) = 0;
 
     /**
      * @brief open or select ((if the file is already loaded in CodeLite) editor with a given `file_name` to the
@@ -232,29 +302,15 @@ public:
     virtual clTreeCtrl* GetFileExplorerTree() = 0;
     virtual clTreeCtrl* GetWorkspaceTree() = 0;
 
-    /**
-     * @brief return a pointer to the workspace pane notebook (the one with the 'workspace' title)
-     * @return pointer to Notebook
-     * @sa Notebook
-     */
-    virtual Notebook* GetWorkspacePaneNotebook() = 0;
-
-    /**
-     * @brief return a pointer to the output pane notebook (the one with the 'output' title)
-     * @return pointer to Notebook
-     * @sa Notebook
-     */
-    virtual Notebook* GetOutputPaneNotebook() = 0;
-
     /**
      * @brief return the main editor notebook
      */
-    virtual Notebook* GetMainNotebook() = 0;
+    virtual MainNotebook* GetMainNotebook() = 0;
 
     /**
      * @brief append text line to the tab in the "Output View"
      */
-    virtual void AppendOutputTabText(eOutputPaneTab tab, const wxString& text) = 0;
+    virtual void AppendOutputTabText(eOutputPaneTab tab, const wxString& text, bool toggle_view = true) = 0;
 
     /**
      * @brief clear the content of the selected output tab
@@ -310,7 +366,7 @@ public:
      * @brief add files to a virtual folder in the project
      * @param item a tree item which represents the tree item of the virtual folder
      * @param paths an array of files to add
-     * @return true on sucesss, false otherwise
+     * @return true on success, false otherwise
      */
     virtual bool AddFilesToVirtualFolder(wxTreeItemId& item, wxArrayString& paths) = 0;
 
@@ -318,7 +374,7 @@ public:
      * @brief add files to a virtual folder in the project
      * @param vdFullPath virtual directory full path in the form of <project>:vd1:vd2:...:vdN
      * @param paths an array of files to add
-     * @return true on sucesss, false otherwise
+     * @return true on success, false otherwise
      */
     virtual bool AddFilesToVirtualFolder(const wxString& vdFullPath, wxArrayString& paths) = 0;
 
@@ -326,7 +382,7 @@ public:
      * @brief Add a pair of cpp/h files to the :src/include folders, if these exist
      * @param vdFullPath virtual directory full path in the form of <project>:vd1:vd2:...:vdN
      * @param paths an array of files to add
-     * @return true on sucesss, false otherwise
+     * @return true on success, false otherwise
      */
     virtual bool AddFilesToVirtualFolderIntelligently(const wxString& vdFullPath, wxArrayString& paths) = 0;
 
@@ -373,7 +429,7 @@ public:
     /**
      * @brief return the project execution command as set in the project's settings
      * @param projectName the project
-     * @param wd starting dirctory
+     * @param wd starting directory
      * @return the execution command or wxEmptyString if the project does not exist
      */
     virtual wxString GetProjectExecutionCommand(const wxString& projectName, wxString& wd) = 0;
@@ -514,8 +570,11 @@ public:
     /**
      * @brief add a page to the mainbook
      */
-    virtual bool AddPage(wxWindow* win, const wxString& text, const wxString& tooltip = wxEmptyString,
-                         const wxString& bmpResourceName = wxEmptyString, bool selected = false) = 0;
+    virtual bool AddPage(wxWindow* win,
+                         const wxString& text,
+                         const wxString& tooltip = wxEmptyString,
+                         const wxString& bmpResourceName = wxEmptyString,
+                         bool selected = false) = 0;
 
     /**
      * @brief select a window in mainbook
@@ -543,11 +602,6 @@ public:
      */
     virtual BitmapLoader* GetStdIcons() = 0;
 
-    /**
-     * @brief return the compilation flags for a file in a given project
-     */
-    virtual wxArrayString GetProjectCompileFlags(const wxString& projectName, bool isCppFile) = 0;
-
     /**
      * @brief return the selected project item. Note that this is different than
      * returning the *active* project. A selected project, is the project that it is
@@ -575,7 +629,7 @@ public:
      * @brief return list of all open editors in the main notebook.
      * This function returns only instances of IEditor (i.e. a file text editor)
      */
-    virtual size_t GetAllEditors(IEditor::List_t& editors, bool inOrder = false) = 0;
+    virtual size_t GetAllEditors(IEditor::List_t& editors) = 0;
 
     /**
      * @brief return list of open tabs in the main notebook. If you need only editors, use GetAllEditors
@@ -660,8 +714,15 @@ public:
     /**
      * @brief display message to the user using the info bar
      */
-    virtual void DisplayMessage(const wxString& message, int flags = wxICON_INFORMATION,
+    virtual void DisplayMessage(const wxString& message,
+                                int flags = wxICON_INFORMATION,
                                 const std::vector<std::pair<wxWindowID, wxString>>& buttons = {}) = 0;
+
+    /**
+     * @brief return the info bar
+     */
+    virtual clInfoBar* GetInfoBar() = 0;
+
     /**
      * @brief return list of all breakpoints
      */
@@ -671,6 +732,41 @@ public:
      * @brief build and display the build menu for a toolbar button
      */
     virtual void ShowBuildMenu(clToolBar* toolbar, wxWindowID buttonId) = 0;
+
+    ///--------------------
+    /// Book management
+    ///--------------------
+
+    /// Add a book page
+    virtual void
+    BookAddPage(PaneId pane_id, wxWindow* page, const wxString& label, const wxString& bmp = wxEmptyString) = 0;
+
+    /// Find a book page by its label
+    virtual wxWindow* BookGetPage(PaneId pane_id, const wxString& label) = 0;
+
+    /// Remove a book page (do not destroy it), return the removed page
+    virtual wxWindow* BookRemovePage(PaneId pane_id, const wxString& label) = 0;
+
+    /// Remove a book page (do not destroy it), return the removed page
+    virtual wxWindow* BookRemovePage(PaneId pane_id, wxWindow* page) = 0;
+
+    /// Delete a book page, return true on success, false otherwise
+    virtual bool BookDeletePage(PaneId pane_id, wxWindow* page) = 0;
+
+    /// Delete a book page, return true on success, false otherwise
+    virtual bool BookDeletePage(PaneId pane_id, const wxString& label) = 0;
+
+    /// Delete a book page, return true on success, false otherwise
+    virtual void BookSelectPage(PaneId pane_id, const wxString& label) = 0;
+
+    /// Delete a book page, return true on success, false otherwise
+    virtual void BookSelectPage(PaneId pane_id, wxWindow* win) = 0;
+
+    /// Get the book control
+    virtual wxWindow* BookGet(PaneId pane_id) = 0;
+
+    /// Return the main panel of the top level frame
+    virtual wxPanel* GetMainPanel() = 0;
 };
 
 #endif // IMANAGER_H
