@@ -3,18 +3,18 @@
 
 #include "CodeLiteRemoteHelper.hpp"
 #include "LSP/LSPEvent.h"
+#include "LSP/LanguageServerProtocol.h"
 #include "LSP/basic_types.h"
 #include "LanguageServerEntry.h"
-#include "LanguageServerProtocol.h"
 #include "clWorkspaceEvent.hpp"
 #include "cl_command_event.h"
-#include "entry.h"
+#include "database/entry.h"
+#include "wxStringHash.h"
 
 #include <unordered_set>
 #include <vector>
 #include <wx/event.h>
 #include <wx/sharedptr.h>
-#include <wxStringHash.h>
 
 class LSPOutlineViewDlg;
 class LanguageServerPlugin;
@@ -49,7 +49,7 @@ public:
     void SetWorkspaceType(FileExtManager::FileType type);
 
     /**
-     * @brief covnert LSP::SignatureHelp class to TagEntryPtrVector_t
+     * @brief convert LSP::SignatureHelp class to TagEntryPtrVector_t
      */
     void LSPSignatureHelpToTagEntries(TagEntryPtrVector_t& tags, const LSP::SignatureHelp& sighelp);
 
@@ -63,6 +63,7 @@ protected:
     void OnLSPInitialized(LSPEvent& event);
     void OnMethodNotFound(LSPEvent& event);
     void OnWorkspaceClosed(clWorkspaceEvent& event);
+    void OnFileSaved(clCommandEvent& event);
     void OnWorkspaceOpen(clWorkspaceEvent& event);
     void OnCompileCommandsGenerated(clCommandEvent& event);
     void OnSetDiagnostics(LSPEvent& event);
@@ -78,6 +79,9 @@ protected:
     void OnEditorClosed(clCommandEvent& event);
     void OnActiveEditorChanged(wxCommandEvent& event);
     void OnWorkspaceScanCompleted(clWorkspaceEvent& event);
+    void OnMarginClicked(clEditorEvent& event);
+    void OnCodeActionAvailable(LSPEvent& event);
+    void OnApplyEdits(LSPEvent& event);
 
     wxString GetEditorFilePath(IEditor* editor) const;
     /**
