@@ -1,32 +1,29 @@
 #include "languageserver.h"
 
-#include "CompileCommandsGenerator.h"
 #include "LSPDetectorManager.hpp"
 #include "LanguageServerConfig.h"
 #include "LanguageServerSettingsDlg.h"
-#include "ServiceProviderManager.h"
+#include "StringUtils.h"
+#include "clInfoBar.h"
 #include "cl_standard_paths.h"
+#include "clangd/CompileCommandsGenerator.h"
 #include "event_notifier.h"
 #include "file_logger.h"
 #include "globals.h"
 #include "ieditor.h"
+#include "macros.h"
 
-#include <macros.h>
 #include <thread>
 #include <wx/app.h>
 #include <wx/datetime.h>
+#include <wx/notifmsg.h>
 #include <wx/stc/stc.h>
 #include <wx/xrc/xmlres.h>
 
-static LanguageServerPlugin* thePlugin = NULL;
-
 // Define the plugin entry point
 CL_PLUGIN_API IPlugin* CreatePlugin(IManager* manager)
 {
-    if(thePlugin == NULL) {
-        thePlugin = new LanguageServerPlugin(manager);
-    }
-    return thePlugin;
+    return new LanguageServerPlugin(manager);
 }
 
 CL_PLUGIN_API PluginInfo* GetPluginInfo()
@@ -47,21 +44,21 @@ LanguageServerPlugin::LanguageServerPlugin(IManager* manager)
     m_longName = _("Support for Language Server Protocol (LSP)");
     m_shortName = wxT("LanguageServerPlugin");
 
-    // add log view
-    m_logView = new LanguageServerLogView(m_mgr->GetOutputPaneNotebook());
-    auto outputBook = m_mgr->GetOutputPaneNotebook();
-    int bmp = outputBook->GetBitmaps()->Add("cog");
-    outputBook->AddPage(m_logView, _("Language Server"), false, bmp);
-    m_tabToggler.reset(new clTabTogglerHelper(_("Language Server"), m_logView, "", NULL));
-    m_tabToggler->SetOutputTabBmp(bmp);
-
     // Load the configuration
     LanguageServerConfig::Get().Load();
-    m_servers.reset(new LanguageServerCluster(this));
+    m_servers = new LanguageServerCluster(this);
+
+    // add log view
+    m_logView = new LanguageServerLogView(m_mgr->BookGet(PaneId::BOTTOM_BAR), m_servers);
+    m_mgr->BookAddPage(PaneId::BOTTOM_BAR, m_logView, _("Language Server"));
+    m_tabToggler.reset(new clTabTogglerHelper(_("Language Server"), m_logView, "", NULL));
+
     EventNotifier::Get()->Bind(wxEVT_INIT_DONE, &LanguageServerPlugin::OnInitDone, this);
     EventNotifier::Get()->Bind(wxEVT_CONTEXT_MENU_EDITOR, &LanguageServerPlugin::OnEditorContextMenu, this);
     wxTheApp->Bind(wxEVT_MENU, &LanguageServerPlugin::OnSettings, this, XRCID("language-server-settings"));
     wxTheApp->Bind(wxEVT_MENU, &LanguageServerPlugin::OnRestartLSP, this, XRCID("language-server-restart"));
+    clGetManager()->GetInfoBar()->Bind(wxEVT_BUTTON, &LanguageServerPlugin::OnFixLSPPaths, this,
+                                       XRCID("lsp-fix-paths"));
 
     EventNotifier::Get()->Bind(wxEVT_LSP_STOP_ALL, &LanguageServerPlugin::OnLSPStopAll, this);
     EventNotifier::Get()->Bind(wxEVT_LSP_START_ALL, &LanguageServerPlugin::OnLSPStartAll, this);
@@ -75,9 +72,35 @@ LanguageServerPlugin::LanguageServerPlugin(IManager* manager)
     EventNotifier::Get()->Bind(wxEVT_LSP_ENABLE_SERVER, &LanguageServerPlugin::OnLSPEnableServer, this);
     EventNotifier::Get()->Bind(wxEVT_LSP_DISABLE_SERVER, &LanguageServerPlugin::OnLSPDisableServer, this);
     EventNotifier::Get()->Bind(wxEVT_WORKSPACE_CLOSED, &LanguageServerPlugin::OnWorkspaceClosed, this);
+
+    /// initialise the LSP library
+    LSP::Initialise();
+
+    CallAfter(&LanguageServerPlugin::CheckServers);
 }
 
-LanguageServerPlugin::~LanguageServerPlugin() {}
+LanguageServerPlugin::~LanguageServerPlugin() { wxDELETE(m_servers); }
+
+void LanguageServerPlugin::CheckServers()
+{
+    auto broken_lsps = GetBrokenLSPs();
+    if (broken_lsps.empty()) {
+        return;
+    }
+
+    clSYSTEM() << "The following LSPs contain paths to a non existing locations:" << broken_lsps << endl;
+    // Show a notification message with a suggestion for a fix
+    wxString message;
+    message << "The following LSPs contain paths to a non existing locations: [";
+    for (const auto& name : broken_lsps) {
+        message << name << ", ";
+    }
+    message.RemoveLast(2);
+    message << "]";
+
+    clGetManager()->DisplayMessage(message, wxICON_WARNING,
+                                   { { wxID_CANCEL, _("Cancel") }, { XRCID("lsp-fix-paths"), _("Attempt to fix") } });
+}
 
 void LanguageServerPlugin::CreateToolBar(clToolBarGeneric* toolbar)
 {
@@ -114,25 +137,22 @@ void LanguageServerPlugin::UnPlug()
     EventNotifier::Get()->Unbind(wxEVT_WORKSPACE_CLOSED, &LanguageServerPlugin::OnWorkspaceClosed, this);
 
     LanguageServerConfig::Get().Save();
-    m_servers.reset(nullptr);
 
     // before this plugin is un-plugged we must remove the tab we added
-    for(size_t i = 0; i < m_mgr->GetOutputPaneNotebook()->GetPageCount(); i++) {
-        if(m_logView == m_mgr->GetOutputPaneNotebook()->GetPage(i)) {
-            m_mgr->GetOutputPaneNotebook()->RemovePage(i);
-            m_logView->Destroy();
-            break;
-        }
+    if (!m_mgr->BookDeletePage(PaneId::BOTTOM_BAR, m_logView)) {
+        m_logView->Destroy();
     }
+    m_logView = nullptr;
+    wxDELETE(m_servers);
 }
 
 void LanguageServerPlugin::OnSettings(wxCommandEvent& e)
 {
     LanguageServerSettingsDlg dlg(EventNotifier::Get()->TopFrame(), false);
-    if(dlg.ShowModal() == wxID_OK) {
+    if (dlg.ShowModal() == wxID_OK) {
         // restart all language servers
         dlg.Save();
-        if(m_servers) {
+        if (m_servers) {
             // Lets assume that we fixed something in the settings
             // and clear all the restart counters
             m_servers->ClearRestartCounters();
@@ -144,7 +164,7 @@ void LanguageServerPlugin::OnSettings(wxCommandEvent& e)
 void LanguageServerPlugin::OnRestartLSP(wxCommandEvent& e)
 {
     wxUnusedVar(e);
-    if(m_servers) {
+    if (m_servers) {
         m_servers->Reload();
     }
 }
@@ -156,28 +176,28 @@ void LanguageServerPlugin::OnInitDone(wxCommandEvent& event)
 
     bool force = false;
     const auto& servers = LanguageServerConfig::Get().GetServers();
-    for(auto& server : servers) {
-        if(server.second.GetCommand().Contains(".codelite/lsp/clang-tools")) {
+    for (auto& server : servers) {
+        if (server.second.GetCommand().Contains(".codelite/lsp/clang-tools")) {
             force = true;
             break;
         }
     }
 
-    if(LanguageServerConfig::Get().GetServers().empty() || force) {
-        clDEBUG() << "Scanning..." << clEndl;
+    if (LanguageServerConfig::Get().GetServers().empty() || force) {
+        LSP_DEBUG() << "Scanning..." << endl;
         std::thread thr(
             [=](LanguageServerPlugin* plugin) {
                 std::vector<LSPDetector::Ptr_t> matches;
                 LSPDetectorManager detector;
-                clDEBUG() << "***"
-                          << "Scanning for LSPs... ***" << clEndl;
-                if(detector.Scan(matches)) {
-                    clDEBUG() << "   ******"
-                              << "found!" << clEndl;
+                LSP_DEBUG() << "***"
+                            << "Scanning for LSPs... ***" << endl;
+                if (detector.Scan(matches)) {
+                    LSP_DEBUG() << "   ******"
+                                << "found!" << endl;
                 }
-                clDEBUG() << "***"
-                          << "Scanning for LSPs... is done ***" << clEndl;
-                clDEBUG() << "*** Calling   ConfigureLSPs" << clEndl;
+                LSP_DEBUG() << "***"
+                            << "Scanning for LSPs... is done ***" << endl;
+                LSP_DEBUG() << "*** Calling   ConfigureLSPs" << endl;
                 plugin->CallAfter(&LanguageServerPlugin::ConfigureLSPs, matches);
             },
             this);
@@ -201,37 +221,46 @@ void LanguageServerPlugin::OnEditorContextMenu(clContextMenuEvent& event)
     bool add_rename_symbol = lsp->IsRenameSupported();
 
     // nothing to be done here
-    if(!add_find_symbol && !add_find_references && !add_rename_symbol) {
+    if (!add_find_symbol && !add_find_references && !add_rename_symbol) {
         return;
     }
 
     wxMenu* menu = event.GetMenu();
-    if(add_find_references) {
+    if (add_find_references) {
         menu->PrependSeparator();
         menu->Prepend(XRCID("lsp_find_references"), _("Find references"));
     }
     menu->PrependSeparator();
-    if(add_rename_symbol && false) {
+    if (add_rename_symbol) {
         menu->Prepend(XRCID("lsp_rename_symbol"), _("Rename symbol"));
     }
     menu->Prepend(XRCID("lsp_find_symbol"), _("Find symbol"));
 
-    // TODO:
-    // add here "Find References" and "Rename Symbol"
-    // menu entries if supported by the LSP
-    // we always add them to the top of the list
     menu->Bind(wxEVT_MENU, &LanguageServerPlugin::OnMenuFindSymbol, this, XRCID("lsp_find_symbol"));
     menu->Bind(wxEVT_MENU, &LanguageServerPlugin::OnMenuFindReferences, this, XRCID("lsp_find_references"));
     menu->Bind(wxEVT_MENU, &LanguageServerPlugin::OnMenuRenameSymbol, this, XRCID("lsp_rename_symbol"));
 }
 
-void LanguageServerPlugin::OnMenuRenameSymbol(wxCommandEvent& event) {}
+void LanguageServerPlugin::OnMenuRenameSymbol(wxCommandEvent& event)
+{
+    wxUnusedVar(event);
+
+    LSP_DEBUG() << "OnMenuRenameSymbol is called" << endl;
+
+    IEditor* editor = clGetManager()->GetActiveEditor();
+    CHECK_PTR_RET(editor);
+
+    LanguageServerProtocol::Ptr_t lsp = m_servers->GetServerForEditor(editor);
+    CHECK_PTR_RET(lsp);
+
+    lsp->RenameSymbol(editor);
+}
 
 void LanguageServerPlugin::OnMenuFindReferences(wxCommandEvent& event)
 {
     wxUnusedVar(event);
 
-    clDEBUG() << "OnMenuFindReferences is called" << endl;
+    LSP_DEBUG() << "OnMenuFindReferences is called" << endl;
 
     IEditor* editor = clGetManager()->GetActiveEditor();
     CHECK_PTR_RET(editor);
@@ -250,48 +279,47 @@ void LanguageServerPlugin::OnMenuFindSymbol(wxCommandEvent& event)
     clCodeCompletionEvent findEvent(wxEVT_CC_FIND_SYMBOL);
     findEvent.SetPosition(editor->GetCurrentPosition());
     findEvent.SetFileName(editor->GetFileName().GetFullPath());
-    ServiceProviderManager::Get().AddPendingEvent(findEvent);
+    EventNotifier::Get()->AddPendingEvent(findEvent);
 }
 
 void LanguageServerPlugin::ConfigureLSPs(const std::vector<LSPDetector::Ptr_t>& lsps)
 {
-    clDEBUG() << "   ******"
-              << "ConfigureLSPs is called!" << clEndl;
-    if(lsps.empty()) {
-        clDEBUG() << "ConfigureLSPs: no LSPs found. Nothing to be done here" << clEndl;
+    LSP_DEBUG() << "   ******"
+                << "ConfigureLSPs is called!" << endl;
+    if (lsps.empty()) {
+        LSP_DEBUG() << "ConfigureLSPs: no LSPs found. Nothing to be done here" << endl;
         return;
     }
 
     LanguageServerConfig& config = LanguageServerConfig::Get();
     // remove clangd installed under ~/.codelite/lsp/clang-tools
     wxArrayString serversToRemove;
-    for(const auto& server : config.GetServers()) {
-        if(server.second.GetCommand().Contains(".codelite/lsp/clang-tools")) {
+    for (const auto& server : config.GetServers()) {
+        if (server.second.GetCommand().Contains(".codelite/lsp/clang-tools")) {
             serversToRemove.Add(server.first);
         }
     }
 
     bool force = !serversToRemove.IsEmpty();
     // remove all old entries
-    for(const auto& name : serversToRemove) {
-        clSYSTEM() << "Removing broken LSP server:" << name << endl;
+    for (const auto& name : serversToRemove) {
+        LSP_SYSTEM() << "Removing broken LSP server:" << name << endl;
         config.RemoveServer(name);
     }
 
-    clDEBUG() << "ConfigureLSPs: there are currently" << config.GetServers().size() << "LSPs configured" << clEndl;
-    if(config.GetServers().empty() || force) {
-        clDEBUG() << "No LSPs configured - auto configuring" << clEndl;
+    LSP_DEBUG() << "ConfigureLSPs: there are currently" << config.GetServers().size() << "LSPs configured" << endl;
+    if (config.GetServers().empty() || force) {
+        LSP_DEBUG() << "No LSPs configured - auto configuring" << endl;
         // Only if the user did not configure LSP before, we configure it for him
-        for(auto lsp : lsps) {
+        for (auto lsp : lsps) {
             LanguageServerEntry entry;
             lsp->GetLanguageServerEntry(entry);
-            entry.SetEnabled(true);
             config.AddServer(entry);
-            clDEBUG() << "Adding LSP:" << entry.GetName() << clEndl;
+            LSP_DEBUG() << "Adding LSP:" << entry.GetName() << endl;
         }
         config.SetEnabled(true);
         config.Save();
-        if(m_servers) {
+        if (m_servers) {
             m_servers->Reload();
         }
     }
@@ -306,16 +334,18 @@ void LanguageServerPlugin::OnLSPStopAll(clLanguageServerEvent& event)
 void LanguageServerPlugin::OnLSPStartAll(clLanguageServerEvent& event)
 {
     CHECK_PTR_RET(m_servers);
+    wxBusyCursor bc;
     m_servers->StartAll();
 }
 
 void LanguageServerPlugin::OnLSPRestartAll(clLanguageServerEvent& event)
 {
-    clDEBUG() << "LSP: restarting all LSPs" << endl;
+    wxBusyCursor bc;
+    LSP_DEBUG() << "LSP: restarting all LSPs" << endl;
     CHECK_PTR_RET(m_servers);
     m_servers->StopAll();
     m_servers->StartAll();
-    clDEBUG() << "LSP: restarting all LSPs...done" << endl;
+    LSP_DEBUG() << "LSP: restarting all LSPs...done" << endl;
 }
 
 void LanguageServerPlugin::OnLSPStopOne(clLanguageServerEvent& event)
@@ -347,8 +377,8 @@ void LanguageServerPlugin::OnLSPConfigure(clLanguageServerEvent& event)
     LanguageServerEntry* pentry = &entry;
 
     auto d = LanguageServerConfig::Get().GetServer(event.GetLspName());
-    if(d.IsValid()) {
-        clDEBUG() << "an LSP with the same name:" << event.GetLspName() << "already exists. updating it" << endl;
+    if (!d.IsNull()) {
+        LSP_DEBUG() << "an LSP with the same name:" << event.GetLspName() << "already exists. updating it" << endl;
         pentry = &d;
     }
 
@@ -356,10 +386,9 @@ void LanguageServerPlugin::OnLSPConfigure(clLanguageServerEvent& event)
     pentry->SetLanguages(event.GetLanguages());
     pentry->SetName(event.GetLspName());
     pentry->SetCommand(event.GetLspCommand());
-    pentry->SetDisaplayDiagnostics(event.GetFlags() & clLanguageServerEvent::kDisaplyDiags);
+    pentry->SetDisplayDiagnostics(event.GetFlags() & clLanguageServerEvent::kDisaplyDiags);
     pentry->SetConnectionString(event.GetConnectionString());
     pentry->SetEnabled(event.GetFlags() & clLanguageServerEvent::kEnabled);
-    pentry->SetPriority(event.GetPriority());
     pentry->SetWorkingDirectory(event.GetRootUri());
     LanguageServerConfig::Get().AddServer(*pentry);
 }
@@ -367,9 +396,9 @@ void LanguageServerPlugin::OnLSPConfigure(clLanguageServerEvent& event)
 void LanguageServerPlugin::OnLSPDelete(clLanguageServerEvent& event)
 {
     CHECK_PTR_RET(m_servers);
-    clDEBUG() << "Deleting server:" << event.GetLspName() << endl;
+    LSP_DEBUG() << "Deleting server:" << event.GetLspName() << endl;
     m_servers->DeleteServer(event.GetLspName());
-    clDEBUG() << "Success" << endl;
+    LSP_DEBUG() << "Success" << endl;
 }
 
 void LanguageServerPlugin::OnLSPShowSettingsDlg(clLanguageServerEvent& event)
@@ -383,7 +412,7 @@ wxString LanguageServerPlugin::GetEditorFilePath(IEditor* editor) const { return
 void LanguageServerPlugin::OnLSPEnableServer(clLanguageServerEvent& event)
 {
     auto& lsp_config = LanguageServerConfig::Get().GetServer(event.GetLspName());
-    if(!lsp_config.IsValid()) {
+    if (lsp_config.IsNull()) {
         return;
     }
     lsp_config.SetEnabled(true);
@@ -392,7 +421,7 @@ void LanguageServerPlugin::OnLSPEnableServer(clLanguageServerEvent& event)
 void LanguageServerPlugin::OnLSPDisableServer(clLanguageServerEvent& event)
 {
     auto& lsp_config = LanguageServerConfig::Get().GetServer(event.GetLspName());
-    if(!lsp_config.IsValid()) {
+    if (lsp_config.IsNull()) {
         return;
     }
     lsp_config.SetEnabled(false);
@@ -402,28 +431,28 @@ void LanguageServerPlugin::LogMessage(const wxString& server_name, const wxStrin
 {
     auto& builder = m_logView->GetDvListCtrl()->GetBuilder(true);
 
-    eAsciiColours ansi_colour_code = eAsciiColours::NORMAL_TEXT;
+    int ansi_colour_code = AnsiColours::NormalText();
     wxString label = "T "; // trace
-    switch(log_leve) {
+    switch (log_leve) {
     case 1:
-        ansi_colour_code = eAsciiColours::RED; // error
+        ansi_colour_code = AnsiColours::Red(); // error
         label = "E ";
         break;
     case 2:
-        ansi_colour_code = eAsciiColours::YELLOW; // warning
+        ansi_colour_code = AnsiColours::Yellow(); // warning
         label = "W ";
         break;
     case 3:
-        ansi_colour_code = eAsciiColours::GREEN; // info
+        ansi_colour_code = AnsiColours::Green(); // info
         label = "I ";
     default:
         break;
     }
 
     builder.Add(label, ansi_colour_code);
-    builder.Add(wxDateTime::Now().FormatISOTime() + " ", eAsciiColours::GRAY);
-    builder.Add(server_name + " ", eAsciiColours::NORMAL_TEXT);
-    builder.Add(message, eAsciiColours::NORMAL_TEXT);
+    builder.Add(wxDateTime::Now().FormatISOTime() + " ", AnsiColours::Gray());
+    builder.Add(server_name + " ", AnsiColours::Magenta());
+    builder.Add(message, AnsiColours::NormalText());
     m_logView->GetDvListCtrl()->AddLine(builder.GetString(), false);
     m_logView->GetDvListCtrl()->ScrollToBottom();
 }
@@ -433,3 +462,60 @@ void LanguageServerPlugin::OnWorkspaceClosed(clWorkspaceEvent& event)
     event.Skip();
     m_logView->GetDvListCtrl()->DeleteAllItems();
 }
+
+void LanguageServerPlugin::OnFixLSPPaths(wxCommandEvent& event)
+{
+    // Hide and layout the view
+    clGetManager()->GetInfoBar()->Hide();
+    EventNotifier::Get()->TopFrame()->SendSizeEvent(wxSEND_EVENT_POST);
+
+    wxUnusedVar(event);
+    auto broken_lsps = GetBrokenLSPs();
+    if (broken_lsps.empty()) {
+        return;
+    }
+
+    wxBusyCursor bc;
+    std::vector<LSPDetector::Ptr_t> matches;
+    LSPDetectorManager detector;
+    if (detector.Scan(matches)) {
+        wxArrayString fixed;
+        for (const wxString& broken_lsp : broken_lsps) {
+            auto& lsp = LanguageServerConfig::Get().GetServer(broken_lsp);
+            if (lsp.IsNull()) {
+                // Could not find it
+                continue;
+            }
+
+            // Check to see if
+            for (size_t i = 0; i < matches.size(); ++i) {
+                LanguageServerEntry entry;
+                matches[i]->GetLanguageServerEntry(entry);
+                if (entry.GetName() == broken_lsp) {
+                    lsp = entry;
+                    fixed.Add(broken_lsp);
+                    break;
+                }
+            }
+        }
+
+        if (!fixed.empty()) {
+            LanguageServerConfig::Get().Save();
+            m_servers->Reload();
+        }
+    }
+}
+
+wxArrayString LanguageServerPlugin::GetBrokenLSPs() const
+{
+    wxArrayString broken_lsps;
+    const auto& servers = LanguageServerConfig::Get().GetServers();
+    for (const auto& [name, server] : servers) {
+        auto argv = StringUtils::BuildArgv(server.GetCommand());
+        // Check that the first argument (the executable path) exists
+        if (server.IsEnabled() && argv.empty() || !wxFileName::FileExists(argv[0])) {
+            broken_lsps.push_back(name);
+        }
+    }
+    return broken_lsps;
+}
