@@ -26,18 +26,18 @@
 #include "CompilerMainPage.h"
 
 #include "EditCmpTemplateDialog.h"
+#include "EditDlg.h"
 #include "NewFileTemplateDialog.h"
 #include "advanced_settings.h"
+#include "build_config.h"
+#include "build_settings_config.h"
 #include "compiler.h"
+#include "event_notifier.h"
+#include "globals.h"
 #include "imanager.h"
+#include "windowattrmanager.h"
+#include "workspace.h"
 
-#include <EditDlg.h>
-#include <build_config.h>
-#include <build_settings_config.h>
-#include <event_notifier.h>
-#include <globals.h>
-#include <windowattrmanager.h>
-#include <workspace.h>
 #include <wx/menu.h>
 #include <wx/msgdlg.h>
 #include <wx/textdlg.h>
@@ -53,25 +53,15 @@ CompilerMainPage::CompilerMainPage(wxWindow* parent)
     // =============-----------------------------
     // Patterns page initialization
     // =============-----------------------------
-    m_listErrPatterns->InsertColumn(0, _("Pattern"));
-    m_listErrPatterns->InsertColumn(1, _("File name index"));
-    m_listErrPatterns->InsertColumn(2, _("Line number index"));
-    m_listErrPatterns->InsertColumn(3, _("Column index"));
+    m_dvListCtrlErrors->AddHeader(_("Pattern"));
+    m_dvListCtrlErrors->AddHeader(_("File name index"), wxNullBitmap, wxCOL_WIDTH_DEFAULT);
+    m_dvListCtrlErrors->AddHeader(_("Line number index"), wxNullBitmap, wxCOL_WIDTH_DEFAULT);
+    m_dvListCtrlErrors->AddHeader(_("Column index"), wxNullBitmap, wxCOL_WIDTH_DEFAULT);
 
-    m_listErrPatterns->SetColumnWidth(0, 200);
-    m_listErrPatterns->SetColumnWidth(1, 50);
-    m_listErrPatterns->SetColumnWidth(2, 50);
-    m_listErrPatterns->SetColumnWidth(3, 50);
-
-    m_listWarnPatterns->InsertColumn(0, _("Pattern"));
-    m_listWarnPatterns->InsertColumn(1, _("File name index"));
-    m_listWarnPatterns->InsertColumn(2, _("Line number index"));
-    m_listWarnPatterns->InsertColumn(3, _("Column index"));
-
-    m_listWarnPatterns->SetColumnWidth(0, 200);
-    m_listWarnPatterns->SetColumnWidth(1, 50);
-    m_listWarnPatterns->SetColumnWidth(2, 50);
-    m_listWarnPatterns->SetColumnWidth(3, 50);
+    m_dvListCtrlWarnings->AddHeader(_("Pattern"));
+    m_dvListCtrlWarnings->AddHeader(_("File name index"), wxNullBitmap, wxCOL_WIDTH_DEFAULT);
+    m_dvListCtrlWarnings->AddHeader(_("Line number index"), wxNullBitmap, wxCOL_WIDTH_DEFAULT);
+    m_dvListCtrlWarnings->AddHeader(_("Column index"), wxNullBitmap, wxCOL_WIDTH_DEFAULT);
 
     // ==============------------------
     // Switches
@@ -107,11 +97,10 @@ void CompilerMainPage::OnBtnAddErrPattern(wxCommandEvent& event)
 {
     CompilerPatternDlg dlg(wxGetTopLevelParent(this), _("Add compiler error pattern"));
     if(dlg.ShowModal() == wxID_OK) {
-        long item = AppendListCtrlRow(m_listErrPatterns);
-        SetColumnText(m_listErrPatterns, item, 0, dlg.GetPattern());
-        SetColumnText(m_listErrPatterns, item, 1, dlg.GetFileIndex());
-        SetColumnText(m_listErrPatterns, item, 2, dlg.GetLineIndex());
-        SetColumnText(m_listErrPatterns, item, 3, dlg.GetColumnIndex());
+        auto item = m_dvListCtrlErrors->AppendItem(dlg.GetPattern());
+        m_dvListCtrlErrors->SetItemText(item, dlg.GetFileIndex(), 1);
+        m_dvListCtrlErrors->SetItemText(item, dlg.GetLineIndex(), 2);
+        m_dvListCtrlErrors->SetItemText(item, dlg.GetColumnIndex(), 3);
         m_isDirty = true;
     }
 }
@@ -120,52 +109,51 @@ void CompilerMainPage::OnBtnAddWarnPattern(wxCommandEvent& event)
 {
     CompilerPatternDlg dlg(wxGetTopLevelParent(this), _("Add compiler warning pattern"));
     if(dlg.ShowModal() == wxID_OK) {
+        auto item = m_dvListCtrlWarnings->AppendItem(dlg.GetPattern());
+        m_dvListCtrlWarnings->SetItemText(item, dlg.GetFileIndex(), 1);
+        m_dvListCtrlWarnings->SetItemText(item, dlg.GetLineIndex(), 2);
+        m_dvListCtrlWarnings->SetItemText(item, dlg.GetColumnIndex(), 3);
         m_isDirty = true;
-        long item = AppendListCtrlRow(m_listWarnPatterns);
-        SetColumnText(m_listWarnPatterns, item, 0, dlg.GetPattern());
-        SetColumnText(m_listWarnPatterns, item, 1, dlg.GetFileIndex());
-        SetColumnText(m_listWarnPatterns, item, 2, dlg.GetLineIndex());
-        SetColumnText(m_listWarnPatterns, item, 3, dlg.GetColumnIndex());
     }
 }
 
 void CompilerMainPage::OnBtnDelErrPattern(wxCommandEvent& event)
 {
-    int sel = m_listErrPatterns->GetNextItem(-1, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED);
-    if(sel == wxNOT_FOUND) {
-        return;
-    }
-    m_listErrPatterns->DeleteItem(sel);
+    wxUnusedVar(event);
+    auto item = m_dvListCtrlErrors->GetSelection();
+    CHECK_ITEM_RET(item);
+
+    m_dvListCtrlErrors->DeleteItem(m_dvListCtrlErrors->ItemToRow(item));
     m_isDirty = true;
 }
 
 void CompilerMainPage::OnBtnDelWarnPattern(wxCommandEvent& event)
 {
-    int sel = m_listWarnPatterns->GetNextItem(-1, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED);
-    if(sel == wxNOT_FOUND) {
-        return;
-    }
-    m_listWarnPatterns->DeleteItem(sel);
+    wxUnusedVar(event);
+    auto item = m_dvListCtrlWarnings->GetSelection();
+    CHECK_ITEM_RET(item);
+
+    m_dvListCtrlWarnings->DeleteItem(m_dvListCtrlWarnings->ItemToRow(item));
     m_isDirty = true;
 }
 
 void CompilerMainPage::OnBtnUpdateErrPattern(wxCommandEvent& event)
 {
-    int sel = m_listErrPatterns->GetNextItem(-1, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED);
-    if(sel == wxNOT_FOUND) {
-        return;
-    }
-    DoUpdateErrPattern(sel);
+    wxUnusedVar(event);
+    auto item = m_dvListCtrlErrors->GetSelection();
+    CHECK_ITEM_RET(item);
+
+    DoUpdateErrPattern(item);
     m_isDirty = true;
 }
 
 void CompilerMainPage::OnBtnUpdateWarnPattern(wxCommandEvent& event)
 {
-    int sel = m_listWarnPatterns->GetNextItem(-1, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED);
-    if(sel == wxNOT_FOUND) {
-        return;
-    }
-    DoUpdateWarnPattern(sel);
+    wxUnusedVar(event);
+    auto item = m_dvListCtrlWarnings->GetSelection();
+    CHECK_ITEM_RET(item);
+
+    DoUpdateWarnPattern(item);
     m_isDirty = true;
 }
 
@@ -287,48 +275,44 @@ void CompilerMainPage::OnEditLibraryPaths(wxCommandEvent& event)
     }
 }
 
-void CompilerMainPage::OnErrItemActivated(wxListEvent& event)
+void CompilerMainPage::OnErrItemActivated(wxDataViewEvent& event)
 {
-    DoUpdateErrPattern(event.GetIndex());
+    DoUpdateErrPattern(event.GetItem());
     m_isDirty = true;
 }
 
 void CompilerMainPage::OnErrorPatternSelectedUI(wxUpdateUIEvent& event)
 {
-    int sel = m_listErrPatterns->GetNextItem(-1, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED);
-    event.Enable(sel != wxNOT_FOUND);
+    event.Enable(!m_dvListCtrlErrors->IsEmpty());
 }
 
-void CompilerMainPage::DoUpdateWarnPattern(long item)
+void CompilerMainPage::DoUpdatePattern(clThemedListCtrl* list, const wxDataViewItem& item, const wxString& dialog_title)
 {
-    wxString pattern = GetColumnText(m_listWarnPatterns, item, 0);
-    wxString fileIdx = GetColumnText(m_listWarnPatterns, item, 1);
-    wxString lineIdx = GetColumnText(m_listWarnPatterns, item, 2);
-    wxString colIdx = GetColumnText(m_listWarnPatterns, item, 3);
-    CompilerPatternDlg dlg(wxGetTopLevelParent(this), _("Update compiler warning pattern"));
+    wxString pattern = list->GetItemText(item, 0);
+    wxString fileIdx = list->GetItemText(item, 1);
+    wxString lineIdx = list->GetItemText(item, 2);
+    wxString colIdx = list->GetItemText(item, 3);
+
+    CompilerPatternDlg dlg(wxGetTopLevelParent(this), dialog_title);
     dlg.SetPattern(pattern, lineIdx, fileIdx, colIdx);
-    if(dlg.ShowModal() == wxID_OK) {
-        SetColumnText(m_listWarnPatterns, item, 0, dlg.GetPattern());
-        SetColumnText(m_listWarnPatterns, item, 1, dlg.GetFileIndex());
-        SetColumnText(m_listWarnPatterns, item, 2, dlg.GetLineIndex());
-        SetColumnText(m_listWarnPatterns, item, 3, dlg.GetColumnIndex());
+    if(dlg.ShowModal() != wxID_OK) {
+        return;
     }
+
+    list->SetItemText(item, dlg.GetPattern(), 0);
+    list->SetItemText(item, dlg.GetFileIndex(), 1);
+    list->SetItemText(item, dlg.GetLineIndex(), 2);
+    list->SetItemText(item, dlg.GetColumnIndex(), 3);
 }
 
-void CompilerMainPage::DoUpdateErrPattern(long item)
+void CompilerMainPage::DoUpdateWarnPattern(const wxDataViewItem& item)
 {
-    wxString pattern = GetColumnText(m_listErrPatterns, item, 0);
-    wxString fileIdx = GetColumnText(m_listErrPatterns, item, 1);
-    wxString lineIdx = GetColumnText(m_listErrPatterns, item, 2);
-    wxString colIdx = GetColumnText(m_listErrPatterns, item, 3);
-    CompilerPatternDlg dlg(wxGetTopLevelParent(this), _("Update compiler error pattern"));
-    dlg.SetPattern(pattern, lineIdx, fileIdx, colIdx);
-    if(dlg.ShowModal() == wxID_OK) {
-        SetColumnText(m_listErrPatterns, item, 0, dlg.GetPattern());
-        SetColumnText(m_listErrPatterns, item, 1, dlg.GetFileIndex());
-        SetColumnText(m_listErrPatterns, item, 2, dlg.GetLineIndex());
-        SetColumnText(m_listErrPatterns, item, 3, dlg.GetColumnIndex());
-    }
+    DoUpdatePattern(m_dvListCtrlWarnings, item, _("Update compiler warning pattern"));
+}
+
+void CompilerMainPage::DoUpdateErrPattern(const wxDataViewItem& item)
+{
+    DoUpdatePattern(m_dvListCtrlErrors, item, _("Update compiler error pattern"));
 }
 
 void CompilerMainPage::DoFileTypeActivated(const wxDataViewItem& item)
@@ -459,44 +443,40 @@ void CompilerMainPage::OnNewLinkerOption(wxCommandEvent& event)
     }
 }
 
-void CompilerMainPage::OnWarnItemActivated(wxListEvent& event)
+void CompilerMainPage::OnWarnItemActivated(wxDataViewEvent& event)
 {
-    DoUpdateWarnPattern(event.GetIndex());
+    DoUpdateWarnPattern(event.GetItem());
     m_isDirty = true;
 }
 
 void CompilerMainPage::OnWarningPatternSelectedUI(wxUpdateUIEvent& event)
 {
-    int sel = m_listWarnPatterns->GetNextItem(-1, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED);
-    event.Enable(sel != wxNOT_FOUND);
+    event.Enable(!m_dvListCtrlWarnings->IsEmpty());
+}
+
+void CompilerMainPage::DoAddPattern(clThemedListCtrl* list, const Compiler::CmpInfoPattern& pattern)
+{
+    auto item = list->AppendItem(pattern.pattern);
+    list->SetItemText(item, pattern.fileNameIndex, 1);
+    list->SetItemText(item, pattern.lineNumberIndex, 2);
+    list->SetItemText(item, pattern.columnIndex, 3);
 }
 
 void CompilerMainPage::InitializePatterns()
 {
     // Clear the content
-    m_listErrPatterns->DeleteAllItems();
-    m_listWarnPatterns->DeleteAllItems();
+    m_dvListCtrlErrors->DeleteAllItems();
+    m_dvListCtrlWarnings->DeleteAllItems();
 
     // Populate with new content
     CHECK_PTR_RET(m_compiler);
 
-    const Compiler::CmpListInfoPattern& errPatterns = m_compiler->GetErrPatterns();
-    Compiler::CmpListInfoPattern::const_iterator itPattern;
-    for(itPattern = errPatterns.begin(); itPattern != errPatterns.end(); ++itPattern) {
-        long item = AppendListCtrlRow(m_listErrPatterns);
-        SetColumnText(m_listErrPatterns, item, 0, itPattern->pattern);
-        SetColumnText(m_listErrPatterns, item, 1, itPattern->fileNameIndex);
-        SetColumnText(m_listErrPatterns, item, 2, itPattern->lineNumberIndex);
-        SetColumnText(m_listErrPatterns, item, 3, itPattern->columnIndex);
+    for(const auto& pattern : m_compiler->GetErrPatterns()) {
+        DoAddPattern(m_dvListCtrlErrors, pattern);
     }
 
-    const Compiler::CmpListInfoPattern& warnPatterns = m_compiler->GetWarnPatterns();
-    for(itPattern = warnPatterns.begin(); itPattern != warnPatterns.end(); ++itPattern) {
-        long item = AppendListCtrlRow(m_listWarnPatterns);
-        SetColumnText(m_listWarnPatterns, item, 0, itPattern->pattern);
-        SetColumnText(m_listWarnPatterns, item, 1, itPattern->fileNameIndex);
-        SetColumnText(m_listWarnPatterns, item, 2, itPattern->lineNumberIndex);
-        SetColumnText(m_listWarnPatterns, item, 3, itPattern->columnIndex);
+    for(const auto& pattern : m_compiler->GetWarnPatterns()) {
+        DoAddPattern(m_dvListCtrlWarnings, pattern);
     }
 }
 
@@ -506,6 +486,7 @@ void CompilerMainPage::LoadCompiler(const wxString& compilerName)
     if(m_isDirty) {
         Save();
     }
+
     m_compiler = BuildSettingsConfigST::Get()->GetCompiler(compilerName);
 
     // Start initialization
@@ -516,23 +497,26 @@ void CompilerMainPage::SavePatterns()
 {
     CHECK_PTR_RET(m_compiler);
     Compiler::CmpListInfoPattern errPatterns;
-    for(int i = 0; i < m_listErrPatterns->GetItemCount(); ++i) {
+
+    for(int i = 0; i < m_dvListCtrlErrors->GetItemCount(); ++i) {
+        auto item = m_dvListCtrlErrors->RowToItem(i);
         Compiler::CmpInfoPattern infoPattern;
-        infoPattern.pattern = GetColumnText(m_listErrPatterns, i, 0);
-        infoPattern.fileNameIndex = GetColumnText(m_listErrPatterns, i, 1);
-        infoPattern.lineNumberIndex = GetColumnText(m_listErrPatterns, i, 2);
-        infoPattern.columnIndex = GetColumnText(m_listErrPatterns, i, 3);
+        infoPattern.pattern = m_dvListCtrlErrors->GetItemText(item, 0);
+        infoPattern.fileNameIndex = m_dvListCtrlErrors->GetItemText(item, 1);
+        infoPattern.lineNumberIndex = m_dvListCtrlErrors->GetItemText(item, 2);
+        infoPattern.columnIndex = m_dvListCtrlErrors->GetItemText(item, 3);
         errPatterns.push_back(infoPattern);
     }
     m_compiler->SetErrPatterns(errPatterns);
 
     Compiler::CmpListInfoPattern warnPatterns;
-    for(int i = 0; i < m_listWarnPatterns->GetItemCount(); ++i) {
+    for(int i = 0; i < m_dvListCtrlWarnings->GetItemCount(); ++i) {
+        auto item = m_dvListCtrlWarnings->RowToItem(i);
         Compiler::CmpInfoPattern infoPattern;
-        infoPattern.pattern = GetColumnText(m_listWarnPatterns, i, 0);
-        infoPattern.fileNameIndex = GetColumnText(m_listWarnPatterns, i, 1);
-        infoPattern.lineNumberIndex = GetColumnText(m_listWarnPatterns, i, 2);
-        infoPattern.columnIndex = GetColumnText(m_listWarnPatterns, i, 3);
+        infoPattern.pattern = m_dvListCtrlWarnings->GetItemText(item, 0);
+        infoPattern.fileNameIndex = m_dvListCtrlWarnings->GetItemText(item, 1);
+        infoPattern.lineNumberIndex = m_dvListCtrlWarnings->GetItemText(item, 2);
+        infoPattern.columnIndex = m_dvListCtrlWarnings->GetItemText(item, 3);
         warnPatterns.push_back(infoPattern);
     }
     m_compiler->SetWarnPatterns(warnPatterns);
@@ -849,7 +833,18 @@ CompilerPatternDlg::CompilerPatternDlg(wxWindow* parent, const wxString& title)
     : CompilerPatternDlgBase(parent, wxID_ANY, title)
 {
     SetName("CompilerPatternDlg");
-    WindowAttrManager::Load(this);
+
+    if(parent) {
+        wxSize parentSize = parent->GetSize();
+        double dlgWidth = (double)parentSize.GetWidth() * 0.67;
+        parentSize.SetWidth(dlgWidth);
+        parentSize.SetHeight(wxNOT_FOUND);
+        SetSize(parentSize);
+        SetSizeHints(parentSize);
+        GetSizer()->Fit(this);
+        GetSizer()->Layout();
+        CentreOnParent();
+    }
 }
 
 CompilerPatternDlg::~CompilerPatternDlg() {}
