@@ -24,16 +24,17 @@
 //////////////////////////////////////////////////////////////////////////////
 #include "acceltabledlg.h"
 
+#include "Keyboard/newkeyshortcutdlg.h"
 #include "fileutils.h"
 #include "globals.h"
 #include "manager.h"
-#include "newkeyshortcutdlg.h"
 #include "pluginmanager.h"
 #include "windowattrmanager.h"
 
 #include <algorithm>
 #include <wx/ffile.h>
 #include <wx/imaglist.h>
+#include <wx/msgdlg.h>
 #include <wx/stdpaths.h>
 #include <wx/tokenzr.h>
 
@@ -44,10 +45,6 @@
 AccelTableDlg::AccelTableDlg(wxWindow* parent)
     : AccelTableBaseDlg(parent)
 {
-    wxImageList* imageList = new wxImageList(16, 16);
-    imageList->Add(PluginManager::Get()->GetStdIcons()->LoadBitmap("list-control/16/sort"));
-    imageList->Add(PluginManager::Get()->GetStdIcons()->LoadBitmap("list-control/16/sort"));
-
     clKeyboardManager::Get()->GetAllAccelerators(m_accelMap);
     PopulateTable("");
 
