@@ -25,41 +25,50 @@
 
 #include "app.h"
 
-#include "BuildTab.hpp"
+#ifdef __WXGTK__
+#include "exelocator.h"
+#endif
+
+#ifdef __WXMSW__
+#include "CompilerLocator/CompilerLocatorCygwin.h"
+#include "cl_registry.h"
+#include "procutils.h"
+#endif
+
 #include "ColoursAndFontsManager.h"
-#include "CompilerLocatorCygwin.h"
+#include "Keyboard/clKeyboardManager.h"
+#include "SideBar.hpp"
 #include "SocketAPI/clSocketClient.h"
-#include "asyncprocess.h" // IProcess
 #include "autoversion.h"
-#include "clKeyboardManager.h"
 #include "clSystemSettings.h"
 #include "cl_config.h"
-#include "cl_registry.h"
 #include "conffilelocator.h"
-#include "dirsaver.h"
 #include "editor_config.h"
 #include "environmentconfig.h"
-#include "event_notifier.h"
-#include "evnvarlist.h"
-#include "exelocator.h"
+#include "envvarlist.h"
 #include "file_logger.h"
 #include "fileexplorer.h"
 #include "fileextmanager.h"
 #include "frame.h"
 #include "globals.h"
-#include "macros.h"
 #include "manager.h"
-#include "precompiled_header.h"
-#include "procutils.h"
+#include "pluginmanager.h"
 #include "singleinstancethreadjob.h"
 #include "stack_walker.h"
-#include "workspace_pane.h"
-#include "wx_xml_compatibility.h"
-#include "xmlutils.h"
 
+#include <wx/crt.h>
+#include <wx/dir.h>
+#include <wx/fontmap.h>
 #include <wx/imagjpeg.h>
+#include <wx/msgdlg.h>
 #include <wx/persist.h>
 #include <wx/regex.h>
+#include <wx/socket.h>
+#include <wx/stream.h>
+#include <wx/sysopt.h>
+#include <wx/tooltip.h>
+#include <wx/txtstrm.h>
+#include <wx/wfstream.h>
 
 // #define __PERFORMANCE
 #include "performance.h"
@@ -148,18 +157,20 @@ static void massCopy(const wxString& sourceDir, const wxString& spec, const wxSt
 {
     wxArrayString files;
     wxDir::GetAllFiles(sourceDir, &files, spec, wxDIR_FILES);
-    for(size_t i = 0; i < files.GetCount(); i++) {
+    for (size_t i = 0; i < files.GetCount(); i++) {
         wxFileName fn(files.Item(i));
         wxCopyFile(files.Item(i), destDir + wxT("/") + fn.GetFullName());
     }
 }
 #ifndef __WXMSW__
-static void ChildTerminatedSingalHandler(int signo)
+namespace
+{
+void ChildTerminatedSingalHandler(int signo)
 {
     int status;
-    while(true) {
+    while (true) {
         pid_t pid = ::waitpid(-1, &status, WNOHANG);
-        if(pid > 0) {
+        if (pid > 0) {
             // waitpid succeeded
             IProcess::SetProcessExitCode(pid, WEXITSTATUS(status));
 
@@ -170,15 +181,22 @@ static void ChildTerminatedSingalHandler(int signo)
 }
 
 // Block/Restore sigchild
-static struct sigaction old_behvior;
-static struct sigaction new_behvior;
-static void CodeLiteBlockSigChild()
+struct sigaction old_behvior;
+struct sigaction new_behvior;
+void CodeLiteBlockSigChild()
 {
     sigfillset(&new_behvior.sa_mask);
     new_behvior.sa_handler = ChildTerminatedSingalHandler;
     new_behvior.sa_flags = 0;
     sigaction(SIGCHLD, &new_behvior, &old_behvior);
 }
+
+void on_sigpipe(int sig)
+{
+    clERROR() << "Received SIGPIPE!" << endl;
+    signal(SIGPIPE, on_sigpipe);
+}
+} // namespace
 #endif
 
 #ifdef __WXGTK__
@@ -194,7 +212,7 @@ static void WaitForDebugger(int signo)
         << wxT("Attach debugger?\n");
 
     int rc = wxMessageBox(msg, wxT("CodeLite Crash Handler"), wxYES_NO | wxCENTER | wxICON_ERROR);
-    if(rc == wxYES) {
+    if (rc == wxYES) {
 
         // Launch a shell command with the following command:
         // gdb -p <PID>
@@ -202,19 +220,19 @@ static void WaitForDebugger(int signo)
         char command[256];
         memset(command, 0, sizeof(command));
 
-        if(ExeLocator::Locate(wxT("gnome-terminal"), where)) {
+        if (ExeLocator::Locate(wxT("gnome-terminal"), where)) {
             sprintf(command, "gnome-terminal -t 'gdb' -e 'gdb -p %d'", getpid());
-        } else if(ExeLocator::Locate(wxT("konsole"), where)) {
+        } else if (ExeLocator::Locate(wxT("konsole"), where)) {
             sprintf(command, "konsole -T 'gdb' -e 'gdb -p %d'", getpid());
-        } else if(ExeLocator::Locate(wxT("terminal"), where)) {
+        } else if (ExeLocator::Locate(wxT("terminal"), where)) {
             sprintf(command, "terminal -T 'gdb' -e 'gdb -p %d'", getpid());
-        } else if(ExeLocator::Locate(wxT("lxterminal"), where)) {
+        } else if (ExeLocator::Locate(wxT("lxterminal"), where)) {
             sprintf(command, "lxterminal -T 'gdb' -e 'gdb -p %d'", getpid());
         } else {
             sprintf(command, "xterm -T 'gdb' -e 'gdb -p %d'", getpid());
         }
 
-        if(system(command) == 0) {
+        if (system(command) == 0) {
             signal(signo, SIG_DFL);
             raise(signo);
         } else {
@@ -253,7 +271,7 @@ CodeLiteApp::CodeLiteApp(void)
 CodeLiteApp::~CodeLiteApp(void)
 {
     wxImage::CleanUpHandlers();
-    if(m_singleInstance) {
+    if (m_singleInstance) {
         delete m_singleInstance;
     }
     wxDELETE(m_persistencManager);
@@ -263,9 +281,7 @@ static wxLogNull NO_LOG;
 
 bool CodeLiteApp::OnInit()
 {
-#if defined(__WXMSW__) && CL_DEBUG_BUILD
-    SetAppName(wxT("codelite-dbg"));
-#elif defined(__WXOSX__)
+#if defined(__WXOSX__)
     SetAppName(wxT("CodeLite"));
 #else
     SetAppName(wxT("codelite"));
@@ -277,14 +293,21 @@ bool CodeLiteApp::OnInit()
     installationDir.RemoveLast(sizeof("/share/codelite") - 1);
     wxStandardPaths::Get().SetInstallPrefix(installationDir);
 #endif
-#if defined(__WXGTK__) || defined(__WXMAC__)
 
+#if defined(__WXGTK__) || defined(__WXMAC__)
     // block signal pipe
     sigset_t mask_set;
     sigemptyset(&mask_set);
     sigaddset(&mask_set, SIGPIPE);
     sigaddset(&mask_set, SIGTTIN);
-    sigprocmask(SIG_SETMASK, &mask_set, NULL);
+    sigprocmask(SIG_SETMASK, &mask_set, nullptr);
+
+    // CodeLite is a MT app, use pthread_sigmask()
+    sigset_t thr_mask_set;
+    sigemptyset(&thr_mask_set);
+    sigaddset(&thr_mask_set, SIGPIPE);
+    sigaddset(&thr_mask_set, SIGTTIN);
+    pthread_sigmask(SIG_SETMASK, &thr_mask_set, nullptr);
 
     // Handle sigchld
     CodeLiteBlockSigChild();
@@ -294,6 +317,7 @@ bool CodeLiteApp::OnInit()
     signal(SIGSEGV, WaitForDebugger);
     signal(SIGABRT, WaitForDebugger);
 #endif
+    signal(SIGPIPE, on_sigpipe);
 
 #endif
     wxSocketBase::Initialize();
@@ -311,11 +335,12 @@ bool CodeLiteApp::OnInit()
 #endif
 
 #ifdef __WXMSW__
-    typedef BOOL WINAPI (*SetProcessDPIAwareFunc)();
+    // HiDPI support
+    typedef BOOL(WINAPI * SetProcessDPIAwareFunc)();
     HINSTANCE user32Dll = LoadLibrary(L"User32.dll");
-    if(user32Dll) {
+    if (user32Dll) {
         SetProcessDPIAwareFunc pFunc = (SetProcessDPIAwareFunc)GetProcAddress(user32Dll, "SetProcessDPIAware");
-        if(pFunc) {
+        if (pFunc) {
             pFunc();
         }
         FreeLibrary(user32Dll);
@@ -328,18 +353,18 @@ bool CodeLiteApp::OnInit()
     // parse command line
     m_parser.SetDesc(cmdLineDesc);
     m_parser.SetCmdLine(wxAppBase::argc, wxAppBase::argv);
-    if(m_parser.Parse(false) != 0) {
+    if (m_parser.Parse(false) != 0) {
         PrintUsage(m_parser);
         return false;
     }
     wxString newDataDir(wxEmptyString);
-    if(m_parser.Found(wxT("d"), &newDataDir)) {
+    if (m_parser.Found(wxT("d"), &newDataDir)) {
         // ensure that the data dir exists
         wxFileName dd(newDataDir, wxEmptyString);
-        if(dd.IsRelative()) {
+        if (dd.IsRelative()) {
             dd.MakeAbsolute();
         }
-        if(!dd.DirExists()) {
+        if (!dd.DirExists()) {
             dd.Mkdir(wxS_DIR_DEFAULT, wxPATH_MKDIR_FULL);
         }
         clStandardPaths::Get().SetUserDataDir(dd.GetFullPath());
@@ -349,29 +374,34 @@ bool CodeLiteApp::OnInit()
     wxSystemOptions::SetOption(_T("msw.remap"), 0);
     wxSystemOptions::SetOption("msw.notebook.themed-background", 1);
     wxXmlResource::Get()->InitAllHandlers();
-    wxImage::AddHandler(new wxPNGHandler);
-    wxImage::AddHandler(new wxCURHandler);
-    wxImage::AddHandler(new wxICOHandler);
-    wxImage::AddHandler(new wxXPMHandler);
-    wxImage::AddHandler(new wxGIFHandler);
-    wxImage::AddHandler(new wxJPEGHandler);
 
-#if defined(__WXMSW__)
-    if(clConfig::Get().Read("CodeLiteAppearance", 0) == 1) {
+    ::wxInitAllImageHandlers();
+#if wxCHECK_VERSION(3, 3, 0)
+    int appearance = clConfig::Get().Read("CodeLiteAppearance", 0);
+    switch (appearance) {
+    case 1:
         // force dark
-        MSWEnableDarkMode(wxApp::DarkMode_Always);
-    } else {
-        MSWEnableDarkMode(wxApp::DarkMode_Auto);
+        SetAppearance(Appearance::Dark);
+        break;
+    case 2:
+        SetAppearance(Appearance::Light);
+        break;
+    default:
+        // use system default
+        SetAppearance(Appearance::System);
+        break;
     }
 #endif
 
+#ifndef CL_DEBUG_BUILD
+    // dont show the splash in debug builds
     bool show_splash = clConfig::Get().Read("ShowSplashScreen", true);
-    if(show_splash) {
+    if (show_splash) {
         wxBitmap bitmap;
         wxFileName splashscreen_png(clStandardPaths::Get().GetDataDir(), "splashscreen.png");
         splashscreen_png.AppendDir("images");
 
-        if(splashscreen_png.FileExists() && bitmap.LoadFile(splashscreen_png.GetFullPath(), wxBITMAP_TYPE_PNG)) {
+        if (splashscreen_png.FileExists() && bitmap.LoadFile(splashscreen_png.GetFullPath(), wxBITMAP_TYPE_PNG)) {
             wxSplashScreen* splash =
                 new wxSplashScreen(bitmap, wxSPLASH_CENTRE_ON_SCREEN | wxSPLASH_TIMEOUT, 2000, nullptr, -1,
                                    wxDefaultPosition, wxDefaultSize, wxBORDER_SIMPLE | wxSTAY_ON_TOP);
@@ -379,30 +409,31 @@ bool CodeLiteApp::OnInit()
         }
         wxYield();
     }
+#endif
 
     InitXmlResource();
 
-    if(m_parser.Found("g", &m_exeToDebug)) {
+    if (m_parser.Found("g", &m_exeToDebug)) {
         SetStartedInDebuggerMode(true);
         // Check to see if the user also passed "--working-directory" switch
         m_parser.Found("w", &m_debuggerWorkingDirectory);
-        for(size_t i = 0; i < m_parser.GetParamCount(); ++i) {
+        for (size_t i = 0; i < m_parser.GetParamCount(); ++i) {
             m_debuggerArgs << m_parser.GetParam(i) << " ";
         }
     }
 
     // check for single instance
-    if(!IsSingleInstance(m_parser)) {
+    if (!IsSingleInstance(m_parser)) {
         return false;
     }
 
-    if(m_parser.Found(wxT("h"))) {
+    if (m_parser.Found(wxT("h"))) {
         // print usage
         PrintUsage(m_parser);
         return false;
     }
 
-    if(m_parser.Found(wxT("v"))) {
+    if (m_parser.Found(wxT("v"))) {
 // print version
 #ifdef __WXMSW__
         ::wxMessageBox(wxString() << "CodeLite IDE v" << CODELITE_VERSION_STRING, "CodeLite");
@@ -413,16 +444,16 @@ bool CodeLiteApp::OnInit()
     }
 
     // When launching CodeLite as a debugger interface, disable the plugins
-    if(m_parser.Found(wxT("n")) || IsStartedInDebuggerMode()) {
+    if (m_parser.Found(wxT("n")) || IsStartedInDebuggerMode()) {
         // Load codelite without plugins
         SetPluginLoadPolicy(PP_None);
     }
 
     wxString plugins;
-    if(m_parser.Found(wxT("p"), &plugins)) {
+    if (m_parser.Found(wxT("p"), &plugins)) {
         wxArrayString pluginsArr = ::wxStringTokenize(plugins, wxT(","));
         // Trim and make lower case
-        for(size_t i = 0; i < pluginsArr.GetCount(); i++) {
+        for (size_t i = 0; i < pluginsArr.GetCount(); i++) {
             pluginsArr.Item(i).Trim().Trim(false).MakeLower();
         }
 
@@ -433,9 +464,9 @@ bool CodeLiteApp::OnInit()
 
 #if defined(__WXMSW__)
     wxString newBaseDir;
-    if(m_parser.Found(wxT("b"), &newBaseDir)) {
+    if (m_parser.Found(wxT("b"), &newBaseDir)) {
         wxFileName bd(newBaseDir, wxEmptyString);
-        if(bd.IsRelative()) {
+        if (bd.IsRelative()) {
             bd.MakeAbsolute();
         }
         homeDir = bd.GetPath();
@@ -464,10 +495,10 @@ bool CodeLiteApp::OnInit()
     ::wxSetEnv("GCC_COLORS", "");
 
 #if defined(__WXGTK__)
-    if(homeDir.IsEmpty()) {
+    if (homeDir.IsEmpty()) {
         homeDir = clStandardPaths::Get()
                       .GetUserDataDir(); // By default, ~/Library/Application Support/codelite or ~/.codelite
-        if(!wxFileName::Exists(homeDir)) {
+        if (!wxFileName::Exists(homeDir)) {
             wxLogNull noLog;
             wxFileName::Mkdir(homeDir, wxS_DIR_DEFAULT, wxPATH_MKDIR_FULL);
             wxCHECK_MSG(wxFileName::DirExists(homeDir), false, "Failed to create the requested data dir");
@@ -485,7 +516,7 @@ bool CodeLiteApp::OnInit()
 
         // copy the settings from the global location if needed
         wxString installPath(INSTALL_DIR, wxConvUTF8);
-        if(!CopySettings(homeDir, installPath))
+        if (!CopySettings(homeDir, installPath))
             return false;
         ManagerST::Get()->SetInstallDir(installPath);
 
@@ -497,7 +528,7 @@ bool CodeLiteApp::OnInit()
 
 #elif defined(__WXMAC__)
     homeDir = clStandardPaths::Get().GetUserDataDir();
-    if(!wxFileName::Exists(homeDir)) {
+    if (!wxFileName::Exists(homeDir)) {
         wxLogNull noLog;
         wxFileName::Mkdir(homeDir, wxS_DIR_DEFAULT, wxPATH_MKDIR_FULL);
         wxCHECK_MSG(wxFileName::DirExists(homeDir), false, "Failed to create the requested data dir");
@@ -522,7 +553,7 @@ bool CodeLiteApp::OnInit()
     CopySettings(homeDir, installPath);
 
 #else //__WXMSW__
-    if(homeDir.IsEmpty()) { // did we got a basedir from user?
+    if (homeDir.IsEmpty()) { // did we got a basedir from user?
 #ifdef USE_POSIX_LAYOUT
         homeDir = clStandardPaths::Get().GetDataDir();
 #else
@@ -536,13 +567,13 @@ bool CodeLiteApp::OnInit()
 
     // try to locate the menu/rc.xrc file
     wxFileName fn(homeDir + wxT("/rc"), MENU_XRC);
-    if(!fn.FileExists()) {
+    if (!fn.FileExists()) {
         // we got wrong home directory
         wxFileName appFn(wxAppBase::argv[0]);
         homeDir = appFn.GetPath();
     }
 
-    if(fnHomdDir.IsRelative()) {
+    if (fnHomdDir.IsRelative()) {
         fnHomdDir.MakeAbsolute();
         homeDir = fnHomdDir.GetPath();
     }
@@ -564,7 +595,7 @@ bool CodeLiteApp::OnInit()
     // into one giant XRC file if you wanted, but then they become more
     // diffcult to manage, and harder to reuse in later projects.
     // The menubar
-    if(!wxXmlResource::Get()->Load(DoFindMenuFile(ManagerST::Get()->GetInstallDir(), wxT("2.0"))))
+    if (!wxXmlResource::Get()->Load(DoFindMenuFile(ManagerST::Get()->GetInstallDir(), wxT("2.0"))))
         return false;
 
     // keep the startup directory
@@ -598,7 +629,7 @@ bool CodeLiteApp::OnInit()
     // Update codelite revision and Version
     wxString strVersion = CODELITE_VERSION_STRING;
     cfg->Init(strVersion, wxT("2.0.2"));
-    if(!cfg->Load()) {
+    if (!cfg->Load()) {
         clERROR() << "Failed to load configuration file: config/codelite.xml. Workding directory:" << wxGetCwd()
                   << endl;
         return false;
@@ -606,7 +637,7 @@ bool CodeLiteApp::OnInit()
 
 #ifdef __WXGTK__
     bool redirect = clConfig::Get().Read(kConfigRedirectLogOutput, true);
-    if(redirect) {
+    if (redirect) {
         // Redirect stdout/error to a file
         wxFileName stdout_err(clStandardPaths::Get().GetUserDataDir(), "codelite-stdout-stderr.log");
         FILE* new_stdout = ::freopen(stdout_err.GetFullPath().mb_str(wxConvISO8859_1).data(), "a+b", stdout);
@@ -620,7 +651,7 @@ bool CodeLiteApp::OnInit()
     // Set environment variable for CodeLiteDir (make it first
     // on the list so it can be used by other variables)
     //---------------------------------------------------------
-    EvnVarList vars;
+    EnvVarList vars;
     EnvironmentConfig::Instance()->Load();
     EnvironmentConfig::Instance()->ReadObject(wxT("Variables"), &vars);
 
@@ -637,20 +668,20 @@ bool CodeLiteApp::OnInit()
 #endif
 
     // Set up the locale if appropriate
-    if(EditorConfigST::Get()->GetOptions()->GetUseLocale()) {
+    if (EditorConfigST::Get()->GetOptions()->GetUseLocale()) {
         int preferredLocale = wxLANGUAGE_ENGLISH;
         // The locale had to be saved as the canonical locale name, as the wxLanguage enum wasn't consistent between wx
         // versions
         wxString preferredLocalename = EditorConfigST::Get()->GetOptions()->GetPreferredLocale();
-        if(!preferredLocalename.IsEmpty()) {
+        if (!preferredLocalename.IsEmpty()) {
             wxString localeToFind = preferredLocalename.BeforeFirst(':');
-            if(localeToFind.IsEmpty()) {
+            if (localeToFind.IsEmpty()) {
                 localeToFind << preferredLocalename;
             }
             const wxLanguageInfo* info = wxLocale::FindLanguageInfo(localeToFind);
-            if(info) {
+            if (info) {
                 preferredLocale = info->Language;
-                if(preferredLocale == wxLANGUAGE_UNKNOWN) {
+                if (preferredLocale == wxLANGUAGE_UNKNOWN) {
                     preferredLocale = wxLANGUAGE_ENGLISH;
                 }
             }
@@ -674,11 +705,11 @@ bool CodeLiteApp::OnInit()
         m_locale.Init(preferredLocale);
 
         bool codelitemo_found = m_locale.AddCatalog(wxT("codelite"));
-        if(!codelitemo_found) {
+        if (!codelitemo_found) {
             m_locale.AddCatalog(wxT("CodeLite")); // Hedge bets re our spelling
         }
 
-        if(!codelitemo_found) {
+        if (!codelitemo_found) {
             // I wanted to 'un-init' the locale if no translations were found
             // as otherwise, in a RTL locale, menus, dialogs etc will be displayed RTL, in English...
             // However I couldn't find a way to do this
@@ -722,8 +753,12 @@ bool CodeLiteApp::OnInit()
 #ifdef __WXGTK__
     wxUpdateUIEvent::SetUpdateInterval(500);
 #elif defined(__WXMSW__)
-    wxUpdateUIEvent::SetUpdateInterval(50);
+    wxUpdateUIEvent::SetUpdateInterval(100);
 #endif
+
+    // don't show the tooltip too fast
+    wxToolTip::SetDelay(500);
+    wxToolTip::SetReshow(500);
     return TRUE;
 }
 
@@ -731,41 +766,20 @@ void CodeLiteApp::ProcessCommandLineParams()
 {
     long lineNumber(0);
     m_parser.Found(wxT("l"), &lineNumber);
-    if(lineNumber > 0) {
+    if (lineNumber > 0) {
         lineNumber--;
     } else {
         lineNumber = 0;
     }
 
-    if(!IsStartedInDebuggerMode()) {
-        for(size_t i = 0; i < m_parser.GetParamCount(); i++) {
+    if (!IsStartedInDebuggerMode()) {
+        for (size_t i = 0; i < m_parser.GetParamCount(); i++) {
             OpenItem(m_parser.GetParam(i), lineNumber);
         }
     }
 }
 
-int CodeLiteApp::OnExit()
-{
-    clDEBUG() << "Bye" << endl;
-    EditorConfigST::Free();
-    ConfFileLocator::Release();
-
-    // flush any saved changes to the configuration file
-    clConfig::Get().Save();
-
-    if(IsRestartCodeLite()) {
-        // Execute new CodeLite instance
-        clSYSTEM() << "Restarting CodeLite:" << GetRestartCommand();
-        if(!this->m_restartWD.empty()) {
-            ::wxSetWorkingDirectory(this->m_restartWD);
-        }
-        wxExecute(GetRestartCommand(), wxEXEC_ASYNC | wxEXEC_MAKE_GROUP_LEADER);
-    }
-
-    // Delete the temp folder
-    wxFileName::Rmdir(clStandardPaths::Get().GetTempDir(), wxPATH_RMDIR_RECURSIVE);
-    return 0;
-}
+int CodeLiteApp::OnExit() { return 0; }
 
 bool CodeLiteApp::CopySettings(const wxString& destDir, wxString& installPath)
 {
@@ -779,8 +793,6 @@ bool CodeLiteApp::CopySettings(const wxString& destDir, wxString& installPath)
     massCopy(installPath + wxT("/images/"), wxT("*.png"), destDir + wxT("/images/"));
     wxCopyFile(installPath + wxT("/index.html"), destDir + wxT("/index.html"));
     wxCopyFile(installPath + wxT("/svnreport.html"), destDir + wxT("/svnreport.html"));
-    wxCopyFile(installPath + wxT("/astyle.sample"), destDir + wxT("/astyle.sample"));
-    wxCopyFile(installPath + wxT("/php.sample"), destDir + wxT("/php.sample"));
     return true;
 }
 
@@ -802,7 +814,7 @@ void CodeLiteApp::OnFatalException()
 bool CodeLiteApp::IsSingleInstance(const wxCmdLineParser& m_parser)
 {
     // check for single instance
-    if(clConfig::Get().Read(kConfigSingleInstance, false)) {
+    if (clConfig::Get().Read(kConfigSingleInstance, false)) {
         wxString name = wxString::Format(wxT("CodeLite-%s"), wxGetUserId().c_str());
 
         wxString path;
@@ -810,10 +822,10 @@ bool CodeLiteApp::IsSingleInstance(const wxCmdLineParser& m_parser)
         path = "/tmp";
 #endif
         m_singleInstance = new wxSingleInstanceChecker(name, path);
-        if(m_singleInstance->IsAnotherRunning()) {
+        if (m_singleInstance->IsAnotherRunning()) {
             // prepare commands file for the running instance
             wxArrayString files;
-            for(size_t i = 0; i < m_parser.GetParamCount(); i++) {
+            for (size_t i = 0; i < m_parser.GetParamCount(); i++) {
                 wxString argument = m_parser.GetParam(i);
 
                 // convert to full path and open it
@@ -830,10 +842,15 @@ bool CodeLiteApp::IsSingleInstance(const wxCmdLineParser& m_parser)
 
                 JSON json(cJSON_Object);
                 json.toElement().addProperty("args", files);
+
+                long lineNumber(0);
+                m_parser.Found(wxT("l"), &lineNumber);
+                json.toElement().addProperty("lineno", lineNumber);
+
                 client.WriteMessage(json.toElement().format());
                 return false;
 
-            } catch(clSocketException& e) {
+            } catch (const clSocketException& e) {
                 clERROR() << "Failed to send single instance request" << e.what() << endl;
             }
         }
@@ -843,7 +860,7 @@ bool CodeLiteApp::IsSingleInstance(const wxCmdLineParser& m_parser)
 
 void CodeLiteApp::MacOpenFile(const wxString& fileName)
 {
-    switch(FileExtManager::GetType(fileName)) {
+    switch (FileExtManager::GetType(fileName)) {
     case FileExtManager::TypeWorkspace:
         ManagerST::Get()->OpenWorkspace(fileName);
         break;
@@ -857,7 +874,7 @@ void CodeLiteApp::MSWReadRegistry()
 {
 #ifdef __WXMSW__
 
-    EvnVarList vars;
+    EnvVarList vars;
     EnvironmentConfig::Instance()->Load();
     EnvironmentConfig::Instance()->ReadObject(wxT("Variables"), &vars);
 
@@ -879,7 +896,7 @@ void CodeLiteApp::MSWReadRegistry()
     wxString iniFile;
     iniFile << ManagerST::Get()->GetInstallDir() << wxFileName::GetPathSeparator() << wxT("registry.ini");
 
-    if(wxFileName::FileExists(iniFile)) {
+    if (wxFileName::FileExists(iniFile)) {
         clRegistry::SetFilename(iniFile);
         clRegistry registry;
 
@@ -890,16 +907,16 @@ void CodeLiteApp::MSWReadRegistry()
         registry.Read(wxT("unittestpp"), strUnitTestPP);
 
         // Supprot for wxWidgets
-        if(strWx.IsEmpty() == false) {
+        if (strWx.IsEmpty() == false) {
             // we have WX installed on this machine, set the path of WXWIN & WXCFG to point to it
             EnvMap envs = vars.GetVariables(wxT("Default"), false, wxEmptyString, wxEmptyString);
 
-            if(!envs.Contains(wxT("WXWIN"))) {
+            if (!envs.Contains(wxT("WXWIN"))) {
                 vars.AddVariable(wxT("Default"), wxT("WXWIN"), strWx);
                 vars.AddVariable(wxT("Default"), wxT("PATH"), wxT("$(WXWIN)\\lib\\gcc_dll;$(PATH)"));
             }
 
-            if(!envs.Contains(wxT("WXCFG")))
+            if (!envs.Contains(wxT("WXCFG")))
                 vars.AddVariable(wxT("Default"), wxT("WXCFG"), wxT("gcc_dll\\mswu"));
 
             EnvironmentConfig::Instance()->WriteObject(wxT("Variables"), &vars);
@@ -907,11 +924,11 @@ void CodeLiteApp::MSWReadRegistry()
         }
 
         // Support for UnitTest++
-        if(strUnitTestPP.IsEmpty() == false) {
+        if (strUnitTestPP.IsEmpty() == false) {
             // we have UnitTest++ installed on this machine
             EnvMap envs = vars.GetVariables(wxT("Default"), false, wxEmptyString, wxEmptyString);
 
-            if(!envs.Contains(wxT("UNIT_TEST_PP_SRC_DIR"))) {
+            if (!envs.Contains(wxT("UNIT_TEST_PP_SRC_DIR"))) {
                 vars.AddVariable(wxT("Default"), wxT("UNIT_TEST_PP_SRC_DIR"), strUnitTestPP);
             }
 
@@ -919,7 +936,7 @@ void CodeLiteApp::MSWReadRegistry()
         }
 
         // Support for MinGW
-        if(strMingw.IsEmpty() == false) {
+        if (strMingw.IsEmpty() == false) {
             // Make sure that codelite's MinGW comes first before any other
             // MinGW installation that might exist on the machine
             strMingw << wxFileName::GetPathSeparator() << wxT("bin;");
@@ -958,7 +975,7 @@ void CodeLiteApp::AdjustPathForCygwinIfNeeded()
 {
 #ifdef __WXMSW__
     clDEBUG() << "AdjustPathForCygwinIfNeeded called" << endl;
-    if(!::clIsCygwinEnvironment()) {
+    if (!::clIsCygwinEnvironment()) {
         clDEBUG() << "Not running under Cygwin - nothing be done" << endl;
         return;
     }
@@ -967,7 +984,7 @@ void CodeLiteApp::AdjustPathForCygwinIfNeeded()
 
     wxString cygwinRootDir;
     CompilerLocatorCygwin cygwin;
-    if(cygwin.Locate()) {
+    if (cygwin.Locate()) {
         // this will return the base folder for cygwin (e.g. D:\cygwin)
         cygwinRootDir = (*cygwin.GetCompilers().begin())->GetInstallationPath();
     }
@@ -979,7 +996,7 @@ void CodeLiteApp::AdjustPathForCygwinIfNeeded()
 
     // Always add the default paths
     wxArrayString paths;
-    if(!cygwinRootDir.IsEmpty()) {
+    if (!cygwinRootDir.IsEmpty()) {
         clSYSTEM() << "Cygwin root folder is:" << cygwinRootDir << endl;
         wxFileName cygwinBinFolder(cygwinRootDir, "");
         cygwinBinFolder.AppendDir("bin");
@@ -997,10 +1014,10 @@ void CodeLiteApp::AdjustPathForCygwinIfNeeded()
     paths.insert(paths.end(), userPaths.begin(), userPaths.end());
 
     wxString fixedPath;
-    for(size_t i = 0; i < paths.GetCount(); ++i) {
+    for (size_t i = 0; i < paths.GetCount(); ++i) {
         wxString& curpath = paths.Item(i);
         static wxRegEx reCygdrive("/cygdrive/([A-Za-z])");
-        if(reCygdrive.Matches(curpath)) {
+        if (reCygdrive.Matches(curpath)) {
             // Get the drive letter
             wxString volume = reCygdrive.GetMatch(curpath, 1);
             volume << ":";
@@ -1019,7 +1036,7 @@ void CodeLiteApp::AdjustPathForMSYSIfNeeded()
 {
 #ifdef __WXMSW__
     clDEBUG() << "AdjustPathForMSYSIfNeeded called" << endl;
-    if(!::clIsMSYSEnvironment()) {
+    if (!::clIsMSYSEnvironment()) {
         clDEBUG() << "Not running under MSYS - nothing be done" << endl;
         return;
     }
@@ -1037,7 +1054,7 @@ void CodeLiteApp::AdjustPathForMSYSIfNeeded()
     wxString rootDir = "/"; // Default
     // determine the baseroot of the MSYS installation
     wxString msysRoot = ProcUtils::SafeExecuteCommand("sh -c 'cd / && pwd -W'");
-    if(!msysRoot.IsEmpty()) {
+    if (!msysRoot.IsEmpty()) {
         clSYSTEM() << "MSYS Root folder is set to:" << msysRoot << endl;
         msysRoot.Trim().Trim(false);
         rootDir.Clear();
@@ -1073,7 +1090,7 @@ void CodeLiteApp::PrintUsage(const wxCmdLineParser& m_parser)
 void CodeLiteApp::OpenFolder(const wxString& path)
 {
     wxArrayString files;
-    if(wxDir::GetAllFiles(path, &files, "*.workspace", wxDIR_FILES) == 1) {
+    if (wxDir::GetAllFiles(path, &files, "*.workspace", wxDIR_FILES) == 1) {
         ManagerST::Get()->OpenWorkspace(files.Item(0));
     } else {
         clMainFrame::Get()->GetFileExplorer()->OpenFolder(path);
@@ -1084,7 +1101,7 @@ void CodeLiteApp::OpenFolder(const wxString& path)
 void CodeLiteApp::OpenFile(const wxString& path, long lineNumber)
 {
     wxFileName fn(path);
-    if(fn.GetExt() == wxT("workspace")) {
+    if (fn.GetExt() == wxT("workspace")) {
         ManagerST::Get()->OpenWorkspace(fn.GetFullPath());
     } else {
         clMainFrame::Get()->GetMainBook()->OpenFile(fn.GetFullPath(), wxEmptyString, lineNumber);
@@ -1094,13 +1111,13 @@ void CodeLiteApp::OpenFile(const wxString& path, long lineNumber)
 void CodeLiteApp::OpenItem(const wxString& path, long lineNumber)
 {
     // convert to full path and open it
-    if(path == ".") {
+    if (path == ".") {
         // Open the current folder
         OpenFolder(ManagerST::Get()->GetOriginalCwd());
     } else {
         wxFileName fn(path);
         fn.MakeAbsolute(ManagerST::Get()->GetOriginalCwd());
-        if(wxFileName::DirExists(fn.GetFullPath())) {
+        if (wxFileName::DirExists(fn.GetFullPath())) {
             OpenFolder(fn.GetFullPath());
 
         } else {
@@ -1108,3 +1125,31 @@ void CodeLiteApp::OpenItem(const wxString& path, long lineNumber)
         }
     }
 }
+
+// Restart related code
+bool CodeLiteApp::m_restartCodeLite = false;
+wxString CodeLiteApp::m_restartCommand;
+wxString CodeLiteApp::m_restartWD;
+
+void CodeLiteApp::FinalizeShutdown()
+{
+    clDEBUG() << "Finalizing shutdown..." << endl;
+
+    EditorConfigST::Free();
+    ConfFileLocator::Release();
+
+    // flush any saved changes to the configuration file
+    clConfig::Get().Save();
+    if (m_restartCodeLite) {
+        // Execute new CodeLite instance
+        if (!m_restartWD.empty()) {
+            ::wxSetWorkingDirectory(m_restartWD);
+        }
+        clSYSTEM() << "Restarting CodeLite:" << GetRestartCommand() << endl;
+        ::wxExecute(GetRestartCommand(), wxEXEC_ASYNC | wxEXEC_MAKE_GROUP_LEADER);
+    }
+
+    // Delete the temp folder
+    wxFileName::Rmdir(clStandardPaths::Get().GetTempDir(), wxPATH_RMDIR_RECURSIVE);
+    clDEBUG() << "Finalizing shutdown...success" << endl;
+}
\ No newline at end of file
