@@ -5,6 +5,7 @@
 #include "cl_command_event.h"
 
 #include <wx/arrstr.h>
+#include <wx/choice.h>
 #include <wx/panel.h>
 
 #define OPEN_CONFIG_MGR_STR _("Open Workspace Configuration Manager...")
@@ -27,7 +28,6 @@ protected:
     void OnActiveProjectChanged(clProjectSettingsEvent& event);
 
 protected:
-    void DoUpdateChoiceWithProjects();
     void DoWorkspaceConfig();
     void DoOpenConfigurationManagerDlg();
     void DoConfigChanged(const wxString& newConfigName);
@@ -42,11 +42,6 @@ public:
      */
     void Update(const wxArrayString& projects, const wxArrayString& configurations);
 
-    /**
-     * @brief clear everything
-     */
-    void Clear();
-
     void SetActiveConfiguration(const wxString& activeConfiguration);
     void SetConfigurations(const wxArrayString& configurations, const wxString& activeConfig);
 
