@@ -25,51 +25,34 @@
 #ifndef LITEEDITOR_EDITOR_H
 #define LITEEDITOR_EDITOR_H
 
+#include "Debugger/debuggermanager.h"
 #include "LSP/CompletionItem.h"
 #include "SFTPClientData.hpp"
 #include "bookmark_manager.h"
 #include "browse_record.h"
+#include "buildtabsettingsdata.h"
 #include "clEditorStateLocker.h"
 #include "cl_calltip.h"
 #include "cl_defs.h"
 #include "cl_unredo.h"
 #include "context_base.h"
-#include "debuggermanager.h"
-#include "entry.h"
+#include "database/entry.h"
 #include "findreplacedlg.h"
 #include "globals.h"
+#include "lexer_configuration.h"
 #include "navigationmanager.h"
 #include "plugin.h"
 #include "stringhighlighterjob.h"
-#include "wx/filename.h"
-#include "wx/menu.h"
 
 #include <map>
-#include <stack>
+#include <unordered_map>
 #include <vector>
 #include <wx/bitmap.h>
 #include <wx/cmndata.h>
+#include <wx/filename.h>
+#include <wx/menu.h>
 #include <wx/stc/stc.h>
 
-#define DEBUGGER_INDICATOR 11
-#define MATCH_INDICATOR 10
-#define MARKER_WORD_HIGHLIGHT 2
-#define USER_INDICATOR 3
-#define HYPERLINK_INDICATOR 4
-#define MARKER_FIND_BAR_WORD_HIGHLIGHT 5
-#define MARKER_CONTEXT_WORD_HIGHLIGHT 6
-
-#if(wxVERSION_NUMBER < 3101)
-// Some wxSTC keycodes names were altered in 311, & the old versions deprecated
-// So, to avoid deprecation-warning spam, #define for older versions
-#define wxSTC_KEYMOD_NORM wxSTC_SCMOD_NORM
-#define wxSTC_KEYMOD_SHIFT wxSTC_SCMOD_SHIFT
-#define wxSTC_KEYMOD_CTRL wxSTC_SCMOD_CTRL
-#define wxSTC_KEYMOD_ALT wxSTC_SCMOD_ALT
-#define wxSTC_KEYMOD_SUPER wxSTC_SCMOD_SUPER
-#define wxSTC_KEYMOD_META wxSTC_SCMOD_META
-#endif
-
 class wxRichToolTip;
 class CCBoxTipWindow;
 class IManager;
@@ -95,6 +78,50 @@ typedef struct _BPtoMarker {
     marker_mask_type mask_disabled;
 } BPtoMarker;
 
+enum TrimFlags {
+    TRIM_ENABLED = (1 << 0),
+    TRIM_APPEND_LF = (1 << 1),
+    TRIM_MODIFIED_LINES = (1 << 2),
+    TRIM_IGNORE_CARET_LINE = (1 << 3),
+};
+
+/// Current editor state
+struct EditorViewState {
+    int current_line = wxNOT_FOUND;
+    int first_visible_line = wxNOT_FOUND;
+    int lines_on_screen = wxNOT_FOUND;
+
+    bool operator==(const EditorViewState& other) const
+    {
+        return current_line == other.current_line && first_visible_line == other.first_visible_line &&
+               lines_on_screen == other.lines_on_screen;
+    }
+
+    void Reset()
+    {
+        current_line = wxNOT_FOUND;
+        first_visible_line = wxNOT_FOUND;
+        lines_on_screen = wxNOT_FOUND;
+    }
+
+    EditorViewState& operator=(const EditorViewState& other)
+    {
+        current_line = other.current_line;
+        first_visible_line = other.first_visible_line;
+        lines_on_screen = other.lines_on_screen;
+        return *this;
+    }
+
+    static EditorViewState From(wxStyledTextCtrl* ctrl)
+    {
+        EditorViewState state;
+        state.first_visible_line = ctrl->GetFirstVisibleLine();
+        state.current_line = ctrl->GetCurrentLine();
+        state.lines_on_screen = ctrl->LinesOnScreen();
+        return state;
+    }
+};
+
 wxDECLARE_EVENT(wxCMD_EVENT_REMOVE_MATCH_INDICATOR, wxCommandEvent);
 wxDECLARE_EVENT(wxCMD_EVENT_ENABLE_WORD_HIGHLIGHT, wxCommandEvent);
 
@@ -247,13 +274,11 @@ protected:
     wxChar m_lastCharEntered;
     int m_lastCharEnteredPos;
     bool m_isFocused;
-    bool m_pluginInitializedRMenu;
     BOM m_fileBom;
-    int m_positionToEnsureVisible;
     bool m_preserveSelection;
     std::vector<std::pair<int, int>> m_savedMarkers;
     bool m_findBookmarksActive;
-    std::map<int, wxString> m_compilerMessagesMap;
+    std::map<int, CompilerMessage> m_compilerMessagesMap;
     CLCommandProcessor m_commandsProcessor;
     wxString m_preProcessorsWords;
     SelectionInfo m_prevSelectionInfo;
@@ -261,7 +286,6 @@ protected:
     wxTimer* m_timerHighlightMarkers;
     IManager* m_mgr;
     OptionsConfigPtr m_options;
-    bool m_hasCCAnnotation;
     wxRichToolTip* m_richTooltip;
     wxString m_keywordClasses;
     wxString m_keywordMethods;
@@ -269,18 +293,29 @@ protected:
     wxString m_keywordLocals;
     int m_editorBitmap = wxNOT_FOUND;
     size_t m_statusBarFields;
-    int m_lastBeginLine = wxNOT_FOUND;
-    int m_lastLine = wxNOT_FOUND;
+    EditorViewState m_editorState;
     int m_lastEndLine;
     int m_lastLineCount;
     wxColour m_selTextColour;
     wxColour m_selTextBgColour;
     bool m_zoomProgrammatically = false;
-    std::vector<eLineStatus> m_modifiedLines;
+    std::unordered_map<size_t, eLineStatus> m_modifiedLines;
     bool m_trackChanges = false;
     std::unordered_map<int, wxString> m_breakpoints_tooltips;
     size_t m_default_text_width = wxNOT_FOUND;
     bool m_scrollbar_recalc_is_required = false;
+    // we keep an integer that will check whether a CC needs to be triggered
+    // in the given location. This is done inside OnSciUpdateUI() method
+    // after the styles have been updated
+    int m_trigger_cc_at_pos = wxNOT_FOUND;
+    bool m_clearModifiedLines = false;
+
+    // track the position between Idle event calls
+    long m_lastIdlePosition = wxNOT_FOUND;
+    // track the position between OnSciUpdateUI calls
+    long m_lastUpdatePosition = wxNOT_FOUND;
+    uint64_t m_lastIdleEvent = 0;
+    BuildTabSettingsData m_buildOptions;
 
 public:
     static bool m_ccShowPrivateMembers;
@@ -291,37 +326,24 @@ public:
 
     IManager* GetManager() { return m_mgr; }
 
+    /// Clear the modified lines tracker
+    void ClearModifiedLines() override;
+
     /**
      * @brief CodeLite preferences updated
      */
     void PreferencesChanged();
-    /**
-     * @brief are the CC annotations visible?
-     */
-    bool IsHasCCAnnotation() const { return m_hasCCAnnotation; }
-    void ClearCCAnnotations();
 
     void SetEditorBitmap(int editorBitmap) { this->m_editorBitmap = editorBitmap; }
     int GetEditorBitmap() const { return m_editorBitmap; }
 
     void NotifyMarkerChanged(int lineNumber = wxNOT_FOUND);
 
-    /**
-     * @brief static version of the below `CenterLine`
-     * so we can use it outside of this class, e.g. from `QuickFindBar`
-     */
-    static void CenterLine(wxStyledTextCtrl* ctrl, int line, int col);
-
     /**
      * @brief static version
      */
     static void CenterLinePreserveSelection(wxStyledTextCtrl* ctrl, int line);
 
-    /**
-     * @brief static version of the below
-     */
-    static void SetCaretAt(wxStyledTextCtrl* ctrl, long pos);
-
     /**
      * @brief wrapper calling CenterLinePreserveSelection using CallAfter()
      */
@@ -342,7 +364,6 @@ public:
     bool IsFocused() const;
     CLCommandProcessor& GetCommandsProcessor() { return m_commandsProcessor; }
 
-public:
     /// Construct a clEditor object
     clEditor(wxWindow* parent);
 
@@ -418,15 +439,6 @@ public:
     // Set the project name
     void SetProject(const wxString& proj) { m_project = proj; }
 
-    /**
-     * @brief attempt to code complete the expression up until the caret position
-     * @param refreshingList when set to true, it means that the 'CodeComplete' was invoked
-     * by the code completion box itself in attempt to request new items for the list
-     * This feature is only supported internally for C++ and is not exposed to plugins
-     * i.e. the event wxEVT_CC_CODE_COMPLETE is fired only when refreshingList == false
-     */
-    void CodeComplete(bool refreshingList = false);
-
     /**
      * @brief toggle line comment
      * @param commentSymbol the comment symbol to insert (e.g. "//")
@@ -446,10 +458,6 @@ public:
 
     // User clicked Ctrl+.
     void GotoDefinition();
-    /**
-     * find declaration file for the current expression
-     */
-    void FindDeclarationFile();
 
     // return the EOL according to the content
     int GetEOLByContent();
@@ -470,9 +478,6 @@ public:
     // try to match a brace from the current caret pos and select the region
     void MatchBraceAndSelect(bool selRegion);
 
-    // Popup a find/replace dialog
-    void DoFindAndReplace(bool isReplaceDlg);
-
     // set this page as active, this usually happened when user changed the notebook
     // page to this one
     void SetActive() override;
@@ -523,11 +528,6 @@ public:
 
     // Bookmark API
     //-----------------------------------------
-    /**
-     * @brief return true if this editor has at least one compiler
-     * marker (warning or error)
-     */
-    bool HasCompilerMarkers();
 
     /**
      * @brief center the line in the editor
@@ -559,6 +559,11 @@ public:
     // Toggle marker at the current line
     void ToggleMarker();
 
+    /**
+     * @brief notify the control that was updated externally
+     */
+    void NotifyTextUpdated() override;
+
     /**
      * Delete markers from the current document
      * @param which_type if >0, delete the matching bookmark type; 0 delete the currently-active type; -1 delete all
@@ -619,7 +624,7 @@ public:
     // Replace all
     bool ReplaceAll();
     bool ReplaceAllExactMatch(const wxString& what, const wxString& replaceWith);
-    // mark all occurances
+    // mark all occurrences
     bool MarkAllFinds();
 
     // Folding API
@@ -660,12 +665,13 @@ public:
     void QuickAddNext();
 
     /**
-     * @brief find all occurances of the selected text and select
+     * @brief find all occurrences of the selected text and select
      */
     void QuickFindAll();
 
     bool FindAndSelect();
-    bool SelectRange(const LSP::Range& range) override;
+    bool SelectRangeAfter(const LSP::Range& range) override;
+    void SelectRange(const LSP::Range& range) override;
     bool SelectLocation(const LSP::Location& range) override;
     bool FindAndSelect(const FindReplaceData& data);
     bool FindAndSelect(const wxString& pattern, const wxString& name);
@@ -737,6 +743,7 @@ public:
      * Open file and clear the undo buffer
      */
     virtual void Create(const wxString& project, const wxFileName& fileName);
+    virtual void CreateRemote(const wxString& local_path, const wxString& remote_path, const wxString& ssh_account);
 
     /**
      * Insert text to the editor and keeping the page indentation
@@ -800,7 +807,7 @@ public:
      * @param pattern pattern to search in the editor
      * @param what    sub string of pattern to select
      * @param pos     start the search from 'pos'
-     * @param navmgr  Navigation manager to place browsing recrods
+     * @param navmgr  Navigation manager to place browsing records
      * @return return true if a match was found, false otherwise
      */
     bool FindAndSelect(const wxString& pattern, const wxString& what, int pos, NavMgr* navmgr) override;
@@ -818,8 +825,8 @@ public:
     void UnHighlightAll() override;
 
     // compiler warnings and errors
-    void SetWarningMarker(int lineno, const wxString& annotationText) override;
-    void SetErrorMarker(int lineno, const wxString& annotationText) override;
+    void SetWarningMarker(int lineno, CompilerMessage&& msg) override;
+    void SetErrorMarker(int lineno, CompilerMessage&& msg) override;
     void DelAllCompilerMarkers() override;
 
     void DoShowCalltip(int pos, const wxString& title, const wxString& tip, bool strip_html_tags = true);
@@ -857,13 +864,6 @@ public:
      */
     void UpdateColours();
 
-    /**
-     * @brief display completion box. This function also moves the completion box to the current position
-     * @param tags list of tags to work with
-     * @param word part of the word
-     */
-    void ShowCompletionBox(const std::vector<TagEntryPtr>& tags, const wxString& word);
-
     /**
      * @brief return true if the completion box is visible
      */
@@ -882,6 +882,12 @@ public:
      */
     void TrimText(bool trim, bool appendLf);
 
+    /**
+     * @brief an overloaded version for `TrimText()` method that accepts flags of type `TrimFlags`
+     * @param flags bitwise `TrimFlags` options
+     */
+    void TrimText(size_t flags);
+
     /**
      *--------------------------------------------------
      * Implemetation for IEditor interace
@@ -889,14 +895,6 @@ public:
      */
     wxStyledTextCtrl* GetCtrl() override { return static_cast<wxStyledTextCtrl*>(this); }
 
-    /**
-     * @brief set a code completion annotation at the given line. code completion
-     * annotations are automatically cleared on the next char added
-     * @param text
-     * @param lineno
-     */
-    void SetCodeCompletionAnnotation(const wxString& text, int lineno) override;
-
     wxString GetEditorText() override { return GetText(); }
     size_t GetEditorTextRaw(std::string& text) override;
     void SetEditorText(const wxString& text) override;
@@ -981,15 +979,15 @@ public:
     wxString FormatTextKeepIndent(const wxString& text, int pos, size_t flags = 0) override;
 
     /**
-     * @brief return the line numebr containing 'pos'
+     * @brief return the line number containing 'pos'
      * @param pos the position
      */
     int LineFromPos(int pos) override;
 
     /**
-     * @brief return the start pos of line nummber
+     * @brief return the start pos of line number
      * @param line the line number
-     * @return line nummber or 0 if the document is empty
+     * @return line number or 0 if the document is empty
      */
     int PosFromLine(int line) override;
 
@@ -1058,18 +1056,13 @@ public:
     /**
      * Get a vector of relevant position changes. Used for 'GoTo next/previous FindInFiles match'
      */
-    void GetChanges(std::vector<int>& changes);
+    std::vector<int> GetChanges();
 
     /**
      * Tells the EditorDeltasHolder that there's been (another) FindInFiles call
      */
     void OnFindInFiles();
 
-    /**
-     * @brief paste the clipboard content one line above the caret position
-     */
-    void PasteLineAbove();
-
     /**
      * @brief update editor options based on the global + workspace settings
      */
@@ -1103,11 +1096,16 @@ public:
     SFTPClientData* GetRemoteData() const override;
 
 private:
+    void DrawLineNumbers(bool force);
     void UpdateLineNumberMarginWidth();
     void DoUpdateTLWTitle(bool raise);
     void DoWrapPrevSelectionWithChars(wxChar first, wxChar last);
     int GetFirstSingleLineCommentPos(int from, int commentStyle);
-    void DoSelectRange(const LSP::Range& range);
+    void DoSelectRange(const LSP::Range& range, bool center_line);
+    /**
+     * @brief attempt to code complete the expression up until the caret position
+     */
+    void CodeComplete();
 
     /**
      * @brief set the zoom factor
@@ -1134,7 +1132,6 @@ private:
     size_t SearchFlags(const FindReplaceData& data);
 
     void AddDebuggerContextMenu(wxMenu* menu);
-    void RemoveDebuggerContextMenu(wxMenu* menu);
     void DoBreakptContextMenu(wxPoint clientPt);
     void DoMarkHyperlink(wxMouseEvent& event, bool isMiddle);
     void DoQuickJump(wxMouseEvent& event, bool isMiddle);
@@ -1148,8 +1145,8 @@ private:
     void DoToggleFold(int line, const wxString& textTag);
 
     // Line numbers drawings
-    void DoUpdateLineNumbers(bool relative_numbers);
-    void UpdateLineNumbers();
+    void DoUpdateLineNumbers(bool relative_numbers, bool force);
+    void UpdateLineNumbers(bool force);
     void UpdateDefaultTextWidth();
 
     // Event handlers
@@ -1192,6 +1189,8 @@ private:
     void OnTimer(wxTimerEvent& event);
     void OnEditorConfigChanged(wxCommandEvent& event);
     void OnColoursAndFontsUpdated(clCommandEvent& event);
+    void OnModifiedExternally(clFileSystemEvent& event);
+    void OnActiveEditorChanged(wxCommandEvent& event);
 };
 
 #endif // LITEEDITOR_EDITOR_H
