@@ -25,16 +25,15 @@
 
 #include "code_completion_manager.h"
 
-#include "CxxScannerTokens.h"
-#include "CxxVariableScanner.h"
-#include "ServiceProviderManager.h"
+#include "Cxx/CxxScannerTokens.h"
+#include "Cxx/CxxVariableScanner.h"
 #include "bitmap_loader.h"
+#include "clangd/compilation_database.h"
 #include "cl_editor.h"
 #include "code_completion_api.h"
-#include "compilation_database.h"
 #include "compiler_command_line_parser.h"
 #include "ctags_manager.h"
-#include "entry.h"
+#include "database/entry.h"
 #include "event_notifier.h"
 #include "file_logger.h"
 #include "fileextmanager.h"
@@ -71,25 +70,17 @@ struct EditorDimmerDisabler {
 };
 
 CodeCompletionManager::CodeCompletionManager()
-    : ServiceProvider("BuiltIn C++ Code Completion", eServiceType::kCodeCompletion)
-    , m_options(CC_CTAGS_ENABLED)
-    , m_wordCompletionRefreshNeeded(false)
+    : m_options(CC_CTAGS_ENABLED)
     , m_buildInProgress(false)
 {
-    SetPriority(75);
-    EventNotifier::Get()->Connect(wxEVT_BUILD_STARTED, clBuildEventHandler(CodeCompletionManager::OnBuildStarted), NULL,
-                                  this);
+    EventNotifier::Get()->Bind(wxEVT_BUILD_STARTED, &CodeCompletionManager::OnBuildStarted, this);
     EventNotifier::Get()->Bind(wxEVT_COMPILE_COMMANDS_JSON_GENERATED,
                                &CodeCompletionManager::OnCompileCommandsFileGenerated, this);
 
-    EventNotifier::Get()->Connect(wxEVT_FILE_SAVED, clCommandEventHandler(CodeCompletionManager::OnFileSaved), NULL,
-                                  this);
-    EventNotifier::Get()->Connect(wxEVT_FILE_LOADED, clCommandEventHandler(CodeCompletionManager::OnFileLoaded), NULL,
-                                  this);
-    EventNotifier::Get()->Connect(wxEVT_WORKSPACE_CONFIG_CHANGED,
-                                  wxCommandEventHandler(CodeCompletionManager::OnWorkspaceConfig), NULL, this);
-    EventNotifier::Get()->Connect(wxEVT_CMD_PROJ_SETTINGS_SAVED,
-                                  wxCommandEventHandler(CodeCompletionManager::OnWorkspaceConfig), NULL, this);
+    EventNotifier::Get()->Bind(wxEVT_FILE_SAVED, &CodeCompletionManager::OnFileSaved, this);
+    EventNotifier::Get()->Bind(wxEVT_FILE_LOADED, &CodeCompletionManager::OnFileLoaded, this);
+    EventNotifier::Get()->Bind(wxEVT_WORKSPACE_CONFIG_CHANGED, &CodeCompletionManager::OnWorkspaceConfig, this);
+    EventNotifier::Get()->Bind(wxEVT_CMD_PROJ_SETTINGS_SAVED, &CodeCompletionManager::OnWorkspaceConfig, this);
     wxTheApp->Bind(wxEVT_ACTIVATE_APP, &CodeCompletionManager::OnAppActivated, this);
 
     EventNotifier::Get()->Bind(wxEVT_WORKSPACE_CLOSED, &CodeCompletionManager::OnWorkspaceClosed, this);
@@ -117,27 +108,17 @@ CodeCompletionManager::~CodeCompletionManager()
                                  &CodeCompletionManager::OnBlockCommentWordComplete, this);
 
     EventNotifier::Get()->Unbind(wxEVT_BUILD_ENDED, &CodeCompletionManager::OnBuildEnded, this);
-    EventNotifier::Get()->Disconnect(wxEVT_BUILD_STARTED, clBuildEventHandler(CodeCompletionManager::OnBuildStarted),
-                                     NULL, this);
+    EventNotifier::Get()->Unbind(wxEVT_BUILD_STARTED, &CodeCompletionManager::OnBuildStarted, this);
     EventNotifier::Get()->Unbind(wxEVT_COMPILE_COMMANDS_JSON_GENERATED,
                                  &CodeCompletionManager::OnCompileCommandsFileGenerated, this);
-    EventNotifier::Get()->Disconnect(wxEVT_FILE_SAVED, clCommandEventHandler(CodeCompletionManager::OnFileSaved), NULL,
-                                     this);
-    EventNotifier::Get()->Disconnect(wxEVT_FILE_LOADED, clCommandEventHandler(CodeCompletionManager::OnFileLoaded),
-                                     NULL, this);
-    EventNotifier::Get()->Disconnect(wxEVT_WORKSPACE_CONFIG_CHANGED,
-                                     wxCommandEventHandler(CodeCompletionManager::OnWorkspaceConfig), NULL, this);
-    EventNotifier::Get()->Disconnect(wxEVT_CMD_PROJ_SETTINGS_SAVED,
-                                     wxCommandEventHandler(CodeCompletionManager::OnWorkspaceConfig), NULL, this);
+    EventNotifier::Get()->Unbind(wxEVT_FILE_SAVED, &CodeCompletionManager::OnFileSaved, this);
+    EventNotifier::Get()->Unbind(wxEVT_FILE_LOADED, &CodeCompletionManager::OnFileLoaded, this);
+    EventNotifier::Get()->Unbind(wxEVT_WORKSPACE_CONFIG_CHANGED, &CodeCompletionManager::OnWorkspaceConfig, this);
+    EventNotifier::Get()->Unbind(wxEVT_CMD_PROJ_SETTINGS_SAVED, &CodeCompletionManager::OnWorkspaceConfig, this);
     EventNotifier::Get()->Unbind(wxEVT_WORKSPACE_CLOSED, &CodeCompletionManager::OnWorkspaceClosed, this);
     wxTheApp->Unbind(wxEVT_ACTIVATE_APP, &CodeCompletionManager::OnAppActivated, this);
     EventNotifier::Get()->Unbind(wxEVT_ENVIRONMENT_VARIABLES_MODIFIED,
                                  &CodeCompletionManager::OnEnvironmentVariablesModified, this);
-
-    if(m_compileCommandsThread) {
-        m_compileCommandsThread->join();
-        wxDELETE(m_compileCommandsThread);
-    }
 }
 
 CodeCompletionManager& CodeCompletionManager::Get()
@@ -192,7 +173,6 @@ void CodeCompletionManager::OnWorkspaceConfig(wxCommandEvent& event)
 void CodeCompletionManager::OnWorkspaceClosed(clWorkspaceEvent& event)
 {
     event.Skip();
-    LanguageST::Get()->ClearAdditionalScopesCache();
 }
 
 void CodeCompletionManager::OnEnvironmentVariablesModified(clCommandEvent& event)
@@ -203,34 +183,6 @@ void CodeCompletionManager::OnEnvironmentVariablesModified(clCommandEvent& event
     }
 }
 
-void CodeCompletionManager::DoProcessCompileCommands()
-{
-    // return; // for now, dont use it
-    if(m_compileCommandsThread) {
-        return;
-    }
-
-    // Create a thread that will process the current workspace folder and search for any compile_commands.json file
-    m_compileCommandsThread = new std::thread(&CodeCompletionManager::ThreadProcessCompileCommandsEntry, this,
-                                              clCxxWorkspaceST::Get()->GetDir());
-}
-
-void CodeCompletionManager::ThreadProcessCompileCommandsEntry(CodeCompletionManager* owner, const wxString& rootFolder)
-{
-    // Search for compile_commands file, process it and send back the results to the main thread
-    wxArrayString includePaths = CompilationDatabase::FindIncludePaths(rootFolder, owner->m_compileCommands,
-                                                                       owner->m_compileCommandsLastModified);
-    owner->CallAfter(&CodeCompletionManager::CompileCommandsFileProcessed, includePaths);
-}
-
-void CodeCompletionManager::CompileCommandsFileProcessed(const wxArrayString& includePaths)
-{
-    if(m_compileCommandsThread) {
-        m_compileCommandsThread->join();
-        wxDELETE(m_compileCommandsThread);
-    }
-}
-
 void CodeCompletionManager::OnBlockCommentCodeComplete(clCodeCompletionEvent& event)
 {
     event.Skip();
