@@ -25,16 +25,16 @@
 #ifndef CONTEXT_BASE_H
 #define CONTEXT_BASE_H
 
-#include "entry.h"
+#include "database/entry.h"
 #include "lexer_configuration.h"
 #include "macros.h"
-#include "smart_ptr.h"
-#include "wx/filename.h"
-#include "wx/string.h"
 
+#include <memory>
 #include <set>
 #include <vector>
+#include <wx/filename.h>
 #include <wx/stc/stc.h>
+#include <wx/string.h>
 
 class clEditor;
 
@@ -120,14 +120,14 @@ public:
     virtual void OnDwellEnd(wxStyledTextEvent& event) { event.Skip(); }
     virtual void OnDbgDwellEnd(wxStyledTextEvent& event) { event.Skip(); }
     virtual void OnDbgDwellStart(wxStyledTextEvent& event) { event.Skip(); }
-    virtual void OnKeyDown(wxKeyEvent& event) { event.Skip(); }
+    virtual void OnKeyDown(wxKeyEvent& event);
     virtual void AddMenuDynamicContent(wxMenu* WXUNUSED(menu)) {}
     virtual void RemoveMenuDynamicContent(wxMenu* WXUNUSED(menu)) {}
     virtual void OnSciUpdateUI(wxStyledTextEvent& WXUNUSED(event)) {}
     virtual void OnFileSaved() {}
     virtual void OnEnterHit() {}
     virtual void RetagFile() {}
-    virtual void OnUserTypedXChars(const wxString& word);
+    virtual void OnUserTypedXChars(int pos);
     virtual wxString CallTipContent() { return wxEmptyString; }
     virtual void SetActive() {}
     virtual bool IsCommentOrString(long WXUNUSED(pos)) { return false; }
@@ -147,7 +147,6 @@ public:
         wxUnusedVar(pos);
         return false;
     }
-    virtual bool GetHoverTip(int pos) { return false; }
     virtual bool GotoDefinition() { return false; }
     virtual TagEntryPtr GetTagAtCaret(bool scoped, bool impl) { return NULL; }
     virtual wxString GetCurrentScopeName() { return wxEmptyString; }
@@ -168,5 +167,5 @@ public:
     int PositionBeforeCurrent() const;
 };
 
-typedef SmartPtr<ContextBase> ContextBasePtr;
+using ContextBasePtr = std::shared_ptr<ContextBase>;
 #endif // CONTEXT_BASE_H
