@@ -22,13 +22,10 @@
 //
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
-#include "event_notifier.h"
 #include "fileexplorer.h"
-#include "wx/sizer.h"
-#include "wx/tokenzr.h"
-#include "wx/xrc/xmlres.h"
 
 #include "OpenFolderDlg.h"
+#include "SideBar.hpp"
 #include "clFileOrFolderDropTarget.h"
 #include "clToolBarButton.h"
 #include "clTreeCtrlPanel.h"
@@ -36,15 +33,19 @@
 #include "cl_config.h"
 #include "codelite_events.h"
 #include "editor_config.h"
+#include "event_notifier.h"
 #include "file_logger.h"
 #include "frame.h"
 #include "globals.h"
 #include "macros.h"
 #include "manager.h"
 #include "plugin.h"
-#include "workspace_pane.h"
+
 #include <wx/arrstr.h>
 #include <wx/dirdlg.h>
+#include <wx/sizer.h>
+#include <wx/tokenzr.h>
+#include <wx/xrc/xmlres.h>
 
 FileExplorer::FileExplorer(wxWindow* parent, const wxString& caption)
     : wxPanel(parent, wxID_ANY, wxDefaultPosition, wxSize(250, 300))
@@ -63,7 +64,7 @@ void FileExplorer::CreateGUIControls()
     SetSizer(mainSizer);
     m_view = new clTreeCtrlPanel(this);
     auto images = m_view->GetToolBar()->GetBitmapsCreateIfNeeded();
-    m_view->GetToolBar()->AddTool(wxID_OPEN, _("Open folder"), images->Add("folder"));
+    m_view->GetToolBar()->AddTool(wxID_OPEN, _("Open folder"), images->Add("folder-yellow-opened"));
     m_view->GetToolBar()->Realize();
     m_view->GetToolBar()->Bind(wxEVT_TOOL, &FileExplorer::OnOpenFolder, this, wxID_OPEN);
     // For the file explorer we use the standard configuration tool
@@ -79,10 +80,7 @@ void FileExplorer::OnFolderDropped(clCommandEvent& event)
     for(size_t i = 0; i < folders.size(); ++i) {
         m_view->AddFolder(folders.Item(i));
     }
-    size_t index = clGetManager()->GetWorkspacePaneNotebook()->GetPageIndex(_("Explorer"));
-    if(index != wxString::npos) {
-        clGetManager()->GetWorkspacePaneNotebook()->ChangeSelection(index);
-    }
+    clGetManager()->BookSelectPage(PaneId::SIDE_BAR, _("Explorer"));
 }
 
 void FileExplorer::OpenFolder(const wxString& path) { m_view->AddFolder(path); }
