@@ -25,9 +25,10 @@
 #ifndef LITEEDITOR_FRAME_H
 #define LITEEDITOR_FRAME_H
 
+#include "AsyncProcess/ZombieReaperPOSIX.h"
 #include "EnvironmentVariablesDlg.h"
 #include "Notebook.h"
-#include "ZombieReaperPOSIX.h"
+#include "SecondarySideBar.hpp"
 #include "clCaptionBar.hpp"
 #include "clDockingManager.h"
 #include "clInfoBar.h"
@@ -67,7 +68,7 @@ class CodeLiteApp;
 class clSingleInstanceThread;
 class wxCustomStatusBar;
 class TagEntry;
-class WorkspacePane;
+class SideBar;
 class wxToolBar;
 class OpenWindowsPanel;
 class WorkspaceTab;
@@ -97,7 +98,8 @@ class clMainFrame : public wxFrame
     static clMainFrame* m_theFrame;
     clDockingManager m_mgr;
     OutputPane* m_outputPane;
-    WorkspacePane* m_workspacePane;
+    SideBar* m_sidebar = nullptr;
+    SecondarySideBar* m_secondary_sidebar = nullptr;
     wxArrayString m_files;
     wxTimer* m_timer;
     std::map<int, wxString> m_viewAsMap;
@@ -146,7 +148,8 @@ class clMainFrame : public wxFrame
     clCaptionBar* m_captionBar = nullptr;
 #endif
     // the main tool default style
-    int m_mainToolbarStyle = wxTB_FLAT | wxTB_NODIVIDER | wxTB_LEFT;
+    int m_mainToolbarStyle = wxTB_FLAT | wxTB_NODIVIDER /* toolbar is hidden by default */;
+    wxString m_mainFrameTitleTemplate;
 
 public:
     static bool m_initCompleted;
@@ -168,6 +171,8 @@ public:
     static clMainFrame* Get();
     static void Initialize(bool loadLastSession);
 
+    wxPanel* GetMainPanel() const { return m_mainPanel; }
+
     clInfoBar* GetMessageBar() { return m_infoBar; }
 
     /**
@@ -269,7 +274,12 @@ public:
     /**
      * @return the workspace pane (the one that contained the Symbol view & class view)
      */
-    WorkspacePane* GetWorkspacePane() { return m_workspacePane; }
+    SideBar* GetWorkspacePane() { return m_sidebar; }
+
+    /**
+     * @return the workspace pane (the one that contained the Symbol view & class view)
+     */
+    SecondarySideBar* GetSecondarySideBar() { return m_secondary_sidebar; }
 
     /**
      * return the workspace tab pane
@@ -295,7 +305,7 @@ public:
 
     /**
      * Compelete the main frame initialization
-     * this method is called immediatly after the
+     * this method is called immediately after the
      * main frame construction is over.
      */
     void CompleteInitialization();
@@ -359,8 +369,6 @@ private:
                 long style = wxMINIMIZE_BOX | wxMAXIMIZE_BOX | wxCLOSE_BOX | wxCAPTION | wxSYSTEM_MENU |
                              wxRESIZE_BORDER | wxCLIP_CHILDREN);
     void AddKeyboardAccelerators();
-    wxString CreateWorkspaceTable();
-    wxString CreateFilesTable();
     void StartTimer();
 
 private:
@@ -378,11 +386,6 @@ private:
 
     void PostConstruct();
 
-    /**
-     * \brief update the path & name of the build tool
-     * on windows, try to locate make, followed by mingw32-make
-     */
-    void UpdateBuildTools();
     /**
      * Helper function that prompt user with a simple wxTextEntry dialog
      * @param msg message to display to user
@@ -401,29 +404,12 @@ private:
     void CreateRecentlyOpenedFilesMenu();
     void CreateWelcomePage();
     bool ReloadExternallyModifiedProjectFiles();
-    void DoEnableWorkspaceViewFlag(bool enable, int flag);
-    bool IsWorkspaceViewFlagEnabled(int flag);
     /**
      * @brief show the startup wizard
      * @return true if a restart is needed
      */
     bool StartSetupWizard(bool firstTime);
 
-    /**
-     * @brief see if the wizard changed developer profile
-     * @return true if the 'Save Perspective' dialog should not be shown
-     */
-    bool GetAndResetNoSavePerspectivePrompt()
-    {
-        bool ans = m_noSavePerspectivePrompt;
-        m_noSavePerspectivePrompt = false;
-        return ans;
-    }
-    /**
-     * @brief mark not to show the 'Save Perspective' dialog on next close
-     */
-    void SetNoSavePerspectivePrompt(bool devProfileChanged) { m_noSavePerspectivePrompt = devProfileChanged; }
-
     void DoShowCaptions(bool show);
 
 public:
@@ -604,7 +590,6 @@ protected:
     void OnCloseAllButThis(wxCommandEvent& e);
     void OnCloseTabsToTheRight(wxCommandEvent& e);
     void OnWorkspaceMenuUI(wxUpdateUIEvent& e);
-    void OnUpdateBuildRefactorIndexBar(wxCommandEvent& e);
     void OnBuildWorkspace(wxCommandEvent& e);
     void OnBuildWorkspaceUI(wxUpdateUIEvent& e);
     void OnCleanWorkspace(wxCommandEvent& e);
@@ -647,6 +632,7 @@ protected:
     void OnPrevTab(wxCommandEvent& e);
     void OnNextPrevTab_UI(wxUpdateUIEvent& e);
     void OnShowFullScreen(wxCommandEvent& e);
+    void OnShowBuiltInTerminal(wxCommandEvent& e);
     void OnFindResourceXXX(wxCommandEvent& e);
     void OnShowActiveProjectSettings(wxCommandEvent& e);
     void OnShowActiveProjectSettingsUI(wxUpdateUIEvent& e);
@@ -655,10 +641,8 @@ protected:
     void OnSetActivePoject(wxCommandEvent& e);
     void OnSetActivePojectUI(wxUpdateUIEvent& e);
 
-    // Clang
-    void OnPchCacheStarted(wxCommandEvent& e);
-    void OnPchCacheEnded(wxCommandEvent& e);
-
+    void OnMainToolBarHide(wxCommandEvent& event);
+    void OnMainToolBarHideUI(wxUpdateUIEvent& event);
     void OnMainToolBarPlaceTop(wxCommandEvent& event);
     void OnMainToolBarPlaceTopUI(wxUpdateUIEvent& event);
     void OnMainToolBarPlaceBottom(wxCommandEvent& event);
@@ -673,7 +657,6 @@ protected:
     void OnActiveEditorChanged(wxCommandEvent& e);
     void OnWorkspaceLoaded(clWorkspaceEvent& e);
     void OnWorkspaceClosed(clWorkspaceEvent& e);
-    void OnRefactoringCacheStatus(wxCommandEvent& e);
     void OnChangeActiveBookmarkType(wxCommandEvent& e);
     void OnSettingsChanged(wxCommandEvent& e);
     void OnEditMenuOpened(wxMenuEvent& e);
@@ -682,8 +665,7 @@ protected:
     // Search handlers
     void OnFindSelection(wxCommandEvent& event);
     void OnFindSelectionPrev(wxCommandEvent& event);
-    void OnFindWordAtCaret(wxCommandEvent& event);
-    void OnFindWordAtCaretPrev(wxCommandEvent& event);
+
     DECLARE_EVENT_TABLE()
 };
 
