@@ -23,19 +23,18 @@
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 
+#include "localstable.h"
+
+#include "Debugger/debuggermanager.h"
 #include "debuggerconfigtool.h"
-#include "debuggermanager.h"
-#include "drawingutils.h"
 #include "event_notifier.h"
 #include "frame.h"
 #include "globals.h"
-#include "localstable.h"
 #include "macros.h"
 #include "manager.h"
-#include "new_quick_watch_dlg.h"
-#include <algorithm>
-#include <set>
+
 #include <wx/regex.h>
+#include <wx/textdlg.h>
 #include <wx/utils.h>
 #include <wx/wupdlock.h>
 #include <wx/xrc/xmlres.h>
@@ -81,7 +80,7 @@ void LocalsTable::Initialize()
 
     DebuggerInformation info;
     IDebugger* dbgr = DebuggerMgr::Get().GetActiveDebugger();
-    if(dbgr) {
+    if (dbgr) {
         DebuggerMgr::Get().GetDebuggerInformation(dbgr->GetName(), info);
         m_resolveLocals = info.resolveLocals;
         m_arrayAsCharPtr = info.charArrAsPtr;
@@ -96,11 +95,11 @@ void LocalsTable::OnCreateVariableObj(const DebuggerEventData& event)
 {
     wxString expr = event.m_expression;
     std::map<wxString, wxTreeItemId>::iterator iter = m_createVarItemId.find(expr);
-    if(iter != m_createVarItemId.end()) {
+    if (iter != m_createVarItemId.end()) {
 
         // set the variable object
         DbgTreeItemData* data = static_cast<DbgTreeItemData*>(m_listTable->GetItemData(iter->second));
-        if(data) {
+        if (data) {
 
             data->_gdbId = event.m_variableObject.gdbId;
             data->_kind = DbgTreeItemData::VariableObject;
@@ -111,7 +110,7 @@ void LocalsTable::OnCreateVariableObj(const DebuggerEventData& event)
 
             // refresh this item only
             IDebugger* dbgr = DoGetDebugger();
-            if(dbgr)
+            if (dbgr)
                 DoRefreshItem(dbgr, iter->second, false);
 
             dbgr->UpdateVariableObject(data->_gdbId, m_DBG_USERR);
@@ -126,7 +125,7 @@ void LocalsTable::OnListChildren(const DebuggerEventData& event)
 {
     wxString gdbId = event.m_expression;
     std::map<wxString, wxTreeItemId>::iterator iter = m_listChildItemId.find(gdbId);
-    if(iter == m_listChildItemId.end())
+    if (iter == m_listChildItemId.end())
         return;
 
     IDebugger* dbgr = DoGetDebugger();
@@ -135,12 +134,12 @@ void LocalsTable::OnListChildren(const DebuggerEventData& event)
     wxTreeItemId item = iter->second;
     m_listChildItemId.erase(iter);
 
-    if(event.m_userReason == m_LIST_CHILDS) {
+    if (event.m_userReason == m_LIST_CHILDS) {
         m_listTable->Begin();
-        if(event.m_varObjChildren.empty() == false) {
-            for(size_t i = 0; i < event.m_varObjChildren.size(); i++) {
+        if (event.m_varObjChildren.empty() == false) {
+            for (size_t i = 0; i < event.m_varObjChildren.size(); i++) {
                 const VariableObjChild& ch = event.m_varObjChildren.at(i);
-                if(ch.varName == "public" || ch.varName == "private" || ch.varName == "protected") {
+                if (ch.varName == "public" || ch.varName == "private" || ch.varName == "protected") {
                     // not really a node...
                     // ask for information about this node children
                     dbgr->ListChildren(ch.gdbId, m_LIST_CHILDS);
@@ -156,7 +155,7 @@ void LocalsTable::OnListChildren(const DebuggerEventData& event)
                     m_listTable->SetItemText(child, ch.type, 2);
 
                     // Add a dummy node
-                    if(child.IsOk() && ch.numChilds > 0) {
+                    if (child.IsOk() && ch.numChilds > 0) {
                         m_listTable->AppendItem(child, wxT("<dummy>"));
                     }
 
@@ -176,10 +175,10 @@ void LocalsTable::OnVariableObjUpdate(const DebuggerEventData& event)
     VariableObjectUpdateInfo updateInfo = event.m_varObjUpdateInfo;
 
     // remove all obsolete items
-    for(size_t i = 0; i < updateInfo.removeIds.GetCount(); i++) {
+    for (size_t i = 0; i < updateInfo.removeIds.GetCount(); i++) {
         wxString gdbId = updateInfo.removeIds.Item(i);
         wxTreeItemId item = DoFindItemByGdbId(gdbId);
-        if(item.IsOk()) {
+        if (item.IsOk()) {
             DoDeleteWatch(item);
             m_listTable->Delete(item);
         }
@@ -187,7 +186,7 @@ void LocalsTable::OnVariableObjUpdate(const DebuggerEventData& event)
 
     // refresh the values of the items that requires that
     IDebugger* dbgr = DoGetDebugger();
-    if(dbgr) {
+    if (dbgr) {
         wxArrayString itemsToRefresh = event.m_varObjUpdateInfo.refreshIds;
         DoRefreshItemRecursively(dbgr, m_listTable->GetRootItem(), itemsToRefresh);
     }
@@ -200,19 +199,19 @@ void LocalsTable::OnItemExpanding(wxTreeEvent& event)
     wxTreeItemId child = m_listTable->GetFirstChild(event.GetItem(), cookie);
 
     IDebugger* dbgr = DoGetDebugger();
-    if(!dbgr || !event.GetItem()) {
+    if (!dbgr || !event.GetItem()) {
         // dont allow the expansion of this item
         event.Veto();
         return;
     }
 
     size_t childCount = m_listTable->GetChildrenCount(event.GetItem());
-    if(childCount > 1) {
+    if (childCount > 1) {
         // make sure there is no <dummy> node and continue
         wxTreeItemIdValue cookieOne;
         wxTreeItemId dummyItem = m_listTable->GetFirstChild(event.GetItem(), cookieOne);
-        while(dummyItem.IsOk()) {
-            if(m_listTable->GetItemText(dummyItem) == wxT("<dummy>")) {
+        while (dummyItem.IsOk()) {
+            if (m_listTable->GetItemText(dummyItem) == wxT("<dummy>")) {
                 m_listTable->Delete(dummyItem);
                 event.Skip();
                 return;
@@ -220,13 +219,13 @@ void LocalsTable::OnItemExpanding(wxTreeEvent& event)
             dummyItem = m_listTable->GetNextChild(event.GetItem(), cookieOne);
         }
 
-    } else if(child.IsOk() && m_listTable->GetItemText(child) == wxT("<dummy>")) {
+    } else if (child.IsOk() && m_listTable->GetItemText(child) == wxT("<dummy>")) {
 
         // a dummy node, replace it with the real node content
         m_listTable->Delete(child);
 
         wxString gdbId = DoGetGdbId(event.GetItem());
-        if(gdbId.IsEmpty() == false) {
+        if (gdbId.IsEmpty() == false) {
             dbgr->UpdateVariableObject(gdbId, m_DBG_USERR);
             dbgr->ListChildren(gdbId, m_LIST_CHILDS);
             m_listChildItemId[gdbId] = event.GetItem();
@@ -236,7 +235,7 @@ void LocalsTable::OnItemExpanding(wxTreeEvent& event)
             // create a variable object
             wxString expres = m_listTable->GetItemText(event.GetItem());
             DbgTreeItemData* data = (DbgTreeItemData*)m_listTable->GetItemData(event.GetItem());
-            if(data && data->_kind == DbgTreeItemData::FuncRetValue) {
+            if (data && data->_kind == DbgTreeItemData::FuncRetValue) {
                 expres = data->_retValueGdbValue;
             }
 
@@ -255,11 +254,11 @@ void LocalsTable::DoClearNonVariableObjectEntries(wxArrayString& itemsNotRemoved
     std::vector<wxTreeItemId> itemsToRemove;
 
     wxTreeItemId item = m_listTable->GetFirstChild(m_listTable->GetRootItem(), cookie);
-    while(item.IsOk()) {
+    while (item.IsOk()) {
         wxString gdbId = DoGetGdbId(item);
-        if(gdbId.IsEmpty()) {
+        if (gdbId.IsEmpty()) {
             DbgTreeItemData* data = static_cast<DbgTreeItemData*>(m_listTable->GetItemData(item));
-            if(data && (data->_kind & flags)) {
+            if (data && (data->_kind & flags)) {
                 // not a variable object entry, remove it
                 itemsToRemove.push_back(item);
             }
@@ -270,7 +269,7 @@ void LocalsTable::DoClearNonVariableObjectEntries(wxArrayString& itemsNotRemoved
         item = m_listTable->GetNextChild(m_listTable->GetRootItem(), cookie);
     }
 
-    for(size_t i = 0; i < itemsToRemove.size(); i++) {
+    for (size_t i = 0; i < itemsToRemove.size(); i++) {
         oldValues[m_listTable->GetItemText(itemsToRemove[i])] = m_listTable->GetItemText(itemsToRemove[i], 1);
         m_listTable->Delete(itemsToRemove[i]);
     }
@@ -280,7 +279,7 @@ void LocalsTable::DoUpdateLocals(const LocalVariables& localsUnSorted, size_t ki
 {
     LocalVariables locals = localsUnSorted;
     wxTreeItemId root = m_listTable->GetRootItem();
-    if(!root.IsOk())
+    if (!root.IsOk())
         return;
 
     IDebugger* dbgr = DoGetDebugger();
@@ -290,33 +289,33 @@ void LocalsTable::DoUpdateLocals(const LocalVariables& localsUnSorted, size_t ki
 
     std::map<wxString, wxString> oldValues;
     DoClearNonVariableObjectEntries(itemsNotRemoved, kind, oldValues);
-    for(size_t i = 0; i < locals.size(); i++) {
+    for (size_t i = 0; i < locals.size(); i++) {
 
         // try to replace the
         wxString newVarName;
-        if(m_resolveLocals) {
+        if (m_resolveLocals) {
             newVarName = m_preDefTypes.GetPreDefinedTypeForTypename(locals[i].type, locals[i].name);
         }
 
         // Evaluate arrays as char*?
         static wxRegEx reConstArr(wxT("(const )?[ ]*(w)?char(_t)? *[\\[0-9\\]]*"));
         wxString type = locals[i].type;
-        if(m_arrayAsCharPtr && reConstArr.Matches(type)) {
+        if (m_arrayAsCharPtr && reConstArr.Matches(type)) {
             // array
             newVarName.Clear();
             newVarName << wxT("(char*)") << locals[i].name;
         }
 
-        if(newVarName.IsEmpty() == false && !newVarName.Contains(wxT("@"))) {
+        if (newVarName.IsEmpty() == false && !newVarName.Contains(wxT("@"))) {
             wxTreeItemId treeItem = DoFindItemByExpression(newVarName);
-            if(treeItem.IsOk()) {
+            if (treeItem.IsOk()) {
                 // an item with this expression already exists, skip it
                 continue;
             }
 
             // replace the local with a variable object
             // but make sure we dont enter a duplicate item
-            if(itemsNotRemoved.Index(newVarName) == wxNOT_FOUND) {
+            if (itemsNotRemoved.Index(newVarName) == wxNOT_FOUND) {
                 // this type has a pre-defined type, use it instead
 
                 // Mark this item as VariableObject so incase another call
@@ -328,7 +327,7 @@ void LocalsTable::DoUpdateLocals(const LocalVariables& localsUnSorted, size_t ki
                 m_listTable->AppendItem(item, wxT("<dummy>"));
                 m_listTable->Collapse(item);
 
-                if(dbgr) {
+                if (dbgr) {
                     dbgr->CreateVariableObject(newVarName, false, m_DBG_USERR);
                     m_createVarItemId[newVarName] = item;
                 }
@@ -336,7 +335,7 @@ void LocalsTable::DoUpdateLocals(const LocalVariables& localsUnSorted, size_t ki
 
         } else {
 
-            if(itemsNotRemoved.Index(locals[i].name) == wxNOT_FOUND) {
+            if (itemsNotRemoved.Index(locals[i].name) == wxNOT_FOUND) {
                 // New entry
                 wxTreeItemId item = m_listTable->AppendItem(root, locals[i].name, -1, -1, new DbgTreeItemData());
                 // m_listTable->SetItemTextColour(item, DrawingUtils::GetMenuTextColour());
@@ -345,7 +344,7 @@ void LocalsTable::DoUpdateLocals(const LocalVariables& localsUnSorted, size_t ki
                 m_listTable->SetItemText(item, locals[i].type, 2);
 
                 std::map<wxString, wxString>::iterator iter = oldValues.find(locals[i].name);
-                if(iter != oldValues.end() && iter->second != locals[i].value) {
+                if (iter != oldValues.end() && iter->second != locals[i].value) {
                     m_listTable->SetItemTextColour(item, *wxRED, 1);
                 }
 
@@ -358,8 +357,8 @@ void LocalsTable::DoUpdateLocals(const LocalVariables& localsUnSorted, size_t ki
 
 void LocalsTable::UpdateFrameInfo()
 {
-    if(ManagerST::Get()->DbgGetCurrentFrameInfo().IsValid() &&
-       ManagerST::Get()->DbgGetCurrentFrameInfo() != m_curStackInfo) {
+    if (ManagerST::Get()->DbgGetCurrentFrameInfo().IsValid() &&
+        ManagerST::Get()->DbgGetCurrentFrameInfo() != m_curStackInfo) {
         Clear();
         m_curStackInfo = ManagerST::Get()->DbgGetCurrentFrameInfo();
         clMainFrame::Get()->GetDebuggerPane()->GetDebugWindow()->AppendLine(wxString::Format(
@@ -370,7 +369,7 @@ void LocalsTable::UpdateFrameInfo()
 void LocalsTable::OnRefresh(wxCommandEvent& event)
 {
     IDebugger* dbgr = DoGetDebugger();
-    if(dbgr) {
+    if (dbgr) {
         Clear();
         dbgr->QueryLocals();
     }
@@ -388,22 +387,22 @@ void LocalsTable::OnItemRightClick(wxTreeEvent& event)
 void LocalsTable::OnEditValue(wxCommandEvent& event)
 {
     wxTreeItemId selectedItem = m_listTable->GetSelection();
-    if(selectedItem.IsOk() == false)
+    if (selectedItem.IsOk() == false)
         return;
 
     wxString itemPath = GetItemPath(selectedItem);
     wxString newValue =
         wxGetTextFromUser(wxString::Format(_("Insert new value for '%s':"), itemPath.c_str()), _("Edit expression"));
-    if(newValue.IsEmpty())
+    if (newValue.IsEmpty())
         return;
 
     IDebugger* debugger = DoGetDebugger();
-    if(debugger) {
+    if (debugger) {
         debugger->AssignValue(itemPath, newValue);
 
         // refresh the item
         DbgTreeItemData* data = (DbgTreeItemData*)m_listTable->GetItemData(selectedItem);
-        if(data && data->_gdbId.IsEmpty()) {
+        if (data && data->_gdbId.IsEmpty()) {
             m_listTable->Delete(selectedItem);
             debugger->QueryLocals();
 
@@ -417,7 +416,7 @@ void LocalsTable::OnEditValueUI(wxUpdateUIEvent& event)
 {
     IDebugger* debugger = DoGetDebugger();
     wxTreeItemId selectedItem = m_listTable->GetSelection();
-    if(selectedItem.IsOk() == false) {
+    if (selectedItem.IsOk() == false) {
         event.Enable(false);
 
     } else {
@@ -429,14 +428,14 @@ void LocalsTable::OnEditValueUI(wxUpdateUIEvent& event)
 void LocalsTable::UpdateFuncReturnValue(const wxString& retValueGdbId)
 {
     wxTreeItemId root = m_listTable->GetRootItem();
-    if(!root.IsOk())
+    if (!root.IsOk())
         return;
 
     wxArrayString itemsNotRemoved;
     // remove the non-variable objects and return a list
     // of all the variable objects (at the top level)
     wxTreeItemId item = DoFindItemByExpression(wxT("Function Returned"));
-    if(item.IsOk()) {
+    if (item.IsOk()) {
         DoDeleteWatch(item);
     }
     m_listTable->Delete(item);
@@ -465,7 +464,7 @@ void LocalsTable::OnStackSelected(clCommandEvent& event)
     event.Skip();
     Clear();
     IDebugger* dbgr = DebuggerMgr::Get().GetActiveDebugger();
-    if(dbgr && dbgr->IsRunning() && ManagerST::Get()->IsDebuggerViewVisible(wxGetTranslation(DebuggerPane::LOCALS))) {
+    if (dbgr && dbgr->IsRunning() && ManagerST::Get()->IsDebuggerViewVisible(wxGetTranslation(DebuggerPane::LOCALS))) {
         dbgr->QueryLocals();
     }
 }
@@ -483,7 +482,7 @@ void LocalsTable::SetSortingFunction()
 {
     // Should a be placed before b?
     clSortFunc_t func = [=](clRowEntry* a, clRowEntry* b) {
-        if(m_sortAsc) {
+        if (m_sortAsc) {
             return (a->GetLabel().CmpNoCase(b->GetLabel()) < 0);
         } else {
             return (a->GetLabel().CmpNoCase(b->GetLabel()) > 0);
