@@ -26,20 +26,17 @@
 #define MAINBOOK_H
 
 #include "Notebook.h"
+#include "clAuiBook.hpp"
 #include "clEditorBar.h"
 #include "cl_command_event.h"
 #include "cl_editor.h"
-#include "editorframe.h"
 #include "filehistory.h"
-#include "navigationmanager.h"
 #include "quickfindbar.h"
 #include "sessionmanager.h"
-#include "wxStringHash.h"
 
-#include <deque>
 #include <functional>
-#include <set>
 #include <vector>
+#include <wx/aui/auibook.h>
 #include <wx/panel.h>
 
 class FilesModifiedDlg;
@@ -56,9 +53,8 @@ class MainBook : public wxPanel
 private:
     FileHistory m_recentFiles;
     clEditorBar* m_navBar;
-    Notebook* m_book;
+    MainNotebook* m_book = nullptr;
     bool m_useBuffereLimit;
-    EditorFrame::List_t m_detachedEditors;
     bool m_isWorkspaceReloading;
     bool m_reloadingDoRaise; // Prevents multiple Raises() during RestoreSession()
     FilesModifiedDlg* m_filesModifiedDlg;
@@ -68,17 +64,9 @@ private:
     std::unordered_map<wxString, CallbackVec_t> m_callbacksTable;
     bool m_initDone = false;
 
-public:
-    enum {
-        kGetAll_Default = 0x00000000,         // booked editors only
-        kGetAll_RetainOrder = 0x00000001,     // Order must keep
-        kGetAll_IncludeDetached = 0x00000002, // return both booked editors and detached
-        kGetAll_DetachedOnly = 0x00000004,    // return detached editors only
-    };
-
 private:
     FilesModifiedDlg* GetFilesModifiedDlg();
-    void DoShowTabLabelContextMenu();
+    void DoShowTabLabelContextMenu(size_t tabIdx);
     void CreateGuiControls();
     void ConnectEvents();
     void DoUpdateNotebookTheme();
@@ -101,19 +89,16 @@ private:
     void OnWorkspaceClosed(clWorkspaceEvent& e);
     void OnDebugEnded(clDebugEvent& e);
     void OnInitDone(wxCommandEvent& e);
-    void OnDetachedEditorClosed(clCommandEvent& e);
     void OnThemeChanged(clCommandEvent& e);
     void OnColoursAndFontsChanged(clCommandEvent& e);
     bool DoSelectPage(wxWindow* win);
     void DoHandleFrameMenu(clEditor* editor);
-    void DoEraseDetachedEditor(IEditor* editor);
     void OnWorkspaceReloadStarted(clWorkspaceEvent& e);
     void OnWorkspaceReloadEnded(clWorkspaceEvent& e);
     void OnEditorSettingsChanged(wxCommandEvent& e);
     void OnSettingsChanged(wxCommandEvent& e);
     void OnIdle(wxIdleEvent& event);
-    WelcomePage* GetOrCreateWelcomePage();
-
+    void OnSessionLoaded(clCommandEvent& event);
     /**
      * @brief return proper tab label for a given filename
      */
@@ -137,11 +122,14 @@ private:
     bool has_callbacks(const wxString& fullpath) const;
 
     int FindEditorIndexByFullPath(const wxString& fullpath);
+    void DoRestoreSession(const SessionEntry& entry);
 
 public:
     MainBook(wxWindow* parent);
     virtual ~MainBook();
 
+    WelcomePage* GetWelcomePage(bool createIfMissing = true);
+
     void SetFindBar(QuickFindBar* findBar);
     QuickFindBar* GetFindBar() const { return m_findBar; }
 
@@ -161,8 +149,6 @@ public:
      */
     void MovePage(bool movePageRight);
 
-    const EditorFrame::List_t& GetDetachedEditors() const { return m_detachedEditors; }
-    void DetachActiveEditor();
     void ClearFileHistory();
     void GetRecentlyOpenedFiles(wxArrayString& files);
     FileHistory& GetRecentlyOpenedFilesClass() { return m_recentFiles; }
@@ -184,30 +170,23 @@ public:
     void SetEditorBar(clEditorBar* bar) { m_navBar = bar; }
 
     void SaveSession(SessionEntry& session, wxArrayInt* excludeArr = NULL);
-    void RestoreSession(SessionEntry& session);
+    void RestoreSession(const SessionEntry& session);
     /**
      * @brief create session from current IDE state
      */
     void CreateSession(SessionEntry& session, wxArrayInt* excludeArr = NULL);
 
-    clEditor* GetActiveEditor(bool includeDetachedEditors = false);
+    clEditor* GetActiveEditor();
     /**
      * @brief return vector of all editors in the notebook. This function only returns instances of type clEditor
-     * @param editors [output]
-     * @param flags kGetAll_*
      */
-    void GetAllEditors(clEditor::Vec_t& editors, size_t flags);
+    clEditor::Vec_t GetAllEditors();
     /**
      * @brief return vector of all tabs in the notebook
      * @param tabs [output]
      */
     void GetAllTabs(clTab::Vec_t& tabs);
 
-    /**
-     * @brief return a list of the detached tabs
-     */
-    void GetDetachedTabs(clTab::Vec_t& tabs);
-
     clEditor* FindEditor(const wxString& fileName);
     bool CloseEditor(const wxString& fileName) { return ClosePage(FindEditor(fileName)); }
 
@@ -232,6 +211,12 @@ public:
      */
     clEditor* OpenFileAsync(const wxString& file_name, std::function<void(IEditor*)>&& callback);
 
+    /**
+     * @brief open a remote file into the editor mainbook
+     */
+    clEditor* OpenRemoteFile(const wxString& local_path, const wxString& remote_path, const wxString& ssh_account,
+                             const wxString& tooltip = wxEmptyString);
+
     clEditor* OpenFile(const wxString& file_name, const wxString& projectName = wxEmptyString, int lineno = wxNOT_FOUND,
                        long position = wxNOT_FOUND, OF_extra extra = OF_AddJump, bool preserveSelection = true,
                        int bmp = wxNOT_FOUND, const wxString& tooltip = wxEmptyString);
@@ -295,7 +280,7 @@ public:
     void SetUseBuffereLimit(bool useBuffereLimit) { this->m_useBuffereLimit = useBuffereLimit; }
     bool GetUseBuffereLimit() const { return m_useBuffereLimit; }
 
-    Notebook* GetNotebook() { return m_book; }
+    MainNotebook* GetNotebook() { return m_book; }
 };
 
 #endif // MAINBOOK_H
