@@ -28,6 +28,7 @@
 #include "Notebook.h"
 #include "cl_command_event.h"
 #include "shelltab.h"
+#include "wxTerminalCtrl/clBuiltinTerminalPane.hpp"
 
 #include <wx/panel.h>
 
@@ -44,7 +45,6 @@ class ShellTab;
 class TaskPanel;
 class OutputPaneBook;
 class FindUsageTab;
-
 /**
  * \ingroup LiteEditor
  * This class represents the default bottom pane in the editor
@@ -90,7 +90,7 @@ private:
     TaskPanel* m_taskPanel;
     FindUsageTab* m_showUsageTab;
     BuildTab* m_build_tab = nullptr;
-
+    clBuiltinTerminalPane* m_terminal = nullptr;
     bool m_buildInProgress;
 
 protected:
@@ -101,6 +101,7 @@ protected:
     void OnSettingsChanged(wxCommandEvent& event);
     void OnToggleTab(clCommandEvent& event);
     void OnOutputBookFileListMenu(clContextMenuEvent& event);
+    void OnPageChanged(wxBookCtrlEvent& event);
 
 public:
     /**
@@ -138,6 +139,7 @@ public:
     BuildTab* GetBuildTab() { return m_build_tab; }
     ShellTab* GetOutputWindow() { return m_outputWind; }
     FindUsageTab* GetShowUsageTab() { return m_showUsageTab; }
+    clBuiltinTerminalPane* GetBuiltInTerminal() { return m_terminal; }
 };
 
 #endif // OUTPUT_PANE_H
