@@ -24,9 +24,9 @@
 //////////////////////////////////////////////////////////////////////////////
 
 #include "reconcileproject.h"
+
 #include "VirtualDirectorySelectorDlg.h"
 #include "clFilesCollector.h"
-#include "event_notifier.h"
 #include "fileutils.h"
 #include "frame.h"
 #include "globals.h"
@@ -35,12 +35,15 @@
 #include "tree_node.h"
 #include "windowattrmanager.h"
 #include "workspace.h"
+
 #include <algorithm>
 #include <wx/busyinfo.h>
 #include <wx/dir.h>
 #include <wx/dirdlg.h>
 #include <wx/log.h>
+#include <wx/msgdlg.h>
 #include <wx/regex.h>
+#include <wx/textdlg.h>
 #include <wx/tokenzr.h>
 
 // ---------------------------------------------------------
@@ -97,7 +100,7 @@ bool ReconcileProjectDlg::LoadData()
 {
     ReconcileProjectFiletypesDlg dlg(clMainFrame::Get(), m_projname);
     dlg.SetData();
-    if(dlg.ShowModal() != wxID_OK) {
+    if (dlg.ShowModal() != wxID_OK) {
         return false;
     }
     wxString toplevelDir, filespec, ignorefilespec;
@@ -106,7 +109,7 @@ bool ReconcileProjectDlg::LoadData()
     m_regexes = regexes;
 
     wxDir dir(toplevelDir);
-    if(!dir.IsOpened()) {
+    if (!dir.IsOpened()) {
         return false;
     }
 
@@ -122,13 +125,13 @@ bool ReconcileProjectDlg::LoadData()
         wxStringSet_t excludeFoldersSet;
         std::for_each(excludeFolders.begin(), excludeFolders.end(),
                       [&](const wxString& folder) { excludeFoldersSet.insert(folder); });
-        if(scanner.Scan(toplevelDir, filesOutput, filespec, ignorefilespec, excludeFoldersSet)) {
+        if (scanner.Scan(toplevelDir, filesOutput, filespec, ignorefilespec, excludeFoldersSet)) {
             m_allfiles.insert(filesOutput.begin(), filesOutput.end());
             DoFindFiles();
         }
     }
 
-    if(m_newfiles.empty() && m_stalefiles.empty()) {
+    if (m_newfiles.empty() && m_stalefiles.empty()) {
         wxMessageBox(_("No new or stale files found. The project is up-to-date"), _("CodeLite"),
                      wxICON_INFORMATION | wxOK, this);
         return false;
@@ -144,17 +147,17 @@ void ReconcileProjectDlg::DistributeFiles(bool usingAutoallocate)
     wxArrayString selectedFiles;
     bool onlySelections = false;
 
-    if(usingAutoallocate) {
+    if (usingAutoallocate) {
         vdTree.BuildTree(m_projname);
         // If we're autoallocating, cache the current selections as
         // 1) we only want to operate on those, and 2) m_dvListCtrl1Unassigned is about to be cleared!
         wxDataViewItemArray selecteditems;
         m_dvListCtrl1Unassigned->GetSelections(selecteditems);
-        for(size_t i = 0; i < selecteditems.GetCount(); ++i) {
+        for (size_t i = 0; i < selecteditems.GetCount(); ++i) {
             wxVariant v;
             m_dvListCtrl1Unassigned->GetValue(v, m_dvListCtrl1Unassigned->GetStore()->GetRow(selecteditems.Item(i)), 0);
             wxDataViewIconText iv;
-            if(!v.IsNull()) {
+            if (!v.IsNull()) {
                 iv << v;
                 selectedFiles.Add(iv.GetText());
             }
@@ -174,17 +177,17 @@ void ReconcileProjectDlg::DistributeFiles(bool usingAutoallocate)
         newFilesV.reserve(m_newfiles.size());
         newFilesV.insert(newFilesV.end(), m_newfiles.begin(), m_newfiles.end());
         std::sort(newFilesV.begin(), newFilesV.end()); // Sort the files
-        for(size_t i = 0; i < newFilesV.size(); ++i) {
+        for (size_t i = 0; i < newFilesV.size(); ++i) {
             const wxString& filename = newFilesV[i];
             wxFileName fn(filename);
             fn.MakeRelativeTo(m_toplevelDir);
 
             // Even without auto-allocation, apply any regex as that'll be most likely to reflect the user's choice
             bool bFileAllocated = false;
-            for(size_t i = 0; i < m_regexes.GetCount(); ++i) {
+            for (size_t i = 0; i < m_regexes.GetCount(); ++i) {
                 wxString virtualFolder(m_regexes.Item(i).BeforeFirst('|'));
                 wxRegEx regex(m_regexes.Item(i).AfterFirst('|'));
-                if(regex.IsValid() && regex.Matches(filename)) {
+                if (regex.IsValid() && regex.Matches(filename)) {
                     wxVector<wxVariant> cols;
                     cols.push_back(::MakeIconText(fn.GetFullPath(), GetBitmap(filename)));
                     cols.push_back(virtualFolder);
@@ -195,18 +198,18 @@ void ReconcileProjectDlg::DistributeFiles(bool usingAutoallocate)
                 }
             }
 
-            if(usingAutoallocate) {
+            if (usingAutoallocate) {
                 bool attemptAllocation(true);
                 // First see if we should only process selected files and, if so, was this file selected
-                if(onlySelections) {
-                    if(selectedFiles.Index(fn.GetFullPath()) == wxNOT_FOUND) {
+                if (onlySelections) {
+                    if (selectedFiles.Index(fn.GetFullPath()) == wxNOT_FOUND) {
                         attemptAllocation = false;
                     }
                 }
 
-                if(attemptAllocation) {
+                if (attemptAllocation) {
                     wxString virtualFolder = vdTree.FindBestMatchVDir(fn.GetPath(), fn.GetExt());
-                    if(!virtualFolder.empty()) {
+                    if (!virtualFolder.empty()) {
                         wxASSERT_MSG(virtualFolder.find(':') != wxNOT_FOUND, "Invalid virtual folder");
                         wxVector<wxVariant> cols;
                         cols.push_back(::MakeIconText(fn.GetFullPath(), GetBitmap(filename)));
@@ -218,7 +221,7 @@ void ReconcileProjectDlg::DistributeFiles(bool usingAutoallocate)
                 }
             }
 
-            if(!bFileAllocated) {
+            if (!bFileAllocated) {
                 wxVector<wxVariant> cols;
                 cols.push_back(::MakeIconText(fn.GetFullPath(), GetBitmap(filename)));
                 m_dvListCtrl1Unassigned->AppendItem(cols, (wxUIntPtr)NULL);
@@ -255,14 +258,14 @@ wxArrayString ReconcileProjectDlg::RemoveStaleFiles(const wxArrayString& StaleFi
     ProjectPtr proj = ManagerST::Get()->GetProject(m_projname);
     wxCHECK_MSG(proj, removals, "Can't find a Project with the supplied name");
 
-    for(size_t n = 0; n < StaleFiles.GetCount(); ++n) {
+    for (size_t n = 0; n < StaleFiles.GetCount(); ++n) {
         // Reconstruct the VD path in projectname:foo:bar format
         int index = StaleFiles[n].Find(": ");
         wxCHECK_MSG(index != wxNOT_FOUND, removals, "Badly-formed stalefile string");
         wxString vdPath = StaleFiles[n].Left(index);
         wxString filepath = StaleFiles[n].Mid(index + 2);
 
-        if(proj->RemoveFile(filepath, vdPath)) {
+        if (proj->RemoveFile(filepath, vdPath)) {
             removals.Add(StaleFiles[n]);
         }
     }
@@ -278,12 +281,12 @@ wxArrayString ReconcileProjectDlg::AddMissingFiles(const wxArrayString& files, c
     wxCHECK_MSG(proj, additions, "Can't find a Project with the supplied name");
 
     wxString VD = vdPath;
-    if(VD.empty()) {
+    if (VD.empty()) {
         // If we were called from the root panel (so the user is trying to add unallocated files, or all files at once)
         // we need to know which VD to use
         VirtualDirectorySelectorDlg selector(this, clCxxWorkspaceST::Get(), "", m_projname);
         selector.SetText("Please choose the Virtual Directory to which to add the files");
-        if(selector.ShowModal() == wxID_OK) {
+        if (selector.ShowModal() == wxID_OK) {
             VD = selector.GetVirtualDirectoryPath();
         } else {
             return additions;
@@ -292,8 +295,8 @@ wxArrayString ReconcileProjectDlg::AddMissingFiles(const wxArrayString& files, c
 
     VD = VD.AfterFirst(':'); // Remove the projectname
 
-    for(size_t n = 0; n < files.GetCount(); ++n) {
-        if(proj->FastAddFile(files[n], VD)) {
+    for (size_t n = 0; n < files.GetCount(); ++n) {
+        if (proj->FastAddFile(files[n], VD)) {
             additions.Add(files[n]);
         }
     }
@@ -314,13 +317,13 @@ void ReconcileProjectDlg::DoFindFiles()
     wxStringSet_t projectfilesSet;
     std::for_each(files.begin(), files.end(), [&](const Project::FilesMap_t::value_type& vt) {
         projectfilesSet.insert(vt.first);
-        if(!wxFileName::FileExists(vt.second->GetFilename())) {
+        if (!wxFileName::FileExists(vt.second->GetFilename())) {
             m_stalefiles.insert({ vt.second->GetFilename(), vt.second });
         }
     });
 
     std::for_each(m_allfiles.begin(), m_allfiles.end(), [&](const wxString& file) {
-        if(projectfilesSet.count(file) == 0) {
+        if (projectfilesSet.count(file) == 0) {
             m_newfiles.insert(file);
         }
     });
@@ -336,25 +339,25 @@ void ReconcileProjectDlg::OnAddFile(wxCommandEvent& event)
     wxString suggestedPath, suggestedName;
     bool guessed = GuessNewVirtualDirName(suggestedPath, suggestedName);
     VirtualDirectorySelectorDlg selector(this, clCxxWorkspaceST::Get(), suggestedPath, m_projname);
-    if(guessed && !suggestedPath.empty()) {
+    if (guessed && !suggestedPath.empty()) {
         selector.SelectPath(m_projname + ':' + suggestedPath);
     } else {
         selector.SelectPath(m_projname); // Either a top-level file, or a top-level dir that's not yet in the VDir tree
     }
     selector.SetSuggestedName(suggestedName);
 
-    if(selector.ShowModal() == wxID_OK) {
+    if (selector.ShowModal() == wxID_OK) {
         wxString vd = selector.GetVirtualDirectoryPath();
         wxDataViewItemArray items;
         m_dvListCtrl1Unassigned->GetSelections(items);
 
-        for(size_t i = 0; i < items.GetCount(); ++i) {
+        for (size_t i = 0; i < items.GetCount(); ++i) {
             wxVariant v;
             m_dvListCtrl1Unassigned->GetValue(v, m_dvListCtrl1Unassigned->GetStore()->GetRow(items.Item(i)), 0);
 
             wxString path;
             wxDataViewIconText iv;
-            if(!v.IsNull()) {
+            if (!v.IsNull()) {
                 iv << v;
                 path = iv.GetText();
             }
@@ -376,7 +379,7 @@ bool ReconcileProjectDlg::GuessNewVirtualDirName(wxString& suggestedPath, wxStri
 {
     wxDataViewItemArray items;
     m_dvListCtrl1Unassigned->GetSelections(items);
-    if(!items.GetCount()) {
+    if (!items.GetCount()) {
         return false;
     }
 
@@ -386,7 +389,7 @@ bool ReconcileProjectDlg::GuessNewVirtualDirName(wxString& suggestedPath, wxStri
 
     wxString path;
     wxDataViewIconText iv;
-    if(!v.IsNull()) {
+    if (!v.IsNull()) {
         iv << v;
         path = iv.GetText();
     }
@@ -395,7 +398,7 @@ bool ReconcileProjectDlg::GuessNewVirtualDirName(wxString& suggestedPath, wxStri
     wxString pathSegments(fn.GetPath());
     pathSegments.Replace(wxFILE_SEP_PATH, ":");
 
-    if(pathSegments.empty()) {
+    if (pathSegments.empty()) {
         return true;
     } // This must be a top-level file
 
@@ -403,7 +406,7 @@ bool ReconcileProjectDlg::GuessNewVirtualDirName(wxString& suggestedPath, wxStri
     vdTree.BuildTree(m_projname);
     do {
         wxString virtualFolder = vdTree.FindBestMatchVDir(path, fn.GetExt());
-        if(!virtualFolder.empty()) {
+        if (!virtualFolder.empty()) {
             suggestedPath = path;
             suggestedPath.Replace(wxFILE_SEP_PATH, ":");
             suggestedName = pathSegments.Mid(suggestedPath.Len() + 1);
@@ -411,7 +414,7 @@ bool ReconcileProjectDlg::GuessNewVirtualDirName(wxString& suggestedPath, wxStri
         }
 
         path = path.BeforeLast(wxFILE_SEP_PATH);
-    } while(!path.empty());
+    } while (!path.empty());
 
     suggestedName =
         pathSegments; // This may be a top-level dir not in the VDir tree. pathSegments holds the likely name
@@ -435,11 +438,11 @@ void ReconcileProjectDlg::OnUndoSelectedFiles(wxCommandEvent& event)
     wxDataViewItemArray items;
     m_dataviewAssigned->GetSelections(items);
 
-    for(size_t i = 0; i < items.GetCount(); ++i) {
+    for (size_t i = 0; i < items.GetCount(); ++i) {
         wxVariant v;
         ReconcileFileItemData* data =
             dynamic_cast<ReconcileFileItemData*>(m_dataviewAssignedModel->GetClientObject(items.Item(i)));
-        if(data) {
+        if (data) {
             wxFileName fn(data->GetFilename());
             fn.MakeRelativeTo(m_toplevelDir);
 
@@ -451,7 +454,7 @@ void ReconcileProjectDlg::OnUndoSelectedFiles(wxCommandEvent& event)
 
     // get the list of items
     wxArrayString allfiles;
-    for(int i = 0; i < m_dvListCtrl1Unassigned->GetItemCount(); ++i) {
+    for (int i = 0; i < m_dvListCtrl1Unassigned->GetItemCount(); ++i) {
         wxVariant v;
         m_dvListCtrl1Unassigned->GetValue(v, i, 0);
         wxDataViewIconText it;
@@ -466,7 +469,7 @@ void ReconcileProjectDlg::OnUndoSelectedFiles(wxCommandEvent& event)
     m_dvListCtrl1Unassigned->DeleteAllItems();
 
     std::sort(allfiles.begin(), allfiles.end());
-    for(size_t i = 0; i < allfiles.GetCount(); ++i) {
+    for (size_t i = 0; i < allfiles.GetCount(); ++i) {
         wxVector<wxVariant> cols;
         cols.push_back(::MakeIconText(allfiles.Item(i), GetBitmap(allfiles.Item(i))));
         m_dvListCtrl1Unassigned->AppendItem(cols, (wxUIntPtr)NULL);
@@ -484,17 +487,17 @@ void ReconcileProjectDlg::OnDeleteStaleFiles(wxCommandEvent& event)
     wxCHECK_RET(proj, "Can't find a Project with the supplied name");
 
     wxDataViewItemArray items;
-    if(event.GetId() == wxID_DELETE) {
+    if (event.GetId() == wxID_DELETE) {
         m_dataviewStaleFiles->GetSelections(items);
     } else {
         m_dataviewStaleFilesModel->GetChildren(wxDataViewItem(0), items);
     }
 
     proj->BeginTranscation();
-    for(size_t i = 0; i < items.GetCount(); ++i) {
+    for (size_t i = 0; i < items.GetCount(); ++i) {
         ReconcileFileItemData* data =
             dynamic_cast<ReconcileFileItemData*>(m_dataviewStaleFilesModel->GetClientObject(items.Item(i)));
-        if(data) {
+        if (data) {
             proj->RemoveFile(data->GetFilename(), data->GetVirtualFolder());
         }
         m_projectModified = true;
@@ -517,7 +520,7 @@ void ReconcileProjectDlg::OnDeleteAllStaleFilesUI(wxUpdateUIEvent& event)
 void ReconcileProjectDlg::OnClose(wxCommandEvent& event)
 {
     // reload the workspace
-    if(m_projectModified) {
+    if (m_projectModified) {
         wxCommandEvent evt(wxEVT_COMMAND_MENU_SELECTED, XRCID("reload_workspace"));
         evt.SetEventObject(clMainFrame::Get());
         clMainFrame::Get()->GetEventHandler()->AddPendingEvent(evt);
@@ -529,7 +532,7 @@ void ReconcileProjectDlg::OnApply(wxCommandEvent& event)
 {
     // get the list of files to add to the project
     wxDataViewItemArray items;
-    if(event.GetId() == wxID_APPLY) {
+    if (event.GetId() == wxID_APPLY) {
         m_dataviewAssigned->GetSelections(items);
     } else {
         m_dataviewAssignedModel->GetChildren(wxDataViewItem(0), items);
@@ -538,31 +541,31 @@ void ReconcileProjectDlg::OnApply(wxCommandEvent& event)
     // virtual folder to file name
     wxStringSet_t vds;
     StringMultimap_t filesToAdd;
-    for(size_t i = 0; i < items.GetCount(); ++i) {
+    for (size_t i = 0; i < items.GetCount(); ++i) {
         ReconcileFileItemData* data =
             dynamic_cast<ReconcileFileItemData*>(m_dataviewAssignedModel->GetClientObject(items.Item(i)));
-        if(data) {
+        if (data) {
             filesToAdd.insert(std::make_pair(data->GetVirtualFolder(), data->GetFilename()));
             vds.insert(data->GetVirtualFolder());
         }
     }
 
     wxStringSet_t::const_iterator iter = vds.begin();
-    for(; iter != vds.end(); ++iter) {
+    for (; iter != vds.end(); ++iter) {
         std::pair<StringMultimap_t::iterator, StringMultimap_t::iterator> range = filesToAdd.equal_range(*iter);
         StringMultimap_t::iterator from = range.first;
         wxArrayString vdFiles;
-        for(; from != range.second; ++from) {
+        for (; from != range.second; ++from) {
             vdFiles.Add(from->second);
         }
         wxArrayString additions = AddMissingFiles(vdFiles, *iter);
 
-        if(additions.GetCount()) {
+        if (additions.GetCount()) {
             m_projectModified = true;
         }
         // We must also remove the processed files from m_newfiles, otherwise a rerun of the wizard will offer them for
         // insertion again
-        for(size_t n = 0; n < additions.GetCount(); ++n) {
+        for (size_t n = 0; n < additions.GetCount(); ++n) {
             m_newfiles.erase(additions.Item(n));
         }
     }
@@ -593,26 +596,26 @@ void ReconcileProjectDlg::OnDeleteSelectedNewFiles(wxCommandEvent& e)
 {
     wxDataViewItemArray items;
     m_dvListCtrl1Unassigned->GetSelections(items);
-    if(items.IsEmpty())
+    if (items.IsEmpty())
         return;
 
     wxString msg;
-    if(items.GetCount() > 1) {
+    if (items.GetCount() > 1) {
         msg = wxString::Format(_("Delete the %i selected files from the filesystem?"), (int)items.GetCount());
     } else {
         msg = wxString::Format(_("Delete the selected file from the filesystem?"));
     }
 
-    if(::wxMessageBox(msg, "CodeLite", wxICON_WARNING | wxYES_NO, this) != wxYES) {
+    if (::wxMessageBox(msg, "CodeLite", wxICON_WARNING | wxYES_NO, this) != wxYES) {
         return;
     }
 
     int successes(0);
-    for(size_t n = 0; n < items.GetCount(); ++n) {
+    for (size_t n = 0; n < items.GetCount(); ++n) {
         wxVariant v;
         int row = m_dvListCtrl1Unassigned->GetStore()->GetRow(items.Item(n));
         m_dvListCtrl1Unassigned->GetValue(v, row, 0);
-        if(v.IsNull()) {
+        if (v.IsNull()) {
             continue;
         }
 
@@ -622,7 +625,7 @@ void ReconcileProjectDlg::OnDeleteSelectedNewFiles(wxCommandEvent& e)
         fn.MakeAbsolute(m_toplevelDir);
 
         wxLogNull NoAnnoyingFileSystemMessages;
-        if(clRemoveFile(fn.GetFullPath())) {
+        if (clRemoveFile(fn.GetFullPath())) {
             m_dvListCtrl1Unassigned->DeleteItem(row);
             ++successes;
         }
@@ -651,16 +654,16 @@ void ReconcileProjectFiletypesDlg::SetData()
     wxArrayString ignorefiles, excludes, regexes;
     proj->GetReconciliationData(topleveldir, types, ignorefiles, excludes, regexes);
 
-    if(topleveldir.empty()) {
+    if (topleveldir.empty()) {
         topleveldir = proj->GetFileName().GetPath();
     }
     wxFileName tld(topleveldir);
-    if(tld.IsRelative()) {
+    if (tld.IsRelative()) {
         tld.MakeAbsolute(proj->GetFileName().GetPath());
     }
     m_dirPickerToplevel->SetPath(tld.GetFullPath());
 
-    if(types.empty()) {
+    if (types.empty()) {
         types << "cpp;c;h;hpp;xrc;wxcp;fbp";
     }
     m_textExtensions->ChangeValue(types);
@@ -672,7 +675,7 @@ void ReconcileProjectFiletypesDlg::SetData()
     m_listExclude->Append(excludes);
 
     m_listCtrlRegexes->DeleteAllItems();
-    for(size_t n = 0; n < regexes.GetCount(); ++n) {
+    for (size_t n = 0; n < regexes.GetCount(); ++n) {
         SetRegex(regexes[n]);
     }
 }
@@ -688,9 +691,9 @@ void ReconcileProjectFiletypesDlg::GetData(wxString& toplevelDir, wxString& type
 
     // Fix the types to fit a standard mask string
     wxArrayString typesArr = ::wxStringTokenize(types, "|,;", wxTOKEN_STRTOK);
-    for(size_t i = 0; i < typesArr.size(); ++i) {
+    for (size_t i = 0; i < typesArr.size(); ++i) {
         wxString& fileExt = typesArr.Item(i);
-        if(!fileExt.StartsWith("*")) {
+        if (!fileExt.StartsWith("*")) {
             fileExt.Prepend("*.");
         }
     }
@@ -701,12 +704,12 @@ void ReconcileProjectFiletypesDlg::GetData(wxString& toplevelDir, wxString& type
 
     // Fix the exclude paths. First make absolute
     wxString tld(toplevelDir);
-    if(tld.Last() != wxFILE_SEP_PATH) {
+    if (tld.Last() != wxFILE_SEP_PATH) {
         tld << wxFILE_SEP_PATH;
     }
-    for(size_t i = 0; i < rawExcludePaths.size(); ++i) {
+    for (size_t i = 0; i < rawExcludePaths.size(); ++i) {
         wxString& path = rawExcludePaths.Item(i);
-        if(!path.StartsWith(wxFILE_SEP_PATH)) {
+        if (!path.StartsWith(wxFILE_SEP_PATH)) {
             path.Prepend(tld);
         }
         // Now fix any symlinks in the path and add to the array
@@ -732,7 +735,7 @@ void ReconcileProjectFiletypesDlg::SetRegex(const wxString& regex)
 wxArrayString ReconcileProjectFiletypesDlg::GetRegexes() const
 {
     wxArrayString array;
-    for(int n = 0; n < m_listCtrlRegexes->GetItemCount(); ++n) {
+    for (int n = 0; n < m_listCtrlRegexes->GetItemCount(); ++n) {
         wxString regex = GetColumnText(m_listCtrlRegexes, n, 0);
         wxString VD = GetColumnText(m_listCtrlRegexes, n, 1);
         array.Add(VD + '|' +
@@ -750,19 +753,19 @@ void ReconcileProjectFiletypesDlg::OnIgnoreBrowse(wxCommandEvent& WXUNUSED(event
     wxArrayString ignorefiles, excludes, regexes;
     proj->GetReconciliationData(topleveldir, types, ignorefiles, excludes, regexes);
 
-    if(topleveldir.empty()) {
+    if (topleveldir.empty()) {
         topleveldir = proj->GetFileName().GetPath();
     }
 
     wxFileName tld(topleveldir);
-    if(tld.IsRelative()) {
+    if (tld.IsRelative()) {
         tld.MakeAbsolute(proj->GetFileName().GetPath());
     }
     wxString new_exclude = wxDirSelector(_("Select a directory to ignore:"), tld.GetFullPath(), wxDD_DEFAULT_STYLE,
                                          wxDefaultPosition, this);
 
-    if(!new_exclude.empty()) {
-        if(m_listExclude->FindString(new_exclude) == wxNOT_FOUND) {
+    if (!new_exclude.empty()) {
+        if (m_listExclude->FindString(new_exclude) == wxNOT_FOUND) {
             m_listExclude->Append(new_exclude);
         }
     }
@@ -771,7 +774,7 @@ void ReconcileProjectFiletypesDlg::OnIgnoreBrowse(wxCommandEvent& WXUNUSED(event
 void ReconcileProjectFiletypesDlg::OnIgnoreRemove(wxCommandEvent& WXUNUSED(event))
 {
     int sel = m_listExclude->GetSelection();
-    if(sel != wxNOT_FOUND) {
+    if (sel != wxNOT_FOUND) {
         m_listExclude->Delete(sel);
     }
 }
@@ -784,8 +787,8 @@ void ReconcileProjectFiletypesDlg::OnIgnoreRemoveUpdateUI(wxUpdateUIEvent& event
 void ReconcileProjectFiletypesDlg::OnIgnoreFileBrowse(wxCommandEvent& WXUNUSED(event))
 {
     wxString name = wxGetTextFromUser(_("Enter the filename to ignore e.g. foo*.cpp"), _("CodeLite"), "", this);
-    if(!name.empty()) {
-        if(m_listIgnoreFiles->FindString(name) == wxNOT_FOUND) {
+    if (!name.empty()) {
+        if (m_listIgnoreFiles->FindString(name) == wxNOT_FOUND) {
             m_listIgnoreFiles->Append(name);
         }
     }
@@ -794,7 +797,7 @@ void ReconcileProjectFiletypesDlg::OnIgnoreFileBrowse(wxCommandEvent& WXUNUSED(e
 void ReconcileProjectFiletypesDlg::OnIgnoreFileRemove(wxCommandEvent& WXUNUSED(event))
 {
     int sel = m_listIgnoreFiles->GetSelection();
-    if(sel != wxNOT_FOUND) {
+    if (sel != wxNOT_FOUND) {
         m_listIgnoreFiles->Delete(sel);
     }
 }
@@ -807,7 +810,7 @@ void ReconcileProjectFiletypesDlg::OnIgnoreFileRemoveUpdateUI(wxUpdateUIEvent& e
 void ReconcileProjectFiletypesDlg::OnAddRegex(wxCommandEvent& event)
 {
     ReconcileByRegexDlg dlg(this, m_projname);
-    if(dlg.ShowModal() == wxID_OK) {
+    if (dlg.ShowModal() == wxID_OK) {
         SetRegex(dlg.GetRegex());
     }
 }
@@ -817,7 +820,7 @@ void ReconcileProjectFiletypesDlg::OnRemoveRegex(wxCommandEvent& event)
     wxUnusedVar(event);
 
     long selecteditem = m_listCtrlRegexes->GetNextItem(-1, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED);
-    if(selecteditem != wxNOT_FOUND) {
+    if (selecteditem != wxNOT_FOUND) {
         m_listCtrlRegexes->DeleteItem(selecteditem);
     }
 }
@@ -840,7 +843,7 @@ ReconcileByRegexDlg::~ReconcileByRegexDlg() {}
 
 void ReconcileByRegexDlg::OnTextEnter(wxCommandEvent& event)
 {
-    if(m_buttonOK->IsEnabled()) {
+    if (m_buttonOK->IsEnabled()) {
         EndModal(wxID_OK);
     }
 }
@@ -849,7 +852,7 @@ void ReconcileByRegexDlg::OnVDBrowse(wxCommandEvent& WXUNUSED(event))
 {
     VirtualDirectorySelectorDlg selector(this, clCxxWorkspaceST::Get(), m_textCtrlVirtualFolder->GetValue(),
                                          m_projname);
-    if(selector.ShowModal() == wxID_OK) {
+    if (selector.ShowModal() == wxID_OK) {
         m_textCtrlVirtualFolder->ChangeValue(selector.GetVirtualDirectoryPath());
     }
 }
@@ -867,19 +870,19 @@ void VirtualDirectoryTree::BuildTree(const wxString& projName)
     ProjectTreePtr tree = proj->AsTree();
     TreeWalker<wxString, ProjectItem> walker(tree->GetRoot());
 
-    for(; !walker.End(); walker++) {
+    for (; !walker.End(); walker++) {
         ProjectTreeNode* node = walker.GetNode();
         wxString displayname(node->GetData().GetDisplayName());
-        if(node->GetData().GetKind() == ProjectItem::TypeVirtualDirectory) {
+        if (node->GetData().GetKind() == ProjectItem::TypeVirtualDirectory) {
             wxString vdPath = displayname;
             ProjectTreeNode* tempnode = node->GetParent();
-            while(tempnode) {
+            while (tempnode) {
                 vdPath = tempnode->GetData().GetDisplayName() + ':' + vdPath;
                 tempnode = tempnode->GetParent();
             }
 
             VirtualDirectoryTree* parent = FindParent(vdPath.BeforeLast(':'));
-            if(parent) {
+            if (parent) {
                 parent->StoreChild(displayname, vdPath);
             } else {
                 // Any orphans must be root's top-level children, and we're root
@@ -891,13 +894,13 @@ void VirtualDirectoryTree::BuildTree(const wxString& projName)
 
 VirtualDirectoryTree* VirtualDirectoryTree::FindParent(const wxString& vdChildPath)
 {
-    if(!vdChildPath.empty()) {
-        if(m_vdPath == vdChildPath) {
+    if (!vdChildPath.empty()) {
+        if (m_vdPath == vdChildPath) {
             return this;
         }
-        for(size_t n = 0; n < m_children.size(); ++n) {
+        for (size_t n = 0; n < m_children.size(); ++n) {
             VirtualDirectoryTree* item = m_children[n]->FindParent(vdChildPath);
-            if(item) {
+            if (item) {
                 return item;
             }
         }
@@ -909,7 +912,7 @@ VirtualDirectoryTree* VirtualDirectoryTree::FindParent(const wxString& vdChildPa
 void VirtualDirectoryTree::StoreChild(const wxString& displayname, const wxString& vdPath)
 {
     VirtualDirectoryTree* child = new VirtualDirectoryTree(this, displayname, vdPath);
-    if(IsSourceVD(displayname.Lower()) || IsHeaderVD(displayname.Lower()) || IsResourceVD(displayname.Lower())) {
+    if (IsSourceVD(displayname.Lower()) || IsHeaderVD(displayname.Lower()) || IsResourceVD(displayname.Lower())) {
         m_children.push_back(child); // We want these processed last, so push_back
     } else {
         m_children.push_front(child);
@@ -919,9 +922,9 @@ void VirtualDirectoryTree::StoreChild(const wxString& displayname, const wxStrin
 wxString VirtualDirectoryTree::FindBestMatchVDir(const wxString& path, const wxString& ext) const
 {
     // Try all children first
-    for(size_t n = 0; n < m_children.size(); ++n) {
+    for (size_t n = 0; n < m_children.size(); ++n) {
         wxString vdir = m_children[n]->FindBestMatchVDir(path, ext);
-        if(!vdir.empty()) {
+        if (!vdir.empty()) {
             return vdir;
         }
     }
@@ -930,25 +933,25 @@ wxString VirtualDirectoryTree::FindBestMatchVDir(const wxString& path, const wxS
     // child
     wxString vdpath(m_vdPath.AfterFirst(':')); // We need to compare without the projectname
     vdpath.Replace(":", wxString(wxFILE_SEP_PATH));
-    if(vdpath == path) {
+    if (vdpath == path) {
         // Try for a src/header/etc immediate child. If there is one, it's presumably where files with a matching ext
         // should go
-        for(size_t c = 0; c < m_children.size(); ++c) {
+        for (size_t c = 0; c < m_children.size(); ++c) {
             wxString childname = m_children[c]->GetDisplayname();
-            if(IsSourceVD(childname.Lower())) {
-                if(ext == "cpp" || ext == "c" || ext == "cc") {
+            if (IsSourceVD(childname.Lower())) {
+                if (ext == "cpp" || ext == "c" || ext == "cc") {
                     return m_children[c]->GetVPath();
                 }
             }
 
-            if(IsHeaderVD(childname.Lower())) {
-                if(ext == "h" || ext == "hpp" || ext == "hh") {
+            if (IsHeaderVD(childname.Lower())) {
+                if (ext == "h" || ext == "hpp" || ext == "hh") {
                     return m_children[c]->GetVPath();
                 }
             }
 
-            if(IsResourceVD(childname.Lower())) {
-                if(ext == "rc") {
+            if (IsResourceVD(childname.Lower())) {
+                if (ext == "rc") {
                     return m_children[c]->GetVPath();
                 }
             }
