@@ -28,11 +28,11 @@
 #include "ColoursAndFontsManager.h"
 #include "FontUtils.hpp"
 #include "NewThemeDialog.h"
-#include "ThemeImporterCXX.hpp"
-#include "ThemeImporterManager.hpp"
+#include "ThemeImporters/ThemeImporterCXX.hpp"
+#include "ThemeImporters/ThemeImporterManager.hpp"
+#include "Zip/clZipReader.h"
+#include "Zip/clZipWriter.h"
 #include "clSystemSettings.h"
-#include "clZipReader.h"
-#include "clZipWriter.h"
 #include "cl_config.h"
 #include "cl_defs.h"
 #include "context_manager.h"
@@ -53,6 +53,7 @@
 #include <wx/filedlg.h>
 #include <wx/msgdlg.h>
 #include <wx/notebook.h>
+#include <wx/notifmsg.h>
 #include <wx/richtooltip.h>
 #include <wx/treebook.h>
 #include <wx/utils.h>
@@ -66,13 +67,14 @@ namespace
 enum CodeLiteAppearance : int {
     SYSTEM_DEFAULT = 0,
     FORCE_DARK = 1,
+    FORCE_LIGHT = 2,
 };
 }
 
 const wxString sampleText = R"(class Demo {
 private:
     std::string m_str;
-    int m_integer = 0;
+    int m_integer = 12345;
 
 public:
     /**
@@ -97,22 +99,22 @@ SyntaxHighlightDlg::SyntaxHighlightDlg(wxWindow* parent)
 {
     // Get list of available lexers
     wxString lexerName;
-    clEditor* editor = clMainFrame::Get()->GetMainBook()->GetActiveEditor(true);
+    clEditor* editor = clMainFrame::Get()->GetMainBook()->GetActiveEditor();
     wxArrayString lexers = ColoursAndFontsManager::Get().GetAllLexersNames();
-    if(editor) {
+    if (editor) {
         lexerName = editor->GetContext()->GetName().Lower();
     }
 
-    for(size_t i = 0; i < lexers.GetCount(); ++i) {
-        if(lexers.Item(i) == "c++") {
+    for (size_t i = 0; i < lexers.GetCount(); ++i) {
+        if (lexers.Item(i) == "c++") {
             m_listBox->Append(CXX_AND_JAVASCRIPT);
         } else {
             m_listBox->Append(lexers.Item(i));
         }
     }
 
-    if(!m_listBox->IsEmpty()) {
-        if(lexerName.IsEmpty()) {
+    if (!m_listBox->IsEmpty()) {
+        if (lexerName.IsEmpty()) {
             m_listBox->Select(0);
         } else {
             m_listBox->SetStringSelection(lexerName == "c++" ? CXX_AND_JAVASCRIPT : lexerName);
@@ -124,9 +126,20 @@ SyntaxHighlightDlg::SyntaxHighlightDlg(wxWindow* parent)
     m_choiceGlobalTheme->Append(ColoursAndFontsManager::Get().GetAvailableThemesForLexer("c++"));
     m_choiceGlobalTheme->SetStringSelection(ColoursAndFontsManager::Get().GetGlobalTheme());
 
+    wxColour line_numbers_dark = clConfig::Get().Read("GloabLineNumbersColour/DarkTheme", wxNullColour);
+    wxColour line_numbers_light = clConfig::Get().Read("GloabLineNumbersColour/LightTheme", wxNullColour);
+
+    if (line_numbers_dark.IsOk()) {
+        m_colourPickerLineNumbersDark->SetColour(line_numbers_dark);
+    }
+    if (line_numbers_light.IsOk()) {
+        m_colourPickerLineNumbersLight->SetColour(line_numbers_light);
+    }
+
     // Set the current editor font to the default one
     wxFont font = clConfig::Get().Read("GlobalThemeFont", FontUtils::GetDefaultMonospacedFont());
     m_fontPickerGlobal->SetSelectedFont(font);
+
     DoUpdatePreview();
 
     m_isModified = true;
@@ -149,37 +162,42 @@ SyntaxHighlightDlg::SyntaxHighlightDlg(wxWindow* parent)
     m_toolbar->Bind(wxEVT_TOOL, &SyntaxHighlightDlg::OnRestoreDefaults, this, XRCID("revert_changes"));
     m_toolbar->Bind(wxEVT_TOOL, &SyntaxHighlightDlg::OnImportEclipseTheme, this, XRCID("import_eclipse_theme"));
 
-#if !defined(__WXMSW__)
-    m_choiceAppearance->SetSelection(CodeLiteAppearance::SYSTEM_DEFAULT);
-    m_choiceAppearance->Enable(false);
-#else
+#if wxCHECK_VERSION(3, 3, 0)
     int appearance = clConfig::Get().Read("CodeLiteAppearance", CodeLiteAppearance::SYSTEM_DEFAULT);
     m_choiceAppearance->SetSelection(appearance);
+#else
+    m_choiceAppearance->SetSelection((int)CodeLiteAppearance::SYSTEM_DEFAULT);
+    m_choiceAppearance->Disable();
 #endif
-    // Theme handling
 
-    GetSizer()->Fit(this);
+    // Use a default big size for this dialog
+    ::clSetDialogBestSizeAndPosition(this);
+
+    // Theme handling
     CentreOnParent();
 }
 
-void SyntaxHighlightDlg::DoUpdatePreview()
+void SyntaxHighlightDlg::DoUpdatePreview(const wxColour& lineNumberColour)
 {
     // Populate the preview
     LexerConf::Ptr_t previewLexer =
         ColoursAndFontsManager::Get().GetLexer("c++", m_choiceGlobalTheme->GetStringSelection());
 
-    if(previewLexer) {
+    if (previewLexer) {
         previewLexer->Apply(m_stcPreview, true);
         previewLexer->ApplyWordSet(m_stcPreview, LexerConf::WS_CLASS, "Demo std string");
         previewLexer->ApplyWordSet(m_stcPreview, LexerConf::WS_VARIABLES, "other m_integer m_str a_string");
         previewLexer->ApplyWordSet(m_stcPreview, LexerConf::WS_FUNCTIONS, "CallMethod GetPointer");
     }
 
+    if (lineNumberColour.IsOk()) {
+        m_stcPreview->StyleSetForeground(wxSTC_STYLE_LINENUMBER, lineNumberColour);
+    }
+
     m_stcPreview->SetEditable(true);
     m_stcPreview->SetText(sampleText);
     m_stcPreview->HideSelection(true);
     m_stcPreview->SetEditable(false);
-    ::clRecalculateSTCHScrollBar(m_stcPreview);
 }
 
 void SyntaxHighlightDlg::OnButtonOK(wxCommandEvent& event)
@@ -230,10 +248,10 @@ void SyntaxHighlightDlg::LoadLexer(const wxString& themeName)
     wxWindowUpdateLocker locker(this);
     Clear();
     wxString lexer = m_listBox->GetStringSelection();
-    if(lexer.IsEmpty())
+    if (lexer.IsEmpty())
         return;
 
-    if(lexer == CXX_AND_JAVASCRIPT) {
+    if (lexer == CXX_AND_JAVASCRIPT) {
         lexer = "c++";
     }
 
@@ -259,14 +277,14 @@ void SyntaxHighlightDlg::SaveChanges()
     // Make sure we got a valid text selection
     // foreground colour
     StyleProperty& selProp = m_lexer->GetProperty(SEL_TEXT_ATTR_ID);
-    if(!selProp.IsNull()) {
+    if (!selProp.IsNull()) {
         selProp.SetFgColour(m_colourPickerSelTextFgColour->GetColour().GetAsString(wxC2S_HTML_SYNTAX));
     }
 
     // Update the active theme for the lexer
     ColoursAndFontsManager::Get().SetActiveTheme(m_lexer->GetName(), m_choiceLexerThemes->GetStringSelection());
 
-    if(m_globalThemeChanged) {
+    if (m_globalThemeChanged) {
         wxBusyInfo bi(_("Applying changes..."));
         wxBusyCursor bc;
         // Set the theme, it will update the global theme as well
@@ -275,7 +293,7 @@ void SyntaxHighlightDlg::SaveChanges()
 
         // Match the active tab colour with the selected theme
         LexerConf::Ptr_t cppLexer = ColoursAndFontsManager::Get().GetLexer("c++");
-        if(cppLexer) {
+        if (cppLexer) {
             clConfig::Get().Write("ActiveTabMarkerColour", wxColour(cppLexer->GetProperty(wxSTC_C_WORD).GetFgColour()));
         }
 
@@ -284,9 +302,7 @@ void SyntaxHighlightDlg::SaveChanges()
     }
 
     // Save the base colour changes
-#if defined(__WXMSW__)
     clConfig::Get().Write("CodeLiteAppearance", m_choiceAppearance->GetSelection());
-#endif
 
     // Update the text selection colours
     UpdateTextSelectionColours();
@@ -300,7 +316,7 @@ SyntaxHighlightDlg::~SyntaxHighlightDlg()
 {
     // Write the global font
     wxFont font = m_fontPickerGlobal->GetSelectedFont();
-    if(font.IsOk()) {
+    if (font.IsOk()) {
         clConfig::Get().Write("GlobalThemeFont", font);
     }
 }
@@ -311,19 +327,19 @@ void SyntaxHighlightDlg::OnColourChanged(wxColourPickerEvent& event)
     m_isModified = true;
     // update colour
     wxObject* obj = event.GetEventObject();
-    if(obj == m_colourPicker) {
+    if (obj == m_colourPicker) {
         wxColour colour = event.GetColour();
         StyleProperty::Vec_t::iterator iter = GetSelectedStyle();
         iter->SetFgColour(colour.GetAsString(wxC2S_HTML_SYNTAX));
 
-    } else if(obj == m_bgColourPicker) {
+    } else if (obj == m_bgColourPicker) {
 
         wxColour colour = event.GetColour();
         StyleProperty::Vec_t::iterator iter = GetSelectedStyle();
 
         iter->SetBgColour(colour.GetAsString(wxC2S_HTML_SYNTAX));
 
-    } else if(obj == m_globalBgColourPicker) {
+    } else if (obj == m_globalBgColourPicker) {
         wxColour colour = event.GetColour();
         DoSetGlobalBgColour(colour);
     }
@@ -334,7 +350,7 @@ void SyntaxHighlightDlg::EditKeyWords(int set)
 
     wxString keywords = m_lexer->GetKeyWords(set);
     FreeTextDialog dlg(this, keywords);
-    if(dlg.ShowModal() == wxID_OK) {
+    if (dlg.ShowModal() == wxID_OK) {
         m_isModified = true;
         m_lexer->SetKeyWords(dlg.GetValue(), set);
     }
@@ -373,7 +389,7 @@ void SyntaxHighlightDlg::OnEolFilled(wxCommandEvent& event)
     m_isModified = true;
     StyleProperty::Vec_t& properties = m_lexer->GetLexerProperties();
     StyleProperty::Vec_t::iterator iter = GetSelectedStyle();
-    if(iter != properties.end()) {
+    if (iter != properties.end()) {
         iter->SetEolFilled(event.IsChecked());
     }
 }
@@ -386,15 +402,15 @@ void SyntaxHighlightDlg::OnFontChanged(wxFontPickerEvent& event)
     StyleProperty::Vec_t& properties = m_lexer->GetLexerProperties();
     // update f
     wxObject* obj = event.GetEventObject();
-    if(obj == m_fontPicker) {
+    if (obj == m_fontPicker) {
         wxFont f = event.GetFont();
         StyleProperty::Vec_t::iterator iter = GetSelectedStyle();
         DoFontChanged(*iter, f);
 
-    } else if(obj == m_globalFontPicker) {
+    } else if (obj == m_globalFontPicker) {
         wxFont f = event.GetFont();
         StyleProperty::Vec_t::iterator iter = properties.begin();
-        for(; iter != properties.end(); ++iter) {
+        for (; iter != properties.end(); ++iter) {
             DoFontChanged(*iter, f);
         }
         // update the style f picker as well
@@ -412,8 +428,8 @@ void SyntaxHighlightDlg::OnItemSelected(wxCommandEvent& event)
     StyleProperty::Vec_t& properties = m_lexer->GetLexerProperties();
     wxFont default_font = FontUtils::GetDefaultMonospacedFont();
 
-    for(const auto& p : properties) {
-        if(p.GetName() == selectionString) {
+    for (const auto& p : properties) {
+        if (p.GetName() == selectionString) {
             // update font & color
             wxString colour = p.GetFgColour();
             wxString bgColour = p.GetBgColour();
@@ -425,18 +441,12 @@ void SyntaxHighlightDlg::OnItemSelected(wxCommandEvent& event)
             m_bgColourPicker->SetColour(bgColour);
             m_colourPicker->SetColour(colour);
             m_eolFilled->SetValue(p.GetEolFilled());
+            m_checkBoxBoldFont->SetValue(p.IsBold());
+            m_checkBoxItalicFont->SetValue(p.GetItalic());
         }
     }
 }
 
-void SyntaxHighlightDlg::OnOutputViewColourChanged(wxColourPickerEvent& event)
-{
-    CHECK_PTR_RET(m_lexer);
-    event.Skip();
-    m_isModified = true;
-    m_globalBgColourChanged = true;
-}
-
 void SyntaxHighlightDlg::OnSelTextChanged(wxColourPickerEvent& event)
 {
     CHECK_PTR_RET(m_lexer);
@@ -444,7 +454,8 @@ void SyntaxHighlightDlg::OnSelTextChanged(wxColourPickerEvent& event)
     m_isModified = true;
     ColoursAndFontsManager::Get().SetThemeTextSelectionColours(m_lexer->GetThemeName(),
                                                                m_colourPickerSelTextBgColour->GetColour(),
-                                                               m_colourPickerSelTextFgColour->GetColour(), true);
+                                                               m_colourPickerSelTextFgColour->GetColour(),
+                                                               true);
 }
 
 void SyntaxHighlightDlg::OnStyleWithinPreprocessor(wxCommandEvent& event)
@@ -460,9 +471,9 @@ void SyntaxHighlightDlg::OnStyleWithingPreProcessorUI(wxUpdateUIEvent& event)
 
     StyleProperty::Vec_t& properties = m_lexer->GetLexerProperties();
     StyleProperty::Vec_t::iterator iter = GetSelectedStyle();
-    if(iter == properties.end())
+    if (iter == properties.end())
         event.Enable(false);
-    else if(iter->GetName() == "Preprocessor")
+    else if (iter->GetName() == "Preprocessor")
         event.Enable(true);
     else
         event.Enable(false);
@@ -484,15 +495,15 @@ void SyntaxHighlightDlg::CreateLexerPage()
     StyleProperty::Vec_t::const_iterator it = m_propertyList.begin();
     StyleProperty selTextProperties;
 
-    for(; it != m_propertyList.end(); it++) {
-        if(it->GetId() != SEL_TEXT_ATTR_ID) {
+    for (; it != m_propertyList.end(); it++) {
+        if (it->GetId() != SEL_TEXT_ATTR_ID) {
             m_properties->Append(it->GetName());
         } else {
             selTextProperties = *it;
         }
     }
 
-    if(m_properties->GetCount()) {
+    if (m_properties->GetCount()) {
         m_properties->SetSelection(0);
     }
 
@@ -502,13 +513,13 @@ void SyntaxHighlightDlg::CreateLexerPage()
     bool initialStyleWithinPreProcessor(true);
 
     wxFont initialFont = ColoursAndFontsManager::Get().GetGlobalFont();
-    if(!initialFont.IsOk()) {
+    if (!initialFont.IsOk()) {
         initialFont = FontUtils::GetDefaultMonospacedFont();
     }
 
     initialStyleWithinPreProcessor = m_lexer->GetStyleWithinPreProcessor();
     const StyleProperty& defaultStyle = m_lexer->GetProperty(0);
-    if(!defaultStyle.IsNull()) {
+    if (!defaultStyle.IsNull()) {
         m_colourPicker->SetColour(defaultStyle.GetFgColour());
         m_bgColourPicker->SetColour(defaultStyle.GetBgColour());
         m_globalBgColourPicker->SetColour(defaultStyle.GetBgColour());
@@ -526,7 +537,7 @@ void SyntaxHighlightDlg::CreateLexerPage()
     m_colourPickerSelTextBgColour->SetColour(selTextProperties.GetBgColour());
     m_colourPickerSelTextFgColour->SetColour(selTextProperties.GetFgColour());
 
-    if(m_propertyList.empty()) {
+    if (m_propertyList.empty()) {
         m_fontPicker->Enable(false);
         m_colourPicker->Enable(false);
     }
@@ -535,11 +546,11 @@ void SyntaxHighlightDlg::CreateLexerPage()
     m_choiceLexerThemes->Clear();
     wxArrayString themes = ColoursAndFontsManager::Get().GetAvailableThemesForLexer(m_lexer->GetName());
     int sel = themes.Index(m_lexer->GetThemeName());
-    if(sel == -1) {
+    if (sel == -1) {
         sel = 0;
     }
     m_choiceLexerThemes->Append(themes);
-    if(!m_choiceLexerThemes->IsEmpty()) {
+    if (!m_choiceLexerThemes->IsEmpty()) {
         m_choiceLexerThemes->SetSelection(sel);
     }
 }
@@ -548,18 +559,19 @@ StyleProperty::Vec_t::iterator SyntaxHighlightDlg::GetSelectedStyle()
 {
     wxString selectedProperty = m_properties->GetStringSelection();
     StyleProperty::Vec_t& lexerProperties = m_lexer->GetLexerProperties();
-    return std::find_if(lexerProperties.begin(), lexerProperties.end(),
-                        [&selectedProperty](const StyleProperty& prop) { return prop.GetName() == selectedProperty; });
+    return std::find_if(lexerProperties.begin(), lexerProperties.end(), [&selectedProperty](const StyleProperty& prop) {
+        return prop.GetName() == selectedProperty;
+    });
 }
 
 void SyntaxHighlightDlg::OnLexerSelected(wxCommandEvent& event)
 {
     wxString lexerName = m_listBox->GetStringSelection();
-    if(lexerName == CXX_AND_JAVASCRIPT) {
+    if (lexerName == CXX_AND_JAVASCRIPT) {
         lexerName = "c++";
     }
 
-    if(m_isModified) {
+    if (m_isModified) {
         SaveChanges();
     }
     m_isModified = false;
@@ -583,7 +595,8 @@ void SyntaxHighlightDlg::UpdateTextSelectionColours()
 {
     ColoursAndFontsManager::Get().SetThemeTextSelectionColours(m_lexer->GetThemeName(),
                                                                m_colourPickerSelTextBgColour->GetColour(),
-                                                               m_colourPickerSelTextFgColour->GetColour(), true);
+                                                               m_colourPickerSelTextFgColour->GetColour(),
+                                                               true);
 }
 
 void SyntaxHighlightDlg::OnNewTheme(wxCommandEvent& event)
@@ -591,11 +604,11 @@ void SyntaxHighlightDlg::OnNewTheme(wxCommandEvent& event)
     // Create new theme
     CHECK_PTR_RET(m_lexer);
     NewThemeDialog dlg(this, m_lexer);
-    if(dlg.ShowModal() == wxID_OK) {
+    if (dlg.ShowModal() == wxID_OK) {
         // Create new XML and load it
         LexerConf::Ptr_t newLexer =
             ColoursAndFontsManager::Get().CopyTheme(dlg.GetLexerName(), dlg.GetThemeName(), dlg.GetBaseTheme());
-        if(newLexer) {
+        if (newLexer) {
             LoadLexer(newLexer->GetName());
         }
     }
@@ -604,7 +617,7 @@ void SyntaxHighlightDlg::OnNewTheme(wxCommandEvent& event)
 void SyntaxHighlightDlg::OnImport(wxCommandEvent& event)
 {
     wxString path = ::wxFileSelector(_("Select file"), "", "", "", "Zip Files (*.zip)|*.zip", wxFD_OPEN);
-    if(path.IsEmpty())
+    if (path.IsEmpty())
         return;
 
     wxFileName fn(path);
@@ -612,7 +625,7 @@ void SyntaxHighlightDlg::OnImport(wxCommandEvent& event)
     zr.Extract("lexers.json", clStandardPaths::Get().GetTempDir());
 
     wxFileName fileToImport(clStandardPaths::Get().GetTempDir(), "lexers.json");
-    if(ColoursAndFontsManager::Get().ImportLexersFile(fileToImport, true)) {
+    if (ColoursAndFontsManager::Get().ImportLexersFile(fileToImport, true)) {
         EndModal(wxID_OK);
         // relaunch the dialog
         wxCommandEvent openEvent(wxEVT_COMMAND_MENU_SELECTED, XRCID("syntax_highlight"));
@@ -625,12 +638,12 @@ void SyntaxHighlightDlg::OnExportSelective(wxCommandEvent& event)
     // Get list of choices
     wxArrayString lexers = ColoursAndFontsManager::Get().GetAllThemes();
     wxArrayInt choices;
-    if(::wxGetSelectedChoices(choices, _("Select which themes to export:"), _("Export Themes"), lexers, this) ==
-       wxNOT_FOUND) {
+    if (::wxGetSelectedChoices(choices, _("Select which themes to export:"), _("Export Themes"), lexers, this) ==
+        wxNOT_FOUND) {
         return;
     }
     wxArrayString lexersToExport;
-    for(size_t i = 0; i < choices.GetCount(); ++i) {
+    for (size_t i = 0; i < choices.GetCount(); ++i) {
         wxString lexerName = lexers.Item(choices.Item(i)).Lower();
         lexersToExport.push_back(lexerName);
     }
@@ -639,14 +652,14 @@ void SyntaxHighlightDlg::OnExportSelective(wxCommandEvent& event)
 
 void SyntaxHighlightDlg::OnExportAll(wxCommandEvent& event) { DoExport(); }
 
-void SyntaxHighlightDlg::OnToolExportAll(wxCommandEvent& event) { DoExport(); }
-
 void SyntaxHighlightDlg::OnRestoreDefaults(wxCommandEvent& event)
 {
     // Ask for confirmation
-    if(::wxMessageBox(_("Are you sure you want to restore colours to factory defaults?\nBy choosing 'Yes', you will "
-                        "lose all your local modifications"),
-                      _("Confirm"), wxICON_WARNING | wxYES_NO | wxCANCEL | wxNO_DEFAULT | wxCENTER, this) != wxYES) {
+    if (::wxMessageBox(_("Are you sure you want to restore colours to factory defaults?\nBy choosing 'Yes', you will "
+                         "lose all your local modifications"),
+                       _("Confirm"),
+                       wxICON_WARNING | wxYES_NO | wxCANCEL | wxNO_DEFAULT | wxCENTER,
+                       this) != wxYES) {
         return;
     }
 
@@ -662,54 +675,61 @@ void SyntaxHighlightDlg::OnRestoreDefaults(wxCommandEvent& event)
 
 void SyntaxHighlightDlg::OnImportEclipseTheme(wxCommandEvent& event)
 {
-    wxFileDialog selector(this, _("Select theme to import"), "", "",
-                          "VSCode JSON Theme (*.json)|*.json|Eclipse Theme Files (*.xml)|*.xml",
-                          wxFD_OPEN | wxFD_FILE_MUST_EXIST);
-    if(selector.ShowModal() == wxID_OK) {
-
-        wxString path = selector.GetPath();
-        if(path.empty())
+    wxFileDialog selector(
+        this,
+        _("Select theme to import"),
+        "",
+        "",
+        "All Files (*.*)|*.*|VSCode JSON Theme (*.json)|*.json|Eclipse Theme Files (*.xml)|*.xml|Alacritty Theme "
+        "(*.yaml)|*.yaml|Alacritty Theme (*.yml)|*.yml|Alacritty Theme (*.toml)|*.toml",
+        wxFD_OPEN | wxFD_FILE_MUST_EXIST | wxFD_MULTIPLE);
+    if (selector.ShowModal() == wxID_OK) {
+        wxArrayString paths;
+        selector.GetPaths(paths);
+        if (paths.empty())
             return;
 
         wxBusyCursor bc;
-        wxString theme_name = ColoursAndFontsManager::Get().ImportEclipseTheme(path);
-        if(theme_name.empty()) {
-            ::wxMessageBox(_("Failed to import theme file: ") + path + _("\nInvalid file"), "CodeLite",
-                           wxICON_WARNING | wxOK | wxOK_DEFAULT, this);
-            return;
+        std::vector<wxString> themes_imported;
+        for (const auto& path : paths) {
+            wxString theme_name = ColoursAndFontsManager::Get().ImportEclipseTheme(path);
+            if (!theme_name.empty()) {
+                themes_imported.push_back(theme_name);
+            }
         }
 
         wxString message;
-        message << _("Theme : '") << theme_name << _("' imported successfully!");
-        ::wxMessageBox(message);
-
-        int pos = m_choiceGlobalTheme->Append(theme_name);
-        if(pos != wxNOT_FOUND) {
-            m_choiceGlobalTheme->SetSelection(pos);
+        if (themes_imported.empty()) {
+            message << _("Failed to import themes!");
+        } else {
+            message << _("Successfully imported ") << themes_imported.size() << " themes";
+            // apply the font by reseting the global font again
+            const wxFont& gFont = ColoursAndFontsManager::Get().GetGlobalFont();
+            if (gFont.IsOk()) {
+                ColoursAndFontsManager::Get().SetGlobalFont(
+                    gFont); // this will fix the newly imported themes to use the global font
+            }
         }
 
-        // Make this lexer the active one
-        LoadLexer(theme_name);
-        DoUpdatePreview();
+        wxNotificationMessage notif(
+            "CodeLite", message, nullptr, themes_imported.empty() ? wxICON_WARNING : wxICON_INFORMATION);
+        notif.Show(5);
 
-        // Mark the dialg is modified and force a save
-        m_isModified = true;
-        SaveChanges();
+        if (!themes_imported.empty()) {
+            // Mark the dialg is modified and force a save+reload
+            m_isModified = true;
+            SaveChanges();
 
-        // Dismiss the dialog
-        EndModal(wxID_OK);
-        // and reload it
-        wxCommandEvent openEvent(wxEVT_COMMAND_MENU_SELECTED, XRCID("syntax_highlight"));
-        clMainFrame::Get()->GetEventHandler()->AddPendingEvent(openEvent);
+            // Dismiss the dialog
+            EndModal(wxID_OK);
+
+            // and reload it
+            wxCommandEvent openEvent(wxEVT_COMMAND_MENU_SELECTED, XRCID("syntax_highlight"));
+            clMainFrame::Get()->GetEventHandler()->AddPendingEvent(openEvent);
+        }
     }
 }
 
-void SyntaxHighlightDlg::OnLoadEclipseThemeWebsite(wxCommandEvent& event)
-{
-    wxUnusedVar(event);
-    ::wxLaunchDefaultBrowser("https://eclipse-color-themes.web.app/");
-}
-
 void SyntaxHighlightDlg::OnGlobalThemeSelected(wxCommandEvent& event)
 {
     DoUpdatePreview();
@@ -732,9 +752,9 @@ void SyntaxHighlightDlg::DoSetGlobalBgColour(const wxColour& colour)
 {
     StyleProperty::Vec_t& properties = m_lexer->GetLexerProperties();
     StyleProperty::Vec_t::iterator iter = properties.begin();
-    for(; iter != properties.end(); ++iter) {
+    for (; iter != properties.end(); ++iter) {
         // Dont change the text selection using the global font picker
-        if(iter->GetName() == wxT("Text Selection"))
+        if (iter->GetName() == wxT("Text Selection"))
             continue;
         iter->SetBgColour(colour.GetAsString(wxC2S_HTML_SYNTAX));
     }
@@ -743,14 +763,12 @@ void SyntaxHighlightDlg::DoSetGlobalBgColour(const wxColour& colour)
     m_bgColourPicker->SetColour(colour.GetAsString(wxC2S_HTML_SYNTAX));
 }
 
-void SyntaxHighlightDlg::DoShowTooltipForGlobalBgColourChanged() {}
-
 void SyntaxHighlightDlg::DoExport(const wxArrayString& lexers)
 {
     // Select the 'save' path
-    wxString path = ::wxFileSelector(_("Save as"), "", "MySettings.zip", "", wxFileSelectorDefaultWildcardStr,
-                                     wxFD_SAVE | wxFD_OVERWRITE_PROMPT);
-    if(path.IsEmpty()) {
+    wxString path = ::wxFileSelector(
+        _("Save as"), "", "MySettings.zip", "", wxFileSelectorDefaultWildcardStr, wxFD_SAVE | wxFD_OVERWRITE_PROMPT);
+    if (path.IsEmpty()) {
         return;
     }
 
@@ -758,7 +776,7 @@ void SyntaxHighlightDlg::DoExport(const wxArrayString& lexers)
     jsonFile.SetFullName("lexers.json");
     // Delete the file when done
     FileUtils::Deleter deleter(jsonFile);
-    if(!ColoursAndFontsManager::Get().ExportThemesToFile(jsonFile, lexers)) {
+    if (!ColoursAndFontsManager::Get().ExportThemesToFile(jsonFile, lexers)) {
         return;
     }
 
@@ -775,33 +793,69 @@ bool SyntaxHighlightDlg::IsRestartRequired() const { return m_promptForRestart;
 void SyntaxHighlightDlg::DoFontChanged(StyleProperty& sp, const wxFont& font)
 {
     sp.SetFontInfoDesc(FontUtils::GetFontInfo(font));
+    sp.SetBold(font.GetWeight() == wxFONTWEIGHT_BOLD);
+    sp.SetItalic(font.GetStyle() == wxFONTSTYLE_ITALIC);
 }
 
 void SyntaxHighlightDlg::OnCodeLiteAppearance(wxCommandEvent& event)
 {
-#if defined(__WXMSW__)
     int selection = event.GetSelection();
-    switch(selection) {
-    default:
-    case CodeLiteAppearance::SYSTEM_DEFAULT:
-        // in case it was something else..
+    switch (selection) {
+    case CodeLiteAppearance::FORCE_DARK:
+        break;
+    case CodeLiteAppearance::FORCE_LIGHT:
         selection = CodeLiteAppearance::SYSTEM_DEFAULT;
         break;
-    case CodeLiteAppearance::FORCE_DARK:
+    case CodeLiteAppearance::SYSTEM_DEFAULT:
+    default:
+        // in case it was something else..
+        selection = CodeLiteAppearance::SYSTEM_DEFAULT;
         break;
     }
 
     // save the new value
     clConfig::Get().Write("CodeLiteAppearance", selection);
     m_promptForRestart = true;
-#else
-    wxUnusedVar(event);
-#endif
 }
 
-void SyntaxHighlightDlg::OnCollapse(wxCollapsiblePaneEvent& event)
+void SyntaxHighlightDlg::OnLineNumberColourChanngedDark(wxColourPickerEvent& event)
 {
-    event.Skip();
-    // re-center the dialog
-    CentreOnParent();
+    wxBusyCursor bc;
+    clConfig::Get().Write("GloabLineNumbersColour/DarkTheme", event.GetColour());
+    ColoursAndFontsManager::Get().SetGlobalLineNumbersColour(event.GetColour(), true);
+    m_isModified = true;
+    if (m_lexer && m_lexer->IsDark()) {
+        DoUpdatePreview(event.GetColour());
+    }
+}
+
+void SyntaxHighlightDlg::OnLineNumberColourChanngedLight(wxColourPickerEvent& event)
+{
+    wxBusyCursor bc;
+    clConfig::Get().Write("GloabLineNumbersColour/LightTheme", event.GetColour());
+    ColoursAndFontsManager::Get().SetGlobalLineNumbersColour(event.GetColour(), false);
+    m_isModified = true;
+    if (m_lexer && !m_lexer->IsDark()) {
+        DoUpdatePreview(event.GetColour());
+    }
+}
+
+void SyntaxHighlightDlg::OnStyleFontBold(wxCommandEvent& event)
+{
+    CHECK_PTR_RET(m_lexer);
+    m_isModified = true;
+
+    // update f
+    StyleProperty::Vec_t::iterator iter = GetSelectedStyle();
+    iter->SetBold(event.IsChecked());
+}
+
+void SyntaxHighlightDlg::OnStyleFontItalic(wxCommandEvent& event)
+{
+    CHECK_PTR_RET(m_lexer);
+    m_isModified = true;
+
+    // update f
+    StyleProperty::Vec_t::iterator iter = GetSelectedStyle();
+    iter->SetItalic(event.IsChecked());
 }
