@@ -35,10 +35,10 @@
 #include "ieditor.h"
 #include "pluginmanager.h"
 #include "tabgroupmanager.h"
-#include "wx_xml_compatibility.h"
 
 #include <algorithm>
 #include <wx/accel.h>
+#include <wx/filedlg.h>
 #include <wx/filename.h>
 #include <wx/msgdlg.h>
 #include <wx/regex.h>
@@ -223,9 +223,7 @@ void TabgroupsPane::OnItemActivated(wxTreeEvent& event)
             return;
         }
 
-        std::vector<clEditor*> editors;
-        clMainFrame::Get()->GetMainBook()->GetAllEditors(editors, MainBook::kGetAll_IncludeDetached |
-                                                                      MainBook::kGetAll_RetainOrder);
+        std::vector<clEditor*> editors = clMainFrame::Get()->GetMainBook()->GetAllEditors();
         if(editors.size() > 0) {
             // If there are editors currently loaded, ask if they are to be replaced or added to
             wxString msg(_("Do you want to replace the existing editors? (Say 'No' to load the new ones alongside)"));
