@@ -26,12 +26,11 @@
 #include "macbundler.h"
 #include "windowattrmanager.h"
 #include "workspace.h"
-#include "wx/msgdlg.h"
-#include "wx/textfile.h"
-#include "wx/wx.h"
-#include "wx/xrc/xmlres.h"
 
-static MacBundler* thePlugin = NULL;
+#include <wx/msgdlg.h>
+#include <wx/textfile.h>
+#include <wx/wx.h>
+#include <wx/xrc/xmlres.h>
 
 // TODO: accept file drops
 class IconPicker : public wxPanel
@@ -287,8 +286,7 @@ public:
 // Define the plugin entry point
 CL_PLUGIN_API IPlugin* CreatePlugin(IManager* manager)
 {
-    if(thePlugin == NULL) { thePlugin = new MacBundler(manager); }
-    return thePlugin;
+    return new MacBundler(manager);
 }
 
 CL_PLUGIN_API PluginInfo* GetPluginInfo()
@@ -365,13 +363,11 @@ void MacBundler::showSettingsDialogFor(ProjectPtr project)
     wxArrayString choices;
 
     // TODO: allow putting the rules in the config root and not in every target
-    BuildConfigPtr buildConfig = settings->GetFirstBuildConfiguration(cookie);
-    while(buildConfig) {
+    for (auto buildConfig = settings->GetFirstBuildConfiguration(cookie); buildConfig;
+         buildConfig = settings->GetNextBuildConfiguration(cookie)) {
 
         configs[buildConfig->GetName()] = buildConfig;
         choices.Add(buildConfig->GetName());
-
-        buildConfig = settings->GetNextBuildConfiguration(cookie);
     }
 
     bool accepted = false;
