@@ -50,15 +50,10 @@
 // Plugin Interface
 //--------------------------------------------
 
-static SymbolViewPlugin* thePlugin = NULL;
-
 // Define the plugin entry point
 CL_PLUGIN_API IPlugin* CreatePlugin(IManager* manager)
 {
-    if(thePlugin == 0) {
-        thePlugin = new SymbolViewPlugin(manager);
-    }
-    return thePlugin;
+    return new SymbolViewPlugin(manager);
 }
 
 CL_PLUGIN_API PluginInfo* GetPluginInfo()
@@ -83,23 +78,12 @@ SymbolViewPlugin::SymbolViewPlugin(IManager* manager)
     m_longName = _("Outline Plugin");
     m_shortName = wxT("Outline");
 
-    Notebook* book = m_mgr->GetWorkspacePaneNotebook();
-    if(IsPaneDetached()) {
-        // Make the window child of the main panel (which is the grand parent of the notebook)
-        DockablePane* cp =
-            new DockablePane(book->GetParent()->GetParent(), book, _("Outline"), false, wxNOT_FOUND, wxSize(200, 200));
-        m_view = new OutlineTab(cp);
-        cp->SetChildNoReparent(m_view);
-
-    } else {
-        m_view = new OutlineTab(book);
-        book->AddPage(m_view, _("Outline"), false, wxNOT_FOUND);
-    }
-    EventNotifier::Get()->Bind(wxEVT_SHOW_WORKSPACE_TAB, &SymbolViewPlugin::OnToggleTab, this);
+    m_view = new OutlineTab(m_mgr->BookGet(PaneId::SIDE_BAR));
+    m_mgr->BookAddPage(PaneId::SIDE_BAR, m_view, _("Outline"), "outline-button");
     m_mgr->AddWorkspaceTab(_("Outline"));
 }
 
-SymbolViewPlugin::~SymbolViewPlugin() { thePlugin = NULL; }
+SymbolViewPlugin::~SymbolViewPlugin() {}
 
 void SymbolViewPlugin::CreateToolBar(clToolBarGeneric* toolbar) { wxUnusedVar(toolbar); }
 
@@ -107,39 +91,9 @@ void SymbolViewPlugin::CreatePluginMenu(wxMenu* pluginsMenu) { wxUnusedVar(plugi
 
 void SymbolViewPlugin::UnPlug()
 {
-    EventNotifier::Get()->Unbind(wxEVT_SHOW_WORKSPACE_TAB, &SymbolViewPlugin::OnToggleTab, this);
-    int where = m_mgr->GetWorkspacePaneNotebook()->GetPageIndex(m_view);
-    if(where != wxNOT_FOUND) {
-        // this window might be floating
-        m_mgr->GetWorkspacePaneNotebook()->RemovePage(where);
-    }
-
-    m_view->Destroy();
-    m_view = NULL;
-}
-
-bool SymbolViewPlugin::IsPaneDetached()
-{
-    DetachedPanesInfo dpi;
-    m_mgr->GetConfigTool()->ReadObject(wxT("DetachedPanesList"), &dpi);
-    wxArrayString detachedPanes = dpi.GetPanes();
-    return detachedPanes.Index(_("Outline")) != wxNOT_FOUND;
-}
-
-void SymbolViewPlugin::OnToggleTab(clCommandEvent& event)
-{
-    if(event.GetString() != _("Outline")) {
-        event.Skip();
-        return;
-    }
-
-    if(event.IsSelected()) {
-        // show it
-        m_mgr->GetWorkspacePaneNotebook()->AddPage(m_view, _("Outline"), true);
-    } else {
-        int where = m_mgr->GetWorkspacePaneNotebook()->GetPageIndex(_("Outline"));
-        if(where != wxNOT_FOUND) {
-            m_mgr->GetWorkspacePaneNotebook()->RemovePage(where);
-        }
+    if (!m_mgr->BookDeletePage(PaneId::SIDE_BAR, m_view)) {
+        // failed to delete, delete it manually
+        m_view->Destroy();
     }
+    m_view = nullptr;
 }
