@@ -26,6 +26,7 @@
 #ifndef __SymbolView__
 #define __SymbolView__
 
+#include "clTabTogglerHelper.h"
 #include "cl_command_event.h"
 #include "dockablepane.h"
 #include "globals.h"
@@ -43,11 +44,7 @@
 class SymbolViewPlugin : public IPlugin
 {
 protected:
-    OutlineTab* m_view;
-
-protected:
-    bool IsPaneDetached();
-    void OnToggleTab(clCommandEvent& event);
+    OutlineTab* m_view = nullptr;
 
 public:
     //--------------------------------------------
@@ -59,8 +56,8 @@ public:
     //--------------------------------------------
     // Abstract methods
     //--------------------------------------------
-    virtual void CreateToolBar(clToolBarGeneric* toolbar);
-    virtual void CreatePluginMenu(wxMenu* pluginsMenu);
-    virtual void UnPlug();
+    void CreateToolBar(clToolBarGeneric* toolbar) override;
+    void CreatePluginMenu(wxMenu* pluginsMenu) override;
+    void UnPlug() override;
 };
 #endif // Outline
