@@ -27,14 +27,16 @@
 #define NOTEBOOK_H
 
 #include "cl_defs.h"
+
 #if CL_USE_NATIVEBOOK
 
-#include "GTKNotebook.hpp"
-typedef clGTKNotebook Notebook;
+#include "clNativeNotebook.hpp"
+typedef clNativeNotebook Notebook;
 #else // !CL_USE_NATIVEBOOK
 
 #include "clGenericNotebook.hpp"
 typedef clGenericNotebook Notebook;
 
 #endif // CL_USE_NATIVEBOOK
+
 #endif // NOTEBOOK_H
