@@ -26,17 +26,20 @@
 #if USE_SFTP
 
 #include "SFTPBrowserDlg.h"
+
 #include "SSHAccountManagerDlg.h"
+#include "environmentconfig.h"
 #include "fileextmanager.h"
 #include "globals.h"
 #include "imanager.h"
 #include "sftp_settings.h"
-#include "ssh_account_info.h"
+#include "ssh/ssh_account_info.h"
 #include "windowattrmanager.h"
+
+#include <wx/app.h>
+#include <wx/busyinfo.h>
 #include <wx/msgdlg.h>
 #include <wx/utils.h>
-#include <wx/busyinfo.h>
-#include <wx/app.h>
 
 // ================================================================================
 // ================================================================================
@@ -52,7 +55,7 @@ public:
         , m_fullpath(fullpath)
     {
         wxFileName fn;
-        if(m_attribute->IsFolder()) {
+        if (m_attribute->IsFolder()) {
             fn = wxFileName(fullpath, "", wxPATH_UNIX);
             fn.Normalize();
             m_fullpath = fn.GetPath(false, wxPATH_UNIX);
@@ -75,7 +78,8 @@ public:
 // ================================================================================
 // ================================================================================
 
-SFTPBrowserDlg::SFTPBrowserDlg(wxWindow* parent, const wxString& title, const wxString& filter, size_t flags)
+SFTPBrowserDlg::SFTPBrowserDlg(wxWindow* parent, const wxString& title, const wxString& filter, size_t flags,
+                               const wxString& selectedAccount)
     : SFTPBrowserBaseDlg(parent)
     , m_sftp(NULL)
     , m_filter(filter)
@@ -86,25 +90,63 @@ SFTPBrowserDlg::SFTPBrowserDlg(wxWindow* parent, const wxString& title, const wx
     settings.Load();
     m_dataview->SetBitmaps(clGetManager()->GetStdIcons()->GetStandardMimeBitmapListPtr());
     const SSHAccountInfo::Vect_t& accounts = settings.GetAccounts();
-    for(const auto& account : accounts) {
-        m_choiceAccount->Append(account.GetAccountName());
+    int selection = wxNOT_FOUND;
+    for (const auto& account : accounts) {
+        int index = m_choiceAccount->Append(account.GetAccountName());
+        if (!selectedAccount.empty() && selectedAccount == account.GetAccountName()) {
+            selection = index;
+        }
     }
 
-    m_toolbar->AddTool(XRCID("ID_CD_UP"), _("Parent Folder"), clGetManager()->GetStdIcons()->LoadBitmap("up"));
-    m_toolbar->AddTool(XRCID("ID_SSH_ACCOUNT_MANAGER"), _("Open SSH Account Manager"),
-                       clGetManager()->GetStdIcons()->LoadBitmap("folder-users"));
+    clBitmapList* images = new clBitmapList;
+    m_toolbar->AddTool(wxID_NEW, _("Create new folder"), images->Add("plus"));
+    m_toolbar->AddTool(XRCID("ID_CD_UP"), _("Parent folder"), images->Add("up"));
+    m_toolbar->AddTool(XRCID("ID_SSH_ACCOUNT_MANAGER"), _("Open SSH account manager"), images->Add("user"));
+    m_toolbar->AssignBitmaps(images);
     m_toolbar->Realize();
 
     m_toolbar->Bind(wxEVT_TOOL, &SFTPBrowserDlg::OnCdUp, this, XRCID("ID_CD_UP"));
-    m_toolbar->Bind(wxEVT_UPDATE_UI, &SFTPBrowserDlg::OnCdUpUI, this, XRCID("ID_CD_UP"));
+    m_toolbar->Bind(wxEVT_UPDATE_UI, &SFTPBrowserDlg::OnConnectedUI, this, XRCID("ID_CD_UP"));
+
+    m_toolbar->Bind(wxEVT_TOOL, &SFTPBrowserDlg::OnNewFolder, this, wxID_NEW);
+    m_toolbar->Bind(wxEVT_UPDATE_UI, &SFTPBrowserDlg::OnConnectedUI, this, wxID_NEW);
+
     m_toolbar->Bind(wxEVT_TOOL, &SFTPBrowserDlg::OnSSHAccountManager, this, XRCID("ID_SSH_ACCOUNT_MANAGER"));
 
-    if(!m_choiceAccount->IsEmpty()) { m_choiceAccount->SetSelection(0); }
+    wxString last_location = clConfig::Get().Read("SFTPBrowserDlg/location", wxString());
+    wxString last_account = clConfig::Get().Read("SFTPBrowserDlg/account", wxString());
+
+    if (selection != wxNOT_FOUND) {
+        m_choiceAccount->SetSelection(selection);
+        m_choiceAccount->Enable(false); // don't allow the user to change the account selection
+    } else {
+        if (!last_location.empty()) {
+            m_textCtrlRemoteFolder->ChangeValue(last_location);
+        }
+        int where = m_choiceAccount->FindString(last_account);
+        if (where != wxNOT_FOUND) {
+            m_choiceAccount->SetSelection(where);
+        } else if (!m_choiceAccount->IsEmpty()) {
+            m_choiceAccount->SetSelection(0);
+        }
+    }
+    CallAfter(&SFTPBrowserDlg::DoSetLocationFocus);
     SetName("SFTPBrowserDlg");
     WindowAttrManager::Load(this);
 }
 
-SFTPBrowserDlg::~SFTPBrowserDlg() {}
+SFTPBrowserDlg::~SFTPBrowserDlg()
+{
+    clConfig::Get().Write("SFTPBrowserDlg/location", m_textCtrlRemoteFolder->GetValue());
+    clConfig::Get().Write("SFTPBrowserDlg/account", m_choiceAccount->GetStringSelection());
+}
+
+void SFTPBrowserDlg::DoSetLocationFocus()
+{
+    // set the insertion point to the end of the text control
+    m_textCtrlRemoteFolder->SetInsertionPointEnd();
+    m_textCtrlRemoteFolder->SetFocus();
+}
 
 void SFTPBrowserDlg::OnRefresh(wxCommandEvent& event)
 {
@@ -120,12 +162,21 @@ void SFTPBrowserDlg::DoDisplayEntriesForPath(const wxString& path)
     try {
         wxString folder;
         SFTPAttribute::List_t attributes;
-        if(path.IsEmpty()) {
+        if (path.IsEmpty()) {
             folder = m_textCtrlRemoteFolder->GetValue();
-            if(folder.IsEmpty()) { folder = "/"; }
+            if (folder.IsEmpty()) {
+                folder = "/";
+            } else {
+                // if the path contains file name, remmove it
+                wxFileName fn(folder);
+                if (fn.GetFullName().Contains(".")) {
+                    folder = fn.GetPath(wxPATH_UNIX);
+                }
+            }
+            folder.Replace("\\", "/");
             attributes = m_sftp->List(folder, m_flags, m_filter);
 
-        } else if(path == "..") {
+        } else if (path == "..") {
             // cd up
             attributes = m_sftp->CdUp(m_flags, m_filter);
             m_textCtrlRemoteFolder->ChangeValue(m_sftp->GetCurrentFolder());
@@ -137,7 +188,7 @@ void SFTPBrowserDlg::DoDisplayEntriesForPath(const wxString& path)
         }
 
         BitmapLoader* loader = clGetManager()->GetStdIcons();
-        for(SFTPAttribute::Ptr_t attr : attributes) {
+        for (SFTPAttribute::Ptr_t attr : attributes) {
             // Set the columns Name (icontext) | Type (text) | Size (text)
             wxVector<wxVariant> cols;
 
@@ -146,14 +197,14 @@ void SFTPBrowserDlg::DoDisplayEntriesForPath(const wxString& path)
             wxString fullname;
             fullname << folder << "/" << attr->GetName();
 
-            if(attr->IsSymlink()) {
-                if(attr->IsFolder()) {
+            if (attr->IsSymlink()) {
+                if (attr->IsFolder()) {
                     imgid = loader->GetMimeImageId(FileExtManager::TypeFolderSymlink);
                 } else {
                     imgid = loader->GetMimeImageId(FileExtManager::TypeFileSymlink);
                 }
             } else {
-                if(attr->IsFolder()) {
+                if (attr->IsFolder()) {
                     imgid = loader->GetMimeImageId(FileExtManager::TypeFolder);
                 } else {
                     wxFileName fn(fullname);
@@ -169,7 +220,7 @@ void SFTPBrowserDlg::DoDisplayEntriesForPath(const wxString& path)
         }
         m_dataview->SetFocus();
 
-    } catch(clException& e) {
+    } catch (const clException& e) {
         ::wxMessageBox(e.What(), "SFTP", wxICON_ERROR | wxOK);
         DoCloseSession();
     }
@@ -177,19 +228,19 @@ void SFTPBrowserDlg::DoDisplayEntriesForPath(const wxString& path)
 
 void SFTPBrowserDlg::DoCloseSession()
 {
-    m_sftp.reset(NULL);
+    m_sftp.reset();
     ClearView();
 }
 
 void SFTPBrowserDlg::OnItemActivated(wxDataViewEvent& event)
 {
-    if(!m_sftp) {
+    if (!m_sftp) {
         DoCloseSession();
         return;
     }
 
     SFTPBrowserEntryClientData* cd = DoGetItemData(event.GetItem());
-    if(cd && cd->GetAttribute()->IsFolder()) {
+    if (cd && cd->GetAttribute()->IsFolder()) {
         m_textCtrlRemoteFolder->ChangeValue(cd->GetFullpath());
         ClearView();
         DoDisplayEntriesForPath();
@@ -198,7 +249,7 @@ void SFTPBrowserDlg::OnItemActivated(wxDataViewEvent& event)
 
 void SFTPBrowserDlg::OnTextEnter(wxCommandEvent& event)
 {
-    if(!m_sftp) {
+    if (!m_sftp) {
         OnRefresh(event);
     } else {
         ClearView();
@@ -208,13 +259,13 @@ void SFTPBrowserDlg::OnTextEnter(wxCommandEvent& event)
 void SFTPBrowserDlg::OnOKUI(wxUpdateUIEvent& event)
 {
     wxString selection = m_textCtrlRemoteFolder->GetValue();
-    if(m_filter.IsEmpty()) { // folder / files - and there is a selection
+    if (m_filter.IsEmpty()) { // folder / files - and there is a selection
         event.Enable(!selection.IsEmpty());
 
-    } else if(!(m_flags & clSFTP::SFTP_BROWSE_FILES)) { // folders only
+    } else if (!(m_flags & clSFTP::SFTP_BROWSE_FILES)) { // folders only
         event.Enable(!selection.IsEmpty());
 
-    } else if(!selection.IsEmpty() && (m_flags & clSFTP::SFTP_BROWSE_FILES) && ::wxMatchWild(m_filter, selection)) {
+    } else if (!selection.IsEmpty() && (m_flags & clSFTP::SFTP_BROWSE_FILES) && ::wxMatchWild(m_filter, selection)) {
         event.Enable(true);
 
     } else {
@@ -224,7 +275,9 @@ void SFTPBrowserDlg::OnOKUI(wxUpdateUIEvent& event)
 
 SFTPBrowserEntryClientData* SFTPBrowserDlg::DoGetItemData(const wxDataViewItem& item) const
 {
-    if(!item.IsOk()) { return NULL; }
+    if (!item.IsOk()) {
+        return NULL;
+    }
     SFTPBrowserEntryClientData* cd = reinterpret_cast<SFTPBrowserEntryClientData*>(m_dataview->GetItemData(item));
     return cd;
 }
@@ -234,7 +287,9 @@ wxString SFTPBrowserDlg::GetPath() const { return m_textCtrlRemoteFolder->GetVal
 void SFTPBrowserDlg::OnItemSelected(wxDataViewEvent& event)
 {
     SFTPBrowserEntryClientData* cd = DoGetItemData(m_dataview->GetSelection());
-    if(cd) { m_textCtrlRemoteFolder->ChangeValue(cd->GetFullpath()); }
+    if (cd) {
+        m_textCtrlRemoteFolder->ChangeValue(cd->GetFullpath());
+    }
 }
 
 wxString SFTPBrowserDlg::GetAccount() const { return m_choiceAccount->GetStringSelection(); }
@@ -243,7 +298,9 @@ void SFTPBrowserDlg::Initialize(const wxString& account, const wxString& path)
 {
     m_textCtrlRemoteFolder->ChangeValue(path);
     int where = m_choiceAccount->FindString(account);
-    if(where != wxNOT_FOUND) { m_choiceAccount->SetSelection(where); }
+    if (where != wxNOT_FOUND) {
+        m_choiceAccount->SetSelection(where);
+    }
 }
 
 void SFTPBrowserDlg::OnKeyDown(wxKeyEvent& event)
@@ -251,8 +308,8 @@ void SFTPBrowserDlg::OnKeyDown(wxKeyEvent& event)
     event.Skip();
     wxChar ch = (wxChar)event.GetKeyCode();
 
-    if(::wxIsprint(ch)) {
-        if(!m_textCtrlInlineSearch->IsShown()) {
+    if (::wxIsprint(ch)) {
+        if (!m_textCtrlInlineSearch->IsShown()) {
             m_textCtrlInlineSearch->SetFocus();
             m_textCtrlInlineSearch->Clear();
 #ifdef __WXMSW__
@@ -269,7 +326,7 @@ void SFTPBrowserDlg::OnInlineSearch()
 {
     wxString text = m_textCtrlInlineSearch->GetValue();
     wxDataViewItem matchedItem = m_dataview->FindNext(wxDataViewItem(nullptr), text);
-    if(matchedItem.IsOk()) {
+    if (matchedItem.IsOk()) {
         m_dataview->Select(matchedItem);
         m_dataview->EnsureVisible(matchedItem);
     }
@@ -278,10 +335,12 @@ void SFTPBrowserDlg::OnInlineSearch()
 void SFTPBrowserDlg::OnInlineSearchEnter()
 {
     wxDataViewItem item = m_dataview->GetSelection();
-    if(!item.IsOk()) { return; }
+    if (!item.IsOk()) {
+        return;
+    }
 
     SFTPBrowserEntryClientData* cd = DoGetItemData(item);
-    if(cd && cd->GetAttribute()->IsFolder()) {
+    if (cd && cd->GetAttribute()->IsFolder()) {
         m_textCtrlRemoteFolder->ChangeValue(cd->GetFullpath());
         ClearView();
         DoDisplayEntriesForPath();
@@ -313,12 +372,12 @@ void SFTPBrowserDlg::OnCdUp(wxCommandEvent& event)
     DoDisplayEntriesForPath("..");
 }
 
-void SFTPBrowserDlg::OnCdUpUI(wxUpdateUIEvent& event) { event.Enable(m_sftp); }
+void SFTPBrowserDlg::OnConnectedUI(wxUpdateUIEvent& event) { event.Enable(m_sftp.get()); }
 
 void SFTPBrowserDlg::OnSSHAccountManager(wxCommandEvent& event)
 {
     SSHAccountManagerDlg dlg(this);
-    if(dlg.ShowModal() == wxID_OK) {
+    if (dlg.ShowModal() == wxID_OK) {
         // Update the selections at the top
         SFTPSettings settings;
         settings.Load();
@@ -326,18 +385,18 @@ void SFTPBrowserDlg::OnSSHAccountManager(wxCommandEvent& event)
 
         m_choiceAccount->Clear();
         const SSHAccountInfo::Vect_t& accounts = settings.GetAccounts();
-        if(accounts.empty()) {
+        if (accounts.empty()) {
             DoCloseSession();
             return;
 
         } else {
             SSHAccountInfo::Vect_t::const_iterator iter = accounts.begin();
-            for(; iter != accounts.end(); ++iter) {
+            for (; iter != accounts.end(); ++iter) {
                 m_choiceAccount->Append(iter->GetAccountName());
             }
 
             int where = m_choiceAccount->FindString(curselection);
-            if(where == wxNOT_FOUND) {
+            if (where == wxNOT_FOUND) {
                 // Our previous session is no longer available, close the session
                 DoCloseSession();
                 where = 0;
@@ -350,7 +409,7 @@ void SFTPBrowserDlg::OnSSHAccountManager(wxCommandEvent& event)
 
 void SFTPBrowserDlg::ClearView()
 {
-    for(size_t i = 0; i < m_dataview->GetItemCount(); ++i) {
+    for (size_t i = 0; i < m_dataview->GetItemCount(); ++i) {
         SFTPBrowserEntryClientData* cd = DoGetItemData(m_dataview->RowToItem(i));
         wxDELETE(cd);
     }
@@ -359,9 +418,7 @@ void SFTPBrowserDlg::ClearView()
 
 void SFTPBrowserDlg::DoBrowse()
 {
-    wxBusyInfo wait("Please wait, connecting...", this);
     wxBusyCursor bc;
-    wxTheApp->Yield();
     DoCloseSession();
     wxString accountName = m_choiceAccount->GetStringSelection();
 
@@ -369,18 +426,20 @@ void SFTPBrowserDlg::DoBrowse()
     settings.Load();
 
     SSHAccountInfo account;
-    if(!settings.GetAccount(accountName, account)) {
+    if (!settings.GetAccount(accountName, account)) {
         ::wxMessageBox(wxString() << _("Could not find account: ") << accountName, "CodeLite", wxICON_ERROR | wxOK,
                        this);
         return;
     }
 
-    clSSH::Ptr_t ssh(new clSSH(account.GetHost(), account.GetUsername(), account.GetPassword(), account.GetPort()));
+    clSSH::Ptr_t ssh(new clSSH(account.GetHost(), account.GetUsername(), account.GetPassword(), account.GetKeyFiles(),
+                               account.GetPort()));
     try {
         wxString message;
-        ssh->Connect();
-        if(!ssh->AuthenticateServer(message)) {
-            if(::wxMessageBox(message, "SSH", wxYES_NO | wxCENTER | wxICON_QUESTION, this) == wxYES) {
+        EnvSetter env;
+        ssh->Open();
+        if (!ssh->AuthenticateServer(message)) {
+            if (::wxMessageBox(message, "SSH", wxYES_NO | wxCENTER | wxICON_QUESTION, this) == wxYES) {
                 ssh->AcceptServerAuthentication();
             }
         }
@@ -391,10 +450,31 @@ void SFTPBrowserDlg::DoBrowse()
 
         DoDisplayEntriesForPath();
 
-    } catch(clException& e) {
+    } catch (const clException& e) {
         ::wxMessageBox(e.What(), "CodeLite", wxICON_ERROR | wxOK, this);
         DoCloseSession();
     }
 }
 
+void SFTPBrowserDlg::OnNewFolder(wxCommandEvent& event)
+{
+    wxUnusedVar(event);
+    CHECK_PTR_RET(m_sftp);
+
+    wxString name = clGetTextFromUser(_("Create new folder"), _("Name:"));
+    if (name.empty()) {
+        return;
+    }
+
+    try {
+        wxString path;
+        path << m_sftp->GetCurrentFolder() << "/" << name;
+        m_sftp->CreateDir(path);
+        ClearView();
+        DoDisplayEntriesForPath();
+    } catch (const clException& e) {
+        ::wxMessageBox(e.What(), "CodeLite", wxICON_ERROR | wxOK, this);
+    }
+}
+
 #endif // USE_SFTP
