@@ -145,8 +145,6 @@ protected:
     std::unordered_map<wxString, wxBitmap> m_toolbarsBitmaps;
     std::unordered_map<wxString, wxString> m_manifest;
     std::unordered_map<int, int> m_fileIndexMap;
-    bool m_bMapPopulated;
-    size_t m_toolbarIconSize;
     clMimeBitmaps m_mimeBitmaps;
 
 protected:
@@ -156,6 +154,8 @@ private:
     BitmapLoader(bool darkTheme);
     virtual ~BitmapLoader();
 
+    void AddBitmapInternal(const wxBitmapBundle& bundle, const wxString& base_name);
+
 public:
     clMimeBitmaps& GetMimeBitmaps() { return m_mimeBitmaps; }
     const clMimeBitmaps& GetMimeBitmaps() const { return m_mimeBitmaps; }
@@ -181,6 +181,11 @@ public:
      */
     int GetMimeImageId(const wxString& filename, bool disabled = false);
 
+    /**
+     * @brief return bitmap bundle by name
+     */
+    const wxBitmapBundle& GetBundle(const wxString& name) const;
+
     /**
      * @brief return the image index in the image list prepared by GetStandardMimeBitmapListPtr()
      * @return wxNOT_FOUND if no match is found, the index otherwise
@@ -193,11 +198,12 @@ protected:
 
 private:
     void Initialize(bool darkTheme);
-    static void SetActiveBitmaps();
-    void OnSysColoursChanged(clCommandEvent& event);
+    void LoadSVGFiles(bool darkTheme);
+    std::unordered_map<wxString, wxBitmapBundle>* GetBundles(bool darkTheme) const;
 
 public:
     const wxBitmap& LoadBitmap(const wxString& name, int requestedSize = 16);
+    bool GetIconBundle(const wxString& name, wxIconBundle* bundle);
 };
 
 wxDECLARE_EXPORTED_EVENT(WXDLLIMPEXP_SDK, wxEVT_BITMAPS_UPDATED, clCommandEvent);
@@ -220,4 +226,11 @@ public:
     BitmapLoader* GetLoader();
     void SysColoursChanged();
 };
-#endif // BITMAP_LOADER_H
+
+/// Helper load function
+WXDLLIMPEXP_SDK void
+clLoadSidebarBitmap(const wxString& name, wxWindow* win, wxBitmap* light_theme_bmp, wxBitmap* dark_theme_bmp);
+
+/// Clear the sidebar bitmaps cache
+void WXDLLIMPEXP_SDK clClearSidebarBitmapCache();
+#endif
