@@ -27,7 +27,6 @@
 
 #include "globals.h"
 #include "macros.h"
-#include "wx_xml_compatibility.h"
 #include "xmlutils.h"
 
 #include <wx/tokenzr.h>
@@ -148,15 +147,15 @@ wxXmlNode* BuildConfigCommon::ToXml() const
     return node;
 }
 
-void BuildConfigCommon::SetPreprocessor(const wxString& pre) { FillFromSmiColonString(m_preprocessor, pre); }
+void BuildConfigCommon::SetPreprocessor(const wxString& pre) { FillFromSemiColonString(m_preprocessor, pre); }
 
-void BuildConfigCommon::SetIncludePath(const wxString& path) { FillFromSmiColonString(m_includePath, path); }
+void BuildConfigCommon::SetIncludePath(const wxString& path) { FillFromSemiColonString(m_includePath, path); }
 
-void BuildConfigCommon::SetLibraries(const wxString& libs) { FillFromSmiColonString(m_libs, libs); }
+void BuildConfigCommon::SetLibraries(const wxString& libs) { FillFromSemiColonString(m_libs, libs); }
 
-void BuildConfigCommon::SetLibPath(const wxString& paths) { FillFromSmiColonString(m_libPath, paths); }
+void BuildConfigCommon::SetLibPath(const wxString& paths) { FillFromSemiColonString(m_libPath, paths); }
 
-static wxString ConvertToSmiColonString(const wxArrayString& array)
+static wxString ConvertToSemiColonString(const wxArrayString& array)
 {
     wxString result;
     for(size_t i = 0; i < array.GetCount(); i++) {
@@ -170,11 +169,11 @@ static wxString ConvertToSmiColonString(const wxArrayString& array)
     return result.BeforeLast(';');
 }
 
-wxString BuildConfigCommon::GetLibPath() const { return ConvertToSmiColonString(m_libPath); }
+wxString BuildConfigCommon::GetLibPath() const { return ConvertToSemiColonString(m_libPath); }
 
-wxString BuildConfigCommon::GetLibraries() const { return ConvertToSmiColonString(m_libs); }
+wxString BuildConfigCommon::GetLibraries() const { return ConvertToSemiColonString(m_libs); }
 
-wxString BuildConfigCommon::GetIncludePath() const { return ConvertToSmiColonString(m_includePath); }
+wxString BuildConfigCommon::GetIncludePath() const { return ConvertToSemiColonString(m_includePath); }
 
 wxString BuildConfigCommon::GetPreprocessor() const
 {
