@@ -35,15 +35,13 @@
 class IEditor;
 class CCBox;
 
-WXDLLIMPEXP_SDK extern const wxEventType wxEVT_TIP_BTN_CLICKED_UP;
-WXDLLIMPEXP_SDK extern const wxEventType wxEVT_TIP_BTN_CLICKED_DOWN;
-
 class WXDLLIMPEXP_SDK CCBoxTipWindow : public wxPopupWindow
 {
 protected:
     wxString m_tip;
     size_t m_numOfTips = 1;
     bool m_stripHtmlTags = false;
+    int m_editorStartPosition = wxNOT_FOUND;
 
 protected:
     void OnPaint(wxPaintEvent& e);
@@ -62,18 +60,14 @@ public:
      * if focusEditor is NOT null, the editor will gain the focus once
      * the tip is shown
      */
-    void PositionRelativeTo(wxWindow* win, wxPoint caretPos, IEditor* focusEdior = NULL);
+    void PositionRelativeTo(wxWindow* win, wxPoint caretPos, int start_position, IEditor* focusEdior = NULL);
 
-    /**
-     * @brief position this window to the left of 'win'
-     * if focusEditor is NOT null, the editor will gain the focus once
-     * the tip is shown
-     */
-    void PositionLeftTo(wxWindow* win, IEditor* focusEditor = NULL);
     /**
      * @brief position and show the tip at a given location
      */
     void PositionAt(const wxPoint& pt, IEditor* focusEdior = NULL);
+
+    int GetEditorStartPosition() const { return m_editorStartPosition; }
 };
 
 #endif // CCBOXTIPWINDOW_H
