@@ -1,5 +1,6 @@
 #include "clAnsiEscapeCodeHandler.hpp"
 
+#include "ColoursAndFontsManager.h"
 #include "drawingutils.h"
 #include "file_logger.h"
 
@@ -308,56 +309,94 @@ clAnsiEscapeCodeHandler::clAnsiEscapeCodeHandler()
     m_8_bit_colours_normal.insert({ 254, wxColour("#e4e4e4") });
     m_8_bit_colours_normal.insert({ 255, wxColour("#eeeeee") });
 
-    // lighten the colours a bit
     m_8_bit_colours_for_dark_theme = m_8_bit_colours_normal;
-    for(auto& vt : m_8_bit_colours_for_dark_theme) {
-        vt.second = vt.second.ChangeLightness(150);
+    // lighten the colours a bit
+    for(auto& [_, colour] : m_8_bit_colours_normal) {
+        colour = colour.ChangeLightness(150);
+    }
+
+    // darken the colours for light theme
+    for(auto& [_, colour] : m_8_bit_colours_normal) {
+        colour = colour.ChangeLightness(80);
     }
 
     m_colours_for_dark_theme = m_colours_normal;
-    for(auto& vt : m_colours_for_dark_theme) {
-        vt.second = vt.second.ChangeLightness(150);
+
+    // lighten the colours a bit
+    for(auto& [_, colour] : m_colours_for_dark_theme) {
+        colour = colour.ChangeLightness(150);
     }
+
+    // darken the colours for light theme
+    for(auto& [_, colour] : m_colours_normal) {
+        colour = colour.ChangeLightness(80);
+    }
+
     m_8_bit_colours = &m_8_bit_colours_normal;
     m_colours = &m_colours_normal;
 }
 
 clAnsiEscapeCodeHandler::~clAnsiEscapeCodeHandler() {}
 
-#define NEXT(EOL)                                      \
-    if(chunk->is_style_reset() || !chunk->d.empty()) { \
-        chunk->set_flag(kCompleted);                   \
-        chunk->set_flag(kEndOfLine, EOL);              \
-        if(chunk->is_eol()) {                          \
-            m_lineNumber++;                            \
-        }                                              \
-        EnsureCurrent();                               \
-        chunk = &m_chunks.back();                      \
-        chunk->line_number = m_lineNumber;             \
+#define NEXT(__is_eol)                               \
+    chunk->is_eol = __is_eol;                        \
+    if(chunk->is_style_reset || !chunk->d.empty()) { \
+        chunk->is_completed = true;                  \
+    }                                                \
+    EnsureCurrent();                                 \
+    chunk = &m_chunks.back().back();
+
+namespace
+{
+wxChar look_ahead(const wxString& buffer, size_t curpos, size_t count)
+{
+    if((curpos + count) < buffer.length()) {
+        return buffer[curpos + count];
     }
+    return wxChar(0);
+}
+} // namespace
 
 void clAnsiEscapeCodeHandler::Parse(const wxString& buffer)
 {
     EnsureCurrent();
-    auto chunk = &m_chunks.back();
-    for(const wxChar& ch : buffer) {
+    eColourHandlerState kCR_prev_state = eColourHandlerState::kNormal;
+    auto chunk = &m_chunks.back().back();
+    for(size_t i = 0; i < buffer.length(); ++i) {
+        wxChar ch = buffer[i];
         switch(m_state) {
+        case eColourHandlerState::kCR:
+            switch(ch) {
+            case '\n':
+                // "\r\n"
+                --i;
+                m_state = kCR_prev_state;
+                break;
+            default:
+                // any other char, we delete this entire line
+                chunk->d.clear();
+                --i;
+                m_state = kCR_prev_state;
+                break;
+            }
+            break;
         case eColourHandlerState::kNormal:
             switch(ch) {
             case 0x1B: // ESC
                 NEXT(false);
                 // remove the text flag
-                chunk->set_flag(kTextChunk, false);
+                chunk->is_text = false;
                 m_state = eColourHandlerState::kInEscape;
                 break;
             case '\r':
-                // ignore CR
+                kCR_prev_state = m_state;
+                m_state = eColourHandlerState::kCR;
                 break;
             case '\n':
                 NEXT(true);
                 break;
             default:
-                chunk->d << ch;
+                chunk->d.append(1, ch);
                 break;
             }
             break;
@@ -377,19 +416,55 @@ void clAnsiEscapeCodeHandler::Parse(const wxString& buffer)
             break;
         case eColourHandlerState::kInOsc:
             // ESC ]
-            if(ch == '\a') {
+            switch(ch) {
+            case 0x07: // BELL
                 // bell, leave the current state
-                chunk->set_flag(kTitleChunk);
-                NEXT(true);
+                chunk->is_completed = true;
+                NEXT(false);
                 m_state = eColourHandlerState::kNormal;
-            } else {
-                chunk->d << ch;
+                break;
+            case '0':
+            case '2':
+                m_state = eColourHandlerState::kOSC_Title;
+                break;
+            case '8':
+                m_state = eColourHandlerState::kOSC_Url;
+                break;
+            default:
+                chunk->d.append(1, ch);
+                break;
             }
             break;
+        case eColourHandlerState::kOSC_Title: {
+            // In this state we skip the first char (';')
+            // and read everything until we find the BELL or EOF
+            chunk->is_title = true;
+            wxChar next_char = look_ahead(buffer, i, 1);
+            while(next_char != 0x07 && next_char != 0) { // while NEXT is NOT BELL
+                chunk->d.append(1, next_char);
+                ++i;
+                next_char = look_ahead(buffer, i, 1);
+            }
+            m_state = eColourHandlerState::kInOsc;
+        } break;
+        case eColourHandlerState::kOSC_Url: {
+            // In this state we skip the first char (';')
+            // and read everything until we find the BELL or EOF, but we don't collect it!
+            wxChar next_char = look_ahead(buffer, i, 1);
+            while(next_char != 0x07 && next_char != 0) { // while NEXT is NOT BELL
+                ++i;
+                next_char = look_ahead(buffer, i, 1);
+            }
+            m_state = eColourHandlerState::kInOsc;
+        } break;
         case eColourHandlerState::kInCsi:
             // found ESC[
             switch(ch) {
             case 'K':
+                // clear the current line
+                chunk->d.clear();
+                m_state = eColourHandlerState::kNormal;
+                break;
             case 'A':
             case 'B':
             case 'C':
@@ -410,50 +485,86 @@ void clAnsiEscapeCodeHandler::Parse(const wxString& buffer)
                 NEXT(false);
                 m_state = eColourHandlerState::kNormal;
                 break;
+            case '?':
+                // Some popular private sequences
+                m_state = eColourHandlerState::kInPrivateSequence;
+                break;
             case 'm':
                 // update the style
                 if(chunk->d.empty() || chunk->d == "0") {
-                    chunk->set_flag(kResetStyle);
+                    chunk->is_style_reset = true;
                 }
                 NEXT(false);
                 m_state = eColourHandlerState::kNormal;
                 break;
             default:
-                chunk->d << ch;
+                chunk->d.append(1, ch);
                 break;
             }
+            break;
+        case eColourHandlerState::kInPrivateSequence:
+            // https://en.wikipedia.org/wiki/ANSI_escape_code#CSI_(Control_Sequence_Introducer)_sequences
+            // (Some popular private sequences)
+            switch(ch) {
+            case '?':
+            case '0':
+            case '1':
+            case '2':
+            case '3':
+            case '4':
+            case '5':
+            case '6':
+            case '7':
+            case '8':
+            case '9':
+                // consume [digits]
+                break;
+            case '\n':
+                NEXT(true);
+                m_state = eColourHandlerState::kNormal;
+                break;
+            case 'h':
+            case 'l':
+                NEXT(false);
+                m_state = eColourHandlerState::kNormal;
+                break;
+            case '\r':
+                *chunk = Chunk{};
+                m_state = eColourHandlerState::kNormal;
+                break;
+            default:
+                // get back to the prev state
+                m_state = eColourHandlerState::kInCsi;
+                break;
+            }
+            break;
         }
     }
 
+    chunk->is_completed = true;
     // remove the last chunk if it is empty
-    if(!m_chunks.empty() && m_chunks.back().is_empty() && m_lines.count(m_chunks.back().line_number)) {
-        auto& v = m_lines[m_chunks.back().line_number];
-        // remove the reference for this chunk from the map (it will be the last item on the line number vector)
-        v.pop_back();
-
-        // remove it from the vector as well
-        m_chunks.pop_back();
+    if(!m_chunks.empty() && m_chunks.back().back().is_empty()) {
+        m_chunks.back().pop_back();
     }
 }
 
 void clAnsiEscapeCodeHandler::Reset()
 {
     m_chunks.clear();
-    m_lines.clear();
-    m_lineNumber = 0;
+    m_windowTitle.clear();
     m_state = eColourHandlerState::kNormal;
 }
 
 void clAnsiEscapeCodeHandler::EnsureCurrent()
 {
-    if(m_chunks.empty() || (m_chunks.back().flags & kCompleted)) {
-        m_chunks.emplace_back();
-        m_chunks.back().line_number = m_lineNumber;
-        if(m_lines.count(m_lineNumber) == 0) {
-            m_lines.insert({ m_lineNumber, {} });
-        }
-        // associate the newly added item index to the current line number
-        m_lines[m_lineNumber].push_back(m_chunks.size() - 1);
+    if(m_chunks.empty() || m_chunks.back().back().is_eol) {
+        // add new row
+        m_chunks.emplace_back(Chunk::Vec_t{});
+        // make sure we have at least 1 element in that row
+        m_chunks.back().push_back(Chunk{});
+    } else {
+        // start new chunk for the current line
+        m_chunks.back().push_back(Chunk{});
     }
 }
 
@@ -461,11 +572,11 @@ void clAnsiEscapeCodeHandler::RenderNoStyle(wxDC& dc, const clRenderDefaultStyle
                                             const wxRect& rect, bool isLightTheme)
 {
     // find the line chunks
-    if(m_lines.count(line) == 0) {
+    if(line >= (int)m_chunks.size()) {
         return;
     }
 
-    const auto& v = m_lines[line];
+    const auto& v = m_chunks[line];
 
     dc.SetFont(defaultStyle.font);
     int text_height = dc.GetTextExtent("Tp").GetHeight();
@@ -476,11 +587,10 @@ void clAnsiEscapeCodeHandler::RenderNoStyle(wxDC& dc, const clRenderDefaultStyle
     int yy = rect.y;
     int xx = X_MARGIN;
     dc.SetClippingRegion(rect);
-    for(size_t i : v) {
+    for(const auto& chunk : v) {
         // ensure to restore the dont once we are done with this line
         wxDCFontChanger font_changer(dc);
-        const auto& chunk = m_chunks[i];
-        if(chunk.is_text()) {
+        if(chunk.is_text) {
             // draw the text
             wxSize text_size = dc.GetTextExtent(chunk.d);
             dc.DrawText(chunk.d, xx, yy);
@@ -488,18 +598,123 @@ void clAnsiEscapeCodeHandler::RenderNoStyle(wxDC& dc, const clRenderDefaultStyle
         }
 
         // if this chunk was EOL, reset the style here
-        if(chunk.is_eol()) {
+        if(chunk.is_eol) {
             defaultStyle.ResetDC(dc);
         }
     }
     dc.DestroyClippingRegion();
 }
 
+void clAnsiEscapeCodeHandler::Render(wxSTCStyleProvider* style_provider, bool isLightTheme)
+{
+    // find the line chunks
+    if(m_chunks.empty()) {
+        return;
+    }
+
+    wxStyledTextCtrl* stc = style_provider->m_ctrl;
+    // Check if this is a dark theme
+    if(isLightTheme) {
+        // normal
+        m_8_bit_colours = &m_8_bit_colours_normal;
+        m_colours = &m_colours_normal;
+    } else {
+        // dark theme background
+        m_8_bit_colours = &m_8_bit_colours_for_dark_theme;
+        m_colours = &m_colours_for_dark_theme;
+    }
+
+    // render everything
+    int curstyle = 0;
+    for(const auto& v : m_chunks) {
+        for(const auto& chunk : v) {
+            // ensure to restore the dont once we are done with this line
+            if(chunk.is_style_reset) {
+                // reset the style
+                curstyle = 0;
+            } else if(chunk.is_text) {
+                if(!chunk.d.empty()) {
+                    // append and style the next text
+                    int pos = stc->GetLength();
+                    int curline = stc->LineFromPosition(pos);
+                    clDEBUG() << "styling from line:" << curline << "with style:" << curstyle << endl;
+                    stc->AppendText(chunk.d);
+                    stc->StartStyling(pos);
+                    stc->SetStyling(chunk.d.length(), curstyle);
+                }
+            } else if(chunk.is_title) {
+                m_windowTitle = chunk.d;
+            } else if(chunk.is_empty()) {
+                // skip it
+            } else {
+                wxTextAttr result;
+                UpdateStyle(chunk, style_provider->GetDefaultStyle(), &result);
+                curstyle = style_provider->GetStyle(result.GetTextColour(), result.GetBackgroundColour());
+            }
+
+            // if this chunk was EOL, reset the style here
+            if(chunk.is_eol) {
+                stc->AppendText("\n");
+            }
+        }
+    }
+    m_chunks.clear();
+}
+
+void clAnsiEscapeCodeHandler::Render(wxTextCtrl* ctrl, const wxTextAttr& defaultStyle, bool isLightTheme)
+{
+    // find the line chunks
+    if(m_chunks.empty()) {
+        return;
+    }
+
+    // Check if this is a dark theme
+    if(isLightTheme) {
+        // normal
+        m_8_bit_colours = &m_8_bit_colours_normal;
+        m_colours = &m_colours_normal;
+    } else {
+        // dark theme background
+        m_8_bit_colours = &m_8_bit_colours_for_dark_theme;
+        m_colours = &m_colours_for_dark_theme;
+    }
+
+    // render everything
+    for(const auto& v : m_chunks) {
+        for(const auto& chunk : v) {
+            // ensure to restore the dont once we are done with this line
+            if(chunk.is_style_reset) {
+                // reset the style
+                ctrl->SetDefaultStyle(defaultStyle);
+            } else if(chunk.is_text) {
+                // draw the text
+                // ctrl->SetInsertionPointEnd();
+                ctrl->AppendText(chunk.d);
+
+            } else if(chunk.is_title || chunk.is_empty()) {
+                m_windowTitle = chunk.d;
+            } else {
+                wxTextAttr result;
+                UpdateStyle(chunk, defaultStyle, &result);
+                ctrl->SetDefaultStyle(result);
+            }
+
+            // if this chunk was EOL, reset the style here
+            if(chunk.is_eol) {
+                // ctrl->SetInsertionPointEnd();
+                ctrl->AppendText("\n");
+                ctrl->SetDefaultStyle(defaultStyle);
+            }
+        }
+    }
+    m_chunks.clear();
+}
+
 void clAnsiEscapeCodeHandler::Render(wxDC& dc, const clRenderDefaultStyle& defaultStyle, int line, const wxRect& rect,
                                      bool isLightTheme)
 {
     // find the line chunks
-    if(m_lines.count(line) == 0) {
+    if(line >= (int)m_chunks.size()) {
         return;
     }
     // Check if this is a dark theme
@@ -513,7 +728,7 @@ void clAnsiEscapeCodeHandler::Render(wxDC& dc, const clRenderDefaultStyle& defau
         m_colours = &m_colours_for_dark_theme;
     }
 
-    const auto& v = m_lines[line];
+    const auto& v = m_chunks[line];
 
     dc.SetFont(defaultStyle.font);
     int text_height = dc.GetTextExtent("Tp").GetHeight();
@@ -525,27 +740,26 @@ void clAnsiEscapeCodeHandler::Render(wxDC& dc, const clRenderDefaultStyle& defau
     int yy = rect.y;
     int xx = X_MARGIN;
     dc.SetClippingRegion(rect);
-    for(size_t i : v) {
+    for(const auto& chunk : v) {
         // ensure to restore the dont once we are done with this line
         wxDCFontChanger font_changer(dc);
-        const auto& chunk = m_chunks[i];
-        if(chunk.is_style_reset()) {
+        if(chunk.is_style_reset) {
             // reset the style
             defaultStyle.ResetDC(dc);
-        } else if(chunk.is_text()) {
+        } else if(chunk.is_text) {
             // draw the text
             wxSize text_size = dc.GetTextExtent(chunk.d);
             dc.DrawText(chunk.d, xx, yy);
             xx += text_size.GetWidth();
 
-        } else if(chunk.is_window_title() || chunk.is_empty()) {
-            // for now, we do nothing
+        } else if(chunk.is_title || chunk.is_empty()) {
+            m_windowTitle = chunk.d;
         } else {
             UpdateStyle(chunk, dc, defaultStyle);
         }
 
         // if this chunk was EOL, reset the style here
-        if(chunk.is_eol()) {
+        if(chunk.is_eol) {
             defaultStyle.ResetDC(dc);
         }
     }
@@ -562,6 +776,125 @@ void clAnsiEscapeCodeHandler::Render(wxDC& dc, const clRenderDefaultStyle& defau
         }                                         \
     }
 
+void clAnsiEscapeCodeHandler::UpdateStyle(const Chunk& chunk, const wxTextAttr& defaultStyle, wxTextAttr* updatedStyle)
+{
+    constexpr int STATE_NORMAL = 0;
+    constexpr int STATE_SET_FG = 1;
+    constexpr int STATE_SET_BG = 2;
+
+    // see: https://en.wikipedia.org/wiki/ANSI_escape_code#SGR_(Select_Graphic_Rendition)_parameters
+    *updatedStyle = defaultStyle;
+    if(chunk.d == "0") {
+        *updatedStyle = defaultStyle;
+    } else {
+        int state = STATE_NORMAL;
+        wxArrayString attrs = ::wxStringTokenize(chunk.d, ";", wxTOKEN_RET_EMPTY);
+        wxFont f = defaultStyle.GetFont();
+        for(size_t i = 0; i < attrs.size(); ++i) {
+            const wxString& attr = attrs[i];
+            long number;
+            if(!attr.ToCLong(&number)) {
+                continue;
+            }
+            switch(state) {
+            case STATE_NORMAL:
+                switch(number) {
+                case 0:
+                    // reset attributes
+                    *updatedStyle = defaultStyle;
+                    break;
+                case 1:
+                    f.SetWeight(wxFONTWEIGHT_BOLD);
+                    break;
+                case 2:
+                    f.SetWeight(wxFONTWEIGHT_LIGHT);
+                    break;
+                case 3:
+                    f.SetStyle(wxFONTSTYLE_ITALIC);
+                    break;
+                case 4:
+                    f.SetUnderlined(true);
+                    break;
+                case 38:
+                    state = STATE_SET_FG;
+                    break;
+                case 48:
+                    state = STATE_SET_BG;
+                    break;
+                default:
+                    if((number >= 30 && number <= 37) || (number >= 90 && number <= 97)) {
+                        // use colour table to set the text colour
+                        wxColour c = GetColour(*m_colours, number);
+                        if(c.IsOk()) {
+                            updatedStyle->SetTextColour(c);
+                        }
+                    } else if((number >= 40 && number <= 47) || (number >= 100 && number <= 107)) {
+                        wxColour c = GetColour(*m_colours, number);
+                        if(c.IsOk()) {
+                            updatedStyle->SetBackgroundColour(c);
+                        }
+                    }
+                    break;
+                }
+                break;
+            case STATE_SET_BG:
+                switch(number) {
+                case 5:
+                    break;
+                case 2: {
+                    // ESC[38;2;R;G;B
+                    wxColour::ChannelType r, g, b;
+                    NEXT_ATTR(i + 1, r);
+                    NEXT_ATTR(i + 2, g);
+                    NEXT_ATTR(i + 3, b);
+                    wxColour c{ r, g, b };
+                    if(c.IsOk()) {
+                        updatedStyle->SetTextColour(c);
+                    }
+                    state = STATE_NORMAL;
+                } break;
+                default: {
+                    // use colour table to set the text colour
+                    wxColour c = GetColour(*m_8_bit_colours, number);
+                    if(c.IsOk()) {
+                        updatedStyle->SetBackgroundColour(c);
+                    }
+                    state = STATE_NORMAL;
+                } break;
+                }
+                break;
+            case STATE_SET_FG:
+                switch(number) {
+                case 5:
+                    break;
+                case 2: {
+                    // ESC[38;2;R;G;B
+                    wxColour::ChannelType r, g, b;
+                    NEXT_ATTR(i + 1, r);
+                    NEXT_ATTR(i + 2, g);
+                    NEXT_ATTR(i + 3, b);
+                    wxColour c{ r, g, b };
+                    if(c.IsOk()) {
+                        updatedStyle->SetTextColour(c);
+                    }
+                    state = STATE_NORMAL;
+                } break;
+                default: {
+                    // use colour table to set the text colour
+                    wxColour c = GetColour(*m_8_bit_colours, number);
+                    if(c.IsOk()) {
+                        updatedStyle->SetTextColour(c);
+                    }
+                    state = STATE_NORMAL;
+                } break;
+                }
+                break;
+            }
+        }
+        updatedStyle->SetFont(f);
+    }
+}
+
 void clAnsiEscapeCodeHandler::UpdateStyle(const Chunk& chunk, wxDC& dc, const clRenderDefaultStyle& defaultStyle)
 {
     constexpr int STATE_NORMAL = 0;
@@ -687,3 +1020,55 @@ const wxColour& clAnsiEscapeCodeHandler::GetColour(const ColoursMap_t& m, int nu
     }
     return m.find(num)->second;
 }
+
+// ===------------------------------------------------------------------------
+// ===------------------------------------------------------------------------
+
+int wxSTCStyleProvider::GetStyle(const wxColour& fg, const wxColour& bg)
+{
+    // build the key for the style
+    wxString key;
+    key << "fg:" << fg.GetAsString(wxC2S_HTML_SYNTAX) << ";bg:" << bg.GetAsString(wxC2S_HTML_SYNTAX);
+    if(m_styleCache.count(key)) {
+        return m_styleCache[key];
+    }
+
+    // no such style, create it
+    if(m_curstyle >= wxSTC_STYLE_MAX) {
+        return 0;
+    }
+
+    int new_style = m_curstyle;
+    m_ctrl->StyleSetBackground(new_style, bg);
+    m_ctrl->StyleSetForeground(new_style, fg);
+    m_styleCache.insert({ key, new_style });
+    ++m_curstyle;
+    return new_style;
+}
+
+wxTextAttr wxSTCStyleProvider::GetDefaultStyle() const
+{
+    wxTextAttr attr;
+    attr.SetFont(m_ctrl->StyleGetFont(0));
+    attr.SetTextColour(m_ctrl->StyleGetForeground(0));
+    attr.SetBackgroundColour(m_ctrl->StyleGetBackground(0));
+    return attr;
+}
+
+wxSTCStyleProvider::~wxSTCStyleProvider() {}
+
+wxSTCStyleProvider::wxSTCStyleProvider(wxStyledTextCtrl* ctrl)
+    : m_ctrl(ctrl)
+{
+    auto lexer = ColoursAndFontsManager::Get().GetLexer("text");
+    lexer->Apply(m_ctrl);
+    m_ctrl->SetLexer(wxSTC_LEX_CONTAINER);
+}
+
+void wxSTCStyleProvider::Clear()
+{
+    m_styleCache.clear();
+    m_curstyle = wxSTC_STYLE_LASTPREDEFINED + 1;
+}
+
+void wxSTCStyleProvider::OnIdle(wxIdleEvent& event) { event.Skip(); }
