@@ -1,17 +1,18 @@
 #include "clCodeLiteRemoteProcess.hpp"
 
+#include "AsyncProcess/asyncprocess.h"
+#include "AsyncProcess/processreaderthread.h"
 #include "JSON.h"
+#include "Platform/Platform.hpp"
 #include "StringUtils.h"
-#include "asyncprocess.h"
-#include "cJSON.h"
 #include "clSFTPManager.hpp"
 #include "cl_command_event.h"
 #include "environmentconfig.h"
 #include "file_logger.h"
 #include "fileutils.h"
 #include "globals.h"
-#include "processreaderthread.h"
 
+#include <cJSON.h>
 #include <functional>
 #include <unordered_map>
 #include <wx/event.h>
@@ -22,6 +23,8 @@ wxDEFINE_EVENT(wxEVT_CODELITE_REMOTE_LIST_FILES, clCommandEvent);
 wxDEFINE_EVENT(wxEVT_CODELITE_REMOTE_LIST_FILES_DONE, clCommandEvent);
 wxDEFINE_EVENT(wxEVT_CODELITE_REMOTE_FIND_RESULTS, clFindInFilesEvent);
 wxDEFINE_EVENT(wxEVT_CODELITE_REMOTE_FIND_RESULTS_DONE, clFindInFilesEvent);
+wxDEFINE_EVENT(wxEVT_CODELITE_REMOTE_REPLACE_RESULTS, clFindInFilesEvent);
+wxDEFINE_EVENT(wxEVT_CODELITE_REMOTE_REPLACE_DONE, clFindInFilesEvent);
 wxDEFINE_EVENT(wxEVT_CODELITE_REMOTE_EXEC_OUTPUT, clProcessEvent);
 wxDEFINE_EVENT(wxEVT_CODELITE_REMOTE_EXEC_DONE, clProcessEvent);
 wxDEFINE_EVENT(wxEVT_CODELITE_REMOTE_LOCATE_DONE, clCommandEvent);
@@ -47,7 +50,7 @@ class CodeLiteRemoteProcess : public IProcess
 private:
     bool DoWrite(const wxString& buff)
     {
-        if(!m_process) {
+        if (!m_process) {
             return false;
         }
         m_process->Write(buff);
@@ -74,7 +77,10 @@ public:
     void Detach() override {}
 
     // Read from process stdout - return immediately if no data is available
-    bool Read(wxString& buff, wxString& buffErr) override { return false; }
+    bool Read(wxString& buff, wxString& buffErr, std::string& raw_buff, std::string& raw_buff_err) override
+    {
+        return false;
+    }
 
     // Write to the process stdin
     // This version add LF to the buffer
@@ -115,7 +121,7 @@ public:
 
     void PostOutputEvent(const wxString& output)
     {
-        if(m_callback) {
+        if (m_callback) {
             // when callback is used, we aggregate the output
             // and post it in the terminated event
             m_output << output;
@@ -129,7 +135,7 @@ public:
 
     void PostTerminateEvent()
     {
-        if(m_callback) {
+        if (m_callback) {
             m_callback(m_output);
         } else {
             clProcessEvent e(wxEVT_ASYNC_PROCESS_TERMINATED);
@@ -153,11 +159,12 @@ clCodeLiteRemoteProcess::~clCodeLiteRemoteProcess()
     wxDELETE(m_process);
 }
 
-void clCodeLiteRemoteProcess::StartInteractive(const wxString& account, const wxString& scriptPath,
+void clCodeLiteRemoteProcess::StartInteractive(const wxString& account,
+                                               const wxString& scriptPath,
                                                const wxString& contextString)
 {
     auto ssh_account = SSHAccountInfo::LoadAccount(account);
-    if(ssh_account.GetAccountName().empty()) {
+    if (ssh_account.GetAccountName().empty()) {
         clWARNING() << "Failed to load ssh account:" << account << endl;
         return;
     }
@@ -166,20 +173,25 @@ void clCodeLiteRemoteProcess::StartInteractive(const wxString& account, const wx
 
 void clCodeLiteRemoteProcess::StartIfNotRunning()
 {
-    if(IsRunning()) {
+    if (IsRunning()) {
         return;
     }
 
     // wrap the command in ssh
-    wxFileName ssh_exe;
+    wxString ssh_exe;
     EnvSetter setter;
-    if(!FileUtils::FindExe("ssh", ssh_exe)) {
+    if (!ThePlatform->Which("ssh", &ssh_exe)) {
         clERROR() << "Could not locate ssh executable in your PATH!" << endl;
         return;
     }
+    std::vector<wxString> command = { ssh_exe, "-o", "ServerAliveInterval=10", "-o", "StrictHostKeyChecking=no" };
+
+    // If this account has custom key files, use it instead
+    if (!m_account.GetKeyFiles().empty()) {
+        command.push_back("-i");
+        command.push_back(m_account.GetKeyFiles()[0]);
+    }
 
-    std::vector<wxString> command = { ssh_exe.GetFullPath(), "-o", "ServerAliveInterval=10", "-o",
-                                      "StrictHostKeyChecking=no" };
     command.push_back(m_account.GetUsername() + "@" + m_account.GetHost());
     command.push_back("-p");
     command.push_back(wxString() << m_account.GetPort());
@@ -192,10 +204,11 @@ void clCodeLiteRemoteProcess::StartIfNotRunning()
     m_process = ::CreateAsyncProcess(this, command, IProcessCreateDefault | IProcessRawOutput);
 }
 
-void clCodeLiteRemoteProcess::StartInteractive(const SSHAccountInfo& account, const wxString& scriptPath,
+void clCodeLiteRemoteProcess::StartInteractive(const SSHAccountInfo& account,
+                                               const wxString& scriptPath,
                                                const wxString& contextString)
 {
-    if(m_process) {
+    if (m_process) {
         return;
     }
 
@@ -204,7 +217,7 @@ void clCodeLiteRemoteProcess::StartInteractive(const SSHAccountInfo& account, co
     wxString localCodeLiteRemoteScript = clStandardPaths::Get().GetBinFolder() + "/codelite-remote";
     clDEBUG() << "Uploading codelite-remote file:" << endl;
     clDEBUG() << localCodeLiteRemoteScript << "->" << scriptPath << endl;
-    if(!clSFTPManager::Get().AwaitSaveFile(localCodeLiteRemoteScript, scriptPath, account.GetAccountName())) {
+    if (!clSFTPManager::Get().AwaitSaveFile(localCodeLiteRemoteScript, scriptPath, account.GetAccountName())) {
         clERROR() << "Failed to upload file:" << scriptPath << "." << clSFTPManager::Get().GetLastError() << endl;
         return;
     }
@@ -230,7 +243,7 @@ void clCodeLiteRemoteProcess::OnProcessTerminated(clProcessEvent& e)
 {
     wxUnusedVar(e);
     Cleanup();
-    if(!m_going_down) {
+    if (!m_going_down) {
         // restart the process
         StartIfNotRunning();
 
@@ -244,7 +257,7 @@ void clCodeLiteRemoteProcess::OnProcessTerminated(clProcessEvent& e)
 void clCodeLiteRemoteProcess::Stop()
 {
     m_going_down = true;
-    if(m_process) {
+    if (m_process) {
         m_process->Write(wxString("exit\n"));
     }
     wxDELETE(m_process);
@@ -253,7 +266,7 @@ void clCodeLiteRemoteProcess::Stop()
 
 void clCodeLiteRemoteProcess::Cleanup()
 {
-    while(!m_completionCallbacks.empty()) {
+    while (!m_completionCallbacks.empty()) {
         m_completionCallbacks.pop_back();
     }
     wxDELETE(m_process);
@@ -263,7 +276,7 @@ bool clCodeLiteRemoteProcess::GetNextBuffer(wxString& raw_input_buffer, wxString
 {
     size_t separator_len = msg_terminator_len;
     size_t where = raw_input_buffer.find(msg_terminator);
-    if(where == wxString::npos) {
+    if (where == wxString::npos) {
         // locate the \n from the end
         is_completed = false;
         where = raw_input_buffer.rfind("\n");
@@ -272,9 +285,9 @@ bool clCodeLiteRemoteProcess::GetNextBuffer(wxString& raw_input_buffer, wxString
         is_completed = true;
     }
 
-    if(where != wxString::npos) {
+    if (where != wxString::npos) {
         size_t length_to_take = where;
-        if(separator_len == 1) {
+        if (separator_len == 1) {
             length_to_take += 1;
         }
         buffer = raw_input_buffer.Mid(0, length_to_take);
@@ -288,29 +301,34 @@ void clCodeLiteRemoteProcess::ProcessOutput()
     bool is_completed = false;
     wxString buffer;
 
-    while(GetNextBuffer(m_outputRead, buffer, is_completed)) {
-        if(m_completionCallbacks.empty()) {
+    while (GetNextBuffer(m_outputRead, buffer, is_completed)) {
+        if (m_completionCallbacks.empty()) {
             clDEBUG() << "Read: [" << buffer << "]. But there are no completion callback" << endl;
             continue;
         }
 
         auto p = m_completionCallbacks.front();
-        if(p.handler) {
+        if (p.user_callback != nullptr) {
+            p.aggregated_output << buffer;
+            if (is_completed) {
+                p.user_callback(p.aggregated_output);
+            }
+        } else if (p.handler) {
             auto handler = static_cast<CodeLiteRemoteProcess*>(p.handler);
             handler->PostOutputEvent(buffer);
-            if(is_completed) {
+            if (is_completed) {
                 handler->PostTerminateEvent();
 
                 // when using callback the handler is handled internally
-                if(handler->IsUsingCallback()) {
+                if (handler->IsUsingCallback()) {
                     delete handler;
                 }
             }
-        } else if(p.func) {
+        } else if (p.func) {
             (this->*p.func)(buffer, is_completed);
         }
 
-        if(is_completed) {
+        if (is_completed) {
             m_completionCallbacks.pop_front();
             ResetStates();
         }
@@ -319,7 +337,7 @@ void clCodeLiteRemoteProcess::ProcessOutput()
 
 void clCodeLiteRemoteProcess::ListLSPs()
 {
-    if(!m_process) {
+    if (!m_process) {
         return;
     }
 
@@ -330,48 +348,42 @@ void clCodeLiteRemoteProcess::ListLSPs()
     m_process->Write(item.format(false) + "\n");
 
     // push a callback
-    m_completionCallbacks.push_back({ &clCodeLiteRemoteProcess::OnListLSPsOutput, nullptr });
+    m_completionCallbacks.push_back({ &clCodeLiteRemoteProcess::OnListLSPsOutput, nullptr, nullptr });
 }
 
 void clCodeLiteRemoteProcess::ListFiles(const wxString& root_dir, const wxString& extensions)
 {
-    if(!m_process) {
+    if (!m_process) {
         return;
     }
 
-    wxString exts = extensions;
-    exts.Replace("*", "");
-
     // build the command and send it
     JSON root(cJSON_Object);
     auto item = root.toElement();
     item.addProperty("command", "ls");
     item.addProperty("root_dir", root_dir);
-    item.addProperty("file_extensions", ::wxStringTokenize(exts, ",; |", wxTOKEN_STRTOK));
+    item.addProperty("file_extensions", ::wxStringTokenize(extensions, ",; |", wxTOKEN_STRTOK));
     LOG_IF_TRACE { clDEBUG1() << "ListFiles: sending command:" << item.format(false) << endl; }
     m_process->Write(item.format(false) + "\n");
 
     // push a callback
-    m_completionCallbacks.push_back({ &clCodeLiteRemoteProcess::OnListFilesOutput, nullptr });
+    m_completionCallbacks.push_back({ &clCodeLiteRemoteProcess::OnListFilesOutput, nullptr, nullptr });
 }
 
-void clCodeLiteRemoteProcess::Search(const wxString& root_dir, const wxString& extensions, const wxString& find_what,
-                                     bool whole_word, bool icase)
+void clCodeLiteRemoteProcess::Search(
+    const wxString& root_dir, const wxString& extensions, const wxString& find_what, bool whole_word, bool icase)
 {
-    if(!m_process) {
+    if (!m_process) {
         return;
     }
 
-    wxString exts = extensions;
-    exts.Replace("*", "");
-
     // build the command and send it
     JSON root(cJSON_Object);
     auto item = root.toElement();
     item.addProperty("command", "find");
     item.addProperty("root_dir", root_dir);
     item.addProperty("find_what", find_what);
-    item.addProperty("file_extensions", ::wxStringTokenize(exts, ",; |", wxTOKEN_STRTOK));
+    item.addProperty("file_extensions", ::wxStringTokenize(extensions, ",; |", wxTOKEN_STRTOK));
     item.addProperty("icase", icase);
     item.addProperty("whole_word", whole_word);
 
@@ -380,13 +392,15 @@ void clCodeLiteRemoteProcess::Search(const wxString& root_dir, const wxString& e
     LOG_IF_TRACE { clDEBUG1() << command << endl; }
 
     // push a callback
-    m_completionCallbacks.push_back({ &clCodeLiteRemoteProcess::OnFindOutput, nullptr });
+    m_completionCallbacks.push_back({ &clCodeLiteRemoteProcess::OnFindOutput, nullptr, nullptr });
 }
 
-void clCodeLiteRemoteProcess::Locate(const wxString& path, const wxString& name, const wxString& ext,
+void clCodeLiteRemoteProcess::Locate(const wxString& path,
+                                     const wxString& name,
+                                     const wxString& ext,
                                      const std::vector<wxString>& versions)
 {
-    if(!m_process) {
+    if (!m_process) {
         return;
     }
 
@@ -402,7 +416,7 @@ void clCodeLiteRemoteProcess::Locate(const wxString& path, const wxString& name,
     wxArrayString v;
     v.reserve(versions.size());
 
-    for(const auto& s : versions) {
+    for (const auto& s : versions) {
         v.Add(s);
     }
 
@@ -413,12 +427,12 @@ void clCodeLiteRemoteProcess::Locate(const wxString& path, const wxString& name,
     LOG_IF_TRACE { clDEBUG1() << command << endl; }
 
     // push a callback
-    m_completionCallbacks.push_back({ &clCodeLiteRemoteProcess::OnLocateOutput, nullptr });
+    m_completionCallbacks.push_back({ &clCodeLiteRemoteProcess::OnLocateOutput, nullptr, nullptr });
 }
 
 void clCodeLiteRemoteProcess::FindPath(const wxString& path)
 {
-    if(!m_process) {
+    if (!m_process) {
         return;
     }
 
@@ -433,7 +447,7 @@ void clCodeLiteRemoteProcess::FindPath(const wxString& path)
     LOG_IF_TRACE { clDEBUG1() << command << endl; }
 
     // push a callback
-    m_completionCallbacks.push_back({ &clCodeLiteRemoteProcess::OnFindPathOutput, nullptr });
+    m_completionCallbacks.push_back({ &clCodeLiteRemoteProcess::OnFindPathOutput, nullptr, nullptr });
 }
 
 void clCodeLiteRemoteProcess::ResetStates()
@@ -442,10 +456,10 @@ void clCodeLiteRemoteProcess::ResetStates()
     m_fif_files_scanned = 0;
 }
 
-bool clCodeLiteRemoteProcess::DoExec(const wxString& cmd, const wxString& working_directory, const clEnvList_t& env,
-                                     IProcess* handler)
+bool clCodeLiteRemoteProcess::DoExec(
+    const wxString& cmd, const wxString& working_directory, const clEnvList_t& env, IProcess* handler, UserCallback cb)
 {
-    if(!m_process) {
+    if (!m_process) {
         return false;
     }
 
@@ -457,7 +471,7 @@ bool clCodeLiteRemoteProcess::DoExec(const wxString& cmd, const wxString& workin
     item.addProperty("cmd", cmd);
 
     auto envarr = item.AddArray("env");
-    for(const auto& p : env) {
+    for (const auto& p : env) {
         auto entry = envarr.AddObject(wxEmptyString);
         entry.addProperty("name", p.first);
         entry.addProperty("value", p.second);
@@ -465,22 +479,33 @@ bool clCodeLiteRemoteProcess::DoExec(const wxString& cmd, const wxString& workin
 
     wxString command = item.format(false);
     m_process->Write(command + "\n");
-    LOG_IF_TRACE { clDEBUG1() << command << endl; }
 
     // push a callback
-    m_completionCallbacks.push_back({ &clCodeLiteRemoteProcess::OnExecOutput, handler });
+    m_completionCallbacks.push_back({ &clCodeLiteRemoteProcess::OnExecOutput, handler, cb });
     return true;
 }
 
 void clCodeLiteRemoteProcess::Exec(const wxArrayString& args, const wxString& working_directory, const clEnvList_t& env)
 {
     wxString cmdstr = GetCmdString(args);
-    if(cmdstr.empty()) {
+    if (cmdstr.empty()) {
         return;
     }
     DoExec(cmdstr, working_directory, env);
 }
 
+void clCodeLiteRemoteProcess::ExecWithCallback(const wxArrayString& args,
+                                               UserCallback cb,
+                                               const wxString& working_directory,
+                                               const clEnvList_t& env)
+{
+    wxString cmdstr = GetCmdString(args);
+    if (cmdstr.empty()) {
+        return;
+    }
+    DoExec(cmdstr, working_directory, env, nullptr, std::move(cb));
+}
+
 void clCodeLiteRemoteProcess::Exec(const wxString& cmd, const wxString& working_directory, const clEnvList_t& env)
 {
     DoExec(cmd, working_directory, env);
@@ -488,33 +513,37 @@ void clCodeLiteRemoteProcess::Exec(const wxString& cmd, const wxString& working_
 
 void clCodeLiteRemoteProcess::Write(const wxString& str)
 {
-    if(IsRunning()) {
+    if (IsRunning()) {
         return;
     }
-    if(!str.EndsWith("\n")) {
+    if (!str.EndsWith("\n")) {
         m_process->Write(str + "\n");
     } else {
         m_process->Write(str);
     }
 }
 
-IProcess* clCodeLiteRemoteProcess::CreateAsyncProcess(wxEvtHandler* handler, const wxString& cmd,
-                                                      const wxString& working_directory, const clEnvList_t& env)
+IProcess* clCodeLiteRemoteProcess::CreateAsyncProcess(wxEvtHandler* handler,
+                                                      const wxString& cmd,
+                                                      const wxString& working_directory,
+                                                      const clEnvList_t& env)
 {
     CodeLiteRemoteProcess* p = new CodeLiteRemoteProcess(handler, this);
-    if(DoExec(cmd, working_directory, env, p)) {
+    if (DoExec(cmd, working_directory, env, p)) {
         return p;
     }
     wxDELETE(p);
     return nullptr;
 }
 
-void clCodeLiteRemoteProcess::CreateAsyncProcessCB(const wxString& cmd, std::function<void(const wxString&)> callback,
-                                                   const wxString& working_directory, const clEnvList_t& env)
+void clCodeLiteRemoteProcess::CreateAsyncProcessCB(const wxString& cmd,
+                                                   std::function<void(const wxString&)> callback,
+                                                   const wxString& working_directory,
+                                                   const clEnvList_t& env)
 {
     CodeLiteRemoteProcess* p = new CodeLiteRemoteProcess(nullptr, this);
     p->SetCallback(std::move(callback));
-    if(DoExec(cmd, working_directory, env, p)) {
+    if (DoExec(cmd, working_directory, env, p)) {
         return;
     }
     wxDELETE(p);
@@ -534,7 +563,7 @@ void clCodeLiteRemoteProcess::OnListLSPsOutput(const wxString& output, bool is_c
     event.SetString(output);
     AddPendingEvent(event);
 
-    if(is_completed) {
+    if (is_completed) {
         clCommandEvent event_done(wxEVT_CODELITE_REMOTE_LIST_LSPS_DONE);
         AddPendingEvent(event_done);
     }
@@ -551,7 +580,7 @@ void clCodeLiteRemoteProcess::OnListFilesOutput(const wxString& output, bool is_
     event.GetStrings().swap(files);
     AddPendingEvent(event);
 
-    if(is_completed) {
+    if (is_completed) {
         clCommandEvent event_done(wxEVT_CODELITE_REMOTE_LIST_FILES_DONE);
         AddPendingEvent(event_done);
     }
@@ -568,7 +597,7 @@ void clCodeLiteRemoteProcess::OnFindPathOutput(const wxString& output, bool is_c
     event.SetString(fullpath);
     AddPendingEvent(event);
 
-    if(is_completed) {
+    if (is_completed) {
         clCommandEvent event_done(wxEVT_CODELITE_REMOTE_FINDPATH_DONE);
         AddPendingEvent(event_done);
     }
@@ -585,99 +614,128 @@ void clCodeLiteRemoteProcess::OnLocateOutput(const wxString& output, bool is_com
     event.SetFileName(fullpath);
     AddPendingEvent(event);
 
-    if(is_completed) {
+    if (is_completed) {
         clCommandEvent event_done(wxEVT_CODELITE_REMOTE_LOCATE_DONE);
         AddPendingEvent(event_done);
     }
 }
 
+namespace
+{
+bool split_line(wxString& line, wxString* filename, long* line_number, wxString* pattern)
+{
+    *filename = line.BeforeFirst(':');
+    line = line.AfterFirst(':');
+    wxString str_line_number = line.BeforeFirst(':');
+    *pattern = line.AfterFirst(':');
+
+    *line_number = 0;
+    if (!str_line_number.ToCLong(line_number)) {
+        return false;
+    }
+    return true;
+}
+} // namespace
+
+void clCodeLiteRemoteProcess::OnReplaceOutput(const wxString& output, bool is_completed)
+{
+    wxArrayString lines = ::wxStringTokenize(output, "\r\n", wxTOKEN_STRTOK);
+    if (lines.empty()) {
+        return;
+    }
+
+    // the progress reports files modified
+    clFindInFilesEvent event_progress(wxEVT_CODELITE_REMOTE_REPLACE_RESULTS);
+    event_progress.GetStrings() = lines;
+    AddPendingEvent(event_progress);
+
+    if (is_completed) {
+        clFindInFilesEvent event_done(wxEVT_CODELITE_REMOTE_REPLACE_DONE);
+        AddPendingEvent(event_done);
+    }
+}
+
 void clCodeLiteRemoteProcess::OnFindOutput(const wxString& output, bool is_completed)
 {
-    wxArrayString files = ::wxStringTokenize(output, "\r\n", wxTOKEN_STRTOK);
-    if(files.empty()) {
-        return;
-    }
-
-    clFindInFilesEvent::Match::vec_t matches;
-    matches.reserve(files.size());
-    for(const wxString& file : files) {
-        JSON j(file);
-        if(!j.isOk()) {
-            continue;
-        }
-
-        auto file_matches = j.toElement();
-
-        if((m_fif_matches_count == 0) && (m_fif_files_scanned == 0) && file_matches.hasNamedObject("files_scanned")) {
-            m_fif_files_scanned = file_matches["files_scanned"].toSize_t();
-            continue;
-        }
-
+    wxArrayString lines = ::wxStringTokenize(output, "\r\n", wxTOKEN_STRTOK);
+    if (!lines.empty()) {
+        clFindInFilesEvent::Match::vec_t matches;
+        matches.reserve(lines.size());
+        wxString curfile;
         clFindInFilesEvent::Match match;
-        match.file = file_matches["file"].toString();
-        auto json_locations = file_matches["matches"];
-        size_t loc_count = json_locations.arraySize();
-
-        // add the locations for this file
-        if(loc_count) {
-            match.locations.reserve(loc_count);
-            for(size_t j = 0; j < loc_count; j++) {
-                clFindInFilesEvent::Location loc;
-                auto json_loc = json_locations[j];
-                loc.line = json_loc["ln"].toSize_t();
-                loc.column_start = json_loc["start"].toSize_t();
-                loc.column_end = json_loc["end"].toSize_t();
-                loc.pattern = json_loc["pattern"].toString();
-                match.locations.push_back(loc);
-                m_fif_matches_count++;
+        for (wxString& line : lines) {
+            wxString filename, pattern;
+            long line_number;
+            if (!split_line(line, &filename, &line_number, &pattern)) {
+                continue;
             }
-            // add the match
+
+            if (match.file != filename && !match.locations.empty()) {
+                // switching files
+                matches.push_back(match);
+                match.locations.clear();
+            }
+
+            match.file = filename;
+            clFindInFilesEvent::Location loc;
+            loc.line = line_number;
+            loc.pattern = pattern;
+            loc.column_end = 0;
+            loc.column_start = 0;
+            match.locations.emplace_back(loc);
+            ++m_fif_matches_count;
+        }
+
+        if (!match.file.empty() && !match.locations.empty()) {
             matches.push_back(match);
+            match.locations.clear();
+        }
+
+        if (!matches.empty()) {
+            clFindInFilesEvent event(wxEVT_CODELITE_REMOTE_FIND_RESULTS);
+            event.SetMatches(matches);
+            AddPendingEvent(event);
         }
     }
 
-    if(!matches.empty()) {
-        clFindInFilesEvent event(wxEVT_CODELITE_REMOTE_FIND_RESULTS);
-        event.SetMatches(matches);
-        AddPendingEvent(event);
-    }
-
-    if(is_completed) {
+    if (is_completed) {
         clFindInFilesEvent event_done(wxEVT_CODELITE_REMOTE_FIND_RESULTS_DONE);
-        event_done.SetInt(m_fif_files_scanned);
+        event_done.SetInt(0);
         AddPendingEvent(event_done);
     }
 }
 
 void clCodeLiteRemoteProcess::OnExecOutput(const wxString& buffer, bool is_completed)
 {
-    if(!buffer.empty()) {
+    if (!buffer.empty()) {
         clProcessEvent output_event(wxEVT_CODELITE_REMOTE_EXEC_OUTPUT);
         output_event.SetOutput(buffer);
         AddPendingEvent(output_event);
     }
 
-    if(is_completed) {
+    if (is_completed) {
         clProcessEvent end_event(wxEVT_CODELITE_REMOTE_EXEC_DONE);
         AddPendingEvent(end_event);
     }
 }
 
-bool clCodeLiteRemoteProcess::SyncExec(const wxString& cmd, const wxString& working_directory, const clEnvList_t& env,
+bool clCodeLiteRemoteProcess::SyncExec(const wxString& cmd,
+                                       const wxString& working_directory,
+                                       const clEnvList_t& env,
                                        wxString* output)
 {
-    if(!m_completionCallbacks.empty()) {
+    if (!m_completionCallbacks.empty()) {
         clWARNING() << "unable to run SyncExec() for command:" << cmd << "async queue is not empty" << endl;
         return false;
     }
-    if(!m_process) {
+    if (!m_process) {
         clWARNING() << "unable to run SyncExec() for command:" << cmd << "no process" << endl;
         return false;
     }
     // disable the background reader thread
     m_process->SuspendAsyncReads();
 
-    if(!DoExec(cmd, working_directory, env)) {
+    if (!DoExec(cmd, working_directory, env)) {
         return false;
     }
 
@@ -687,13 +745,14 @@ bool clCodeLiteRemoteProcess::SyncExec(const wxString& cmd, const wxString& work
 
     // read
     wxString buff_out, buff_err;
+    std::string raw_buff, raw_buff_err;
     m_outputRead.clear();
 
     wxString complete_output;
-    while(m_process->Read(buff_out, buff_err)) {
+    while (m_process->Read(buff_out, buff_err, raw_buff, raw_buff_err)) {
         m_outputRead << buff_out;
         size_t where = m_outputRead.find(msg_terminator);
-        if(where == wxString::npos) {
+        if (where == wxString::npos) {
             continue;
         }
 
@@ -712,3 +771,33 @@ bool clCodeLiteRemoteProcess::SyncExec(const wxString& cmd, const wxString& work
     OnProcessTerminated(dummy);
     return false;
 }
+
+void clCodeLiteRemoteProcess::Replace(const wxString& root_dir,
+                                      const wxString& extensions,
+                                      const wxString& find_what,
+                                      const wxString& replace_with,
+                                      bool whole_word,
+                                      bool icase)
+{
+    if (!m_process) {
+        return;
+    }
+
+    // build the command and send it
+    JSON root(cJSON_Object);
+    auto item = root.toElement();
+    item.addProperty("command", "replace");
+    item.addProperty("root_dir", root_dir);
+    item.addProperty("find_what", find_what);
+    item.addProperty("replace_with", replace_with);
+    item.addProperty("file_extensions", ::wxStringTokenize(extensions, ",; |", wxTOKEN_STRTOK));
+    item.addProperty("icase", icase);
+    item.addProperty("whole_word", whole_word);
+
+    wxString command = item.format(false);
+    m_process->Write(command + "\n");
+    LOG_IF_TRACE { clDEBUG1() << command << endl; }
+
+    // push a callback
+    m_completionCallbacks.push_back({ &clCodeLiteRemoteProcess::OnReplaceOutput, nullptr, nullptr });
+}
\ No newline at end of file
