@@ -1,51 +1,40 @@
 #include "clControlWithItems.h"
 
+#include "clThemedTextCtrl.hpp"
 #include "clTreeCtrl.h"
 #include "file_logger.h"
 
 #include <cmath>
 #include <wx/minifram.h>
+#include <wx/panel.h>
 #include <wx/settings.h>
 #include <wx/sizer.h>
 #include <wx/textctrl.h>
 
-#if defined(__WXGTK__) || defined(__WXOSX__)
-#define USE_PANEL_PARENT 1
-#else
-#define USE_PANEL_PARENT 0
-#endif
-
-#if USE_PANEL_PARENT
-#include <wx/panel.h>
-#endif
-
 wxDEFINE_EVENT(wxEVT_TREE_SEARCH_TEXT, wxTreeEvent);
 wxDEFINE_EVENT(wxEVT_TREE_CLEAR_SEARCH, wxTreeEvent);
 
 //===------------------------
 // Helper class
 //===------------------------
-class clSearchControl :
-#if USE_PANEL_PARENT
-    public wxPanel
-#else
-    public wxMiniFrame
-#endif
+class clSearchControl : public wxPanel
 {
-    wxTextCtrl* m_textCtrl = nullptr;
+    clThemedTextCtrl* m_textCtrl = nullptr;
+    clControlWithItems* m_searchedCtrl = nullptr;
 
 private:
     void DoSelect(bool next)
     {
-        clTreeCtrl* tree = dynamic_cast<clTreeCtrl*>(GetParent());
-        if(!tree || m_textCtrl->IsEmpty()) {
+        clTreeCtrl* tree = dynamic_cast<clTreeCtrl*>(m_searchedCtrl);
+        if (!tree || m_textCtrl->IsEmpty()) {
             return;
         }
+
         wxTreeItemId where = next ? tree->FindNext(tree->GetSelection(), m_textCtrl->GetValue(), 0,
                                                    wxTR_SEARCH_DEFAULT & ~wxTR_SEARCH_INCLUDE_CURRENT_ITEM)
                                   : tree->FindPrev(tree->GetSelection(), m_textCtrl->GetValue(), 0,
                                                    wxTR_SEARCH_DEFAULT & ~wxTR_SEARCH_INCLUDE_CURRENT_ITEM);
-        if(where.IsOk()) {
+        if (where.IsOk()) {
             clRowEntry* row = reinterpret_cast<clRowEntry*>(where.GetID());
             clMatchResult res = row->GetHighlightInfo();
 
@@ -67,106 +56,77 @@ private:
     }
 
 public:
-    clSearchControl(clControlWithItems* parent)
-#if USE_PANEL_PARENT
+    clSearchControl(wxWindow* parent, clControlWithItems* ctrl)
         : wxPanel(parent)
-#else
-        : wxMiniFrame(parent, wxID_ANY, "Find", wxDefaultPosition, wxDefaultSize,
-                      wxFRAME_FLOAT_ON_PARENT | wxBORDER_SIMPLE)
-#endif
+        , m_searchedCtrl(ctrl)
     {
         SetSizer(new wxBoxSizer(wxVERTICAL));
         wxPanel* mainPanel = new wxPanel(this);
         GetSizer()->Add(mainPanel, 1, wxEXPAND);
         mainPanel->SetSizer(new wxBoxSizer(wxVERTICAL));
-        int scrollBarWidth = wxSystemSettings::GetMetric(wxSYS_VSCROLL_X, parent);
-        wxSize searchControlSize(GetParent()->GetSize().GetWidth() / 2 - scrollBarWidth, -1);
-        m_textCtrl = new wxTextCtrl(mainPanel, wxID_ANY, "", wxDefaultPosition, searchControlSize,
-                                    wxTE_RICH | wxTE_PROCESS_ENTER);
-        mainPanel->GetSizer()->Add(m_textCtrl, 0, wxEXPAND);
-        m_textCtrl->CallAfter(&wxTextCtrl::SetFocus);
-        m_textCtrl->Bind(wxEVT_TEXT, &clSearchControl::OnTextUpdated, this);
+        m_textCtrl = new clThemedTextCtrl(mainPanel, wxID_ANY, wxEmptyString, wxDefaultPosition, wxDefaultSize);
+        m_textCtrl->SetUseVerticalScrollBar(false); // don't show v-scrollbar
+        m_textCtrl->SetWrapMode(wxSTC_WRAP_CHAR);   // this will effectively hide the v-scrollbar
+        mainPanel->GetSizer()->Add(m_textCtrl, 1, wxEXPAND);
+        m_textCtrl->Bind(wxEVT_STC_MODIFIED, &clSearchControl::OnTextUpdated, this);
         m_textCtrl->Bind(wxEVT_KEY_DOWN, &clSearchControl::OnKeyDown, this);
+        SetFocusAfter();
         GetSizer()->Fit(this);
-        Hide();
     }
 
     virtual ~clSearchControl()
     {
-        m_textCtrl->Unbind(wxEVT_TEXT, &clSearchControl::OnTextUpdated, this);
+
+        m_textCtrl->Unbind(wxEVT_STC_MODIFIED, &clSearchControl::OnTextUpdated, this);
         m_textCtrl->Unbind(wxEVT_KEY_DOWN, &clSearchControl::OnKeyDown, this);
-
-        // Let the parent know that we were dismissed
-        clControlWithItems* parent = dynamic_cast<clControlWithItems*>(GetParent());
-        parent->SearchControlDismissed();
     }
 
-    void PositionControl()
-    {
-#if USE_PANEL_PARENT
-        int scrollBarHeight = wxSystemSettings::GetMetric(wxSYS_HSCROLL_Y, GetParent());
-        int x = GetParent()->GetSize().GetWidth() / 2;
-        int y = GetParent()->GetSize().GetHeight() - GetSize().GetHeight() - scrollBarHeight;
-        SetPosition(wxPoint(x, y));
-#else
-        wxPoint parentPt = GetParent()->GetScreenPosition();
-        CenterOnParent();
-        SetPosition(wxPoint(GetPosition().x, parentPt.y - m_textCtrl->GetSize().GetHeight()));
-#endif
-    }
     void DoSelectNone() { m_textCtrl->SelectNone(); }
-
-    void InitSearch(const wxChar& ch)
-    {
-        m_textCtrl->SetFocus();
-        m_textCtrl->ChangeValue(wxString() << ch);
-        m_textCtrl->SetInsertionPointEnd();
-        CallAfter(&clSearchControl::DoSelectNone);
-    }
-
-    void ShowControl(const wxChar& ch)
-    {
-        Show();
-        m_textCtrl->ChangeValue("");
-        PositionControl();
-        CallAfter(&clSearchControl::InitSearch, ch);
-    }
-
     void SelectNext() { DoSelect(true); }
-
     void SelectPrev() { DoSelect(false); }
 
+    void SetFocusAfter() { m_textCtrl->CallAfter(&wxStyledTextCtrl::SetFocus); }
+
     void Dismiss()
     {
-        GetParent()->CallAfter(&wxWindow::SetFocus);
+        m_searchedCtrl->CallAfter(&wxWindow::SetFocus);
+
         // Clear the search
         wxTreeEvent e(wxEVT_TREE_CLEAR_SEARCH);
         e.SetEventObject(GetParent());
-        GetParent()->GetEventHandler()->QueueEvent(e.Clone());
-        Hide();
+        m_searchedCtrl->GetEventHandler()->AddPendingEvent(e);
+
+        // remove ourself from the paren't sizer
+        GetParent()->GetSizer()->Detach(this);
+        GetParent()->GetSizer()->Layout();
+
+        // Let the searched control know that we were dismissed
+        m_searchedCtrl->SearchControlDismissed();
+
+        Destroy();
     }
 
-    void OnTextUpdated(wxCommandEvent& event)
+    void OnTextUpdated(wxStyledTextEvent& event)
     {
         event.Skip();
         wxTreeEvent e(wxEVT_TREE_SEARCH_TEXT);
-        e.SetString(m_textCtrl->GetValue());
+        e.SetString(m_textCtrl->GetText());
         e.SetEventObject(GetParent());
-        GetParent()->GetEventHandler()->QueueEvent(e.Clone());
+        m_searchedCtrl->GetEventHandler()->AddPendingEvent(e);
     }
 
     void OnKeyDown(wxKeyEvent& event)
     {
-        if(event.GetKeyCode() == WXK_ESCAPE) {
+        if (event.GetKeyCode() == WXK_ESCAPE) {
             Dismiss();
             return;
-        } else if(event.GetKeyCode() == WXK_DOWN) {
+        } else if (event.GetKeyCode() == WXK_DOWN) {
             SelectNext();
-        } else if(event.GetKeyCode() == WXK_UP) {
+        } else if (event.GetKeyCode() == WXK_UP) {
             SelectPrev();
-        } else if(event.GetKeyCode() == WXK_RETURN || event.GetKeyCode() == WXK_NUMPAD_ENTER) {
+        } else if (event.GetKeyCode() == WXK_RETURN || event.GetKeyCode() == WXK_NUMPAD_ENTER) {
             // Activate the item
-            clTreeCtrl* tree = dynamic_cast<clTreeCtrl*>(GetParent());
+            clTreeCtrl* tree = static_cast<clTreeCtrl*>(m_searchedCtrl);
             wxTreeEvent evt(wxEVT_TREE_ITEM_ACTIVATED);
             evt.SetEventObject(tree);
             evt.SetItem(tree->GetSelection());
@@ -189,7 +149,7 @@ clControlWithItems::clControlWithItems() {}
 
 bool clControlWithItems::Create(wxWindow* parent, wxWindowID id, const wxPoint& pos, const wxSize& size, long style)
 {
-    if(!clScrolledPanel::Create(parent, id, pos, size, style)) {
+    if (!clScrolledPanel::Create(parent, id, pos, size, style)) {
         return false;
     }
     DoInitialize();
@@ -205,7 +165,7 @@ void clControlWithItems::DoInitialize()
     Bind(wxEVT_MOUSEWHEEL, &clControlWithItems::OnMouseScroll, this);
     Bind(wxEVT_SET_FOCUS, [&](wxFocusEvent& e) {
         e.Skip();
-        if(m_searchControl && m_searchControl->IsShown()) {
+        if (m_searchControl && m_searchControl->IsShown()) {
             m_searchControl->Dismiss();
         }
     });
@@ -224,7 +184,7 @@ clControlWithItems::~clControlWithItems()
 
 void clControlWithItems::SetShowHeader(bool b)
 {
-    if(GetHeader()) {
+    if (GetHeader()) {
         GetHeader()->Show(b);
         DoPositionVScrollbar(); // Adjust the vertical scrollbar if needed
         Refresh();
@@ -237,7 +197,7 @@ wxRect clControlWithItems::GetItemsRect() const
 {
     // Return the rectangle taking header into consideration
     int yOffset = 0;
-    if(m_viewHeader && m_viewHeader->IsShown()) {
+    if (m_viewHeader && m_viewHeader->IsShown()) {
         yOffset = m_viewHeader->GetHeight();
     }
     wxRect clientRect = GetClientArea();
@@ -251,23 +211,23 @@ void clControlWithItems::RenderItems(wxDC& dc, long tree_style, const clRowEntry
     AssignRects(items);
 
     // Did the user pass wxTR_COLUMN_WIDTH_NEVER_SHRINKS or wxDV_DYNAMIC_COLUMN_WIDTH ?
-    if(m_recalcColumnWidthOnPaint) {
+    if (m_recalcColumnWidthOnPaint) {
         std::vector<size_t> max_widths;
 
         // calculate the width of the cells
-        for(size_t i = 0; i < items.size(); ++i) {
+        for (size_t i = 0; i < items.size(); ++i) {
             clRowEntry* curitem = items[i];
             auto v_width = curitem->GetColumnWidths(this, dc);
-            if(max_widths.empty()) {
+            if (max_widths.empty()) {
                 max_widths.swap(v_width);
             } else {
-                for(size_t index = 0; index < v_width.size(); ++index) {
+                for (size_t index = 0; index < v_width.size(); ++index) {
                     max_widths[index] = wxMax(max_widths[index], v_width[index]);
                 }
             }
         }
 
-        if(GetHeader()) {
+        if (GetHeader()) {
             GetHeader()->SetColumnsWidth(max_widths);
         }
     }
@@ -276,12 +236,12 @@ void clControlWithItems::RenderItems(wxDC& dc, long tree_style, const clRowEntry
     wxRect clientRect = GetItemsRect();
     int cury = clientRect.y;
     int row_index = 0;
-    for(size_t i = 0; i < items.size(); ++i) {
+    for (size_t i = 0; i < items.size(); ++i) {
         clRowEntry* curitem = items[i];
-        if(curitem->IsHidden()) {
+        if (curitem->IsHidden()) {
             continue;
         }
-        if(m_customRenderer) {
+        if (m_customRenderer) {
             m_customRenderer->RenderItem(this, dc, m_colours, i, curitem);
         } else {
             curitem->Render(this, dc, m_colours, i, &GetSearch());
@@ -296,12 +256,12 @@ void clControlWithItems::RenderItems(wxDC& dc, long tree_style, const clRowEntry
 
     int max_items = GetNumLineCanFitOnScreen();
     int fake_items_count = max_items - lines_drawn;
-    if(fake_items_count > 0) {
-        for(size_t i = 0; i < (size_t)fake_items_count; ++i) {
+    if (fake_items_count > 0) {
+        for (size_t i = 0; i < (size_t)fake_items_count; ++i) {
             wxRect fake_entry_rect{ 0, cury, width, m_lineHeight };
             clRowEntry fake_entry{ nullptr, false, wxEmptyString };
             fake_entry.SetRects(fake_entry_rect, {});
-            if(m_customRenderer) {
+            if (m_customRenderer) {
                 m_customRenderer->RenderItemBackground(dc, tree_style, m_colours, row_index, &fake_entry);
 
             } else {
@@ -317,7 +277,7 @@ int clControlWithItems::GetNumLineCanFitOnScreen(bool fully_fit) const
 {
     wxRect clientRect = GetItemsRect();
     int max_lines_on_screen = 0;
-    if(fully_fit) {
+    if (fully_fit) {
         max_lines_on_screen = std::floor((double)((double)clientRect.GetHeight() / (double)m_lineHeight));
     } else {
         max_lines_on_screen = std::ceil((double)((double)clientRect.GetHeight() / (double)m_lineHeight));
@@ -344,19 +304,19 @@ void clControlWithItems::UpdateScrollBar()
         // H-scrollbar
         int thumbSize = GetClientArea().GetWidth();
         int rangeSize = IsEmpty() ? 0 : m_viewHeader->GetWidth();
-        if((m_firstColumn + thumbSize) > rangeSize) {
+        if ((m_firstColumn + thumbSize) > rangeSize) {
             m_firstColumn = (rangeSize - thumbSize);
         }
         int pageSize = (thumbSize - 1);
         int position = m_firstColumn;
 
         int pixels_after = rangeSize - m_firstColumn - thumbSize;
-        if((pixels_after < 0) && (rangeSize > thumbSize)) {
+        if ((pixels_after < 0) && (rangeSize > thumbSize)) {
             // m_firstColumn += pixels_after; // reduce it from the left side
             clHeaderItem& column = GetHeader()->Item(GetHeader()->size() - 1);
             column.UpdateWidth(column.GetWidth() - pixels_after);
         }
-        if(m_firstColumn < 0) {
+        if (m_firstColumn < 0) {
             m_firstColumn = 0;
         }
         position = m_firstColumn;
@@ -366,7 +326,7 @@ void clControlWithItems::UpdateScrollBar()
 
 void clControlWithItems::Render(wxDC& dc)
 {
-    if(m_customRenderer) {
+    if (m_customRenderer) {
         m_customRenderer->RenderBackground(dc, GetClientRect(), 0, GetColours());
     } else {
         // draw the background on the entire client area
@@ -397,7 +357,7 @@ void clControlWithItems::OnSize(wxSizeEvent& event)
     Refresh();
 }
 
-void clControlWithItems::ScollToColumn(int firstColumn)
+void clControlWithItems::ScrollToColumn(int firstColumn)
 {
     m_firstColumn = firstColumn;
     UpdateScrollBar();
@@ -406,18 +366,18 @@ void clControlWithItems::ScollToColumn(int firstColumn)
 
 void clControlWithItems::ScrollColumns(int steps, wxDirection direction)
 {
-    if((steps == 0) && (direction == wxLEFT)) {
+    if ((steps == 0) && (direction == wxLEFT)) {
         m_firstColumn = 0;
-    } else if((steps == 0) && (direction == wxRIGHT)) {
+    } else if ((steps == 0) && (direction == wxRIGHT)) {
         m_firstColumn = GetHeader()->GetWidth();
     } else {
         int max_width = GetHeader()->GetWidth();
         int firstColumn = m_firstColumn + ((direction == wxRIGHT) ? steps : -steps);
-        if(firstColumn < 0) {
+        if (firstColumn < 0) {
             firstColumn = 0;
         }
         int pageSize = GetClientArea().GetWidth();
-        if((firstColumn + pageSize) > max_width) {
+        if ((firstColumn + pageSize) > max_width) {
             firstColumn = max_width - pageSize;
         }
         m_firstColumn = firstColumn;
@@ -428,31 +388,34 @@ void clControlWithItems::ScrollColumns(int steps, wxDirection direction)
 void clControlWithItems::DoUpdateHeader(clRowEntry* row)
 {
     // do we have header?
-    if(GetHeader()->empty()) {
+    if (GetHeader()->empty()) {
         return;
     }
 
-    if(row && row->IsHidden()) {
+    if (row && row->IsHidden()) {
         return;
     }
 
-    wxDC& dc = GetTempDC();
+    wxBitmap tmpBmp;
+    tmpBmp.CreateWithDIPSize(1, 1, GetDPIScaleFactor());
+    wxMemoryDC mem_dc{ tmpBmp };
+    wxGCDC dc{ mem_dc };
     dc.SetFont(GetDefaultFont());
 
     // Null row means: set the header bar to fit the column's label
     bool forceUpdate = (row == nullptr);
 
     // Use bold font, to get the maximum width needed
-    for(size_t i = 0; i < GetHeader()->size(); ++i) {
+    for (size_t i = 0; i < GetHeader()->size(); ++i) {
         int row_width = 0;
-        if(row) {
+        if (row) {
             row_width = row->CalcItemWidth(dc, m_lineHeight, i);
         } else {
             int colWidth = dc.GetTextExtent(GetHeader()->Item(i).GetLabel()).GetWidth();
             colWidth += 3 * clRowEntry::X_SPACER;
             row_width = colWidth;
         }
-        if(forceUpdate || GetHeader()->Item(i).IsAutoResize()) {
+        if (forceUpdate || GetHeader()->Item(i).IsAutoResize()) {
             GetHeader()->UpdateColWidthIfNeeded(i, row_width, forceUpdate);
         }
     }
@@ -460,7 +423,11 @@ void clControlWithItems::DoUpdateHeader(clRowEntry* row)
 
 wxSize clControlWithItems::GetTextSize(const wxString& label) const
 {
-    wxDC& dc = GetTempDC();
+    wxBitmap tmpBmp;
+    tmpBmp.CreateWithDIPSize(1, 1, GetDPIScaleFactor());
+    wxMemoryDC mem_dc{ tmpBmp };
+    wxGCDC dc{ mem_dc };
+
     wxFont font = GetDefaultFont();
     dc.SetFont(font);
     wxSize textSize = dc.GetTextExtent(label);
@@ -469,7 +436,7 @@ wxSize clControlWithItems::GetTextSize(const wxString& label) const
 
 const wxBitmap& clControlWithItems::GetBitmap(size_t index) const
 {
-    if(!GetBitmaps() || (index >= GetBitmaps()->size())) {
+    if (!GetBitmaps() || (index >= GetBitmaps()->size())) {
         static wxBitmap emptyBitmap;
         return emptyBitmap;
     }
@@ -484,21 +451,43 @@ void clControlWithItems::OnMouseScroll(wxMouseEvent& event)
 
 bool clControlWithItems::DoKeyDown(const wxKeyEvent& event)
 {
-    if(m_searchControl && m_searchControl->IsShown()) {
-        return true;
+    if (!m_search.IsEnabled() || event.GetKeyCode() != '/') {
+        return false;
     }
-    if(m_search.IsEnabled() && wxIsprint(event.GetUnicodeKey()) &&
-       (event.GetModifiers() == wxMOD_NONE || event.GetModifiers() == wxMOD_SHIFT)) {
-        if(!m_searchControl) {
-            m_searchControl = new clSearchControl(this);
+
+    // the search bar is placed at the bottom of the parent
+    // we require a sizer to do this
+    if (GetParent()->GetSizer() == nullptr) {
+        return false;
+    }
+
+    m_searchControl = new clSearchControl(GetParent(), this);
+    auto sizer = GetParent()->GetSizer();
+
+    // find the tree position in the sizer
+    size_t pos = 0;
+    int current_pos = 0;
+    for (auto child : sizer->GetChildren()) {
+        if (child->GetWindow() == this) {
+            // found our position
+            pos = current_pos;
+            break;
         }
-        m_searchControl->ShowControl(event.GetUnicodeKey());
-        return true;
+        ++current_pos;
     }
-    return false;
+
+    // place the search bar just before the tree
+    sizer->Insert(pos, m_searchControl, 0, wxEXPAND);
+
+    // show it
+    m_searchControl->Show();
+    m_searchControl->SetFocusAfter();
+    GetParent()->GetSizer()->Layout();
+    GetParent()->PostSizeEvent();
+    return true;
 }
 
-void clControlWithItems::SearchControlDismissed() {}
+void clControlWithItems::SearchControlDismissed() { m_searchControl = nullptr; }
 
 void clControlWithItems::AssignRects(const clRowEntry::Vec_t& items)
 {
@@ -507,16 +496,16 @@ void clControlWithItems::AssignRects(const clRowEntry::Vec_t& items)
     int header_bar_width = m_viewHeader ? m_viewHeader->GetWidth() : wxNOT_FOUND;
     int width = wxMax(clientRect.GetWidth(), header_bar_width);
 
-    for(size_t i = 0; i < items.size(); ++i) {
+    for (size_t i = 0; i < items.size(); ++i) {
         clRowEntry* curitem = items[i];
-        if(curitem->IsHidden()) {
+        if (curitem->IsHidden()) {
             // Set the item's rects into something non visible
             curitem->SetRects(wxRect(-100, -100, 0, 0), wxRect(-100, -100, 0, 0));
             continue;
         }
         wxRect itemRect = wxRect(clientRect.GetX(), y, width, m_lineHeight);
         wxRect buttonRect;
-        if(curitem->HasChildren()) {
+        if (curitem->HasChildren()) {
             buttonRect = wxRect(itemRect.x + (curitem->GetIndentsCount() * GetIndent()), y, m_lineHeight, m_lineHeight);
         }
         curitem->SetRects(itemRect, buttonRect);
@@ -529,10 +518,10 @@ void clControlWithItems::DoMouseScroll(const wxMouseEvent& event)
     int range = GetRange();
     bool going_up = (event.GetWheelRotation() > 0);
     int new_row = GetFirstItemPosition() + (going_up ? -GetScrollTick() : GetScrollTick());
-    if(new_row < 0) {
+    if (new_row < 0) {
         new_row = 0;
     }
-    if(new_row >= range) {
+    if (new_row >= range) {
         new_row = range - 1;
     }
     ScrollToRow(new_row);
@@ -542,20 +531,20 @@ clHeaderBar* clControlWithItems::GetHeader() const { return m_viewHeader; }
 
 void clControlWithItems::DoPositionVScrollbar()
 {
-    if(IsHeaderVisible()) {
+    if (IsHeaderVisible()) {
         // When the heaer is visible place the vertical scrollbar under it
         wxRect clientRect = GetClientRect();
         wxSize vsbSize = GetVScrollBar()->GetSize();
 
         int height = clientRect.GetHeight();
-        if(GetHScrollBar() && GetHScrollBar()->IsShown()) {
+        if (GetHScrollBar() && GetHScrollBar()->IsShown()) {
             height -= GetHScrollBar()->GetSize().GetHeight();
         }
         int width = vsbSize.GetWidth();
         int x = clientRect.GetWidth() - vsbSize.GetWidth();
         int y = (GetHeader() ? GetHeader()->GetHeight() : 0);
         height -= (GetHeader() ? GetHeader()->GetHeight() : 0);
-        if(height < 0) {
+        if (height < 0) {
             height = 0;
         }
         GetVScrollBar()->SetSize(width, height);
@@ -570,14 +559,14 @@ void clControlWithItems::DoPositionHScrollbar() { clScrolledPanel::DoPositionHSc
 
 void clControlWithItems::SetColumnWidth(size_t col, int width)
 {
-    if(col >= GetHeader()->size()) {
+    if (col >= GetHeader()->size()) {
         return;
     }
     // Handle special values
-    if(width == wxCOL_WIDTH_AUTOSIZE || width == wxCOL_WIDTH_DEFAULT) {
+    if (width == wxCOL_WIDTH_AUTOSIZE || width == wxCOL_WIDTH_DEFAULT) {
         GetHeader()->Item(col).SetWidthValue(width);
         GetHeader()->UpdateColWidthIfNeeded(col, width, true);
-    } else if(width >= 0) {
+    } else if (width >= 0) {
         GetHeader()->Item(col).SetWidthValue(width);
         GetHeader()->UpdateColWidthIfNeeded(col, width, true);
     }
@@ -596,13 +585,13 @@ void clControlWithItems::SetNativeTheme(bool nativeTheme)
 void clControlWithItems::SetImageList(wxImageList* images)
 {
     wxDELETE(m_bitmapsInternal);
-    if(!images || images->GetImageCount() <= 0) {
+    if (!images || images->GetImageCount() <= 0) {
         return;
     }
 
     m_bitmapsInternal = new BitmapVec_t();
     m_bitmapsInternal->reserve(images->GetImageCount());
-    for(size_t i = 0; i < (size_t)images->GetImageCount(); ++i) {
+    for (size_t i = 0; i < (size_t)images->GetImageCount(); ++i) {
         m_bitmapsInternal->push_back(images->GetBitmap(i));
     }
     SetBitmaps(m_bitmapsInternal);
@@ -625,9 +614,7 @@ void clControlWithItems::SetCustomRenderer(clControlWithItemsRowRenderer* render
 void clControlWithItems::SetDefaultFont(const wxFont& font)
 {
     m_defaultFont = font;
-    // update the temp DC with the default font
-    GetTempDC().SetFont(font);
-    if(m_viewHeader) {
+    if (m_viewHeader) {
         m_viewHeader->SetHeaderFont(GetDefaultFont());
     }
 
@@ -638,7 +625,7 @@ void clControlWithItems::SetDefaultFont(const wxFont& font)
 
 wxFont clControlWithItems::GetDefaultFont() const
 {
-    if(m_defaultFont.IsOk()) {
+    if (m_defaultFont.IsOk()) {
         return m_defaultFont;
     }
     return clScrolledPanel::GetDefaultFont();
@@ -656,16 +643,16 @@ bool clSearchText::Matches(const wxString& findWhat, size_t col, const wxString&
 {
     wxString haystack = searchFlags & wxTR_SEARCH_ICASE ? text.Lower() : text;
     wxString needle = searchFlags & wxTR_SEARCH_ICASE ? findWhat.Lower() : findWhat;
-    if(!matches) {
-        if(searchFlags & wxTR_SEARCH_METHOD_CONTAINS) {
+    if (!matches) {
+        if (searchFlags & wxTR_SEARCH_METHOD_CONTAINS) {
             return haystack.Contains(needle);
         } else {
             return (haystack == needle);
         }
     } else {
-        if(searchFlags & wxTR_SEARCH_METHOD_CONTAINS) {
+        if (searchFlags & wxTR_SEARCH_METHOD_CONTAINS) {
             int where = haystack.Find(needle);
-            if(where == wxNOT_FOUND) {
+            if (where == wxNOT_FOUND) {
                 return false;
             }
             Str3Arr_t arr;
@@ -675,7 +662,7 @@ bool clSearchText::Matches(const wxString& findWhat, size_t col, const wxString&
             matches->Add(col, arr);
             return true;
         } else {
-            if(haystack == needle) {
+            if (haystack == needle) {
                 Str3Arr_t arr;
                 arr[0] = "";
                 arr[1] = text;
