@@ -72,8 +72,8 @@ public:
     /**
      * @brief how many items can scroll in the view?
      */
-    int GetRange() const { return GetItemCount(); }
-    bool IsEmpty() const { return GetItemCount() == 0; }
+    int GetRange() const override { return GetItemCount(); }
+    bool IsEmpty() const override { return GetItemCount() == 0; }
 
     ///===--------------------
     /// Search support
@@ -166,7 +166,7 @@ public:
     void SetItemFont(const wxDataViewItem& item, const wxFont& font, size_t col = 0);
     wxFont GetItemFont(const wxDataViewItem& item, size_t col = 0) const;
 
-    virtual void EnableStyle(int style, bool enable, bool refresh = true);
+    void EnableStyle(int style, bool enable, bool refresh = true) override;
 
     clHeaderItem* GetColumn(size_t index);
     size_t GetItemCount() const;
@@ -193,7 +193,7 @@ public:
     /**
      * @brief set sorting function AND apply it
      */
-    void SetSortFunction(const clSortFunc_t& CompareFunc);
+    void SetSortFunction(const clSortFunc_t& CompareFunc) override;
 
     /**
      * @brief remove all columns from the control
@@ -427,6 +427,37 @@ public:
 
 DECLARE_VARIANT_OBJECT_EXPORTED(clDataViewColour, WXDLLIMPEXP_SDK)
 
+class WXDLLIMPEXP_SDK clDataViewControl : public wxObject
+{
+private:
+    wxControl* m_ctrl = nullptr;
+
+public:
+    clDataViewControl(wxControl* ctrl)
+        : m_ctrl(ctrl)
+    {
+    }
+
+    clDataViewControl(const clDataViewControl& other)
+        : wxObject()
+        , m_ctrl(other.m_ctrl)
+    {
+    }
+
+    clDataViewControl() {}
+    // we do not delete the control
+    virtual ~clDataViewControl() {}
+
+    void SetControl(wxControl* ctrl) { this->m_ctrl = ctrl; }
+    wxControl* GetControl() { return m_ctrl; }
+    bool IsSameAs(const clDataViewControl& other) const { return m_ctrl == other.m_ctrl; }
+    bool operator==(const clDataViewControl& other) const { return IsSameAs(other); }
+    bool operator!=(const clDataViewControl& other) const { return !IsSameAs(other); }
+    wxDECLARE_DYNAMIC_CLASS(clDataViewControl);
+};
+
+DECLARE_VARIANT_OBJECT_EXPORTED(clDataViewControl, WXDLLIMPEXP_SDK)
+
 wxDECLARE_EXPORTED_EVENT(WXDLLIMPEXP_SDK, wxEVT_DATAVIEW_SEARCH_TEXT, wxDataViewEvent);
 wxDECLARE_EXPORTED_EVENT(WXDLLIMPEXP_SDK, wxEVT_DATAVIEW_CLEAR_SEARCH, wxDataViewEvent);
 wxDECLARE_EXPORTED_EVENT(WXDLLIMPEXP_SDK, wxEVT_DATAVIEW_ACTION_BUTTON, wxDataViewEvent);
