@@ -27,7 +27,6 @@
 // clang-format off
 #include "bitmap_loader.h"
 #include "bookmark_manager.h"
-#include "clBitmapOverlayCtrl.h"
 #include "cl_config.h"
 #include "codelite_events.h"
 #include "drawingutils.h"
@@ -51,7 +50,7 @@
 // clang-format on
 
 DEFINE_EVENT_TYPE(QUICKFIND_COMMAND_EVENT)
-#define MARKER_FIND_BAR_WORD_HIGHLIGHT 5
+#define INDICATOR_FIND_BAR_WORD_HIGHLIGHT 5
 
 #define CHECK_FOCUS_WIN(evt)                            \
     {                                                   \
@@ -106,8 +105,8 @@ clPluginsFindBar::clPluginsFindBar(wxWindow* parent, wxWindowID id)
     , m_replaceInSelection(false)
 {
     // Handle Edit events
-    m_findEventsHandler.Reset(new clEditEventsHandler(m_textCtrlFind));
-    m_replaceEventsHandler.Reset(new clEditEventsHandler(m_textCtrlReplace));
+    m_findEventsHandler = std::make_unique<clEditEventsHandler>(m_textCtrlFind);
+    m_replaceEventsHandler = std::make_unique<clEditEventsHandler>(m_textCtrlReplace);
     m_findEventsHandler->NoUnbind();
     m_replaceEventsHandler->NoUnbind();
     m_toolbar->SetMiniToolBar(true);
@@ -470,8 +469,6 @@ void clPluginsFindBar::SetEditor(wxStyledTextCtrl* sci)
     }
 }
 
-int clPluginsFindBar::GetCloseButtonId() { return ID_TOOL_CLOSE; }
-
 bool clPluginsFindBar::Show(const wxString& findWhat, bool showReplace)
 {
     // Same as Show() but set the 'findWhat' field with findWhat
@@ -493,7 +490,7 @@ bool clPluginsFindBar::DoShow(bool s, const wxString& findWhat, bool showReplace
         m_sci->IndicatorClearRange(0, m_sci->GetLength());
 
         if(EditorConfigST::Get()->GetOptions()->GetClearHighlitWordsOnFind()) {
-            m_sci->SetIndicatorCurrent(MARKER_FIND_BAR_WORD_HIGHLIGHT);
+            m_sci->SetIndicatorCurrent(INDICATOR_FIND_BAR_WORD_HIGHLIGHT);
             m_sci->IndicatorClearRange(0, m_sci->GetLength());
         }
     }
@@ -615,7 +612,7 @@ void clPluginsFindBar::DoSelectAll(bool addMarkers)
     clGetManager()->SetStatusMessage(wxEmptyString);
 
     if(addMarkers) {
-        m_sci->SetIndicatorCurrent(MARKER_FIND_BAR_WORD_HIGHLIGHT);
+        m_sci->SetIndicatorCurrent(INDICATOR_FIND_BAR_WORD_HIGHLIGHT);
         m_sci->IndicatorClearRange(0, m_sci->GetLength());
     }
 
@@ -698,9 +695,9 @@ void clPluginsFindBar::DoHighlightMatches(bool checked)
         m_sci->SetCurrentPos(0);
         m_sci->SetSelectionEnd(0);
         m_sci->SetSelectionStart(0);
-        m_sci->MarkerDeleteAll(MARKER_FIND_BAR_WORD_HIGHLIGHT);
+        m_sci->MarkerDeleteAll(INDICATOR_FIND_BAR_WORD_HIGHLIGHT);
 
-        m_sci->SetIndicatorCurrent(MARKER_FIND_BAR_WORD_HIGHLIGHT);
+        m_sci->SetIndicatorCurrent(INDICATOR_FIND_BAR_WORD_HIGHLIGHT);
         m_sci->IndicatorClearRange(0, m_sci->GetLength());
 
         int found = 0;
@@ -709,7 +706,7 @@ void clPluginsFindBar::DoHighlightMatches(bool checked)
             if(m_sci->SearchNext(flags, findwhat) != wxNOT_FOUND) {
                 int selStart, selEnd;
                 m_sci->GetSelection(&selStart, &selEnd);
-                m_sci->SetIndicatorCurrent(MARKER_FIND_BAR_WORD_HIGHLIGHT);
+                m_sci->SetIndicatorCurrent(INDICATOR_FIND_BAR_WORD_HIGHLIGHT);
                 m_sci->IndicatorFillRange(selStart, selEnd - selStart);
                 m_sci->MarkerAdd(m_sci->LineFromPosition(selStart), smt_find_bookmark);
 
@@ -733,13 +730,13 @@ void clPluginsFindBar::DoHighlightMatches(bool checked)
         m_matchesFound->SetLabel(matches);
 
     } else {
-        m_sci->MarkerDeleteAll(MARKER_FIND_BAR_WORD_HIGHLIGHT);
+        m_sci->MarkerDeleteAll(INDICATOR_FIND_BAR_WORD_HIGHLIGHT);
 
         IEditor::List_t editors;
         clGetManager()->GetAllEditors(editors);
         std::for_each(editors.begin(), editors.end(), [&](IEditor* pEditor) {
             pEditor->GetCtrl()->MarkerDeleteAll(smt_find_bookmark);
-            pEditor->GetCtrl()->SetIndicatorCurrent(MARKER_FIND_BAR_WORD_HIGHLIGHT);
+            pEditor->GetCtrl()->SetIndicatorCurrent(INDICATOR_FIND_BAR_WORD_HIGHLIGHT);
             pEditor->GetCtrl()->IndicatorClearRange(0, pEditor->GetCtrl()->GetLength());
         });
         m_matchesFound->SetLabel("");
@@ -1154,7 +1151,7 @@ bool clPluginsFindBar::Search(wxStyledTextCtrl* ctrl, const wxString& find_what,
 
     // Clear all search markers if desired
     if(EditorConfigST::Get()->GetOptions()->GetClearHighlitWordsOnFind()) {
-        ctrl->SetIndicatorCurrent(MARKER_FIND_BAR_WORD_HIGHLIGHT);
+        ctrl->SetIndicatorCurrent(INDICATOR_FIND_BAR_WORD_HIGHLIGHT);
         ctrl->IndicatorClearRange(0, ctrl->GetLength());
     }
 
