@@ -1,7 +1,8 @@
 #ifndef CLREGISTERY_HPP
 #define CLREGISTERY_HPP
 
-#include <codelite_exports.h>
+#include "codelite_exports.h"
+
 #include <wx/string.h>
 
 #ifdef __WXMSW__
