@@ -12,12 +12,18 @@ class WXDLLIMPEXP_SDK clRemoteFindDialog : public clRemoteFindDialogBase
 {
     wxString m_root_path;
     FindInFilesSession m_data;
+    bool m_isReplace = false;
 
 protected:
-    virtual void OnSearch(wxCommandEvent& event);
-    virtual void OnOK_UI(wxUpdateUIEvent& event);
-    void UpdateCombo(clThemedComboBox* cb, const wxArrayString& options, const wxString& lastSelection);
-    bool CanOk() const;
+    virtual void OnTool(wxCommandEvent& event);
+    virtual void OnReplaceUI(wxUpdateUIEvent& event);
+    virtual void OnFindUI(wxUpdateUIEvent& event);
+    virtual void OnFind(wxCommandEvent& event);
+    virtual void OnReplace(wxCommandEvent& event);
+
+    void DoShowSearchControls(bool show);
+    void DoShowReplaceControls(bool show);
+    void DoShowControls();
 
 public:
     clRemoteFindDialog(wxWindow* parent, const wxString& account_name, const wxString& rootpath);
@@ -28,14 +34,11 @@ public:
 
     wxString GetWhere() const;
     wxString GetFindWhat() const;
+    wxString GetReplaceWith() const;
     wxString GetFileExtensions() const;
     bool IsIcase() const;
     bool IsWholeWord() const;
-
-    /**
-     * @brief build grep command from the input provided
-     */
-    wxArrayString GetGrepCommand() const;
+    bool IsReplaceAction() const { return m_isReplace; }
 };
 
 #endif // CLREMOTEFINDDIALOG_H
