@@ -1,14 +1,14 @@
 #include "clRemoteFinderHelper.hpp"
 
+#include "AsyncProcess/asyncprocess.h"
+#include "AsyncProcess/processreaderthread.h"
 #include "Notebook.h"
-#include "asyncprocess.h"
 #include "cl_command_event.h"
 #include "event_notifier.h"
 #include "file_logger.h"
 #include "globals.h"
 #include "imanager.h"
 #include "macros.h"
-#include "processreaderthread.h"
 #include "search_thread.h"
 
 #include <wx/tokenzr.h>
@@ -98,16 +98,7 @@ void clRemoteFinderHelper::Search(const wxString& root_dir, const wxString& find
     GetSearchTab()->GetEventHandler()->AddPendingEvent(start_event);
 }
 
-wxWindow* clRemoteFinderHelper::GetSearchTab()
-{
-    auto book = clGetManager()->GetOutputPaneNotebook();
-    for(size_t i = 0; i < book->GetPageCount(); ++i) {
-        if(book->GetPageText(i) == _("Search")) {
-            return book->GetPage(i);
-        }
-    }
-    return nullptr;
-}
+wxWindow* clRemoteFinderHelper::GetSearchTab() { return clGetManager()->BookGetPage(PaneId::BOTTOM_BAR, _("Search")); }
 
 void clRemoteFinderHelper::SetCodeLiteRemote(clCodeLiteRemoteProcess* clr) { m_codeliteRemote = clr; }
 
