@@ -4,15 +4,18 @@
 #include "SFTPClientData.hpp"
 #include "StringUtils.h"
 #include "clSFTPEvent.h"
+#include "clSSHChannelCommon.hpp"
 #include "clTempFile.hpp"
 #include "cl_command_event.h"
 #include "codelite_events.h"
+#include "environmentconfig.h"
 #include "event_notifier.h"
 #include "file_logger.h"
 #include "fileutils.h"
 #include "globals.h"
 #include "ieditor.h"
 #include "imanager.h"
+#include "libssh/libssh.h"
 #include "macros.h"
 
 #include <condition_variable>
@@ -30,6 +33,10 @@
 
 wxDEFINE_EVENT(wxEVT_SFTP_ASYNC_SAVE_COMPLETED, clCommandEvent);
 wxDEFINE_EVENT(wxEVT_SFTP_ASYNC_SAVE_ERROR, clCommandEvent);
+wxDEFINE_EVENT(wxEVT_SFTP_ASYNC_EXEC_ERROR, clCommandEvent);
+wxDEFINE_EVENT(wxEVT_SFTP_ASYNC_EXEC_STDOUT, clCommandEvent);
+wxDEFINE_EVENT(wxEVT_SFTP_ASYNC_EXEC_STDERR, clCommandEvent);
+wxDEFINE_EVENT(wxEVT_SFTP_ASYNC_EXEC_DONE, clCommandEvent);
 
 clSFTPManager::clSFTPManager()
 {
@@ -49,13 +56,13 @@ clSFTPManager::clSFTPManager()
 clSFTPManager::~clSFTPManager()
 {
     StopWorkerThread();
-    if(m_eventsConnected) {
+    if (m_eventsConnected) {
         EventNotifier::Get()->Unbind(wxEVT_GOING_DOWN, &clSFTPManager::OnGoingDown, this);
         EventNotifier::Get()->Unbind(wxEVT_FILE_SAVED, &clSFTPManager::OnFileSaved, this);
         m_eventsConnected = false;
     }
 
-    if(m_timer) {
+    if (m_timer) {
         Unbind(wxEVT_TIMER, &clSFTPManager::OnTimer, this, m_timer->GetId());
         m_timer->Stop();
         wxDELETE(m_timer);
@@ -73,36 +80,45 @@ clSFTPManager& clSFTPManager::Get()
 void clSFTPManager::Release()
 {
     StopWorkerThread();
-    while(!m_connections.empty()) {
+    while (!m_connections.empty()) {
         const auto& conn_info = *(m_connections.begin());
         DeleteConnection(conn_info.first, false);
     }
     m_connections.clear();
 
-    if(m_eventsConnected) {
+    if (m_eventsConnected) {
         EventNotifier::Get()->Unbind(wxEVT_GOING_DOWN, &clSFTPManager::OnGoingDown, this);
         EventNotifier::Get()->Unbind(wxEVT_FILE_SAVED, &clSFTPManager::OnFileSaved, this);
         m_eventsConnected = false;
     }
-    if(m_timer) {
+    if (m_timer) {
         Unbind(wxEVT_TIMER, &clSFTPManager::OnTimer, this, m_timer->GetId());
         m_timer->Stop();
         wxDELETE(m_timer);
     }
-    if(m_worker_thread) {
+    if (m_worker_thread) {
         m_shutdown.store(true);
         m_worker_thread->join();
         wxDELETE(m_worker_thread);
     }
 }
 
+bool clSFTPManager::AddConnection(const wxString& account_name, bool replace)
+{
+    auto acc = SSHAccountInfo::LoadAccount(account_name);
+    if (!acc.IsOk()) {
+        return false;
+    }
+    return AddConnection(acc, replace);
+}
+
 bool clSFTPManager::AddConnection(const SSHAccountInfo& account, bool replace)
 {
     wxBusyCursor bc;
     {
         auto iter = m_connections.find(account.GetAccountName());
-        if(iter != m_connections.end()) {
-            if(!replace) {
+        if (iter != m_connections.end()) {
+            if (!replace) {
                 // do not replace the current connection
                 return true;
             }
@@ -111,11 +127,13 @@ bool clSFTPManager::AddConnection(const SSHAccountInfo& account, bool replace)
     }
 
     try {
-        clSSH::Ptr_t ssh(new clSSH(account.GetHost(), account.GetUsername(), account.GetPassword(), account.GetPort()));
-        ssh->Connect();
+        clSSH::Ptr_t ssh(new clSSH(account.GetHost(), account.GetUsername(), account.GetPassword(),
+                                   account.GetKeyFiles(), account.GetPort()));
+        EnvSetter env;
+        ssh->Open();
         wxString message;
-        if(!ssh->AuthenticateServer(message)) {
-            if(::wxMessageBox(message, "SSH", wxYES_NO | wxCENTER | wxICON_QUESTION) == wxYES) {
+        if (!ssh->AuthenticateServer(message)) {
+            if (::wxMessageBox(message, "SSH", wxYES_NO | wxCENTER | wxICON_QUESTION) == wxYES) {
                 ssh->AcceptServerAuthentication();
             } else {
                 return false;
@@ -124,6 +142,7 @@ bool clSFTPManager::AddConnection(const SSHAccountInfo& account, bool replace)
         ssh->Login();
         clSFTP::Ptr_t sftp(new clSFTP(ssh));
         sftp->Initialize();
+        sftp->SetAccount(account.GetAccountName());
         m_connections.insert({ account.GetAccountName(), { account, sftp } });
 
         // Notify that a session is established
@@ -131,7 +150,7 @@ bool clSFTPManager::AddConnection(const SSHAccountInfo& account, bool replace)
         event.SetAccount(account.GetAccountName());
         EventNotifier::Get()->AddPendingEvent(event);
 
-    } catch(clException& e) {
+    } catch (const clException& e) {
         clERROR() << "AddConnection() error:" << e.What();
         return false;
     }
@@ -141,7 +160,7 @@ bool clSFTPManager::AddConnection(const SSHAccountInfo& account, bool replace)
 std::pair<SSHAccountInfo, clSFTP::Ptr_t> clSFTPManager::GetConnectionPair(const wxString& account) const
 {
     auto iter = m_connections.find(account);
-    if(iter == m_connections.end()) {
+    if (iter == m_connections.end()) {
         return { {}, clSFTP::Ptr_t(nullptr) };
     }
     return iter->second;
@@ -150,7 +169,7 @@ std::pair<SSHAccountInfo, clSFTP::Ptr_t> clSFTPManager::GetConnectionPair(const
 clSFTP::Ptr_t clSFTPManager::GetConnectionPtr(const wxString& account) const
 {
     auto iter = m_connections.find(account);
-    if(iter == m_connections.end()) {
+    if (iter == m_connections.end()) {
         return clSFTP::Ptr_t(nullptr);
     }
     return iter->second.second;
@@ -159,15 +178,15 @@ clSFTP::Ptr_t clSFTPManager::GetConnectionPtr(const wxString& account) const
 clSFTP::Ptr_t clSFTPManager::GetConnectionPtrAddIfMissing(const wxString& account)
 {
     auto iter = m_connections.find(account);
-    if(iter != m_connections.end()) {
+    if (iter != m_connections.end()) {
         return iter->second.second;
     }
     // no such connection, add it
     auto acc = SSHAccountInfo::LoadAccount(account);
-    if(acc.GetAccountName().empty()) {
+    if (acc.GetAccountName().empty()) {
         return clSFTP::Ptr_t(nullptr);
     }
-    if(!AddConnection(acc)) {
+    if (!AddConnection(acc)) {
         return clSFTP::Ptr_t(nullptr);
     }
     return m_connections[account].second;
@@ -176,7 +195,7 @@ clSFTP::Ptr_t clSFTPManager::GetConnectionPtrAddIfMissing(const wxString& accoun
 SFTPClientData* clSFTPManager::GetSFTPClientData(IEditor* editor)
 {
     auto clientData = editor->GetClientData("sftp");
-    if(!clientData) {
+    if (!clientData) {
         return nullptr;
     }
     return dynamic_cast<SFTPClientData*>(clientData);
@@ -186,7 +205,7 @@ IEditor* clSFTPManager::OpenFile(const wxString& path, const SSHAccountInfo& acc
 {
     wxBusyCursor bc;
     bool res = AddConnection(accountInfo);
-    if(!res) {
+    if (!res) {
         return nullptr;
     }
     return OpenFile(path, accountInfo.GetAccountName());
@@ -197,46 +216,26 @@ IEditor* clSFTPManager::OpenFile(const wxString& path, const wxString& accountNa
     // if the file is already opened in the editor, return it
     IEditor::List_t editors;
     clGetManager()->GetAllEditors(editors);
-    for(auto editor : editors) {
+    for (auto editor : editors) {
         auto clientData = GetSFTPClientData(editor);
-        if(clientData && clientData->GetAccountName() == accountName && clientData->GetRemotePath() == path) {
+        if (clientData && clientData->GetAccountName() == accountName && clientData->GetRemotePath() == path) {
             clGetManager()->SelectPage(editor->GetCtrl());
             return editor;
         }
     }
 
     auto account = SSHAccountInfo::LoadAccount(accountName);
-    if(account.GetAccountName().empty()) {
+    if (account.GetAccountName().empty()) {
         m_lastError.clear();
         m_lastError << "failed to locate account:" << accountName;
         return nullptr;
     }
 
     wxFileName localPath = clSFTP::GetLocalFileName(account, path, true);
-    if(!DoSyncDownload(path, localPath.GetFullPath(), accountName)) {
+    if (!DoSyncDownload(path, localPath.GetFullPath(), accountName)) {
         return nullptr;
     }
-
-    // set the client data for this editor
-    SFTPClientData* cd = new SFTPClientData;
-    cd->SetLocalPath(localPath.GetFullPath());
-    cd->SetRemotePath(path);
-    cd->SetPermissions(0); // not used
-    cd->SetLineNumber(wxNOT_FOUND);
-    cd->SetAccountName(accountName);
-
-    wxString tooltip;
-    tooltip << "Local: " << cd->GetLocalPath() << "\n"
-            << "Remote: " << cd->GetRemotePath();
-
-    auto editor = clGetManager()->OpenFile(localPath.GetFullPath(), "download", tooltip);
-    if(!editor) {
-        // probably opened using the image viewer
-        wxDELETE(cd);
-        return nullptr;
-    }
-    editor->SetClientData("sftp", cd);
-    return editor;
+    return clGetManager()->OpenRemoteFile(localPath.GetFullPath(), path, accountName, wxEmptyString);
 }
 
 bool clSFTPManager::DoSyncReadFile(const wxString& remotePath, const wxString& accountName, wxMemoryBuffer* content)
@@ -258,7 +257,7 @@ bool clSFTPManager::DoSyncReadFile(const wxString& remotePath, const wxString& a
             wxUnusedVar(fileAttr);
             read_promise.set_value(buffer);
 
-        } catch(clException& e) {
+        } catch (const clException& e) {
             clERROR() << "Failed to read remote file:" << remotePath << "." << e.What();
             wxDELETE(buffer);
             read_promise.set_value(nullptr);
@@ -268,7 +267,7 @@ bool clSFTPManager::DoSyncReadFile(const wxString& remotePath, const wxString& a
     // queue the task and wait for the response
     m_q.push_back(std::move(read_func));
     auto buffer = future.get();
-    if(!buffer) {
+    if (!buffer) {
         return false;
     }
 
@@ -302,7 +301,7 @@ void clSFTPManager::DoAsyncReadFile(const wxString& remotePath, const wxString&
             event_read.SetContent(content);
             sink->QueueEvent(event_read.Clone());
 
-        } catch(clException& e) {
+        } catch (const clException& e) {
             clERROR() << "Failed to read remote file:" << remotePath << "." << e.What();
         }
     };
@@ -318,30 +317,31 @@ bool clSFTPManager::DoSyncDownload(const wxString& remotePath, const wxString& l
     CHECK_PTR_RET_FALSE(conn);
 
     // if the local file already exists, compare checksums before downloading it
-    if(wxFileName::FileExists(localPath)) {
+    if (wxFileName::FileExists(localPath)) {
         clDEBUG() << "Local file with the same path already exists, comapring checksums..." << endl;
         try {
             // read the file size
             size_t remote_file_checksum, local_file_checksum;
-            if(conn->GetChecksum(remotePath, &remote_file_checksum) &&
-               FileUtils::GetChecksum(localPath, &local_file_checksum) && local_file_checksum == remote_file_checksum) {
+            if (conn->GetChecksum(remotePath, &remote_file_checksum) &&
+                FileUtils::GetChecksum(localPath, &local_file_checksum) &&
+                local_file_checksum == remote_file_checksum) {
                 clDEBUG() << "Using cached local file (checksum are the same)" << endl;
                 return true;
             }
-        } catch(clException& e) {
+        } catch (const clException& e) {
             wxUnusedVar(e);
         }
     }
 
     wxMemoryBuffer file_content;
-    if(!DoSyncReadFile(remotePath, accountName, &file_content)) {
+    if (!DoSyncReadFile(remotePath, accountName, &file_content)) {
         return false;
     }
 
     {
         wxLogNull no_log;
         wxFFile fp(localPath, "w+b");
-        if(!fp.IsOpened()) {
+        if (!fp.IsOpened()) {
             clERROR() << "failed to open local file:" << localPath << "for write" << endl;
             return false;
         }
@@ -368,53 +368,60 @@ void clSFTPManager::DoAsyncSaveFile(const wxString& localPath, const wxString& r
     auto save_func = [localPath, remotePath, conn, sink, delete_local]() {
         try {
             conn->Write(localPath, remotePath);
-            if(sink) {
+            if (sink) {
                 // notify about save success
                 clCommandEvent success_event(wxEVT_SFTP_ASYNC_SAVE_COMPLETED);
                 success_event.SetFileName(remotePath);
+                success_event.SetSshAccount(conn->GetAccount());
                 sink->AddPendingEvent(success_event);
             }
-        } catch(clException& e) {
+        } catch (const clException& e) {
             clERROR() << "(AsyncSaveFile): Failed to write file:" << remotePath << "." << e.What();
             clCommandEvent fail_event(wxEVT_SFTP_ASYNC_SAVE_ERROR);
             fail_event.SetFileName(remotePath);
             fail_event.SetString(e.What());
+            fail_event.SetSshAccount(conn->GetAccount());
             sink->AddPendingEvent(fail_event);
         }
         // always delete the file
-        if(delete_local) {
+        if (delete_local) {
             clRemoveFile(localPath);
         }
     };
     m_q.push_back(std::move(save_func));
 }
 
+bool clSFTPManager::DoSyncSaveFileWithConn(clSFTP::Ptr_t conn, const wxString& localPath, const wxString& remotePath,
+                                           bool delete_local)
+{
+    // prepare the download work
+    std::promise<bool> save_promise;
+    auto future = save_promise.get_future();
+    auto save_func = [localPath, remotePath, conn, delete_local, &save_promise]() {
+        try {
+            conn->Write(localPath, remotePath);
+            save_promise.set_value(true);
+        } catch (const clException& e) {
+            clERROR() << "Failed to write file:" << remotePath << "." << e.What();
+            save_promise.set_value(false);
+        }
+
+        // always delete the file
+        if (delete_local) {
+            clRemoveFile(localPath);
+        }
+    };
+    m_q.push_back(std::move(save_func));
+    return future.get();
+}
+
 bool clSFTPManager::DoSyncSaveFile(const wxString& localPath, const wxString& remotePath, const wxString& accountName,
                                    bool delete_local)
 {
     // save file async
     auto conn = GetConnectionPtrAddIfMissing(accountName);
     CHECK_PTR_RET_FALSE(conn);
-
-    // prepare the download work
-    std::promise<bool> save_promise;
-    auto future = save_promise.get_future();
-    auto save_func = [localPath, remotePath, conn, delete_local, &save_promise]() {
-        try {
-            conn->Write(localPath, remotePath);
-            save_promise.set_value(true);
-        } catch(clException& e) {
-            clERROR() << "Failed to write file:" << remotePath << "." << e.What();
-            save_promise.set_value(false);
-        }
-
-        // always delete the file
-        if(delete_local) {
-            clRemoveFile(localPath);
-        }
-    };
-    m_q.push_back(std::move(save_func));
-    return future.get();
+    return DoSyncSaveFileWithConn(conn, localPath, remotePath, delete_local);
 }
 
 void clSFTPManager::AsyncSaveFile(const wxString& localPath, const wxString& remotePath, const wxString& accountName,
@@ -427,7 +434,7 @@ void clSFTPManager::AsyncSaveFile(const wxString& localPath, const wxString& rem
 void clSFTPManager::OnFileSaved(clCommandEvent& event)
 {
     event.Skip();
-    if(clGetManager()->IsShutdownInProgress()) {
+    if (clGetManager()->IsShutdownInProgress()) {
         return;
     }
 
@@ -453,16 +460,26 @@ bool clSFTPManager::AwaitWriteFile(const wxString& content, const wxString& remo
 {
     clTempFile tmpfile;
     tmpfile.Persist(); // do not delete it on exit
-    if(!tmpfile.Write(content, wxConvUTF8)) {
+    if (!tmpfile.Write(content, wxConvUTF8)) {
         return false;
     }
     return DoSyncSaveFile(tmpfile.GetFullPath(), remotePath, accountName, true);
 }
 
+bool clSFTPManager::AwaitWriteFile(clSFTP::Ptr_t sftp, const wxString& content, const wxString& remotePath)
+{
+    clTempFile tmpfile;
+    tmpfile.Persist(); // do not delete it on exit
+    if (!tmpfile.Write(content, wxConvUTF8)) {
+        return false;
+    }
+    return DoSyncSaveFileWithConn(sftp, tmpfile.GetFullPath(), remotePath, true);
+}
+
 bool clSFTPManager::DeleteConnection(const wxString& accountName, bool promptUser)
 {
     auto iter = m_connections.find(accountName);
-    if(iter == m_connections.end()) {
+    if (iter == m_connections.end()) {
         // nothing to be done here
         return false;
     }
@@ -470,10 +487,10 @@ bool clSFTPManager::DeleteConnection(const wxString& accountName, bool promptUse
     // close all editors owned by this account
     IEditor::List_t editors;
     clGetManager()->GetAllEditors(editors);
-    for(auto editor : editors) {
+    for (auto editor : editors) {
         auto cd = GetSFTPClientData(editor);
-        if(cd && (cd->GetAccountName() == accountName)) {
-            if(!clGetManager()->CloseEditor(editor, promptUser)) {
+        if (cd && (cd->GetAccountName() == accountName)) {
+            if (!clGetManager()->CloseEditor(editor, promptUser)) {
                 // user cancelled
                 return false;
             }
@@ -497,12 +514,12 @@ bool clSFTPManager::DeleteConnection(const wxString& accountName, bool promptUse
     return true;
 }
 
-SFTPAttribute::List_t clSFTPManager::List(const wxString& path, const SSHAccountInfo& accountInfo)
+clResult<SFTPAttribute::List_t, bool> clSFTPManager::List(const wxString& path, const SSHAccountInfo& accountInfo)
 {
     wxBusyCursor bc;
     // save file async
     auto conn = GetConnectionPtrAddIfMissing(accountInfo.GetAccountName());
-    if(!conn) {
+    if (!conn) {
         return {};
     }
 
@@ -515,14 +532,14 @@ SFTPAttribute::List_t clSFTPManager::List(const wxString& path, const SSHAccount
             auto attr = conn->List(path, clSFTP::SFTP_BROWSE_FILES | clSFTP::SFTP_BROWSE_FOLDERS);
             result.swap(attr);
             promise.set_value(true);
-        } catch(clException& e) {
+        } catch (const clException& e) {
             clERROR() << "List error." << e.What();
             promise.set_value(false);
         }
     };
     m_q.push_back(std::move(func));
-    if(!future.get()) {
-        return {};
+    if (!future.get()) {
+        return clResult<SFTPAttribute::List_t, bool>::make_error(false);
     }
     return result;
 }
@@ -539,7 +556,7 @@ bool clSFTPManager::NewFile(const wxString& path, const SSHAccountInfo& accountI
         try {
             conn->CreateEmptyFile(path);
             promise.set_value(true);
-        } catch(clException& e) {
+        } catch (const clException& e) {
             clDEBUG() << "NewFile() error." << e.What();
             promise.set_value(false);
         }
@@ -567,7 +584,7 @@ bool clSFTPManager::NewFolder(const wxString& path, const SSHAccountInfo& accoun
         try {
             conn->CreateDir(path);
             promise.set_value(true);
-        } catch(clException& e) {
+        } catch (const clException& e) {
             clDEBUG() << "NewFolder() error." << e.What();
             promise.set_value(false);
         }
@@ -588,7 +605,7 @@ bool clSFTPManager::Rename(const wxString& oldpath, const wxString& newpath, con
         try {
             conn->Rename(oldpath, newpath);
             promise.set_value(true);
-        } catch(clException& e) {
+        } catch (const clException& e) {
             clERROR() << "Rename() error." << e.What();
             promise.set_value(false);
         }
@@ -609,7 +626,7 @@ bool clSFTPManager::DeleteDir(const wxString& fullpath, const SSHAccountInfo& ac
         try {
             conn->RemoveDir(fullpath);
             promise.set_value(true);
-        } catch(clException& e) {
+        } catch (const clException& e) {
             clERROR() << "Rename() error." << e.What();
             promise.set_value(false);
         }
@@ -631,7 +648,7 @@ bool clSFTPManager::UnlinkFile(const wxString& fullpath, const SSHAccountInfo& a
         try {
             conn->UnlinkFile(fullpath);
             promise.set_value(true);
-        } catch(clException& e) {
+        } catch (const clException& e) {
             clERROR() << "Rename() error." << e.What();
             promise.set_value(false);
         }
@@ -646,17 +663,17 @@ void clSFTPManager::OnTimer(wxTimerEvent& event)
 
     std::vector<clSFTP::Ptr_t> all_connections;
     size_t count = GetAllConnectionsPtr(all_connections);
-    if(count == 0) {
+    if (count == 0) {
         return;
     }
 
     // push SendKeepAlive() function for all the connections that we hold
-    for(auto conn : all_connections) {
+    for (auto conn : all_connections) {
         auto func = [conn]() {
             try {
                 conn->SendKeepAlive();
-            } catch(clException& e) {
-                clWARNING() << "failed to send keep-alive message for account:" << e.What() << endl;
+            } catch (const clException& e) {
+                clERROR() << "failed to send keep-alive message for account:" << e.What() << endl;
             }
         };
         m_q.push_back(std::move(func));
@@ -675,7 +692,7 @@ bool clSFTPManager::IsFileExists(const wxString& fullpath, const SSHAccountInfo&
         try {
             auto d = conn->Stat(fullpath);
             promise.set_value(d->IsFile());
-        } catch(clException& e) {
+        } catch (const clException& e) {
             clDEBUG() << "IsFileExists() error." << e.What();
             promise.set_value(false);
         }
@@ -696,7 +713,7 @@ bool clSFTPManager::IsDirExists(const wxString& fullpath, const SSHAccountInfo&
         try {
             auto d = conn->Stat(fullpath);
             promise.set_value(d->IsFolder());
-        } catch(clException& e) {
+        } catch (const clException& e) {
             clERROR() << "IsDirExists() error." << e.What();
             promise.set_value(false);
         }
@@ -709,14 +726,14 @@ wxFileName clSFTPManager::Download(const wxString& path, const wxString& account
 {
     clDEBUG() << "SFTP Manager: Download() called for" << path << endl;
     wxFileName local_file;
-    if(localFileName.empty()) {
+    if (localFileName.empty()) {
         local_file = wxFileName(clStandardPaths::Get().GetTempDir(), path.AfterLast('/'));
         local_file.AppendDir("sftp-downloads");
     } else {
         local_file = wxFileName(localFileName);
     }
     local_file.Mkdir(wxS_DIR_DEFAULT, wxPATH_MKDIR_FULL);
-    if(DoSyncDownload(path, local_file.GetFullPath(), accountName)) {
+    if (DoSyncDownload(path, local_file.GetFullPath(), accountName)) {
         return local_file;
     }
     return {};
@@ -727,7 +744,7 @@ void clSFTPManager::AsyncWriteFile(const wxString& content, const wxString& remo
 {
     clTempFile tmpfile;
     tmpfile.Persist(); // do not delete it on exit
-    if(!tmpfile.Write(content, wxConvUTF8)) {
+    if (!tmpfile.Write(content, wxConvUTF8)) {
         return;
     }
     AsyncSaveFile(tmpfile.GetFullPath(), remotePath, accountName, sink);
@@ -741,7 +758,7 @@ bool clSFTPManager::GetRemotePath(const wxString& local_path, const wxString& ac
     const auto& account_info = p.first;
     wxString download_folder = clSFTP::GetDefaultDownloadFolder(account_info);
     wxString rest;
-    if(local_path.StartsWith(download_folder, &rest)) {
+    if (local_path.StartsWith(download_folder, &rest)) {
         rest.Replace("\\", "/");
         remote_path.swap(rest);
         return true;
@@ -756,7 +773,7 @@ bool clSFTPManager::GetLocalPath(const wxString& remote_path, const wxString& ac
 
     const auto& account_info = p.first;
     wxFileName fn = clSFTP::GetLocalFileName(account_info, remote_path);
-    if(fn.IsOk()) {
+    if (fn.IsOk()) {
         local_path = fn.GetFullPath();
         return true;
     }
@@ -765,7 +782,7 @@ bool clSFTPManager::GetLocalPath(const wxString& remote_path, const wxString& ac
 
 void clSFTPManager::StopWorkerThread()
 {
-    if(m_worker_thread) {
+    if (m_worker_thread) {
         m_shutdown.store(true);
         m_worker_thread->join();
         wxDELETE(m_worker_thread);
@@ -775,15 +792,15 @@ void clSFTPManager::StopWorkerThread()
 
 void clSFTPManager::StartWorkerThread()
 {
-    if(m_worker_thread) {
+    if (m_worker_thread) {
         return;
     }
 
     m_worker_thread = new std::thread(
         [](SyncQueue<std::function<void()>>& Q, std::atomic_bool& shutdown) {
-            while(!shutdown.load()) {
+            while (!shutdown.load()) {
                 auto work_func = Q.pop_front();
-                if(work_func == nullptr) {
+                if (work_func == nullptr) {
                     continue;
                 }
                 work_func();
@@ -809,7 +826,7 @@ void clSFTPManager::OnSaveError(clCommandEvent& e)
 
 bool clSFTPManager::IsRemoteFile(const wxString& filepath, wxString* account, wxString* remote_path) const
 {
-    if(m_downloadedFileToAccount.count(filepath) == 0) {
+    if (m_downloadedFileToAccount.count(filepath) == 0) {
         return false;
     }
 
@@ -820,14 +837,14 @@ bool clSFTPManager::IsRemoteFile(const wxString& filepath, wxString* account, wx
 
 size_t clSFTPManager::GetAllConnectionsPtr(std::vector<clSFTP::Ptr_t>& connections) const
 {
-    if(m_connections.empty()) {
+    if (m_connections.empty()) {
         return 0;
     }
     connections.clear();
     connections.reserve(m_connections.size());
-    for(const auto& vt : m_connections) {
+    for (const auto& vt : m_connections) {
         auto conn = GetConnectionPtr(vt.first);
-        if(!conn) {
+        if (!conn) {
             continue;
         }
         connections.push_back(conn);
@@ -845,4 +862,162 @@ bool clSFTPManager::AwaitReadFile(const wxString& remotePath, const wxString& ac
     return DoSyncReadFile(remotePath, accountName, content);
 }
 
+#define QUEUE_ERROR_EVENT(msg)                                  \
+    {                                                           \
+        clSFTPEvent event_error{ wxEVT_SFTP_ASYNC_EXEC_ERROR }; \
+        event_error.SetString(msg);                             \
+        sink->AddPendingEvent(event_error);                     \
+    }
+
+ReadOutput_t clSFTPManager::AwaitExecute(const wxString& accountName, const wxString& command, const wxString& wd,
+                                         clEnvList_t* env)
+{
+    clDEBUG() << "SFTP Manager: AwaitExecute:" << command << "for account:" << accountName << endl;
+    auto conn = GetConnectionPtrAddIfMissing(accountName);
+    if (!conn) {
+        clWARNING() << "Failed to obtain connection for command:" << command << ". Account:" << accountName << endl;
+        return {};
+    }
+
+    std::promise<ReadOutput_t> exec_promise;
+    auto future = exec_promise.get_future();
+
+    auto exec_func = [command, wd, conn, env, accountName, &exec_promise]() {
+        // read the file content
+        auto session = conn->GetSsh()->GetSession();
+        auto channel = ssh_channel_new(conn->GetSsh()->GetSession());
+        if (!channel) {
+            clWARNING() << "Execution of command:" << command << "failed." << ssh_get_error(session) << endl;
+            exec_promise.set_value({});
+            return;
+        }
+
+        int rc = SSH_OK;
+        rc = ssh_channel_open_session(channel);
+        if (rc != SSH_OK) {
+            ssh_channel_free(channel);
+            clWARNING() << "Failed to open channel for command:" << command << "." << ssh_get_error(session) << endl;
+            exec_promise.set_value({});
+            return;
+        }
+
+        wxString cmd_w_dir;
+        if (!wd.empty()) {
+            cmd_w_dir << "cd " << StringUtils::WrapWithDoubleQuotes(wd) << " && " << command;
+        } else {
+            cmd_w_dir << command;
+        }
+        rc = ssh_channel_request_exec(channel, cmd_w_dir.mb_str(wxConvUTF8).data());
+        if (rc != SSH_OK) {
+            // mark the channel + ssh session as "broken"
+            ssh_channel_close(channel);
+            ssh_channel_free(channel);
+            clWARNING() << "Execution of command :" << cmd_w_dir << " failed." << ssh_get_error(session) << endl;
+            exec_promise.set_value({});
+            return;
+        }
+
+        std::tuple<std::string, std::string, int> result;
+        std::string std_out;
+        std::string std_err;
+        ssh::channel_read_all(channel, &std_err, true);
+        int exit_code = ssh::channel_read_all(channel, &std_out, false);
+
+        result = { std_out, std_err, exit_code };
+        exec_promise.set_value(std::move(result));
+
+        // release the channel
+        ssh_channel_close(channel);
+        ssh_channel_free(channel);
+    };
+    m_q.push_back(std::move(exec_func));
+    return future.get();
+}
+
+#define QUEUE_ERROR_EVENT(msg)                                  \
+    {                                                           \
+        clSFTPEvent event_error{ wxEVT_SFTP_ASYNC_EXEC_ERROR }; \
+        event_error.SetString(msg);                             \
+        sink->AddPendingEvent(event_error);                     \
+    }
+
+#define QUEUE_OUTPUT_EVENT(output, is_stdout)                                                            \
+    {                                                                                                    \
+        clSFTPEvent event_ok{ is_stdout ? wxEVT_SFTP_ASYNC_EXEC_STDOUT : wxEVT_SFTP_ASYNC_EXEC_STDERR }; \
+        event_ok.SetStringRaw(output);                                                                   \
+        sink->AddPendingEvent(event_ok);                                                                 \
+    }
+
+#define QUEUE_DONE_EVENT(exit_code)                           \
+    {                                                         \
+        clSFTPEvent event_done{ wxEVT_SFTP_ASYNC_EXEC_DONE }; \
+        event_done.SetInt(exit_code);                         \
+        sink->AddPendingEvent(event_done);                    \
+    }
+
+void clSFTPManager::AsyncExecute(wxEvtHandler* sink, const wxString& accountName, const wxString& command,
+                                 const wxString& wd, clEnvList_t* env)
+{
+    clDEBUG() << "SFTP Manager: AsyncExecute:" << command << "for account:" << accountName << endl;
+    auto conn = GetConnectionPtrAddIfMissing(accountName);
+    if (!conn) {
+        QUEUE_ERROR_EVENT(wxString() << "Failed to obtain connection for command:" << command
+                                     << ". Account:" << accountName);
+        return;
+    }
+
+    auto exec_func = [command, wd, conn, env, accountName, sink]() {
+        // read the file content
+        auto session = conn->GetSsh()->GetSession();
+        auto channel = ssh_channel_new(conn->GetSsh()->GetSession());
+        if (!channel) {
+            QUEUE_ERROR_EVENT(wxString() << "Execution of command:" << command << "failed." << ssh_get_error(session));
+            return;
+        }
+
+        int rc = SSH_OK;
+        rc = ssh_channel_open_session(channel);
+        if (rc != SSH_OK) {
+            ssh_channel_free(channel);
+            QUEUE_ERROR_EVENT(wxString() << "Failed to open channel for command:" << command << "."
+                                         << ssh_get_error(session));
+            return;
+        }
+
+        wxString cmd_w_dir;
+        if (!wd.empty()) {
+            cmd_w_dir << "cd " << StringUtils::WrapWithDoubleQuotes(wd) << " && " << command;
+        } else {
+            cmd_w_dir << command;
+        }
+
+        rc = ssh_channel_request_exec(channel, cmd_w_dir.mb_str(wxConvUTF8).data());
+        if (rc != SSH_OK) {
+            // mark the channel + ssh session as "broken"
+            ssh_channel_close(channel);
+            ssh_channel_free(channel);
+            QUEUE_ERROR_EVENT(wxString() << "Execution of command :" << cmd_w_dir << " failed."
+                                         << ssh_get_error(session));
+            return;
+        }
+
+        std::string std_out;
+        std::string std_err;
+        ssh::channel_read_all(channel, &std_err, true);
+        if (!std_err.empty()) {
+            QUEUE_OUTPUT_EVENT(std_err, false);
+        }
+        int exit_code = ssh::channel_read_all(channel, &std_out, false);
+        if (!std_out.empty()) {
+            QUEUE_OUTPUT_EVENT(std_out, true);
+        }
+
+        QUEUE_DONE_EVENT(exit_code);
+
+        // release the channel
+        ssh_channel_close(channel);
+        ssh_channel_free(channel);
+    };
+    m_q.push_back(std::move(exec_func));
+}
 #endif
