@@ -2,9 +2,12 @@
 #define CLSFTPMANAGER_HPP
 
 #if USE_SFTP
+#include "StdToWX.h"
+#include "StringUtils.h"
+#include "clResult.hpp"
 #include "cl_command_event.h"
-#include "cl_sftp.h"
 #include "codelite_exports.h"
+#include "ssh/cl_sftp.h"
 #include "sync_queue.h"
 
 #include <atomic>
@@ -21,6 +24,8 @@
 
 class IEditor;
 class SFTPClientData;
+
+typedef std::tuple<std::string, std::string, int> ReadOutput_t;
 class WXDLLIMPEXP_SDK clSFTPManager : public wxEvtHandler
 {
 protected:
@@ -66,6 +71,9 @@ protected:
     bool DoSyncSaveFile(const wxString& localPath, const wxString& remotePath, const wxString& accountName,
                         bool delete_local);
 
+    bool DoSyncSaveFileWithConn(clSFTP::Ptr_t conn, const wxString& localPath, const wxString& remotePath,
+                                bool delete_local);
+
 public:
     clSFTPManager();
     virtual ~clSFTPManager();
@@ -88,6 +96,12 @@ public:
      */
     bool AddConnection(const SSHAccountInfo& account, bool replace = false);
 
+    /**
+     * @brief add new connection to the manager. if a connection for this account already exists and 'replace' is set to
+     * true, replace it
+     */
+    bool AddConnection(const wxString& account_name, bool replace = false);
+
     /**
      * @brief open remote file in an editor and return a pointer to the editor
      * @param path file path on the remote machine
@@ -159,6 +173,15 @@ public:
      */
     bool AwaitWriteFile(const wxString& content, const wxString& remotePath, const wxString& accountName);
 
+    /**
+     * @brief write file content. this function is sync. This function uses the caller SFTP connection
+     * @param content of the file
+     * @param remotePath file path on the remote machine
+     * @param accountName the account name to use
+     * @return true on success or false
+     */
+    bool AwaitWriteFile(clSFTP::Ptr_t sftp, const wxString& content, const wxString& remotePath);
+
     /**
      * @brief delete a connection
      * if promptUser is set to true and any un-saved files belonged to the connection
@@ -171,7 +194,7 @@ public:
      * @param path
      * @return
      */
-    SFTPAttribute::List_t List(const wxString& path, const SSHAccountInfo& accountInfo);
+    clResult<SFTPAttribute::List_t, bool> List(const wxString& path, const SSHAccountInfo& accountInfo);
 
     /**
      * @brief create new file with a given path
@@ -227,9 +250,47 @@ public:
      * @brief clear last error captured
      */
     void ClearLastError() { m_lastError.clear(); }
+
+    /**
+     * @brief execute a remote command
+     * @returns `ReadOutput_t` is a pair: stdout, stderr
+     */
+    ReadOutput_t AwaitExecute(const wxString& accountName, const wxString& command, const wxString& wd,
+                              clEnvList_t* env = nullptr);
+    /**
+     * @brief execute a remote command
+     * @returns `ReadOutput_t` is a pair: stdout and stderr
+     */
+    ReadOutput_t AwaitExecute(const wxString& accountName, const std::vector<wxString>& command, const wxString& wd,
+                              clEnvList_t* env = nullptr)
+    {
+        const wxArrayString arr = StdToWX::ToArrayString(command);
+        return AwaitExecute(accountName, StringUtils::BuildCommandStringFromArray(arr), wd, env);
+    }
+
+    /**
+     * @brief execute a remote command
+     * @returns this function fires events to report its progress (`wxEVT_SFTP_ASYNC_EXEC_*`)
+     */
+    void AsyncExecute(wxEvtHandler* sink, const wxString& accountName, const wxString& command, const wxString& wd,
+                      clEnvList_t* env = nullptr);
+    /**
+     * @brief execute a remote command
+     * @returns this function fires events to report its progress (`wxEVT_SFTP_ASYNC_EXEC_*`)
+     */
+    void AsyncExecute(wxEvtHandler* sink, const wxString& accountName, const std::vector<wxString>& command,
+                      const wxString& wd, clEnvList_t* env = nullptr)
+    {
+        const wxArrayString arr = StdToWX::ToArrayString(command);
+        return AsyncExecute(sink, accountName, StringUtils::BuildCommandStringFromArray(arr), wd, env);
+    }
 };
 
 wxDECLARE_EXPORTED_EVENT(WXDLLIMPEXP_SDK, wxEVT_SFTP_ASYNC_SAVE_COMPLETED, clCommandEvent);
 wxDECLARE_EXPORTED_EVENT(WXDLLIMPEXP_SDK, wxEVT_SFTP_ASYNC_SAVE_ERROR, clCommandEvent);
+wxDECLARE_EXPORTED_EVENT(WXDLLIMPEXP_SDK, wxEVT_SFTP_ASYNC_EXEC_ERROR, clCommandEvent);
+wxDECLARE_EXPORTED_EVENT(WXDLLIMPEXP_SDK, wxEVT_SFTP_ASYNC_EXEC_STDOUT, clCommandEvent);
+wxDECLARE_EXPORTED_EVENT(WXDLLIMPEXP_SDK, wxEVT_SFTP_ASYNC_EXEC_STDERR, clCommandEvent);
+wxDECLARE_EXPORTED_EVENT(WXDLLIMPEXP_SDK, wxEVT_SFTP_ASYNC_EXEC_DONE, clCommandEvent);
 #endif
 #endif // CLSFTPMANAGER_HPP
