@@ -9,6 +9,12 @@
 #define TASKS _("Tasks")
 #define TRACE_TAB _("Trace")
 #define SHOW_USAGE _("References")
-#define CLANG_TAB _("Clang")
+#define TERMINAL_TAB _("Terminal")
+
+// Panes
+#define PANE_LEFT_SIDEBAR wxT("Workspace View")
+#define PANE_RIGHT_SIDEBAR wxT("Secondary Sidebar")
+#define PANE_DEBUGGER wxT("Debugger")
+#define PANE_OUTPUT wxT("Output View")
 
 #endif // CL_STRINGS_H
