@@ -1,16 +1,11 @@
 #include "clTabRenderer.h"
 
-#include "ColoursAndFontsManager.h"
-#include "Notebook.h"
 #include "clGenericNotebook.hpp"
 #include "clSystemSettings.h"
 #include "clTabRendererMinimal.hpp"
 #include "cl_config.h"
-#include "cl_defs.h"
 #include "editor_config.h"
 #include "globals.h"
-#include "macros.h"
-#include "wxStringHash.h"
 
 #include <wx/dcclient.h>
 #include <wx/dcmemory.h>
@@ -22,6 +17,8 @@
 #include "drawingutils.h"
 #endif
 
+#define TAB_FIXED_WIDTH() (m_tabCtrl ? (m_tabCtrl->IsFixedWidth() ? m_tabCtrl->GetLabelFixedWidth() : 0) : 0)
+
 namespace
 {
 void GetTabColours(const clTabColours& colours, size_t style, wxColour* activeTabBgColour, wxColour* bgColour)
@@ -40,28 +37,17 @@ clTabColours::clTabColours() { UpdateColours(0); }
 void clTabColours::UpdateColours(size_t notebookStyle)
 {
     wxUnusedVar(notebookStyle);
-#ifdef __WXMAC__
-    wxColour base_colour = clSystemSettings::GetDefaultPanelColour();
-    bool is_dark = DrawingUtils::IsDark(base_colour);
-
-    tabAreaColour = base_colour.ChangeLightness(80);
-    activeTabBgColour = base_colour; //.ChangeLightness(120);
-    activeTabTextColour = clSystemSettings::GetColour(wxSYS_COLOUR_BTNTEXT);
-    activeTabPenColour = activeTabBgColour.ChangeLightness(is_dark ? 30 : 70);
-    activeTabInnerPenColour = activeTabPenColour;
-
-    // inactive tab colours
-    inactiveTabTextColour = activeTabTextColour.ChangeLightness(is_dark ? 85 : 115);
-    inactiveTabBgColour = tabAreaColour;
-    inactiveTabPenColour = tabAreaColour.ChangeLightness(90);
-    inactiveTabInnerPenColour = inactiveTabBgColour;
-    markerColour = clConfig::Get().Read("ActiveTabMarkerColour", wxColour("#dc7633"));
-#else
     wxColour base_colour = clSystemSettings::GetDefaultPanelColour();
     bool is_dark = DrawingUtils::IsDark(base_colour);
 
     tabAreaColour = base_colour.ChangeLightness(is_dark ? 60 : 90);
+
+#ifdef __WXMAC__
+    activeTabBgColour = clSystemSettings::GetDefaultPanelColour();
+#else
     activeTabBgColour = base_colour.ChangeLightness(is_dark ? 107 : 100);
+#endif
+
     activeTabTextColour = clSystemSettings::GetColour(wxSYS_COLOUR_BTNTEXT);
     activeTabPenColour = base_colour;
     activeTabInnerPenColour = activeTabPenColour;
@@ -72,7 +58,6 @@ void clTabColours::UpdateColours(size_t notebookStyle)
     inactiveTabPenColour = tabAreaColour.ChangeLightness(90);
     inactiveTabInnerPenColour = inactiveTabBgColour;
     markerColour = clConfig::Get().Read("ActiveTabMarkerColour", wxColour("#dc7633"));
-#endif
 }
 
 bool clTabColours::IsDarkColours() const { return DrawingUtils::IsDark(activeTabBgColour); }
@@ -87,7 +72,7 @@ clTabInfo::clTabInfo(clTabCtrl* tabCtrl, size_t style, wxWindow* page, const wxS
     , m_xButtonState(eButtonState::kDisabled)
 {
     SetBestXButtonSize(tabCtrl);
-    CalculateOffsets(style);
+    CalculateOffsets(style, TAB_FIXED_WIDTH());
     CreateDisabledBitmap();
 }
 
@@ -111,16 +96,16 @@ clTabInfo::clTabInfo(clTabCtrl* tabCtrl)
     , m_xButtonState(eButtonState::kDisabled)
 {
     SetBestXButtonSize(tabCtrl);
-    CalculateOffsets(0);
+    CalculateOffsets(0, 0);
 }
 
-void clTabInfo::CalculateOffsets(size_t style, wxDC& dc)
+void clTabInfo::CalculateOffsets(size_t style, size_t max_width, wxDC& dc)
 {
     m_bmpCloseX = wxNOT_FOUND;
     m_bmpCloseY = wxNOT_FOUND;
 
-    int Y_spacer = m_tabCtrl ? m_tabCtrl->GetArt()->ySpacer : 10;
-    int X_spacer = m_tabCtrl ? m_tabCtrl->GetArt()->xSpacer : 10;
+    int Y_spacer = m_tabCtrl ? m_tabCtrl->GetArt()->ySpacer : DEFAULT_YSPACER;
+    int X_spacer = m_tabCtrl ? m_tabCtrl->GetArt()->xSpacer : DEFAULT_XSPACER;
     bool using_bold_font = m_tabCtrl ? m_tabCtrl->GetArt()->IsUseBoldFont() : false;
 
     wxDCFontChanger font_changer(dc);
@@ -145,7 +130,7 @@ void clTabInfo::CalculateOffsets(size_t style, wxDC& dc)
 
     // x button
     wxRect xrect;
-    if((style & kNotebook_CloseButtonOnActiveTab)) {
+    if ((style & kNotebook_CloseButtonOnActiveTab)) {
         xrect = wxRect(m_width, 0, X_BUTTON_SIZE, X_BUTTON_SIZE);
         m_bmpCloseX = xrect.GetX();
         m_bmpCloseY = 0; // we will fix this later
@@ -155,11 +140,13 @@ void clTabInfo::CalculateOffsets(size_t style, wxDC& dc)
     // Text
     m_textX = m_width;
     m_textY = ((m_height - sz.y) / 2);
-    m_width += sz.x;
-    m_textWidth = sz.x;
+
+    bool isFixedWidth = style & kNotebook_FixedWidth;
+    m_width += (isFixedWidth ? max_width : sz.x);
+    m_textWidth = (isFixedWidth ? max_width : sz.x);
     m_width += X_spacer;
 
-    if(HasBitmap()) {
+    if (HasBitmap()) {
         const wxBitmap& bmp = m_tabCtrl->GetBitmaps()->Get(m_bitmap, false);
         m_bmpX = m_width;
         m_width += bmp.GetScaledWidth();
@@ -172,18 +159,22 @@ void clTabInfo::CalculateOffsets(size_t style, wxDC& dc)
     m_rect.SetHeight(m_height);
 
     // If we got a X button, adjust its Y axis
-    if(!xrect.IsEmpty()) {
+    if (!xrect.IsEmpty()) {
         xrect = xrect.CenterIn(m_rect, wxVERTICAL);
         m_bmpCloseY = xrect.GetY();
     }
 }
 
-void clTabInfo::CalculateOffsets(size_t style)
+void clTabInfo::CalculateOffsets(size_t style, size_t max_width)
 {
-    if(m_tabCtrl) {
-        wxClientDC dc(m_tabCtrl);
+    if (m_tabCtrl) {
+        wxBitmap bmp{ 1, 1 };
+        wxMemoryDC memDC(bmp);
+        wxGCDC gcdc;
+        wxDC& dc = DrawingUtils::GetGCDC(memDC, gcdc);
+
         dc.SetFont(DrawingUtils::GetDefaultGuiFont());
-        CalculateOffsets(style, dc);
+        CalculateOffsets(style, max_width, dc);
     }
 }
 
@@ -191,20 +182,20 @@ void clTabInfo::SetBitmap(int bitmap, size_t style)
 {
     this->m_bitmap = bitmap;
     CreateDisabledBitmap();
-    CalculateOffsets(style);
+    CalculateOffsets(style, TAB_FIXED_WIDTH());
 }
 
 void clTabInfo::SetLabel(const wxString& label, size_t style)
 {
     this->m_label = label;
-    CalculateOffsets(style);
+    CalculateOffsets(style, TAB_FIXED_WIDTH());
 }
 
 void clTabInfo::SetActive(bool active, size_t style)
 {
     this->m_active = active;
     this->m_xButtonState = active ? eButtonState::kNormal : eButtonState::kDisabled;
-    CalculateOffsets(style);
+    CalculateOffsets(style, TAB_FIXED_WIDTH());
 }
 
 wxRect clTabInfo::GetCloseButtonRect() const
@@ -218,7 +209,7 @@ const wxString& clTabInfo::GetBestLabel(size_t style) const { return m_label; }
 
 const wxBitmap& clTabInfo::GetBitmap(int index, bool disabled) const
 {
-    if(!m_tabCtrl) {
+    if (!m_tabCtrl) {
         return wxNullBitmap;
     }
     return m_tabCtrl->GetBitmaps()->Get(index, disabled);
@@ -234,21 +225,15 @@ std::unordered_map<wxString, clTabRenderer*> clTabRenderer::ms_Renderes;
 
 clTabRenderer::clTabRenderer(const wxString& name, const wxWindow* parent)
     : bottomAreaHeight(0)
-    , majorCurveWidth(0)
-    , smallCurveWidth(0)
-    , overlapWidth(0)
-    , verticalOverlapWidth(0)
-    , ySpacer(5)
     , m_name(name)
 {
-    xSpacer = 10;
     ySpacer = EditorConfigST::Get()->GetOptions()->GetNotebookTabHeight() + 2;
 }
 
 wxFont clTabRenderer::GetTabFont(bool bold)
 {
     wxFont f = DrawingUtils::GetDefaultGuiFont();
-    if(bold) {
+    if (bold) {
         f.SetWeight(wxFONTWEIGHT_BOLD);
     }
     return f;
@@ -265,7 +250,7 @@ void clTabRenderer::ClearActiveTabExtraLine(clTabInfo::Ptr_t activeTab, wxDC& dc
 {
     wxPoint pt1, pt2;
     dc.SetPen(colours.activeTabPenColour);
-    if(style & kNotebook_BottomTabs) {
+    if (style & kNotebook_BottomTabs) {
         // bottom tabs
         dc.SetPen(colours.activeTabBgColour);
         pt1 = activeTab->GetRect().GetTopLeft();
@@ -303,14 +288,22 @@ void clTabRenderer::DrawButton(wxWindow* win, wxDC& dc, const clTabInfo& tabInfo
 
     wxColour text_colour = colours.activeTabTextColour;
     wxString unicode_symbol = wxT("\u2715");
-    if(tabInfo.IsModified()) {
+    if (tabInfo.IsModified()) {
         // instead of drawing the standard X we draw
         // a round circele marked in RED indicating that this
         // tab is modified
-        text_colour = colours.markerColour;
+        text_colour = *wxRED;
         unicode_symbol = wxT("\u25CF");
     }
 
+#if defined(__WXMAC__)
+    buttonRect.y -= 3;
+    buttonRect.height += 3;
+
+#elif defined(__WXMSW__)
+    buttonRect.y -= 1;
+#endif
+
     DrawingUtils::DrawButtonX(dc, win, buttonRect, text_colour,
                               tabInfo.IsActive() ? colours.activeTabBgColour : colours.inactiveTabBgColour, state,
                               unicode_symbol);
@@ -319,19 +312,21 @@ void clTabRenderer::DrawButton(wxWindow* win, wxDC& dc, const clTabInfo& tabInfo
 void clTabRenderer::DrawChevron(wxWindow* win, wxDC& dc, const wxRect& rect, const clTabColours& colours)
 {
     wxColour buttonColour;
-    if(DrawingUtils::IsDark(colours.tabAreaColour)) {
+    if (DrawingUtils::IsDark(colours.tabAreaColour)) {
         buttonColour = colours.tabAreaColour.ChangeLightness(150);
     } else {
         buttonColour = colours.tabAreaColour.ChangeLightness(50);
     }
-    DrawingUtils::DrawDropDownArrow(win, dc, rect, buttonColour);
+
+    int flags = wxCONTROL_NONE;
+    DrawingUtils::DrawDropDownArrow(win, dc, rect, flags, buttonColour);
 }
 
 int clTabRenderer::GetDefaultBitmapHeight(int Y_spacer)
 {
     int bmpHeight = 0;
     wxBitmap dummyBmp = clGetManager()->GetStdIcons()->LoadBitmap("cog");
-    if(dummyBmp.IsOk()) {
+    if (dummyBmp.IsOk()) {
         bmpHeight = dummyBmp.GetScaledHeight() + (2 * Y_spacer);
     }
     return bmpHeight;
@@ -339,7 +334,7 @@ int clTabRenderer::GetDefaultBitmapHeight(int Y_spacer)
 
 clTabRenderer::Ptr_t clTabRenderer::CreateRenderer(const wxWindow* win, size_t tabStyle)
 {
-    if(ms_Renderes.empty()) {
+    if (ms_Renderes.empty()) {
         RegisterRenderer(new clTabRendererMinimal(win));
     }
     clTabRenderer::Ptr_t renderer;
@@ -349,14 +344,14 @@ clTabRenderer::Ptr_t clTabRenderer::CreateRenderer(const wxWindow* win, size_t t
 
 wxArrayString clTabRenderer::GetRenderers()
 {
-    if(ms_Renderes.empty()) {
+    if (ms_Renderes.empty()) {
         RegisterRenderer(new clTabRendererMinimal(nullptr));
     }
 
     wxArrayString renderers;
     renderers.reserve(ms_Renderes.size());
 
-    for(auto vt : ms_Renderes) {
+    for (auto vt : ms_Renderes) {
         renderers.Add(vt.first);
     }
     renderers.Sort();
@@ -372,8 +367,8 @@ int clTabRenderer::GetMarkerWidth()
 #endif
 }
 
-wxColour clTabRenderer::DrawBackground(wxWindow* parent, wxDC& dc, const wxRect& clientRect,
-                                       const clTabColours& colours, size_t style)
+void clTabRenderer::DrawBackground(wxWindow* parent, wxDC& dc, const wxRect& clientRect, const clTabColours& colours,
+                                   size_t style)
 {
     wxUnusedVar(parent);
     wxUnusedVar(colours);
@@ -390,7 +385,7 @@ wxColour clTabRenderer::DrawBackground(wxWindow* parent, wxDC& dc, const wxRect&
     bool isBottom = style & kNotebook_BottomTabs;
 
     wxPoint p1, p2;
-    if(isBottom) {
+    if (isBottom) {
         p1 = clientRect.GetTopLeft();
         p2 = clientRect.GetTopRight();
     } else {
@@ -400,7 +395,6 @@ wxColour clTabRenderer::DrawBackground(wxWindow* parent, wxDC& dc, const wxRect&
     dc.SetPen(colours.inactiveTabPenColour);
     dc.DrawLine(p1, p2);
 #endif
-    return colours.tabAreaColour;
 }
 
 void clTabRenderer::FinaliseBackground(wxWindow* parent, wxDC& dc, const wxRect& clientRect,
@@ -409,15 +403,33 @@ void clTabRenderer::FinaliseBackground(wxWindow* parent, wxDC& dc, const wxRect&
     wxUnusedVar(parent);
     wxUnusedVar(activeTabRect);
 
-    // top tabs
+#if defined(__WXMAC__) || defined(__WXMSW__)
     wxColour bg_colour;
     wxColour active_tab_colour;
     GetTabColours(colours, style, &active_tab_colour, &bg_colour);
     bool is_dark = DrawingUtils::IsDark(bg_colour);
-    dc.SetPen(bg_colour.ChangeLightness(is_dark ? 60 : 80));
-    //dc.DrawLine(clientRect.GetTopRight(), clientRect.GetTopLeft());
-    //dc.DrawLine(clientRect.GetTopLeft(), clientRect.GetBottomLeft());
-    //dc.DrawLine(clientRect.GetTopRight(), clientRect.GetBottomRight());
+    dc.SetPen(is_dark ? *wxBLACK_PEN : wxPen(bg_colour.ChangeLightness(90)));
+    if (!(style & kNotebook_BottomTabs)) {
+        // draw black dark line from top left side to the right side
+        // of the notebook bar, skipping the active tab
+        wxPoint from, to;
+        from = clientRect.GetTopLeft();
+        to = activeTabRect.GetTopLeft();
+        to.x -= 1;
+
+        dc.DrawLine(from, to);
+
+        from = activeTabRect.GetTopRight();
+        from.x += 1;
+
+        to = clientRect.GetTopRight();
+
+        dc.DrawLine(from, to);
+
+        // Draw a black line at the bottom of the active tab
+        dc.DrawLine(activeTabRect.GetBottomLeft(), activeTabRect.GetBottomRight());
+    }
+#endif
 }
 
 void clTabRenderer::AdjustColours(clTabColours& colours, size_t style)
@@ -428,7 +440,7 @@ void clTabRenderer::AdjustColours(clTabColours& colours, size_t style)
 
 void clTabRenderer::DrawMarker(wxDC& dc, const clTabInfo& tabInfo, const clTabColours& colours, size_t style)
 {
-    if((style & kNotebook_UnderlineActiveTab) == 0) {
+    if ((style & kNotebook_UnderlineActiveTab) == 0) {
         return;
     }
 
@@ -445,9 +457,9 @@ void clTabRenderer::DrawMarker(wxDC& dc, const clTabInfo& tabInfo, const clTabCo
     bool isGTK3 = true;
     wxDirection direction;
     wxPoint p1, p2;
-    if(style & kNotebook_BottomTabs) {
+    if (style & kNotebook_BottomTabs) {
         // Bottom tabs
-        if(isGTK3) {
+        if (isGTK3) {
             direction = wxDOWN;
             p1 = tabInfo.GetRect().GetTopLeft();
             p2 = tabInfo.GetRect().GetTopRight();
@@ -462,7 +474,7 @@ void clTabRenderer::DrawMarker(wxDC& dc, const clTabInfo& tabInfo, const clTabCo
         DrawMarkerLine(dc, p1, p2, direction);
     } else {
         // Top tabs
-        if(isGTK3) {
+        if (isGTK3) {
             direction = wxUP;
             p1 = tabInfo.GetRect().GetBottomLeft();
             p2 = tabInfo.GetRect().GetBottomRight();
@@ -484,15 +496,15 @@ void clTabRenderer::DrawMarkerLine(wxDC& dc, const wxPoint& p1, const wxPoint& p
     const int width = GetMarkerWidth();
     wxPoint point1 = p1;
     wxPoint point2 = p2;
-    for(int i = 0; i < width; ++i) {
+    for (int i = 0; i < width; ++i) {
         dc.DrawLine(point1, point2);
-        if(direction == wxDOWN) {
+        if (direction == wxDOWN) {
             point1.y++;
             point2.y++;
-        } else if(direction == wxUP) {
+        } else if (direction == wxUP) {
             point1.y--;
             point2.y--;
-        } else if(direction == wxLEFT) {
+        } else if (direction == wxLEFT) {
             point1.x--;
             point2.x--;
         } else {
@@ -507,10 +519,10 @@ int clTabRenderer::GetXButtonSize() { return X_BUTTON_SIZE; }
 
 void clTabRenderer::RegisterRenderer(clTabRenderer* renderer)
 {
-    if(!renderer) {
+    if (!renderer) {
         return;
     }
-    if(ms_Renderes.count(renderer->GetName())) {
+    if (ms_Renderes.count(renderer->GetName())) {
         return;
     }
     ms_Renderes.insert({ renderer->GetName(), renderer });
@@ -518,7 +530,7 @@ void clTabRenderer::RegisterRenderer(clTabRenderer* renderer)
 
 clTabRenderer* clTabRenderer::Create(const wxWindow* parent, const wxString& name)
 {
-    if(ms_Renderes.count(name) == 0) {
+    if (ms_Renderes.count(name) == 0) {
         return nullptr;
     }
     return ms_Renderes.find(name)->second->New(parent);
