@@ -44,7 +44,7 @@ void clThemedChoice::ApplyTheme()
 {
 #if !wxUSE_NATIVE_CHOICE
     clColours colours;
-    colours.InitFromColour(clSystemSettings::GetDefaultPanelColour());
+    colours.InitDefaults();
     SetColours(colours);
 #endif
 }
