@@ -96,23 +96,29 @@ void clTreeCtrlModel::SelectItem(const wxTreeItemId& item, bool select_it, bool
         }
     }
 
-    // Fire an event only if the was no selection prior to this item
+    // Fire an event only if there was no selection prior to this item
     bool fire_event = (m_selectedItems.empty() && select_it);
 
     if(IsMultiSelection() && addSelection) {
         // If we are unselecting it, remove it from the array
-        clRowEntry::Vec_t::iterator iter =
-            std::find_if(m_selectedItems.begin(), m_selectedItems.end(), [&](clRowEntry* p) { return (p == child); });
-        if(iter != m_selectedItems.end() && !select_it) {
-            m_selectedItems.erase(iter);
+        if(!select_it) {
+            auto iter = std::find_if(m_selectedItems.begin(), m_selectedItems.end(),
+                                     [&](clRowEntry* p) { return (p == child); });
+            if(iter != m_selectedItems.end()) {
+                m_selectedItems.erase(iter);
+            }
         }
     } else {
+        // user might veto the "unselect" operation
         if(!ClearSelections(item != GetSingleSelection())) {
             return;
         }
     }
     child->SetSelected(select_it);
-    m_selectedItems.push_back(child);
+    if(select_it) {
+        m_selectedItems.push_back(child);
+    }
+
     if(fire_event) {
         wxTreeEvent evt(wxEVT_TREE_SEL_CHANGED);
         evt.SetEventObject(m_tree);
@@ -369,7 +375,7 @@ int clTreeCtrlModel::GetItemIndex(clRowEntry* item) const
 bool clTreeCtrlModel::GetRange(clRowEntry* from, clRowEntry* to, clRowEntry::Vec_t& items) const
 {
     items.clear();
-    if(from == nullptr || to == nullptr) {
+    if(from == nullptr && to == nullptr) {
         return false;
     }
     if(from == nullptr) {
@@ -457,21 +463,11 @@ clRowEntry* clTreeCtrlModel::GetNextSibling(clRowEntry* item) const
     if(children.empty()) {
         return nullptr;
     }
-    size_t where = -1;
-    for(size_t i = 0; i < children.size(); ++i) {
-        if(item == children[i]) {
-            where = i;
-            break;
-        }
-    }
-
     // if we couldnt find 'item' in the children list or if it's the last child
     // return nullptr
-    if((where == (size_t)-1) || (where == (children.size() - 1))) {
-        return nullptr;
-    }
-    ++where;
-    return children[where];
+    auto it = std::find(children.begin(), std::prev(children.end()), item);
+    ++it;
+    return it == children.end() ? nullptr : *it;
 }
 
 clRowEntry* clTreeCtrlModel::GetPrevSibling(clRowEntry* item) const
@@ -483,22 +479,11 @@ clRowEntry* clTreeCtrlModel::GetPrevSibling(clRowEntry* item) const
     if(children.empty()) {
         return nullptr;
     }
-    size_t where = -1;
-    for(size_t i = 0; i < children.size(); ++i) {
-        if(item == children[i]) {
-            where = i;
-            break;
-        }
-    }
-
     // if we couldnt find item in the children list or if it's the first child
     // we return nullptr
-    if((where == (size_t)-1) || (where == (size_t)0)) {
-        return nullptr;
-    }
-
-    --where;
-    return children[where];
+    auto rit = std::find(children.rbegin(), std::prev(children.rend()), item);
+    ++rit;
+    return rit == children.rend() ? nullptr : *rit;
 }
 
 void clTreeCtrlModel::AddSelection(const wxTreeItemId& item)
