@@ -33,10 +33,9 @@
 #include "clToolBar.h"
 #include "cl_command_event.h"
 #include "cl_config.h"
+#include "imanager.h"
 #include "wxcrafter_plugin.h"
 
-#include <imanager.h>
-
 class clTreeCtrlPanelDefaultPage;
 class WXDLLIMPEXP_SDK clTreeCtrlPanel : public clTreeCtrlPanelBase
 {
@@ -144,6 +143,11 @@ public:
      */
     void RefreshTree();
 
+    /**
+     * @brief refresh the selected nodes in the tree
+     */
+    void RefreshSelections();
+
 protected:
     void UpdateItemDeleted(const wxTreeItemId& item);
     void GetTopLevelFolders(wxArrayString& paths, wxArrayTreeItemIds& items) const;
