@@ -25,19 +25,14 @@
 
 #include "cl_aui_dock_art.h"
 
-#include "ColoursAndFontsManager.h"
 #include "clStatusBar.h"
 #include "clSystemSettings.h"
-#include "clTabRenderer.h"
 #include "cl_command_event.h"
-#include "cl_config.h"
-#include "codelite_events.h"
 #include "drawingutils.h"
 #include "event_notifier.h"
 #include "globals.h"
 #include "imanager.h"
 
-#include <editor_config.h>
 #include <wx/dcmemory.h>
 #include <wx/settings.h>
 #include <wx/xrc/xmlres.h>
@@ -49,8 +44,8 @@ bool IsRectOK(wxDC& dc, const wxRect& rect)
 {
     const wxSize dc_size = dc.GetSize();
 
-    if(0 > rect.x || 0 > rect.y || 0 >= rect.width || 0 >= rect.height || dc_size.GetWidth() < (rect.x + rect.width) ||
-       dc_size.GetHeight() < (rect.y + rect.height))
+    if (0 > rect.x || 0 > rect.y || 0 >= rect.width || 0 >= rect.height || dc_size.GetWidth() < (rect.x + rect.width) ||
+        dc_size.GetHeight() < (rect.y + rect.height))
         return (false);
     return (true);
 }
@@ -61,17 +56,17 @@ wxString wxAuiChopText(wxDC& dc, const wxString& text, int max_size)
 
     // first check if the text fits with no problems
     dc.GetTextExtent(text, &x, &y);
-    if(x <= max_size)
+    if (x <= max_size)
         return text;
 
     size_t i, len = text.Length();
     size_t last_good_length = 0;
-    for(i = 0; i < len; ++i) {
+    for (i = 0; i < len; ++i) {
         wxString s = text.Left(i);
         s += wxT("...");
 
         dc.GetTextExtent(s, &x, &y);
-        if(x > max_size)
+        if (x > max_size)
             break;
 
         last_good_length = i;
@@ -81,6 +76,28 @@ wxString wxAuiChopText(wxDC& dc, const wxString& text, int max_size)
     ret += wxT("...");
     return ret;
 }
+
+void Draw3DSash(wxDC& dc, const wxRect& rect, int orientation, const wxColour& bg, const wxColour& light_colour,
+                const wxColour& dark_colour)
+{
+    dc.SetPen(bg);
+    dc.SetBrush(bg);
+    dc.DrawRectangle(rect);
+
+    if (orientation == wxVERTICAL) {
+        dc.SetPen(dark_colour);
+        dc.DrawLine(rect.GetTopRight(), rect.GetBottomRight());
+
+        dc.SetPen(light_colour);
+        dc.DrawLine(rect.GetTopLeft(), rect.GetBottomLeft());
+    } else {
+        dc.SetPen(dark_colour);
+        dc.DrawLine(rect.GetBottomLeft(), rect.GetBottomRight());
+
+        dc.SetPen(light_colour);
+        dc.DrawLine(rect.GetTopLeft(), rect.GetTopRight());
+    }
+}
 } // namespace
 
 // ------------------------------------------------------------
@@ -105,22 +122,22 @@ void clAuiDockArt::DrawPaneButton(wxDC& dc, wxWindow* window, int button, int bu
 {
     wxRect buttonRect = _rect;
 
-    if(!IsRectOK(dc, _rect))
+    if (!IsRectOK(dc, _rect))
         return;
     // Make sure that the height and width of the button are equals
-    if(buttonRect.GetWidth() != buttonRect.GetHeight()) {
+    if (buttonRect.GetWidth() != buttonRect.GetHeight()) {
         buttonRect.SetHeight(wxMin(buttonRect.GetHeight(), buttonRect.GetWidth()));
         buttonRect.SetWidth(wxMin(buttonRect.GetHeight(), buttonRect.GetWidth()));
     } else {
         buttonRect.Deflate(1);
     }
-    if(buttonRect.GetHeight() < 2) {
+    if (buttonRect.GetHeight() < 2) {
         // A wx3.0.x build may arrive here with a 1*1 rect -> a sigabort in libcairo
         return;
     }
     buttonRect = buttonRect.CenterIn(_rect);
     eButtonState buttonState = eButtonState::kNormal;
-    switch(button_state) {
+    switch (button_state) {
     case wxAUI_BUTTON_STATE_HOVER:
         buttonState = eButtonState::kHover;
         break;
@@ -142,7 +159,7 @@ void clAuiDockArt::DrawPaneButton(wxDC& dc, wxWindow* window, int button, int bu
 #endif
 
     // Prepare the colours
-    switch(button) {
+    switch (button) {
     case wxAUI_BUTTON_CLOSE:
         DrawingUtils::DrawButtonX(dc, window, buttonRect, pen_colour, bg_colour, buttonState);
         break;
@@ -160,7 +177,7 @@ void clAuiDockArt::DrawPaneButton(wxDC& dc, wxWindow* window, int button, int bu
 void clAuiDockArt::DrawCaption(wxDC& dc, wxWindow* window, const wxString& text, const wxRect& rect,
                                wxAuiPaneInfo& pane)
 {
-    if(!IsRectOK(dc, rect))
+    if (!IsRectOK(dc, rect))
         return;
 
     wxRect tmpRect;
@@ -199,13 +216,13 @@ void clAuiDockArt::DrawCaption(wxDC& dc, wxWindow* window, const wxString& text,
     wxRect clip_rect = tmpRect;
     clip_rect.width -= 3; // text offset
     clip_rect.width -= 2; // button padding
-    if(pane.HasCloseButton()) {
+    if (pane.HasCloseButton()) {
         clip_rect.width -= m_buttonSize;
     }
-    if(pane.HasPinButton()) {
+    if (pane.HasPinButton()) {
         clip_rect.width -= m_buttonSize;
     }
-    if(pane.HasMaximizeButton()) {
+    if (pane.HasMaximizeButton()) {
         clip_rect.width -= m_buttonSize;
     }
 
@@ -237,11 +254,11 @@ void clAuiDockArt::DrawCaption(wxDC& dc, wxWindow* window, const wxString& text,
         wxRect clip_rect = tmpRect;
         clip_rect.width -= caption_offset; // text offset
         clip_rect.width -= 2;              // button padding
-        if(pane.HasCloseButton())
+        if (pane.HasCloseButton())
             clip_rect.width -= m_buttonSize;
-        if(pane.HasPinButton())
+        if (pane.HasPinButton())
             clip_rect.width -= m_buttonSize;
-        if(pane.HasMaximizeButton())
+        if (pane.HasMaximizeButton())
             clip_rect.width -= m_buttonSize;
 
         // Truncate the text if needed
@@ -295,12 +312,34 @@ void clAuiDockArt::DrawSash(wxDC& dc, wxWindow* window, int orientation, const w
 {
     wxUnusedVar(orientation);
     wxUnusedVar(window);
-#ifdef __WXMSW__
-    DrawingUtils::DrawStippleBackground(rect, dc);
-#else
-    dc.SetPen(m_bgColour);
-    dc.SetBrush(m_bgColour);
-    dc.DrawRectangle(rect);
+
+    bool isDark = clSystemSettings::IsDark();
+#if defined(__WXGTK__)
+    if (isDark) {
+        auto bg_colour = clSystemSettings::GetDefaultPanelColour().ChangeLightness(120);
+        auto light_col = bg_colour.ChangeLightness(50);
+        auto dark_col = bg_colour.ChangeLightness(50);
+        Draw3DSash(dc, rect, orientation, bg_colour, light_col, dark_col);
+
+    } else {
+        auto bg_colour = clSystemSettings::GetColour(wxSYS_COLOUR_3DFACE).ChangeLightness(110);
+        auto dark_col = bg_colour.ChangeLightness(50);
+        auto light_col = *wxWHITE;
+        Draw3DSash(dc, rect, orientation, bg_colour, light_col, dark_col);
+    }
+#elif defined(__WXMAC__) || defined(__WXMSW__)
+    if (isDark) {
+        auto bg_colour = clSystemSettings::GetDefaultPanelColour().ChangeLightness(110);
+        auto light_col = bg_colour.ChangeLightness(120);
+        auto dark_col = bg_colour.ChangeLightness(60);
+        Draw3DSash(dc, rect, orientation, bg_colour, light_col, dark_col);
+
+    } else {
+        auto dark_col = wxColour("LIGHT GREY");
+        auto light_col = wxColour("WHITE");
+        auto bg_colour = clSystemSettings::GetColour(wxSYS_COLOUR_3DFACE);
+        Draw3DSash(dc, rect, orientation, bg_colour, light_col, dark_col);
+    }
 #endif
 }
 
@@ -308,7 +347,7 @@ void clAuiDockArt::OnSettingsChanged(clCommandEvent& event)
 {
     event.Skip();
     m_bgColour = clSystemSettings::GetDefaultPanelColour();
-    if(DrawingUtils::IsDark(m_bgColour)) {
+    if (DrawingUtils::IsDark(m_bgColour)) {
         m_captionTextColour = wxColour(*wxWHITE).ChangeLightness(80);
     } else {
         m_captionTextColour = wxColour(*wxBLACK).ChangeLightness(120);
