@@ -34,6 +34,7 @@
 #include <wx/arrstr.h>
 #include <wx/bitmap.h>
 #include <wx/panel.h> // Base class: wxPanel
+#include <wx/stc/stc.h>
 
 class WXDLLIMPEXP_SDK clEditorTipWindow : public wxPanel
 {
@@ -55,10 +56,10 @@ protected:
     wxArrayString m_args;
     wxString m_footer; // the line that says  "1 of 2"
     wxString m_header; // The return value line
+    int m_lexerId = wxNOT_FOUND;
 
 protected:
     wxSize DoGetTipSize();
-    int DoGetTextLen(wxDC& dc, const wxString& txt);
     void DoAdjustPosition();
     void DoLayoutTip();
     /**
@@ -67,19 +68,18 @@ protected:
     void DoMakeMultipleLineTip();
 
 public:
-    clEditorTipWindow(wxWindow* parent);
+    explicit clEditorTipWindow(wxStyledTextCtrl* parent);
     virtual ~clEditorTipWindow();
 
     // API
     ///////////////////////////////////////////////////
     void AddCallTip(clCallTipPtr tip);
-    void SelectSignature(const wxString& signature);
     void Remove();
     clCallTipPtr GetTip();
     bool IsEmpty();
     void Clear();
     bool IsActive();
-    void Activate(wxPoint pt, int lineHeight, wxColour parentBgColour);
+    void Activate(wxPoint pt, int lineHeight, wxColour parentBgColour, int lexerId);
     void Deactivate();
     void SelectNext(int argIdxToHilight);
     void SelectPrev(int argIdxToHilight);
