@@ -28,11 +28,11 @@
 #include "editor_config.h"
 #include "globals.h"
 #include "serialized_object.h"
-#include "wx/ffile.h"
-#include "wx/filename.h"
-#include "wx_xml_compatibility.h"
 #include "xmlutils.h"
 
+#include <wx/ffile.h>
+#include <wx/filename.h>
+
 ConfigTool::ConfigTool()
     : m_fileName(wxEmptyString)
 {
