@@ -39,27 +39,24 @@
 const wxEventType wxEVT_CMD_NEW_DOCKPANE = XRCID("new_dockpane");
 const wxEventType wxEVT_CMD_DELETE_DOCKPANE = XRCID("delete_dockpane");
 
-BEGIN_EVENT_TABLE(DockablePane, wxPanel)
-EVT_ERASE_BACKGROUND(DockablePane::OnEraseBg)
-EVT_PAINT(DockablePane::OnPaint)
-END_EVENT_TABLE()
-
-DockablePane::DockablePane(wxWindow* parent, Notebook* book, const wxString& title, bool initialFloat, int bmp,
-                           wxSize size)
+DockablePane::DockablePane(wxWindow* parent, PaneId pane_id, const wxString& title, bool initialFloat,
+                           const wxSize& size)
     : wxPanel(parent, wxID_ANY, wxDefaultPosition, size, wxBORDER_NONE)
     , m_child(NULL)
-    , m_book(book)
     , m_text(title)
-    , m_bmp(bmp)
     , m_notifiedDestroyed(false)
+    , m_paneId(static_cast<int>(pane_id))
 {
+    Bind(wxEVT_ERASE_BACKGROUND, &DockablePane::OnEraseBg, this);
+    Bind(wxEVT_PAINT, &DockablePane::OnPaint, this);
+
     wxBoxSizer* sz = new wxBoxSizer(wxVERTICAL);
     SetSizer(sz);
 
     Connect(XRCID("close_pane"), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(DockablePane::ClosePane));
     wxAuiPaneInfo info;
     info.Name(title).Caption(title);
-    if(initialFloat) {
+    if (initialFloat) {
         info.Float();
     }
     clGetManager()->GetDockingManager()->AddPane(this, info);
@@ -70,22 +67,38 @@ DockablePane::DockablePane(wxWindow* parent, Notebook* book, const wxString& tit
     parent->GetEventHandler()->AddPendingEvent(event);
 }
 
-DockablePane::~DockablePane() {}
+DockablePane::~DockablePane()
+{
+    Unbind(wxEVT_ERASE_BACKGROUND, &DockablePane::OnEraseBg, this);
+    Unbind(wxEVT_PAINT, &DockablePane::OnPaint, this);
+}
 
 void DockablePane::ClosePane(wxCommandEvent& e)
 {
     wxUnusedVar(e);
 
-    if(!m_notifiedDestroyed) {
+    if (!m_notifiedDestroyed) {
         m_notifiedDestroyed = true;
 
-        if(m_book) {
+        if (m_paneId != wxNOT_FOUND) {
             // first detach the child from this pane
             wxSizer* sz = GetSizer();
             sz->Detach(m_child);
 
-            // now we can add it to the noteook (it will be automatically be reparented to the notebook)
-            m_book->AddPage(m_child, m_text, false, m_bmp);
+            // use the new API
+            switch (static_cast<PaneId>(m_paneId)) {
+            case PaneId::SIDE_BAR:
+                break;
+            case PaneId::BOTTOM_BAR:
+                clGetManager()->BookAddPage(PaneId::BOTTOM_BAR, m_child, m_text, wxEmptyString);
+                break;
+            case PaneId::DEBUG_BAR:
+                clGetManager()->BookAddPage(PaneId::DEBUG_BAR, m_child, m_text, wxEmptyString);
+                break;
+            case PaneId::SECONDARY_SIDE_BAR:
+                clGetManager()->BookAddPage(PaneId::SECONDARY_SIDE_BAR, m_child, m_text, wxEmptyString);
+                break;
+            }
         }
 
         wxCommandEvent event(wxEVT_CMD_DELETE_DOCKPANE);
@@ -109,7 +122,7 @@ void DockablePane::SetChildNoReparent(wxWindow* child)
 {
     m_child = child;
     wxSizer* sz = GetSizer();
-    if(!m_child->IsShown()) {
+    if (!m_child->IsShown()) {
         m_child->Show();
     }
     sz->Add(m_child, 1, wxEXPAND | wxALL, 0);
