@@ -24,17 +24,16 @@
 //////////////////////////////////////////////////////////////////////////////
 #include "environmentconfig.h"
 
-#include "evnvarlist.h"
-#include "file_logger.h"
+#include "archive.h"
+#include "envvarlist.h"
 #include "macromanager.h"
-#include "wx/filename.h"
-#include "wx/regex.h"
-#include "wx/utils.h"
-#include "wx_xml_compatibility.h"
 #include "xmlutils.h"
 
 #include <algorithm>
+#include <wx/filename.h>
 #include <wx/log.h>
+#include <wx/regex.h>
+#include <wx/utils.h>
 #include <wx/window.h>
 
 const wxString __NO_SUCH_ENV__ = wxT("__NO_SUCH_ENV__");
@@ -52,7 +51,7 @@ EnvironmentConfig::~EnvironmentConfig() {}
 
 EnvironmentConfig* EnvironmentConfig::Instance()
 {
-    if(ms_instance == 0) {
+    if (ms_instance == 0) {
         ms_instance = new EnvironmentConfig();
     }
     return ms_instance;
@@ -60,7 +59,7 @@ EnvironmentConfig* EnvironmentConfig::Instance()
 
 void EnvironmentConfig::Release()
 {
-    if(ms_instance) {
+    if (ms_instance) {
         delete ms_instance;
     }
     ms_instance = 0;
@@ -71,21 +70,21 @@ wxString EnvironmentConfig::GetRootName() { return wxT("EnvironmentVariables");
 bool EnvironmentConfig::Load()
 {
     bool loaded = ConfigurationToolBase::Load(wxT("config/environment_variables.xml"));
-    if(loaded) {
+    if (loaded) {
         // make sure that we are using the new format
         wxXmlNode* node = XmlUtils::FindFirstByTagName(m_doc.GetRoot(), wxT("ArchiveObject"));
-        if(node) {
+        if (node) {
             node = XmlUtils::FindFirstByTagName(node, wxT("StringMap"));
-            if(node) {
+            if (node) {
 
                 // this is an old version, convert it to the new format
-                EvnVarList vars;
+                EnvVarList vars;
                 wxStringMap_t envSets;
                 wxString content;
 
                 wxXmlNode* child = node->GetChildren();
-                while(child) {
-                    if(child->GetName() == wxT("MapEntry")) {
+                while (child) {
+                    if (child->GetName() == wxT("MapEntry")) {
                         wxString key = child->GetAttribute(wxT("Key"), wxT(""));
                         wxString val = child->GetAttribute(wxT("Value"), wxT(""));
                         content << key << wxT("=") << val << wxT("\n");
@@ -104,7 +103,7 @@ bool EnvironmentConfig::Load()
 wxString EnvironmentConfig::ExpandVariables(const wxString& in, bool applyEnvironment)
 {
     EnvSetter* env = NULL;
-    if(applyEnvironment) {
+    if (applyEnvironment) {
         env = new EnvSetter();
     }
     wxString expandedValue = DoExpandVariables(in);
@@ -123,12 +122,12 @@ void EnvironmentConfig::ApplyEnv(wxStringMap_t* overrideMap, const wxString& pro
     m_cs.Enter();
     ++m_envApplied;
 
-    if(m_envApplied > 1) {
+    if (m_envApplied > 1) {
         return;
     }
 
     // read the environments variables
-    EvnVarList vars;
+    EnvVarList vars;
     ReadObject(wxT("Variables"), &vars);
 
     // get the active environment variables set
@@ -136,22 +135,22 @@ void EnvironmentConfig::ApplyEnv(wxStringMap_t* overrideMap, const wxString& pro
 
     // if we have an "override map" place all the entries from the override map
     // into the global map before applying the environment
-    if(overrideMap) {
+    if (overrideMap) {
         wxStringMap_t::iterator it = overrideMap->begin();
-        for(; it != overrideMap->end(); it++) {
+        for (; it != overrideMap->end(); it++) {
             variables.Put(it->first, it->second);
         }
     }
 
     m_envSnapshot.clear();
-    for(size_t i = 0; i < variables.GetCount(); i++) {
+    for (size_t i = 0; i < variables.GetCount(); i++) {
 
         wxString key, val;
         variables.Get(i, key, val);
 
         // keep old value before changing it
         wxString oldVal(wxEmptyString);
-        if(wxGetEnv(key, &oldVal) == false) {
+        if (wxGetEnv(key, &oldVal) == false) {
             oldVal = __NO_SUCH_ENV__;
         }
 
@@ -161,7 +160,7 @@ void EnvironmentConfig::ApplyEnv(wxStringMap_t* overrideMap, const wxString& pro
         // PATH=$(PATH);\New\Path
         // PATH=$(PATH);\Another\New\Path
         // If we replace the value, PATH will contain the original PATH + \New\Path
-        if(m_envSnapshot.count(key) == 0) {
+        if (m_envSnapshot.count(key) == 0) {
             m_envSnapshot.insert(std::make_pair(key, oldVal));
         }
 
@@ -176,13 +175,13 @@ void EnvironmentConfig::ApplyEnv(wxStringMap_t* overrideMap, const wxString& pro
 void EnvironmentConfig::UnApplyEnv()
 {
     --m_envApplied;
-    if(m_envApplied == 0) {
+    if (m_envApplied == 0) {
         // loop over the old values and restore them
         wxStringMap_t::iterator iter = m_envSnapshot.begin();
-        for(; iter != m_envSnapshot.end(); iter++) {
+        for (; iter != m_envSnapshot.end(); iter++) {
             wxString key = iter->first;
             wxString value = iter->second;
-            if(value == __NO_SUCH_ENV__) {
+            if (value == __NO_SUCH_ENV__) {
                 // Remove the environment completely
                 ::wxUnsetEnv(key);
             } else {
@@ -195,14 +194,14 @@ void EnvironmentConfig::UnApplyEnv()
     m_cs.Leave();
 }
 
-EvnVarList EnvironmentConfig::GetSettings()
+EnvVarList EnvironmentConfig::GetSettings()
 {
-    EvnVarList vars;
+    EnvVarList vars;
     ReadObject(wxT("Variables"), &vars);
     return vars;
 }
 
-void EnvironmentConfig::SetSettings(EvnVarList& vars) { WriteObject(wxT("Variables"), &vars); }
+void EnvironmentConfig::SetSettings(EnvVarList& vars) { WriteObject(wxT("Variables"), &vars); }
 
 wxString EnvironmentConfig::DoExpandVariables(const wxString& in)
 {
@@ -212,10 +211,10 @@ wxString EnvironmentConfig::DoExpandVariables(const wxString& in)
     DollarEscaper de(result);
     wxStringMap_t unresolvedVars;
     int counter(0);
-    while(MacroManager::Instance()->FindVariable(result, varName, text)) {
+    while (MacroManager::Instance()->FindVariable(result, varName, text)) {
 
         wxString replacement;
-        if(varName == wxT("MAKE")) {
+        if (varName == wxT("MAKE")) {
             // ignore this variable, since it is probably was passed here
             // by the makefile generator
             replacement = wxT("___MAKE___");
@@ -223,14 +222,14 @@ wxString EnvironmentConfig::DoExpandVariables(const wxString& in)
         } else {
 
             // search for an environment with this name
-            if(!wxGetEnv(varName, &replacement)) {
+            if (!wxGetEnv(varName, &replacement)) {
                 replacement << "__unresolved__var__" << ++counter;
                 unresolvedVars.insert(std::make_pair(replacement, text));
             }
         }
 
         // dont allow recursive replacements
-        if(replacement.Contains(text)) {
+        if (replacement.Contains(text)) {
             break;
         }
         result.Replace(text, replacement);
@@ -248,13 +247,13 @@ wxString EnvironmentConfig::DoExpandVariables(const wxString& in)
 wxArrayString EnvironmentConfig::GetActiveSetEnvNames(bool includeWorkspace, const wxString& project)
 {
     // read the environments variables
-    EvnVarList vars;
+    EnvVarList vars;
     ReadObject(wxT("Variables"), &vars);
 
     wxArrayString envnames;
     // get the active environment variables set
     EnvMap variables = vars.GetVariables(wxEmptyString, includeWorkspace, project, wxEmptyString);
-    for(size_t i = 0; i < variables.GetCount(); ++i) {
+    for (size_t i = 0; i < variables.GetCount(); ++i) {
         wxString key, val;
         variables.Get(i, key, val);
         envnames.Add(key);
