@@ -26,10 +26,11 @@
 #define FILEPICKER_H
 
 #include "codelite_exports.h"
-#include "wx/button.h"
-#include "wx/filedlg.h"
-#include "wx/panel.h"
-#include "wx/textctrl.h"
+
+#include <wx/button.h>
+#include <wx/filedlg.h>
+#include <wx/panel.h>
+#include <wx/textctrl.h>
 
 /**
  * This control allows the user to select a directory. with a text control on its right side
