@@ -25,8 +25,10 @@
 #ifndef GLOBALS_H
 #define GLOBALS_H
 
+#include "Notebook.h"
 #include "codelite_exports.h"
 #include "fileextmanager.h"
+#include "imanager.h"
 #include "macros.h"
 #include "window_locker.h"
 #include "workspace.h"
@@ -74,13 +76,6 @@ public:
     bool IsEmpty() const { return m_bom.IsEmpty(); }
 };
 
-class WXDLLIMPEXP_SDK clEventDisabler
-{
-public:
-    clEventDisabler();
-    ~clEventDisabler();
-};
-
 /**
  * \brief send command event to the application (wxTheApp),
  * \param eventId
@@ -142,14 +137,6 @@ WXDLLIMPEXP_SDK long AppendListCtrlRow(wxListCtrl* list);
 WXDLLIMPEXP_SDK bool ReadFileWithConversion(const wxString& fileName, wxString& content,
                                             wxFontEncoding encoding = wxFONTENCODING_DEFAULT, BOM* bom = NULL);
 
-/**
- * \brief write file using UTF8 converter
- * \param fileName file path
- * \param content file's content
- * \return true on success, false otherwise
- */
-WXDLLIMPEXP_SDK bool WriteFileUTF8(const wxString& fileName, const wxString& content);
-
 /**
  * \brief compare a file with a wxString using md5
  * \param filePath file's full path
@@ -158,29 +145,10 @@ WXDLLIMPEXP_SDK bool WriteFileUTF8(const wxString& fileName, const wxString& con
  */
 WXDLLIMPEXP_SDK bool CompareFileWithString(const wxString& filePath, const wxString& str);
 
-/**
- * \brief delete directory using shell command
- * \param path directory path
- * \return true on success, false otherwise
- */
-WXDLLIMPEXP_SDK bool RemoveDirectory(const wxString& path);
-
 /**
  * \brief return true of id is a valid cpp identifier
  */
-WXDLLIMPEXP_SDK bool IsValidCppIndetifier(const wxString& id);
-
-/**
- * \brief return true of word is a C++ keyword
- * \param word
- * \return
- */
-WXDLLIMPEXP_SDK bool IsCppKeyword(const wxString& word);
-
-/**
- * \brief return true of id is a valid cpp file
- */
-WXDLLIMPEXP_SDK bool IsValidCppFile(const wxString& id);
+WXDLLIMPEXP_SDK bool IsValidCppIdentifier(const wxString& id);
 
 /**
  * [DEPRECATED] DONT USE THIS METHOD ANYMORE - USE IMacroManager
@@ -250,17 +218,7 @@ WXDLLIMPEXP_SDK bool IsFileReadOnly(const wxFileName& filename);
  * \param arr [out] the array to fill
  * \param str the string to split
  */
-WXDLLIMPEXP_SDK void FillFromSmiColonString(wxArrayString& arr, const wxString& str);
-
-/**
- * \brief return a string semi-colon separated of the given array
- */
-WXDLLIMPEXP_SDK wxString ArrayToSmiColonString(const wxArrayString& array);
-
-/**
- * \brief Remove all semi colons of the given string
- */
-WXDLLIMPEXP_SDK void StripSemiColons(wxString& str);
+WXDLLIMPEXP_SDK void FillFromSemiColonString(wxArrayString& arr, const wxString& str);
 
 /**
  * \brief Normalize the given path (change all \ by /)
@@ -285,7 +243,7 @@ WXDLLIMPEXP_SDK void WrapInShell(wxString& cmd);
 WXDLLIMPEXP_SDK wxString clGetUserName();
 
 /**
- * @brief return list of projects available based on the installed tempaltes
+ * @brief return list of projects available based on the installed templates
  * @param list list of projects
  * @param imageMap when provided, returns the image index (set in the lstImages) mapped to the project type
  */
@@ -409,12 +367,6 @@ WXDLLIMPEXP_SDK wxVariant MakeBitmapIndexText(const wxString& text, int imgIndex
  */
 WXDLLIMPEXP_SDK wxVariant MakeCheckboxVariant(const wxString& label, bool checked, int imgIndex);
 
-/**
- * @brief queue a call to a function to be executed on the next event loop
- */
-WXDLLIMPEXP_SDK void PostCall(wxObject* instance, clEventFunc_t func, wxClientData* arg);
-WXDLLIMPEXP_SDK void PostCall(wxObject* instance, clEventFunc_t func);
-
 /**
  * @brief split lines (using CR|LF as the separator), taking into considertaion line continuation
  * @param trim trim the lines with set to true
@@ -467,19 +419,6 @@ WXDLLIMPEXP_SDK wxStandardID PromptForYesNoDialogWithCheckbox(
  */
 WXDLLIMPEXP_SDK wxString& WrapWithQuotes(wxString& str);
 
-/**
- * @brief wrap string with quotes if needed
- */
-WXDLLIMPEXP_SDK wxString& EscapeSpaces(wxString& str);
-
-/**
- * @brief return an expression from a given position.
- * e.g. if the caret is on a line:
- * variable.m_name.m_value|
- * the | represents the cart, this function will return the entire expression: variable.m_name.m_value
- */
-WXDLLIMPEXP_SDK wxString GetCppExpressionFromPos(long pos, wxStyledTextCtrl* ctrl, bool forCC);
-
 /**
  * @brief save an xml document to file
  */
@@ -504,11 +443,6 @@ WXDLLIMPEXP_SDK bool clIsCygwinEnvironment();
  */
 WXDLLIMPEXP_SDK bool clIsMSYSEnvironment();
 
-/**
- * @brief change the command so it will run in the background
- */
-WXDLLIMPEXP_SDK wxString MakeCommandRunInBackground(const wxString& cmd);
-
 /**
  * @brief enable use of checkbox for boolean properties
  */
@@ -555,7 +489,7 @@ WXDLLIMPEXP_SDK void clStripTerminalColouring(const wxString& buffer, wxString&
 /**
  * @brief return true if the name is valid
  */
-WXDLLIMPEXP_SDK bool clIsVaidProjectName(const wxString& name);
+WXDLLIMPEXP_SDK bool clIsValidProjectName(const wxString& name);
 
 /**
  * @brief support for Hi-Res displays
@@ -588,7 +522,7 @@ WXDLLIMPEXP_SDK void clSetEditorFontEncoding(const wxString& encoding);
 
 /**
  * @brief locate an executable on the system using the PATH environment variable
- * @param name the exe name to locate (you can ommit the .exe on Windows, it will be added automatically)
+ * @param name the exe name to locate (you can omit the .exe on Windows, it will be added automatically)
  * @param exepath [output]
  * @param hint list of directories to search
  */
@@ -602,24 +536,7 @@ WXDLLIMPEXP_SDK bool clFindExecutable(const wxString& name, wxFileName& exepath,
 WXDLLIMPEXP_SDK int clFindMenuItemPosition(wxMenu* menu, int menuItemId);
 
 /**
- * @brief an efficient way to tokenize string into words (separated by SPACE and/or TAB)
- * @code
- * wxString str = "My String That Requires Tokenize";
- * wxString word; // The output
- * size_t offset = 0;
- * while(clNextWord(str, offset, word)) {
- *      // Do something with "word" here
- * }
- * @codeend
- * @param str the string to tokenize
- * @param offset used internally, allocate one on the stack and initialise it to 0
- * @param word [output]
- * @return true if a word was found
- */
-WXDLLIMPEXP_SDK bool clNextWord(const wxString& str, size_t& offset, wxString& word);
-
-/**
- * @brief join strings with "\n" or "\r\n" (depends on eol)
+ * @brief join strings with `\n` or `\r\n` (depends on eol)
  * eol can be wxSTC_EOL_CRLF, wxSTC_EOL_LF etc
  */
 WXDLLIMPEXP_SDK wxString clJoinLinesWithEOL(const wxArrayString& lines, int eol);
@@ -671,4 +588,37 @@ WXDLLIMPEXP_SDK bool clIsWaylandSession();
  */
 WXDLLIMPEXP_SDK bool clShowFileTypeSelectionDialog(wxWindow* parent, const wxArrayString& initial_selection,
                                                    wxArrayString* selected);
+
+/// Find the best window starting from `win` and give it the focus
+WXDLLIMPEXP_SDK bool SetBestFocus(wxWindow* win);
+
+/// Find Notebook parent of a `child`
+WXDLLIMPEXP_SDK Notebook* FindNotebookParentOf(wxWindow* child);
+
+/// Return true if `child` is a child (does not have to be a direct child) of `parent`
+WXDLLIMPEXP_SDK bool IsChildOf(wxWindow* child, wxWindow* parent);
+
+/// Return a random colour suited for the current theme
+WXDLLIMPEXP_SDK wxColour GetRandomColour();
+
+/// Join elements of a container into a string using `glue` as the elements separator
+/// `Container` any container that can be "range looped"
+template <typename Container>
+wxString clJoin(const Container& c, const wxString& glue = "\n")
+{
+    wxString output;
+    for (const auto& ele : c) {
+        output << ele << glue;
+    }
+
+    if (!output.empty()) {
+        output.RemoveLast(glue.length());
+    }
+    return output;
+}
+
+/// Return the selected text in a wxSTC. This function ensures that only
+/// visible text is returned (for example, if the selected text contains
+/// ANSI code style hidden - it will be dropped)
+WXDLLIMPEXP_SDK wxString clGetVisibleSelection(wxStyledTextCtrl* ctrl);
 #endif // GLOBALS_H
