@@ -24,24 +24,28 @@
 //////////////////////////////////////////////////////////////////////////////
 #include "lexer_configuration.h"
 
+#include "ConsoleLexer.hpp"
+#include "ExtraLexers.h"
 #include "FontUtils.hpp"
-#include "StringUtils.h"
-#include "bookmark_manager.h"
 #include "clSystemSettings.h"
 #include "cl_config.h"
 #include "drawingutils.h"
 #include "editor_config.h"
 #include "file_logger.h"
-#include "fileutils.h"
 #include "globals.h"
 #include "macros.h"
-#include "wx_xml_compatibility.h"
-#include "xmlutils.h"
 
 #include <algorithm>
 #include <wx/settings.h>
 #include <wx/stc/stc.h>
 #include <wx/utils.h>
+
+#if wxCHECK_VERSION(3, 3, 0)
+#define HAS_ILEXER 1
+#else
+#define HAS_ILEXER 0
+#endif
+
 namespace
 {
 /**
@@ -51,11 +55,11 @@ namespace
 void allocate_substyles(wxStyledTextCtrl* ctrl, int base_style, size_t num)
 {
     int count = ctrl->GetSubStylesLength(base_style);
-    if(count == 0) {
+    if (count == 0) {
         // allocate the maximum number of substyles that we may require
         int start_index = ctrl->AllocateSubStyles(base_style, num);
-        clDEBUG() << "Allocating" << num << "substyles" << endl;
-        clDEBUG() << "First substyle starting at:" << start_index << endl;
+        clDEBUG1() << "Allocating" << num << "substyles" << endl;
+        clDEBUG1() << "First substyle starting at:" << start_index << endl;
     }
 }
 } // namespace
@@ -71,7 +75,7 @@ wxFont LexerConf::GetFontForStyle(int styleId, const wxWindow* win) const
 {
     wxUnusedVar(win);
     const auto& prop = GetProperty(styleId);
-    if(prop.IsNull()) {
+    if (prop.IsNull()) {
         return FontUtils::GetDefaultMonospacedFont();
     }
     auto font = FontUtils::GetDefaultMonospacedFont();
@@ -96,12 +100,43 @@ wxColour to_wx_colour(const wxString& colour_as_string) { return wxColour(colour
 
 void LexerConf::Apply(wxStyledTextCtrl* ctrl, bool applyKeywords)
 {
-    ctrl->SetLexer(GetLexerId());
+    ConsoleLexerClientData* console_lexer = nullptr;
+#if HAS_ILEXER
+    // Apply the lexer
+    switch (GetLexerId()) {
+    case wxSTC_LEX_TERMINAL: {
+        // Allocate custom lexer
+        auto plexer = CreateExtraLexerTerminal();
+        ctrl->SetILexer(plexer);
+    } break;
+    default:
+        // Standard lexers
+        ctrl->SetLexer(GetLexerId());
+        break;
+    }
+#else
+    // Apply the lexer
+    switch (GetLexerId()) {
+    case wxSTC_LEX_TERMINAL:
+        // Use a container lexer and attach it to the control
+        ctrl->SetLexer(wxSTC_LEX_CONTAINER);
+        console_lexer = new ConsoleLexerClientData(ctrl);
+        ctrl->SetClientObject(console_lexer);
+        break;
+    default:
+        // Standard lexers
+        ctrl->SetLexer(GetLexerId());
+        break;
+    }
+#endif
+
     ctrl->StyleClearAll();
-#if wxCHECK_VERSION(3, 1, 0)
+    if (console_lexer) {
+        console_lexer->GetLexer().SetStyles();
+    }
+
     ctrl->FoldDisplayTextSetStyle(wxSTC_FOLDDISPLAYTEXT_BOXED);
     ctrl->SetIdleStyling(wxSTC_IDLESTYLING_TOVISIBLE);
-#endif
 
 #ifndef __WXMSW__
     ctrl->SetStyleBits(ctrl->GetStyleBitsNeeded());
@@ -119,7 +154,7 @@ void LexerConf::Apply(wxStyledTextCtrl* ctrl, bool applyKeywords)
     ctrl->SetBufferedDraw(false);
 #endif
 
-    if(IsSubstyleSupported()) {
+    if (IsSubstyleSupported()) {
         allocate_substyles(ctrl, GetSubStyleBase(), sizeof(m_wordSets) / sizeof(m_wordSets[0]));
     }
 
@@ -129,27 +164,38 @@ void LexerConf::Apply(wxStyledTextCtrl* ctrl, bool applyKeywords)
     ctrl->SetProperty(wxT("styling.within.preprocessor"), this->GetStyleWithinPreProcessor() ? "1" : "0");
 
     // turn off PP tracking/updating by default
-    if(GetName() == "c++") {
-        // ctrl->SetProperty(wxT("lexer.cpp.track.preprocessor"), "1");
-        // ctrl->SetProperty(wxT("lexer.cpp.update.preprocessor"), "1");
+    if (GetName() == "c++") {
+        ctrl->SetProperty(wxT("lexer.cpp.track.preprocessor"), "0");
+        ctrl->SetProperty(wxT("lexer.cpp.update.preprocessor"), "0");
     }
 
-    if(GetName() == "scss") {
+    if (GetName() == "scss") {
         // Enable SCSS property (will tell the lexer to search for variables)
         ctrl->SetProperty("lexer.css.scss.language", "1");
     }
 
+#if HAS_ILEXER
+    if (ctrl->GetLexer() == wxSTC_LEX_TERMINAL) {
+        ctrl->SetProperty("lexer.terminal.escape.sequences", "1");
+        ctrl->SetProperty("lexer.terminal.value.separate", "1");
+
+        // Hide escape sequence styles
+        ctrl->StyleSetVisible(wxSTC_TERMINAL_ESCSEQ, false);
+        ctrl->StyleSetVisible(wxSTC_TERMINAL_ESCSEQ_UNKNOWN, false);
+    }
+#endif
+
     // Find the default style
     wxFont defaultFont = FontUtils::GetDefaultMonospacedFont();
     bool foundDefaultStyle = false;
 
     StyleProperty defaultStyle;
-    for(const auto& prop : GetLexerProperties()) {
-        if(prop.GetId() == 0 && !prop.IsSubstyle()) {
+    for (const auto& prop : GetLexerProperties()) {
+        if (prop.GetId() == 0 && !prop.IsSubstyle()) {
             defaultStyle = prop;
             prop.FromAttributes(&defaultFont);
             foundDefaultStyle = true;
-            if(!defaultFont.IsOk()) {
+            if (!defaultFont.IsOk()) {
                 clWARNING() << "Found default font, but the font is NOT OK !?" << endl;
                 // make sure we have a font...
                 defaultFont = FontUtils::GetDefaultMonospacedFont();
@@ -160,24 +206,24 @@ void LexerConf::Apply(wxStyledTextCtrl* ctrl, bool applyKeywords)
 
     // Reset all colours to use the default style colour
     bool defaultFontOK = defaultFont.IsOk();
-    if(foundDefaultStyle) {
-        for(int i = 0; i < wxSTC_STYLE_MAX; ++i) {
+    if (foundDefaultStyle) {
+        for (int i = 0; i < wxSTC_STYLE_MAX; ++i) {
             ctrl->StyleSetBackground(i, defaultStyle.GetBgColour());
             ctrl->StyleSetForeground(i, defaultStyle.GetFgColour());
-            if(defaultFontOK) {
+            if (defaultFontOK) {
                 ctrl->StyleSetFont(i, defaultFont);
             }
         }
     } else {
         clSYSTEM() << "Could not found default font!" << endl;
     }
-    for(const auto& sp : GetLexerProperties()) {
+    for (const auto& sp : GetLexerProperties()) {
         // handle special cases
-        switch(sp.GetId()) {
+        switch (sp.GetId()) {
         case WHITE_SPACE_ATTR_ID: {
             // whitespace colour. We dont allow changing the background colour, only the foreground colour
             wxColour whitespaceColour = to_wx_colour(sp.GetFgColour());
-            if(whitespaceColour.IsOk()) {
+            if (whitespaceColour.IsOk()) {
                 ctrl->SetWhitespaceForeground(true, whitespaceColour);
             }
             break;
@@ -197,7 +243,7 @@ void LexerConf::Apply(wxStyledTextCtrl* ctrl, bool applyKeywords)
         case CARET_ATTR_ID: {
             // caret colour
             wxColour caretColour = to_wx_colour(sp.GetFgColour());
-            if(!caretColour.IsOk()) {
+            if (!caretColour.IsOk()) {
                 caretColour = *wxBLACK;
             }
             ctrl->SetCaretForeground(caretColour);
@@ -207,7 +253,7 @@ void LexerConf::Apply(wxStyledTextCtrl* ctrl, bool applyKeywords)
             wxFont font = defaultFont;
             sp.FromAttributes(&font);
 
-            if(sp.GetId() == 0) { // default
+            if (sp.GetId() == 0) { // default
                 ctrl->StyleSetFont(wxSTC_STYLE_DEFAULT, font);
                 ctrl->StyleSetForeground(wxSTC_STYLE_DEFAULT, sp.GetFgColour());
 
@@ -223,18 +269,23 @@ void LexerConf::Apply(wxStyledTextCtrl* ctrl, bool applyKeywords)
             } else {
 
                 int style_id = sp.GetId();
-                if(sp.IsSubstyle() && IsSubstyleSupported()) {
+                if (sp.IsSubstyle() && IsSubstyleSupported()) {
                     style_id = ctrl->GetSubStylesStart(GetSubStyleBase()) + sp.GetId();
                     LOG_IF_TRACE { clDEBUG1() << "* Found Substyle" << endl; }
-                    LOG_IF_TRACE { clDEBUG1() << "* Setting style:" << style_id << ". Is substyle?" << sp.IsSubstyle() << endl; }
+                    LOG_IF_TRACE
+                    {
+                        clDEBUG1() << "* Setting style:" << style_id << ". Is substyle?" << sp.IsSubstyle() << endl;
+                    }
                     LOG_IF_TRACE { clDEBUG1() << "* Parent style:" << sp.GetId() << endl; }
                 }
 
                 // always set the font
                 ctrl->StyleSetFont(style_id, font);
+                ctrl->StyleSetBold(style_id, sp.IsBold());
+                ctrl->StyleSetItalic(style_id, sp.GetItalic());
                 ctrl->StyleSetEOLFilled(style_id, sp.GetEolFilled());
 
-                if(style_id != LINE_NUMBERS_ATTR_ID) {
+                if (style_id != LINE_NUMBERS_ATTR_ID) {
                     // Inactive state is greater by 64 from its counterpart
                     wxColor inactiveColor = GetInactiveColor(sp);
                     ctrl->StyleSetForeground(style_id, to_wx_colour(sp.GetFgColour()));
@@ -250,24 +301,28 @@ void LexerConf::Apply(wxStyledTextCtrl* ctrl, bool applyKeywords)
         } // switch
     }
 
-    // set line number colours
-    wxColour bg_colour = ctrl->StyleGetBackground(0);
-    wxColour fg_colour = bg_colour;
-    if(IsDark()) {
-        fg_colour = bg_colour.ChangeLightness(140);
+    // Update the line numbers background colour based on the currently theme properties
+    auto& lineNumberProp = GetProperty(LINE_NUMBERS_ATTR_ID);
+    if (lineNumberProp.IsNull()) {
+        clSYSTEM() << "Could not locate line numbers property!" << endl;
     } else {
-        fg_colour = fg_colour.ChangeLightness(50);
+        wxColour line_number_text_colour = lineNumberProp.GetFgColour();
+        wxColour line_number_bg_colour = lineNumberProp.GetBgColour();
+        if (!line_number_text_colour.IsOk() || !line_number_bg_colour.IsOk()) {
+            clSYSTEM() << "Invalid colour!" << endl;
+        } else {
+            ctrl->StyleSetBackground(wxSTC_STYLE_LINENUMBER, line_number_bg_colour);
+            ctrl->StyleSetForeground(wxSTC_STYLE_LINENUMBER, line_number_text_colour);
+        }
     }
-    ctrl->StyleSetBackground(LINE_NUMBERS_ATTR_ID, bg_colour);
-    ctrl->StyleSetForeground(LINE_NUMBERS_ATTR_ID, fg_colour);
 
     // set the calltip font
-    if(!tooltip) {
+    if (!tooltip) {
         wxFont font = wxSystemSettings::GetFont(wxSYS_DEFAULT_GUI_FONT);
         ctrl->StyleSetFont(wxSTC_STYLE_CALLTIP, font);
     }
 
-    if(applyKeywords) {
+    if (applyKeywords) {
         ctrl->SetKeyWords(0, GetKeyWords(0));
         ctrl->SetKeyWords(1, GetKeyWords(1));
         ctrl->SetKeyWords(2, GetKeyWords(2));
@@ -275,17 +330,11 @@ void LexerConf::Apply(wxStyledTextCtrl* ctrl, bool applyKeywords)
         ctrl->SetKeyWords(4, GetKeyWords(4));
     }
 
-    // by default indicators are set to be opaque rounded box
-    bool is_dark = DrawingUtils::IsDark(defaultStyle.GetBgColour());
-    if(is_dark) {
-        ctrl->IndicatorSetStyle(1, wxSTC_INDIC_BOX);
-        ctrl->IndicatorSetStyle(2, wxSTC_INDIC_BOX);
-    } else {
-        ctrl->IndicatorSetStyle(1, wxSTC_INDIC_ROUNDBOX);
-        ctrl->IndicatorSetStyle(2, wxSTC_INDIC_ROUNDBOX);
-    }
+    ctrl->IndicatorSetStyle(1, wxSTC_INDIC_FULLBOX);
+    ctrl->IndicatorSetStyle(INDICATOR_WORD_HIGHLIGHT, wxSTC_INDIC_FULLBOX);
 
     wxColour default_bg_colour = defaultStyle.GetBgColour();
+    bool is_dark = DrawingUtils::IsDark(defaultStyle.GetBgColour());
     default_bg_colour = default_bg_colour.ChangeLightness(is_dark ? 105 : 95);
 
     ctrl->SetFoldMarginColour(true, default_bg_colour);
@@ -319,22 +368,29 @@ void LexerConf::Apply(wxStyledTextCtrl* ctrl, bool applyKeywords)
 
     // Overide TAB vs Space settings incase the file is a makefile
     // It is not an option for Makefile to use SPACES
-    if(GetName().Lower() == "makefile") {
+    if (GetName().Lower() == "makefile") {
         ctrl->SetUseTabs(true);
     }
     ctrl->SetLayoutCache(wxSTC_CACHE_PAGE);
 
     // caret width and blink
-    int caretWidth = clConfig::Get().Read("editor/caret_width", 2);
-    caretWidth = ::clGetSize(caretWidth, ctrl);
-    ctrl->SetCaretWidth(caretWidth);
+    ctrl->SetCaretWidth(options->GetCaretWidth());
     ctrl->SetCaretPeriod(options->GetCaretBlinkPeriod());
+
+    // Do not allow for "black" colour on dark theme and white colour on light theme
+    if (ctrl->GetLexer() == wxSTC_LEX_ERRORLIST || ctrl->GetLexer() == wxSTC_LEX_TERMINAL) {
+        if (IsDark()) {
+            ctrl->StyleSetForeground(wxSTC_ERR_ES_BLACK, ctrl->StyleGetForeground(wxSTC_ERR_ES_WHITE));
+        } else {
+            ctrl->StyleSetForeground(wxSTC_ERR_ES_WHITE, ctrl->StyleGetForeground(wxSTC_ERR_ES_BLACK));
+        }
+    }
 }
 
 const StyleProperty& LexerConf::GetProperty(int propertyId) const
 {
-    for(const auto& sp : m_properties) {
-        if(sp.GetId() == propertyId) {
+    for (const auto& sp : m_properties) {
+        if (sp.GetId() == propertyId) {
             return sp;
         }
     }
@@ -346,8 +402,8 @@ const StyleProperty& LexerConf::GetProperty(int propertyId) const
 
 StyleProperty& LexerConf::GetProperty(int propertyId)
 {
-    for(auto& sp : m_properties) {
-        if(sp.GetId() == propertyId) {
+    for (auto& sp : m_properties) {
+        if (sp.GetId() == propertyId) {
             return sp;
         }
     }
@@ -360,7 +416,7 @@ StyleProperty& LexerConf::GetProperty(int propertyId)
 bool LexerConf::IsDark() const
 {
     const StyleProperty& prop = GetProperty(0);
-    if(prop.IsNull()) {
+    if (prop.IsNull()) {
         return false;
     }
     return DrawingUtils::IsDark(prop.GetBgColour());
@@ -369,7 +425,7 @@ bool LexerConf::IsDark() const
 void LexerConf::SetDefaultFgColour(const wxColour& colour)
 {
     StyleProperty& style = GetProperty(0);
-    if(!style.IsNull()) {
+    if (!style.IsNull()) {
         style.SetFgColour(colour.GetAsString(wxC2S_HTML_SYNTAX));
     }
 }
@@ -377,7 +433,7 @@ void LexerConf::SetDefaultFgColour(const wxColour& colour)
 void LexerConf::SetLineNumbersFgColour(const wxColour& colour)
 {
     StyleProperty& style = GetProperty(LINE_NUMBERS_ATTR_ID);
-    if(!style.IsNull()) {
+    if (!style.IsNull()) {
         style.SetFgColour(colour.GetAsString(wxC2S_HTML_SYNTAX));
     }
 }
@@ -407,7 +463,7 @@ JSONItem LexerConf::ToJSON(bool forExport) const
     JSONItem properties = JSONItem::createArray("Properties");
     json.append(properties);
 
-    for(const auto& sp : GetLexerProperties()) {
+    for (const auto& sp : GetLexerProperties()) {
         properties.arrayAppend(sp.ToJSON(forExport));
     }
     return json;
@@ -415,42 +471,42 @@ JSONItem LexerConf::ToJSON(bool forExport) const
 
 void LexerConf::FromJSON(const JSONItem& json)
 {
-    auto word_set = json["WordSet"];
-    if(word_set.arraySize() == 4) {
+    auto M = json.GetAsMap();
+    auto word_set = M["WordSet"].GetAsVector();
+    if (word_set.size() == 4) {
         m_wordSets[WS_CLASS].from_json(word_set[0]);
         m_wordSets[WS_FUNCTIONS].from_json(word_set[1]);
         m_wordSets[WS_VARIABLES].from_json(word_set[2]);
         m_wordSets[WS_OTHERS].from_json(word_set[3]);
     }
 
-    m_name = json.namedObject("Name").toString();
-    m_lexerId = json.namedObject("Id").toInt();
-    m_themeName = json.namedObject("Theme").toString();
-    if(json.hasNamedObject("Flags")) {
-        m_flags = json.namedObject("Flags").toSize_t();
+    m_name = M["Name"].toString();
+    m_lexerId = M["Id"].toInt();
+    m_themeName = M["Theme"].toString();
+    if (M.count("Flags")) {
+        m_flags = M["Flags"].toSize_t();
     } else {
-        SetIsActive(json.namedObject("IsActive").toBool());
-        SetUseCustomTextSelectionFgColour(json.namedObject("UseCustomTextSelFgColour").toBool());
-        SetStyleWithinPreProcessor(json.namedObject("StylingWithinPreProcessor").toBool());
+        SetIsActive(M["IsActive"].toBool());
+        SetUseCustomTextSelectionFgColour(M["UseCustomTextSelFgColour"].toBool());
+        SetStyleWithinPreProcessor(M["StylingWithinPreProcessor"].toBool());
     }
 
-    SetKeyWords(json.namedObject("KeyWords0").toString(), 0);
-    SetKeyWords(json.namedObject("KeyWords1").toString(), 1);
-    SetKeyWords(json.namedObject("KeyWords2").toString(), 2);
-    SetKeyWords(json.namedObject("KeyWords3").toString(), 3);
-    SetKeyWords(json.namedObject("KeyWords4").toString(), 4);
-    SetFileSpec(json.namedObject("Extensions").toString());
-    SetSubstyleBase(json.namedObject("SubstyleBase").toInt(wxNOT_FOUND));
+    SetKeyWords(M["KeyWords0"].toString(), 0);
+    SetKeyWords(M["KeyWords1"].toString(), 1);
+    SetKeyWords(M["KeyWords2"].toString(), 2);
+    SetKeyWords(M["KeyWords3"].toString(), 3);
+    SetKeyWords(M["KeyWords4"].toString(), 4);
+    SetFileSpec(M["Extensions"].toString());
+    SetSubstyleBase(M["SubstyleBase"].toInt(wxNOT_FOUND));
 
     m_properties.clear();
-    JSONItem properties = json.namedObject("Properties");
-    int arrSize = properties.arraySize();
-    m_properties.reserve(arrSize);
+    auto properties = M["Properties"].GetAsVector();
+    m_properties.reserve(properties.size());
 
-    for(int i = 0; i < arrSize; ++i) {
+    for (const auto& prop_json : properties) {
         // Construct a style property
         StyleProperty p;
-        p.FromJSON(properties.arrayItem(i));
+        p.FromJSON(prop_json);
         m_properties.emplace_back(std::move(p));
     }
 }
@@ -471,7 +527,7 @@ void LexerConf::ApplySystemColours(wxStyledTextCtrl* ctrl)
     wxColour bg_colour = clSystemSettings::GetColour(wxSYS_COLOUR_LISTBOX);
 
     wxColour caret_colour;
-    if(!DrawingUtils::IsDark(bg_colour)) {
+    if (!DrawingUtils::IsDark(bg_colour)) {
         bg_colour = *wxWHITE;
         caret_colour = *wxBLACK;
     } else {
@@ -481,7 +537,7 @@ void LexerConf::ApplySystemColours(wxStyledTextCtrl* ctrl)
         caret_colour = *wxWHITE;
     }
 
-    for(int i = 0; i < wxSTC_STYLE_MAX; ++i) {
+    for (int i = 0; i < wxSTC_STYLE_MAX; ++i) {
         ctrl->StyleSetBackground(i, bg_colour);
         ctrl->StyleSetForeground(i, fg_colour);
     }
@@ -496,15 +552,34 @@ void LexerConf::ApplyWordSet(wxStyledTextCtrl* ctrl, eWordSetIndex index, const
     const WordSetIndex& word_set = m_wordSets[index];
     CHECK_COND_RET(word_set.is_ok());
 
-    if(word_set.is_substyle) {
+    if (word_set.is_substyle) {
         allocate_substyles(ctrl, GetSubStyleBase(), sizeof(m_wordSets) / sizeof(m_wordSets[0]));
 
         // index is 0 based, substyles are 1 based
         int substyle_index = ctrl->GetSubStylesStart(GetSubStyleBase()) + word_set.index;
-        LOG_IF_TRACE { clDEBUG1() << "Substyle calculated index is:" << substyle_index << endl; }
         ctrl->SetIdentifiers(substyle_index, keywords);
     } else {
         // default
         ctrl->SetKeyWords(word_set.index, keywords);
     }
 }
+
+void LexerConf::ApplyFont(wxWindow* cb)
+{
+    auto font = GetFontForStyle(0, cb);
+    auto curfont = cb->GetFont();
+    font.SetPointSize(curfont.GetPointSize());
+    cb->SetFont(font);
+}
+
+void LexerConf::SetProperty(const StyleProperty& prop)
+{
+    auto iter = std::find_if(
+        m_properties.begin(), m_properties.end(), [&](const StyleProperty& p) { return prop.GetId() == p.GetId(); });
+
+    if (iter != m_properties.end()) {
+        *iter = prop;
+    } else {
+        m_properties.push_back(prop);
+    }
+}
\ No newline at end of file
