@@ -27,7 +27,6 @@
 #include "cl_defs.h"
 #include "editor_config.h"
 #include "macros.h"
-#include "wx_xml_compatibility.h"
 #include "xmlutils.h"
 
 #include <wx/fontmap.h>
@@ -46,8 +45,8 @@ wxString SetDefaultBookmarkColours()
     // one
     const wxString arr[] = { "#FF0080", "#0000FF", "#FF0000", "#00FF00", "#FFFF00" };
     wxString output;
-    for(size_t n = 0; n < CL_N0_OF_BOOKMARK_TYPES; ++n) {
-        if(n < sizeof(arr) / sizeof(wxString)) {
+    for (size_t n = 0; n < CL_N0_OF_BOOKMARK_TYPES; ++n) {
+        if (n < sizeof(arr) / sizeof(wxString)) {
             output << arr[n] << ';';
         } else {
             output << "#FF0080" << ';';
@@ -58,22 +57,23 @@ wxString SetDefaultBookmarkColours()
 }
 
 OptionsConfig::OptionsConfig(wxXmlNode* node)
-    : m_displayFoldMargin(true)
+    : m_displayFoldMargin(false)
     , m_underlineFoldLine(false)
     , m_scrollBeyondLastLine(true)
-    , m_foldStyle("Flatten Tree Square Headers")
+    , m_foldStyle("Arrows")
     , m_displayBookmarkMargin(true)
     , m_bookmarkShape(wxT("Small Arrow"))
     , m_bookmarkBgColours(SetDefaultBookmarkColours())
     , m_bookmarkFgColours(SetDefaultBookmarkColours())
     , m_bookmarkLabels(defaultBookmarkLabels)
     , m_highlightCaretLine(true)
+    , m_highlightCaretLineWithColour(true)
     , m_clearHighlitWordsOnFind(true)
     , m_displayLineNumbers(true)
     , m_relativeLineNumbers(false)
     , m_showIndentationGuidelines(true)
     , m_caretLineColour(wxT("LIGHT BLUE"))
-    , m_indentUsesTabs(true)
+    , m_indentUsesTabs(false)
     , m_indentWidth(4)
     , m_tabWidth(4)
     , m_iconsSize(16)
@@ -83,7 +83,7 @@ OptionsConfig::OptionsConfig(wxXmlNode* node)
     , m_foldPreprocessor(false)
     , m_highlightMatchedBraces(true)
     , m_foldBgColour(wxColour(240, 240, 240))
-    , m_autoAdjustHScrollBarWidth(false)
+    , m_autoAdjustHScrollBarWidth(true)
     , m_caretWidth(2)
     , m_caretBlinkPeriod(500)
     , m_copyLineEmptySelection(true)
@@ -121,10 +121,10 @@ OptionsConfig::OptionsConfig(wxXmlNode* node)
     , m_preferredLocale(wxT("en_US"))
     , m_useLocale(0)
     , m_trimOnlyModifiedLines(true)
-    , m_workspaceTabsDirection(wxUP)
+    , m_workspaceTabsDirection(wxLEFT)
     , m_outputTabsDirection(wxUP)
     , m_indentedComments(false)
-    , m_nbTabHeight(nbTabHt_Medium)
+    , m_nbTabHeight(nbTabHt_Short)
     , m_webSearchPrefix(wxT("https://www.google.com/search?q="))
     , m_smartParen(true)
 {
@@ -132,12 +132,13 @@ OptionsConfig::OptionsConfig(wxXmlNode* node)
     m_options.set(Opt_NavKey_Shift);
     m_options.set(Opt_FoldHighlightActiveBlock);
     m_options.set(Opt_TabStyleMinimal);
+    m_options.set(Opt_HideDockingWindowCaption);
 
     m_debuggerMarkerLine = DrawingUtils::LightColour("LIME GREEN", 8.0);
     m_mswTheme = false;
     // set the default font name to be wxFONTENCODING_UTF8
     SetFileFontEncoding(wxFontMapper::GetEncodingName(wxFONTENCODING_UTF8));
-    if(node) {
+    if (node) {
         SetFileFontEncoding(
             XmlUtils::ReadString(node, wxT("FileFontEncoding"), wxFontMapper::GetEncodingName(wxFONTENCODING_UTF8)));
 
@@ -152,6 +153,8 @@ OptionsConfig::OptionsConfig(wxXmlNode* node)
         m_bookmarkLabels = XmlUtils::ReadString(node, wxT("BookmarkLabels"), defaultBookmarkLabels);
         m_clearHighlitWordsOnFind = XmlUtils::ReadBool(node, wxT("ClearHighlitWordsOnFind"), m_clearHighlitWordsOnFind);
         m_highlightCaretLine = XmlUtils::ReadBool(node, wxT("HighlightCaretLine"), m_highlightCaretLine);
+        m_highlightCaretLineWithColour =
+            XmlUtils::ReadBool(node, "HighlightCaretLineWithColour", m_highlightCaretLineWithColour);
         m_displayLineNumbers = XmlUtils::ReadBool(node, wxT("ShowLineNumber"), m_displayLineNumbers);
         m_relativeLineNumbers = XmlUtils::ReadBool(node, wxT("RelativeLineNumber"), m_relativeLineNumbers);
         m_lineNumberHighlightCurrent =
@@ -203,8 +206,8 @@ OptionsConfig::OptionsConfig(wxXmlNode* node)
         m_disableSemicolonShift = XmlUtils::ReadBool(node, wxT("DisableSemicolonShift"), m_disableSemicolonShift);
         m_caretLineAlpha = XmlUtils::ReadLong(node, wxT("CaretLineAlpha"), m_caretLineAlpha);
         m_dontAutoFoldResults = XmlUtils::ReadBool(node, wxT("DontAutoFoldResults"), m_dontAutoFoldResults);
-        m_dontOverrideSearchStringWithSelection = XmlUtils::ReadBool(node, wxT("DontOverrideSearchStringWithSelection"),
-                                                                     m_dontOverrideSearchStringWithSelection);
+        m_dontOverrideSearchStringWithSelection = XmlUtils::ReadBool(
+            node, wxT("DontOverrideSearchStringWithSelection"), m_dontOverrideSearchStringWithSelection);
         m_showDebugOnRun = XmlUtils::ReadBool(node, wxT("ShowDebugOnRun"), m_showDebugOnRun);
         m_caretUseCamelCase = XmlUtils::ReadBool(node, wxT("m_caretUseCamelCase"), m_caretUseCamelCase);
         m_wordWrap = XmlUtils::ReadBool(node, wxT("m_wordWrap"), m_wordWrap);
@@ -216,11 +219,11 @@ OptionsConfig::OptionsConfig(wxXmlNode* node)
         m_trimOnlyModifiedLines = XmlUtils::ReadBool(node, wxT("m_trimOnlyModifiedLines"), m_trimOnlyModifiedLines);
 
         wxString options;
-        if(XmlUtils::ReadStringIfExists(node, "options_bits", options)) {
+        if (XmlUtils::ReadStringIfExists(node, "options_bits", options)) {
             m_options.from_string(options);
         }
-        m_debuggerMarkerLine = XmlUtils::ReadString(node, wxT("m_debuggerMarkerLine"),
-                                                    m_debuggerMarkerLine.GetAsString(wxC2S_HTML_SYNTAX));
+        m_debuggerMarkerLine = XmlUtils::ReadString(
+            node, wxT("m_debuggerMarkerLine"), m_debuggerMarkerLine.GetAsString(wxC2S_HTML_SYNTAX));
         m_indentedComments = XmlUtils::ReadBool(node, wxT("IndentedComments"), m_indentedComments);
 
         // These hacks will likely be changed in the future. If so, we'll be able to remove the #include
@@ -237,27 +240,18 @@ OptionsConfig::OptionsConfig(wxXmlNode* node)
         m_outputTabsDirection =
             (wxDirection)XmlUtils::ReadLong(node, "OutputTabsDirection", (int)m_outputTabsDirection);
         m_workspaceTabsDirection =
-            (wxDirection)XmlUtils::ReadLong(node, "WorkspaceTabsDirection", (int)m_workspaceTabsDirection);
-#ifdef __WXOSX__
-        if(m_workspaceTabsDirection == wxLEFT) {
-            m_workspaceTabsDirection = wxTOP;
-        }
-        if(m_workspaceTabsDirection == wxRIGHT) {
-            m_workspaceTabsDirection = wxBOTTOM;
-        }
-#endif
-
+            (wxDirection)XmlUtils::ReadLong(node, "SidebarButtonsPosition", (int)m_workspaceTabsDirection);
         m_webSearchPrefix = XmlUtils::ReadString(node, wxT("m_webSearchPrefix"), m_webSearchPrefix);
     }
 
     // Transitional calls. These checks are relevant for 2 years i.e. until the beginning of 2016
-    if(m_bookmarkFgColours.empty()) {
+    if (m_bookmarkFgColours.empty()) {
         // This must be the first time with multiple BMs, so rescue any old user-set value
         m_bookmarkFgColours = SetDefaultBookmarkColours();
         wxString oldcolour = XmlUtils::ReadString(node, "BookmarkFgColour", "#FF0080");
         SetBookmarkFgColour(oldcolour, 0);
     }
-    if(m_bookmarkBgColours.empty()) {
+    if (m_bookmarkBgColours.empty()) {
         m_bookmarkBgColours = SetDefaultBookmarkColours();
         wxString oldcolour = XmlUtils::ReadString(node, "BookmarkBgColour", "#FF0080");
         SetBookmarkBgColour(oldcolour, 0);
@@ -279,6 +273,7 @@ wxXmlNode* OptionsConfig::ToXml() const
     n->AddAttribute(wxT("BookmarkLabels"), m_bookmarkLabels);
     n->AddAttribute(wxT("ClearHighlitWordsOnFind"), BoolToString(m_clearHighlitWordsOnFind));
     n->AddAttribute(wxT("HighlightCaretLine"), BoolToString(m_highlightCaretLine));
+    n->AddAttribute(wxT("HighlightCaretLineWithColour"), BoolToString(m_highlightCaretLineWithColour));
     n->AddAttribute(wxT("ShowLineNumber"), BoolToString(m_displayLineNumbers));
     n->AddAttribute(wxT("RelativeLineNumber"), BoolToString(m_relativeLineNumbers));
     n->AddAttribute(wxT("LineNumbersHighlightCurrent"), BoolToString(m_lineNumberHighlightCurrent));
@@ -328,7 +323,7 @@ wxXmlNode* OptionsConfig::ToXml() const
     n->AddAttribute(wxT("m_trimOnlyModifiedLines"), BoolToString(m_trimOnlyModifiedLines));
     n->AddAttribute(wxT("m_debuggerMarkerLine"), m_debuggerMarkerLine.GetAsString(wxC2S_HTML_SYNTAX));
     n->AddAttribute(wxT("OutputTabsDirection"), wxString() << (int)m_outputTabsDirection);
-    n->AddAttribute(wxT("WorkspaceTabsDirection"), wxString() << (int)m_workspaceTabsDirection);
+    n->AddAttribute(wxT("SidebarButtonsPosition"), wxString() << (int)m_workspaceTabsDirection);
     n->AddAttribute(wxT("IndentedComments"), BoolToString(m_indentedComments));
     n->AddAttribute(wxT("CopyLineEmptySelection"), BoolToString(m_copyLineEmptySelection));
     n->AddAttribute(wxT("SmartParen"), BoolToString(m_smartParen));
@@ -376,20 +371,20 @@ void OptionsConfig::SetFileFontEncoding(const wxString& strFileFontEncoding)
 {
     this->m_fileFontEncoding = wxFontMapper::Get()->CharsetToEncoding(strFileFontEncoding, false);
 
-    if(wxFONTENCODING_SYSTEM == this->m_fileFontEncoding) {
+    if (wxFONTENCODING_SYSTEM == this->m_fileFontEncoding) {
         this->m_fileFontEncoding = wxFONTENCODING_UTF8;
     }
 }
 
 wxString OptionsConfig::GetEOLAsString() const
 {
-    if(GetEolMode() == wxT("Unix (LF)")) {
+    if (GetEolMode() == wxT("Unix (LF)")) {
         return "\n";
 
-    } else if(GetEolMode() == wxT("Mac (CR)")) {
+    } else if (GetEolMode() == wxT("Mac (CR)")) {
         return "\r";
 
-    } else if(GetEolMode() == wxT("Windows (CRLF)")) {
+    } else if (GetEolMode() == wxT("Windows (CRLF)")) {
         return "\r\n";
 
     } else {
@@ -401,7 +396,7 @@ wxColour OptionsConfig::GetBookmarkFgColour(size_t index) const
 {
     wxColour col;
     wxArrayString arr = wxSplit(m_bookmarkFgColours, ';');
-    if(index < arr.GetCount()) {
+    if (index < arr.GetCount()) {
         return wxColour(arr.Item(index));
     }
 
@@ -411,7 +406,7 @@ wxColour OptionsConfig::GetBookmarkFgColour(size_t index) const
 void OptionsConfig::SetBookmarkFgColour(wxColour c, size_t index)
 {
     wxArrayString arr = wxSplit(m_bookmarkFgColours, ';');
-    if(index < arr.GetCount()) {
+    if (index < arr.GetCount()) {
         arr.Item(index) = c.GetAsString(wxC2S_HTML_SYNTAX);
         m_bookmarkFgColours = wxJoin(arr, ';');
     }
@@ -421,7 +416,7 @@ wxColour OptionsConfig::GetBookmarkBgColour(size_t index) const
 {
     wxColour col;
     wxArrayString arr = wxSplit(m_bookmarkBgColours, ';');
-    if(index < arr.GetCount()) {
+    if (index < arr.GetCount()) {
         return wxColour(arr.Item(index));
     }
 
@@ -431,7 +426,7 @@ wxColour OptionsConfig::GetBookmarkBgColour(size_t index) const
 void OptionsConfig::SetBookmarkBgColour(wxColour c, size_t index)
 {
     wxArrayString arr = wxSplit(m_bookmarkBgColours, ';');
-    if(index < arr.GetCount()) {
+    if (index < arr.GetCount()) {
         arr.Item(index) = c.GetAsString(wxC2S_HTML_SYNTAX);
         m_bookmarkBgColours = wxJoin(arr, ';');
     }
@@ -440,7 +435,7 @@ void OptionsConfig::SetBookmarkBgColour(wxColour c, size_t index)
 wxString OptionsConfig::GetBookmarkLabel(size_t index) const
 {
     wxArrayString arr = wxSplit(m_bookmarkLabels, ';');
-    if(index < arr.GetCount()) {
+    if (index < arr.GetCount()) {
         return arr.Item(index);
     }
 
@@ -450,7 +445,7 @@ wxString OptionsConfig::GetBookmarkLabel(size_t index) const
 void OptionsConfig::SetBookmarkLabel(const wxString& label, size_t index)
 {
     wxArrayString arr = wxSplit(m_bookmarkLabels, ';');
-    if(index < arr.GetCount()) {
+    if (index < arr.GetCount()) {
         arr.Item(index) = label;
         m_bookmarkLabels = wxJoin(arr, ';');
     }
@@ -458,53 +453,37 @@ void OptionsConfig::SetBookmarkLabel(const wxString& label, size_t index)
 
 void OptionsConfig::UpdateFromEditorConfig(const clEditorConfigSection& section)
 {
-    if(section.IsInsertFinalNewlineSet()) {
+    if (section.IsInsertFinalNewlineSet()) {
         this->SetAppendLF(section.IsInsertFinalNewline());
     }
-    if(section.IsSetEndOfLineSet()) {
+    if (section.IsSetEndOfLineSet()) {
         // Convert .editorconfig to CodeLite strings
         wxString eolMode = "Unix (LF)"; // default
-        if(section.GetEndOfLine() == "crlf") {
+        if (section.GetEndOfLine() == "crlf") {
             eolMode = "Windows (CRLF)";
-        } else if(section.GetEndOfLine() == "cr") {
+        } else if (section.GetEndOfLine() == "cr") {
             eolMode = "Mac (CR)";
         }
         this->SetEolMode(eolMode);
     }
-    if(section.IsTabWidthSet()) {
+    if (section.IsTabWidthSet()) {
         this->SetTabWidth(section.GetTabWidth());
     }
-    if(section.IsIndentStyleSet()) {
+    if (section.IsIndentStyleSet()) {
         this->SetIndentUsesTabs(section.GetIndentStyle() == "tab");
     }
-    if(section.IsTabWidthSet()) {
+    if (section.IsTabWidthSet()) {
         this->SetTabWidth(section.GetTabWidth());
     }
-    if(section.IsIndentSizeSet()) {
+    if (section.IsIndentSizeSet()) {
         this->SetIndentWidth(section.GetIndentSize());
     }
-    if(section.IsCharsetSet()) {
+    if (section.IsCharsetSet()) {
         // TODO: fix the locale here
     }
 }
 
-bool OptionsConfig::IsTabColourDark() const
-{
-#if USE_AUI_NOTEBOOK
-    return false;
-#else
-    return HasOption(Opt_TabColourDark);
-#endif
-}
-
-bool OptionsConfig::IsTabColourMatchesTheme() const
-{
-#if USE_AUI_NOTEBOOK
-    return true;
-#else
-    return !HasOption(Opt_TabColourPersistent);
-#endif
-}
-
+bool OptionsConfig::IsTabColourDark() const { return HasOption(Opt_TabColourDark); }
+bool OptionsConfig::IsTabColourMatchesTheme() const { return !HasOption(Opt_TabColourPersistent); }
 void OptionsConfig::EnableOption(size_t flag, bool b) { m_options.set(flag, b); }
 bool OptionsConfig::HasOption(size_t flag) const { return m_options.test(flag); }
