@@ -30,10 +30,12 @@
 #include "clEditorConfig.h"
 #include "codelite_exports.h"
 #include "configuration_object.h"
-#include "wx/colour.h"
-#include "wx/font.h"
-#include "wx/string.h"
-#include "wx/xml/xml.h"
+
+#include <memory>
+#include <wx/colour.h>
+#include <wx/font.h>
+#include <wx/string.h>
+#include <wx/xml/xml.h>
 
 class WXDLLIMPEXP_SDK OptionsConfig : public ConfObject
 {
@@ -91,6 +93,7 @@ protected:
     wxString m_bookmarkFgColours;
     wxString m_bookmarkLabels;
     bool m_highlightCaretLine;
+    bool m_highlightCaretLineWithColour;
     bool m_clearHighlitWordsOnFind;
     bool m_displayLineNumbers;
     bool m_relativeLineNumbers;
@@ -155,7 +158,7 @@ protected:
     int m_nbTabHeight; // Should notebook tabs be too tall, too short or...
     wxString m_webSearchPrefix;
     bool m_smartParen = true;
-    bool m_lineNumberHighlightCurrent = true;
+    bool m_lineNumberHighlightCurrent = false;
     bool m_showRightMarginIndicator = false;
     int m_rightMarginColumn = 120;
 
@@ -332,6 +335,8 @@ public:
     bool GetClearHighlitWordsOnFind() const { return m_clearHighlitWordsOnFind; }
 
     bool GetHighlightCaretLine() const { return m_highlightCaretLine; }
+    bool IsHighlightCaretLineWithColour() const { return m_highlightCaretLineWithColour; }
+    void SetHighlightCaretLineWithColour(bool b) { m_highlightCaretLineWithColour = b; }
     bool GetDisplayLineNumbers() const { return m_displayLineNumbers; }
     bool GetRelativeLineNumbers() const { return m_relativeLineNumbers; }
     bool GetShowIndentationGuidelines() const { return m_showIndentationGuidelines; }
@@ -478,6 +483,6 @@ public:
     wxXmlNode* ToXml() const;
 };
 
-typedef SmartPtr<OptionsConfig> OptionsConfigPtr;
+using OptionsConfigPtr = std::shared_ptr<OptionsConfig>;
 
 #endif // OPTIONS_CONFIG_H
