@@ -27,9 +27,10 @@
 
 #include "build_config.h"
 #include "codelite_exports.h"
-#include "wx/string.h"
 
 #include <map>
+#include <memory>
+#include <wx/string.h>
 
 /**
  * \ingroup SDK
@@ -146,6 +147,6 @@ public:
     void SetProjectType(const wxString& type) { m_projectType = type; }
 };
 
-typedef SmartPtr<ProjectSettings> ProjectSettingsPtr;
+using ProjectSettingsPtr = std::shared_ptr<ProjectSettings>;
 
 #endif // PROJECT_SETTINGS_H
