@@ -31,8 +31,8 @@
 #include "compiler_command_line_parser.h"
 #include "ctags_manager.h"
 #include "environmentconfig.h"
+#include "envvarlist.h"
 #include "event_notifier.h"
-#include "evnvarlist.h"
 #include "file_logger.h"
 #include "fileutils.h"
 #include "globals.h"
@@ -41,13 +41,12 @@
 #include "macros.h"
 #include "plugin.h"
 #include "project.h"
-#include "wx/regex.h"
-#include "wx_xml_compatibility.h"
 #include "xmlutils.h"
 
 #include <wx/app.h>
 #include <wx/log.h>
 #include <wx/msgdlg.h>
+#include <wx/regex.h>
 #include <wx/sstream.h>
 #include <wx/stc/stc.h>
 #include <wx/thread.h>
@@ -81,7 +80,7 @@ wxString clCxxWorkspace::GetName() const
 
 void clCxxWorkspace::CloseWorkspace()
 {
-    m_buildMatrix.Reset(NULL);
+    m_buildMatrix = nullptr;
     if(m_doc.IsOk()) {
         SaveXmlFile();
         m_doc = wxXmlDocument();
@@ -94,35 +93,6 @@ void clCxxWorkspace::CloseWorkspace()
     TagsManagerST::Get()->CloseDatabase();
 }
 
-bool clCxxWorkspace::OpenReadOnly(const wxString& fileName, wxString& errMsg)
-{
-    m_buildMatrix.Reset(NULL);
-    wxFileName workSpaceFile(fileName);
-    if(!workSpaceFile.FileExists()) {
-        return false;
-    }
-    m_fileName = workSpaceFile;
-    m_doc.Load(m_fileName.GetFullPath());
-    if(!m_doc.IsOk()) {
-        return false;
-    }
-
-    m_saveOnExit = false;
-
-    // Make sure we have the WORKSPACE/.codelite folder exists
-    {
-        wxLogNull nolog;
-        wxMkdir(GetPrivateFolder());
-    }
-
-    // Load all projects from the XML file
-    std::vector<wxXmlNode*> removedChildren;
-    DoLoadProjectsFromXml(m_doc.GetRoot(), "", removedChildren);
-
-    DoUpdateBuildMatrix();
-    return true;
-}
-
 bool clCxxWorkspace::OpenWorkspace(const wxString& fileName, wxString& errMsg)
 {
     if(!DoLoadWorkspace(fileName, errMsg)) {
@@ -142,23 +112,6 @@ bool clCxxWorkspace::OpenWorkspace(const wxString& fileName, wxString& errMsg)
 
 BuildMatrixPtr clCxxWorkspace::GetBuildMatrix() const { return m_buildMatrix; }
 
-wxXmlNode* clCxxWorkspace::GetWorkspaceEditorOptions() const
-{
-    return XmlUtils::FindFirstByTagName(m_doc.GetRoot(), wxT("Options"));
-}
-
-void clCxxWorkspace::SetWorkspaceEditorOptions(LocalOptionsConfigPtr opts)
-{
-    wxXmlNode* parent = m_doc.GetRoot();
-    wxXmlNode* oldOptions = XmlUtils::FindFirstByTagName(parent, wxT("Options"));
-    if(oldOptions) {
-        oldOptions->GetParent()->RemoveChild(oldOptions);
-        delete oldOptions;
-    }
-    parent->AddChild(opts->ToXml());
-    SaveXmlFile();
-}
-
 void clCxxWorkspace::SetBuildMatrix(BuildMatrixPtr mapping)
 {
     wxXmlNode* parent = m_doc.GetRoot();
@@ -207,7 +160,7 @@ bool clCxxWorkspace::CreateWorkspace(const wxString& name, const wxString& path,
 
     // This function sets the working directory to the workspace directory!
     ::wxSetWorkingDirectory(m_fileName.GetPath());
-    m_buildMatrix.Reset(NULL);
+    m_buildMatrix = nullptr;
 
     wxFileName dbFileName = GetTagsFileName();
     TagsManagerST::Get()->OpenDatabase(dbFileName);
@@ -562,8 +515,7 @@ bool clCxxWorkspace::RemoveProject(const wxString& name, wxString& errMsg, const
                 // the removed project was active,
                 // select new project to be active
                 if(!m_projects.empty()) {
-                    ProjectMap_t::iterator iter = m_projects.begin();
-                    SetActiveProject(iter->first);
+                    SetActiveProject(m_projects.begin()->first);
                 }
             }
             root->RemoveChild(child);
@@ -1012,16 +964,6 @@ void clCxxWorkspace::SetEnvironmentVariabels(const wxString& envvars)
     SaveXmlFile();
 }
 
-wxArrayString clCxxWorkspace::GetAllProjectPaths()
-{
-    wxArrayString projects;
-    ProjectMap_t::iterator iter = m_projects.begin();
-    for(; iter != m_projects.end(); iter++) {
-        projects.Add(iter->second->GetFileName().GetFullPath());
-    }
-    return projects;
-}
-
 bool clCxxWorkspace::IsOpen() const { return m_doc.IsOk(); }
 
 bool clCxxWorkspace::IsVirtualDirectoryExists(const wxString& vdFullPath)
@@ -1168,8 +1110,8 @@ void clCxxWorkspace::ReplaceCompilers(const wxStringMap_t& compilers)
 
 void clCxxWorkspace::DoUpdateBuildMatrix()
 {
-    m_buildMatrix.Reset(new BuildMatrix(XmlUtils::FindFirstByTagName(m_doc.GetRoot(), "BuildMatrix"),
-                                        GetLocalWorkspace()->GetSelectedBuildConfiguration()));
+    m_buildMatrix = std::make_shared<BuildMatrix>(XmlUtils::FindFirstByTagName(m_doc.GetRoot(), "BuildMatrix"),
+                                                  GetLocalWorkspace()->GetSelectedBuildConfiguration());
 }
 
 void clCxxWorkspace::RenameProject(const wxString& oldname, const wxString& newname)
@@ -1434,7 +1376,7 @@ bool clCxxWorkspace::CreateWorkspaceFolder(const wxString& path) { return (DoCre
 bool clCxxWorkspace::DoLoadWorkspace(const wxString& fileName, wxString& errMsg)
 {
     CloseWorkspace();
-    m_buildMatrix.Reset(NULL);
+    m_buildMatrix = nullptr;
     wxFileName workSpaceFile(fileName);
     if(workSpaceFile.FileExists() == false) {
         errMsg = wxString::Format(_("Could not open workspace file: '%s'"), fileName.c_str());
@@ -1586,30 +1528,6 @@ size_t clCxxWorkspace::GetExcludeFilesForConfig(std::vector<wxString>& files, co
     return files.size();
 }
 
-void clCxxWorkspace::CreateCompileFlags() const
-{
-    // Build the global compiler paths, we will need this later on...
-    wxStringMap_t compilersGlobalPaths;
-    std::unordered_map<wxString, wxArrayString> pathsMap = BuildSettingsConfigST::Get()->GetCompilersGlobalPaths();
-    for(const std::unordered_map<wxString, wxArrayString>::value_type& vt : pathsMap) {
-        wxString compiler_name = vt.first;
-        wxArrayString pathsArr = vt.second;
-        wxString paths;
-        std::for_each(pathsArr.begin(), pathsArr.end(), [&](wxString& path) {
-            path.Trim().Trim(false);
-            if(path.EndsWith("\\")) {
-                path.RemoveLast();
-            }
-            paths << path << ";";
-        });
-        compilersGlobalPaths.insert({ compiler_name, paths });
-    }
-
-    for(const ProjectMap_t::value_type& vt : m_projects) {
-        vt.second->CreateCompileFlags(compilersGlobalPaths);
-    }
-}
-
 void clCxxWorkspace::ClearBacktickCache() { m_backticks.clear(); }
 
 bool clCxxWorkspace::HasBacktick(const wxString& backtick) const { return m_backticks.count(backtick) != 0; }
@@ -1631,43 +1549,8 @@ bool clCxxWorkspace::GetBacktickValue(const wxString& backtick, wxString& value)
 
 void clCxxWorkspace::OnBuildHotspotClicked(clBuildEvent& event)
 {
-    if(!IsOpen()) {
-        event.Skip();
-        return;
-    }
-
-    wxFileName fn(event.GetFileName());
-    if(fn.IsAbsolute()) {
-        // there is a built in mechansim to handle full path files, let it process it
-        event.Skip();
-        return;
-    }
-
-    clDEBUG() << "Handling OnBuildHotspotClicked event" << endl;
-    clDEBUG() << "File:" << event.GetFileName() << endl;
-    clDEBUG() << "Line:" << event.GetLineNumber() << endl;
-    clDEBUG() << "Project:" << event.GetProjectName() << endl;
-
-    event.Skip(false);
-    const wxString& project_name = event.GetProjectName();
-    auto p = GetProject(project_name);
-    if(!p) {
-        clDEBUG() << "Could not find project:" << project_name << "." << endl;
-        return;
-    }
-
-    fn.MakeAbsolute(p->GetFileName().GetPath());
-    clDEBUG() << "Path made abs:" << event.GetFileName() << "->" << fn.GetFullPath() << endl;
-    // attempt to open this file
-
-    auto editor = clGetManager()->FindEditor(fn.GetFullPath());
-    if(!editor) {
-        editor = clGetManager()->OpenFile(fn.GetFullPath(), wxEmptyString, event.GetLineNumber());
-    }
-    if(editor) {
-        clGetManager()->SelectPage(editor->GetCtrl());
-        editor->CenterLine(event.GetLineNumber());
-    }
+    // Let the generic code to handle the file open
+    event.Skip();
 }
 
 void clCxxWorkspace::SetProjectActive(const wxString& project) { SetActiveProject(project); }
