@@ -27,19 +27,19 @@
 
 #include "IWorkspace.h"
 #include "JSON.h"
+#include "cl_command_event.h"
 #include "codelite_exports.h"
 #include "configuration_mapping.h"
 #include "localworkspace.h"
 #include "optionsconfig.h"
 #include "project.h"
 #include "singleton.h"
-#include "wx/filename.h"
-#include "wx/string.h"
 #include "wxStringHash.h"
 
-#include <cl_command_event.h>
 #include <map>
 #include <wx/event.h>
+#include <wx/filename.h>
+#include <wx/string.h>
 #include <wx/xml/xml.h>
 
 #define CURRENT_WORKSPACE_VERSION 11000
@@ -178,11 +178,6 @@ public:
      */
     cJSON* CreateCompileCommandsJSON(bool createCompileFlagsTxt, wxArrayString* generated_paths) const;
 
-    /**
-     * @brief generate compile_flags.txt for each project
-     */
-    void CreateCompileFlags() const;
-
     wxString GetFileName() const override { return GetWorkspaceFileName().GetFullPath(); }
     wxString GetDir() const override { return GetWorkspaceFileName().GetPath(); }
 
@@ -232,15 +227,6 @@ public:
      */
     bool OpenWorkspace(const wxString& fileName, wxString& errMsg);
 
-    /**
-     * @brief this function opens the workspace, but does not open the tags
-     * completion database etc. It only loads the XML and then adds all the
-     * projects XML. It is mainly needed when you just need to explore the
-     * workspace from a secondary thread with no events / UI to get in the
-     * way
-     */
-    bool OpenReadOnly(const wxString& fileName, wxString& errMsg);
-
     /**
      * Close the currently opened workspace
      */
@@ -321,11 +307,6 @@ public:
      */
     wxString GetActiveProjectName() const override;
 
-    /**
-     * @brief return the paths of all projects in the workspace (full paths)
-     */
-    wxArrayString GetAllProjectPaths();
-
     /**
      * Set project as active
      * \param name  project name
@@ -376,16 +357,6 @@ public:
      */
     void Save();
 
-    /**
-     * Return a node pointing to any workspace-wide editor preferences
-     */
-    wxXmlNode* GetWorkspaceEditorOptions() const;
-
-    /**
-     * Add or update local workspace options
-     */
-    void SetWorkspaceEditorOptions(LocalOptionsConfigPtr opts);
-
     /**
      * Return the configuration mapping for the workspace. 'Configuration Mapping' is
      * the build matrix that should be used for this workspace, it contains all possible
