@@ -1,7 +1,7 @@
 #include "wxCodeCompletionBox.h"
 
 #include "ColoursAndFontsManager.h"
-#include "CxxTemplateFunction.h"
+#include "Cxx/CxxTemplateFunction.h"
 #include "StringUtils.h"
 #include "bitmap_loader.h"
 #include "cc_box_tip_window.h"
@@ -25,6 +25,8 @@
 #include <wx/font.h>
 #include <wx/stc/stc.h>
 
+const size_t MAX_TOOLTIP_SIZE = 1 << 10; // 1KB
+
 wxCodeCompletionBox::BmpVec_t wxCodeCompletionBox::m_defaultBitmaps;
 thread_local bool strip_html_tags = false;
 
@@ -37,15 +39,18 @@ wxCodeCompletionBox::wxCodeCompletionBox(wxWindow* parent, wxEvtHandler* eventOb
     , m_flags(flags)
 {
     MSWSetWindowDarkTheme(this);
+    m_tooltipTimer = new wxTimer(this);
+    Bind(wxEVT_TIMER, &wxCodeCompletionBox::OnTooltipWindowTimer, this, m_tooltipTimer->GetId());
+
     // Use the active editor's font (if any)
     wxColour bgColour;
     wxColour textColour;
     LexerConf::Ptr_t lexer = ColoursAndFontsManager::Get().GetLexer("c++");
-    if(!lexer) {
+    if (!lexer) {
         lexer = ColoursAndFontsManager::Get().GetLexer("text");
     }
     IEditor* editor = clGetManager()->GetActiveEditor();
-    if(editor) {
+    if (editor) {
         bgColour = editor->GetCtrl()->StyleGetBackground(0);
         textColour = editor->GetCtrl()->StyleGetForeground(0);
     } else {
@@ -143,10 +148,21 @@ wxCodeCompletionBox::wxCodeCompletionBox(wxWindow* parent, wxEvtHandler* eventOb
     m_list->SetSortFunction(nullptr);
 }
 
-wxCodeCompletionBox::~wxCodeCompletionBox() { DoDestroyTipWindow(); }
+wxCodeCompletionBox::~wxCodeCompletionBox()
+{
+    Unbind(wxEVT_TIMER, &wxCodeCompletionBox::OnTooltipWindowTimer, this, m_tooltipTimer->GetId());
+    if (m_tooltipTimer) {
+        m_tooltipTimer->Stop();
+    }
+    wxDELETE(m_tooltipTimer);
+    DoDestroyTipWindow();
+}
 
 void wxCodeCompletionBox::Reset(wxEvtHandler* eventObject, size_t flags)
 {
+    if (m_tooltipTimer) {
+        m_tooltipTimer->Stop();
+    }
     m_eventObject = eventObject;
     m_flags = flags;
     DoDestroyTipWindow();
@@ -157,18 +173,19 @@ void wxCodeCompletionBox::Reset(wxEvtHandler* eventObject, size_t flags)
     m_list->DeleteAllItems();
 }
 
-void wxCodeCompletionBox::ShowCompletionBox(wxStyledTextCtrl* ctrl, const wxCodeCompletionBoxEntry::Vec_t& entries)
+void wxCodeCompletionBox::ShowCompletionBox(wxStyledTextCtrl* ctrl, const wxCodeCompletionBoxEntry::Vec_t& entries,
+                                            const wxSize& control_size)
 {
     m_stc = ctrl;
     m_allEntries = entries;
 
     // Keep the start position
-    if(m_startPos == wxNOT_FOUND) {
+    if (m_startPos == wxNOT_FOUND) {
         m_startPos = m_stc->WordStartPosition(m_stc->GetCurrentPos(), true);
     }
 
     // Fire "Showing" event
-    if(!(m_flags & kNoShowingEvent)) {
+    if (!(m_flags & kNoShowingEvent)) {
         clCodeCompletionEvent ccEvent(wxEVT_CCBOX_SHOWING);
         ccEvent.SetEntries(m_allEntries);
         ccEvent.SetEventObject(this);
@@ -186,10 +203,9 @@ void wxCodeCompletionBox::ShowCompletionBox(wxStyledTextCtrl* ctrl, const wxCode
     FilterResults(true, startsWithCount, containsCount, exactMatchCount);
     wxUnusedVar(containsCount);
 
-    // If we got a single match - insert it
-    if(m_entries.size() == 1 && (m_flags & kInsertSingleMatch)) {
-        wxString entryText = m_entries[0]->GetText().BeforeFirst('(');
-        if(startsWithCount == 1 && entryText.CmpNoCase(GetFilter()) == 0) {
+    if (m_entries.size() == 1 && !(m_flags & kTriggerUser)) {
+        wxString entryText = m_entries[0]->GetText();
+        if (startsWithCount == 1 && entryText.CmpNoCase(GetFilter()) == 0) {
             DoDestroy();
             return;
         }
@@ -200,27 +216,33 @@ void wxCodeCompletionBox::ShowCompletionBox(wxStyledTextCtrl* ctrl, const wxCode
     int end = m_stc->GetCurrentPos();
 
     wxString word = m_stc->GetTextRange(start, end); // the current word
-    if(m_entries.empty()) {
+    if (m_entries.empty()) {
         // no entries to display
         DoDestroy();
         return;
     }
 
-    DoShowCompletionBox();
+    DoShowCompletionBox(control_size);
 
-    if(m_stc) {
+    if (m_stc) {
         // Set the focus back to the completion control
         m_stc->CallAfter(&wxStyledTextCtrl::SetFocus);
     }
 
     // Display the help window
-    DoDisplayTipWindow();
+    StartTooltipWindowTimer();
 }
 
-void wxCodeCompletionBox::DoDisplayTipWindow()
+void wxCodeCompletionBox::OnTooltipWindowTimer(wxTimerEvent& event)
 {
+    wxUnusedVar(event);
+    if (!IsShown()) {
+        DoDestroyTipWindow();
+        return;
+    }
+
     // Display the tooltip
-    if(m_list->GetItemCount() == 0) {
+    if (m_list->GetItemCount() == 0) {
         DoDestroyTipWindow();
     } else {
         wxDataViewItem item = m_list->GetSelection();
@@ -228,23 +250,40 @@ void wxCodeCompletionBox::DoDisplayTipWindow()
 
         size_t index = static_cast<size_t>(m_list->GetItemData(item));
 
-        wxString docComment = m_entries.at(index)->GetComment();
+        wxString docComment;
+        if (index >= m_entries.size()) {
+            clWARNING() << "wxCodeCompletionBox::DoDisplayTipWindow(): Requesting tip for index:" << index
+                        << ". m_entries.size():" << m_entries.size() << ". m_allEntries.size():" << m_allEntries.size()
+                        << endl;
+            clWARNING() << "m_allEntries[" << index << "].GetText():" << m_allEntries[index]->GetText() << endl;
+            clWARNING() << "m_allEntries[" << index << "].GetCommnet():" << m_allEntries[index]->GetComment() << endl;
+
+        } else {
+            docComment = m_entries[index]->GetComment();
+        }
         docComment.Trim().Trim(false);
 
-        if(docComment.IsEmpty()) {
+        if (docComment.empty()) {
             // No tip to display
             DoDestroyTipWindow();
 
-        } else if(!docComment.IsEmpty() && docComment != m_displayedTip) {
+        } else if (!docComment.IsEmpty() && docComment != m_displayedTip) {
             // destroy old tip window
             DoDestroyTipWindow();
 
+            // Don't allow too large tooltips
+            if (docComment.size() > MAX_TOOLTIP_SIZE) {
+                docComment = docComment.Mid(0, MAX_TOOLTIP_SIZE);
+                docComment << "** ...truncated**";
+            }
+
             // keep the old tip
             m_displayedTip = docComment;
 
             // Construct a new tip window and display the tip
             m_tipWindow = new CCBoxTipWindow(GetParent(), docComment, strip_html_tags);
-            m_tipWindow->PositionRelativeTo(this, m_stc->PointFromPosition(m_stc->GetCurrentPos()));
+            m_tipWindow->PositionRelativeTo(this, m_stc->PointFromPosition(m_stc->GetCurrentPos()),
+                                            m_stc->GetCurrentPos());
 
             // restore focus to the editor
             m_stc->CallAfter(&wxStyledTextCtrl::SetFocus);
@@ -252,15 +291,27 @@ void wxCodeCompletionBox::DoDisplayTipWindow()
     }
 }
 
+void wxCodeCompletionBox::StartTooltipWindowTimer()
+{
+    if (m_tooltipTimer->IsRunning()) {
+        m_tooltipTimer->Stop();
+    }
+    m_tooltipTimer->StartOnce(250);
+}
+
 void wxCodeCompletionBox::StcCharAdded(wxStyledTextEvent& event)
 {
     event.Skip();
+    if (m_flags & kAlwaysShow) {
+        return;
+    }
+
     int keychar = m_stc->GetCharAt(m_stc->PositionBefore(m_stc->GetCurrentPos()));
-    if(((keychar >= 65) && (keychar <= 90)) ||  // A-Z
-       ((keychar >= 97) && (keychar <= 122)) || // a-z
-       ((keychar >= 48) && (keychar <= 57)) ||  // 0-9
-       (keychar == 95) ||                       // _
-       (keychar == 33))                         // !
+    if (((keychar >= 65) && (keychar <= 90)) ||  // A-Z
+        ((keychar >= 97) && (keychar <= 122)) || // a-z
+        ((keychar >= 48) && (keychar <= 57)) ||  // 0-9
+        (keychar == 95) ||                       // _
+        (keychar == 33))                         // !
     {
         DoUpdateList();
     } else {
@@ -280,14 +331,14 @@ bool wxCodeCompletionBox::FilterResults(bool updateEntries, size_t& startsWithCo
     containsCount = 0;
     startsWithCount = 0;
     wxString word = GetFilter();
-    if(word.IsEmpty()) {
-        if(updateEntries) {
+    if (word.empty()) {
+        if (updateEntries) {
             m_entries = m_allEntries;
         }
         return false;
     }
 
-    if(updateEntries) {
+    if (updateEntries) {
         m_entries.clear();
     }
     wxString lcFilter = word.Lower();
@@ -297,28 +348,28 @@ bool wxCodeCompletionBox::FilterResults(bool updateEntries, size_t& startsWithCo
     // Starts with
     // Contains
     wxCodeCompletionBoxEntry::Vec_t exactMatches, exactMatchesI, startsWith, startsWithI, contains, containsI;
-    for(size_t i = 0; i < m_allEntries.size(); ++i) {
-        wxString entryText = m_allEntries.at(i)->GetText().BeforeFirst('(');
+    for (size_t i = 0; i < m_allEntries.size(); ++i) {
+        wxString entryText = m_allEntries.at(i)->GetText();
         entryText.Trim().Trim(false);
         wxString lcEntryText = entryText.Lower();
 
         // Exact match:
-        if(word == entryText) {
+        if (word == entryText) {
             exactMatches.push_back(m_allEntries.at(i));
 
-        } else if(lcEntryText == lcFilter) {
+        } else if (lcEntryText == lcFilter) {
             exactMatchesI.push_back(m_allEntries.at(i));
 
-        } else if(entryText.StartsWith(word)) {
+        } else if (entryText.StartsWith(word)) {
             startsWith.push_back(m_allEntries.at(i));
 
-        } else if(lcEntryText.StartsWith(lcFilter)) {
+        } else if (lcEntryText.StartsWith(lcFilter)) {
             startsWithI.push_back(m_allEntries.at(i));
 
-        } else if(entryText.Contains(word)) {
+        } else if (entryText.Contains(word)) {
             contains.push_back(m_allEntries.at(i));
 
-        } else if(lcEntryText.Contains(lcFilter)) {
+        } else if (lcEntryText.Contains(lcFilter)) {
             containsI.push_back(m_allEntries.at(i));
         }
     }
@@ -328,7 +379,7 @@ bool wxCodeCompletionBox::FilterResults(bool updateEntries, size_t& startsWithCo
     exactMatchCount = exactMatches.size();
 
     // Merge the results
-    if(updateEntries) {
+    if (updateEntries) {
         m_entries.insert(m_entries.end(), exactMatches.begin(), exactMatches.end());
         m_entries.insert(m_entries.end(), exactMatchesI.begin(), exactMatchesI.end());
         m_entries.insert(m_entries.end(), startsWith.begin(), startsWith.end());
@@ -341,34 +392,31 @@ bool wxCodeCompletionBox::FilterResults(bool updateEntries, size_t& startsWithCo
 
 void wxCodeCompletionBox::InsertSelection(wxCodeCompletionBoxEntry::Ptr_t entry)
 {
-
-    if(m_stc) {
+    if (m_stc) {
         wxCodeCompletionBoxEntry::Ptr_t match = entry;
-        if(match == nullptr) {
+        if (match == nullptr) {
             wxDataViewItem item = m_list->GetSelection();
             CHECK_PTR_RET(item);
             size_t index = static_cast<size_t>(m_list->GetItemData(item));
-
             match = m_entries[index];
         }
 
-        // Let the owner override the default behavior
+        // Let the owner override the default behaviour
         clCodeCompletionEvent e(wxEVT_CCBOX_SELECTION_MADE);
         e.SetWord(match->GetInsertText());
         e.SetEventObject(m_eventObject);
         e.SetEntry(match);
-        if(!EventNotifier::Get()->ProcessEvent(e)) {
-            // execute the default behavior
-            if(match->m_tag && match->m_tag->IsTemplateFunction()) {
+        if (!EventNotifier::Get()->ProcessEvent(e)) {
+            // execute the default behaviour
+            if (match->m_tag && match->m_tag->IsTemplateFunction()) {
                 CxxTemplateFunction tf(match->m_tag);
-                if(!tf.CanTemplateArgsDeduced()) {
+                if (!tf.CanTemplateArgsDeduced()) {
                     // Insert a template function
-                    wxCodeCompletionBoxManager::Get().CallAfter(
-                        &wxCodeCompletionBoxManager::InsertSelectionTemplateFunction, match->GetText());
+                    wxCodeCompletionBoxManager::Get().InsertSelectionTemplateFunction(match->GetText());
                     return;
                 }
             }
-            wxCodeCompletionBoxManager::Get().CallAfter(&wxCodeCompletionBoxManager::InsertSelection, match, true);
+            wxCodeCompletionBoxManager::Get().InsertSelection(match, true);
         }
     }
 }
@@ -376,7 +424,7 @@ void wxCodeCompletionBox::InsertSelection(wxCodeCompletionBoxEntry::Ptr_t entry)
 wxCodeCompletionBoxEntry::Vec_t wxCodeCompletionBox::TagsToEntries(const TagEntryPtrVector_t& tags)
 {
     wxCodeCompletionBoxEntry::Vec_t entries;
-    for(size_t i = 0; i < tags.size(); ++i) {
+    for (size_t i = 0; i < tags.size(); ++i) {
         TagEntryPtr tag = tags[i];
         wxCodeCompletionBoxEntry::Ptr_t entry = TagToEntry(tag);
         entries.push_back(entry);
@@ -388,47 +436,48 @@ int wxCodeCompletionBox::GetImageId(TagEntryPtr entry)
 {
     wxString kind = entry->GetKind();
     wxString access = entry->GetAccess();
-    if(kind == wxT("class"))
+    if (kind == wxT("class"))
         return 0;
-    if(kind == wxT("struct"))
+    if (kind == wxT("struct"))
         return 1;
-    if(kind == wxT("namespace"))
+    if (kind == wxT("namespace"))
         return 2;
-    if(kind == wxT("variable"))
+    if (kind == wxT("variable"))
         return 3;
-    if(kind == wxT("typedef"))
+    if (kind == wxT("typedef"))
         return 4;
-    if(kind == wxT("member") && access.Contains(wxT("private")))
+    if (kind == wxT("member") && access.Contains(wxT("private")))
         return 5;
-    if(kind == wxT("member") && access.Contains(wxT("public")))
+    if (kind == wxT("member") && access.Contains(wxT("public")))
         return 6;
-    if(kind == wxT("member") && access.Contains(wxT("protected")))
+    if (kind == wxT("member") && access.Contains(wxT("protected")))
         return 7;
     // member with no access? (maybe part of namespace??)
-    if(kind == wxT("member"))
+    if (kind == wxT("member"))
         return 6;
-    if((kind == wxT("function") || kind == wxT("prototype")) && access.Contains(wxT("private")))
+    if ((kind == wxT("function") || kind == wxT("prototype")) && access.Contains(wxT("private")))
         return 8;
-    if((kind == wxT("function") || kind == wxT("prototype")) && (access.Contains(wxT("public")) || access.IsEmpty()))
+    if ((kind == wxT("function") || kind == wxT("prototype")) && (access.Contains(wxT("public")) || access.IsEmpty()))
         return 9;
-    if((kind == wxT("function") || kind == wxT("prototype")) && access.Contains(wxT("protected")))
+    if ((kind == wxT("function") || kind == wxT("prototype")) && access.Contains(wxT("protected")))
         return 10;
-    if(kind == wxT("macro"))
+    if (kind == wxT("macro"))
         return 11;
-    if(kind == wxT("enum"))
+    if (kind == wxT("enum"))
         return 12;
-    if(kind == wxT("enumerator"))
+    if (kind == wxT("enumerator"))
         return 13;
-    if(kind == wxT("cpp_keyword"))
+    if (kind == wxT("cpp_keyword"))
         return 17;
-    if(kind == "cenum")
+    if (kind == "cenum")
         return 18;
     return wxNOT_FOUND;
 }
 
-void wxCodeCompletionBox::ShowCompletionBox(wxStyledTextCtrl* ctrl, const TagEntryPtrVector_t& tags)
+void wxCodeCompletionBox::ShowCompletionBox(wxStyledTextCtrl* ctrl, const TagEntryPtrVector_t& tags,
+                                            const wxSize& control_size)
 {
-    ShowCompletionBox(ctrl, TagsToEntries(tags));
+    ShowCompletionBox(ctrl, TagsToEntries(tags), control_size);
 }
 
 void wxCodeCompletionBox::DoUpdateList()
@@ -442,16 +491,16 @@ void wxCodeCompletionBox::DoUpdateList()
     wxUnusedVar(refreshList);
 
     // If there a single entry exact match hide the cc box
-    if(m_entries.size() == 1) {
-        wxString entryText = m_entries[0]->GetText().BeforeFirst('(');
-        if(entryText.CmpNoCase(GetFilter()) == 0) {
+    if (m_entries.size() == 1) {
+        wxString entryText = m_entries[0]->GetText();
+        if (entryText.CmpNoCase(GetFilter()) == 0) {
             CallAfter(&wxCodeCompletionBox::DoDestroy);
             return;
         }
     }
 
     // int curpos = m_stc->GetCurrentPos();
-    if(!GetFilter().empty() && (m_entries.empty() && !m_allEntries.empty())) {
+    if (!GetFilter().empty() && (m_entries.empty() && !m_allEntries.empty())) {
         // the CC might not reported all possible matches
         // (we have a limit to the number of matches we display)
         // trigger another CC action
@@ -459,14 +508,9 @@ void wxCodeCompletionBox::DoUpdateList()
         wxTheApp->GetTopWindow()->GetEventHandler()->AddPendingEvent(event);
         DoDestroy();
     } else {
-        DoDisplayTipWindow();
+        StartTooltipWindowTimer();
         DoPopulateList();
     }
-
-    if(exactMatchCount == 0) {
-        wxCommandEvent event(wxEVT_MENU, XRCID("complete_word"));
-        wxTheApp->GetTopWindow()->GetEventHandler()->AddPendingEvent(event);
-    }
 }
 
 wxCodeCompletionBoxEntry::Ptr_t wxCodeCompletionBox::TagToEntry(TagEntryPtr tag)
@@ -489,10 +533,10 @@ void wxCodeCompletionBox::DoDestroy() { wxCodeCompletionBoxManager::Get().Destro
 
 void wxCodeCompletionBox::DoDestroyTipWindow()
 {
-    if(m_tipWindow) {
+    if (m_tipWindow) {
         m_tipWindow->Hide();
         m_tipWindow->Destroy();
-        m_tipWindow = NULL;
+        m_tipWindow = nullptr;
         m_displayedTip.Clear();
     }
 }
@@ -505,7 +549,7 @@ void wxCodeCompletionBox::StcLeftDown(wxMouseEvent& event)
 
 void wxCodeCompletionBox::StcKeyDown(wxKeyEvent& event)
 {
-    switch(event.GetKeyCode()) {
+    switch (event.GetKeyCode()) {
     case WXK_UP:
         m_list->LineUp();
         break;
@@ -549,7 +593,7 @@ void wxCodeCompletionBox::StcKeyDown(wxKeyEvent& event)
             m_list->PageDown();
         } else if (modifier_key == wxMOD_CONTROL && (ch == 'J' || ch == 'N')) {
             m_list->LineDown();
-        }  else if (modifier_key == wxMOD_CONTROL && (ch == 'K' || ch == 'P')) {
+        } else if (modifier_key == wxMOD_CONTROL && (ch == 'K' || ch == 'P')) {
             m_list->LineUp();
         } else {
             event.Skip();
@@ -559,11 +603,13 @@ void wxCodeCompletionBox::StcKeyDown(wxKeyEvent& event)
     }
 }
 
-void wxCodeCompletionBox::DoShowCompletionBox()
+void wxCodeCompletionBox::DoShowCompletionBox(const wxSize& control_size)
 {
     CHECK_PTR_RET(m_stc);
     DoPopulateList();
-
+    if (control_size.GetWidth() != wxNOT_FOUND || control_size.GetHeight() != wxNOT_FOUND) {
+        SetSizeHints(control_size);
+    }
     int lineHeight = m_stc->TextHeight(m_stc->GetCurrentLine());
     wxRect rect = GetRect();
 
@@ -575,19 +621,19 @@ void wxCodeCompletionBox::DoShowCompletionBox()
 
     wxRect screenSize = clGetDisplaySize();
     int displayIndex = wxDisplay::GetFromPoint(pt);
-    if(displayIndex != wxNOT_FOUND) {
+    if (displayIndex != wxNOT_FOUND) {
         screenSize = wxDisplay(displayIndex).GetGeometry();
     }
 
     // Check Y axis
-    if((pt.y + rect.GetHeight()) > screenSize.GetHeight()) {
+    if ((pt.y + rect.GetHeight()) > screenSize.GetHeight()) {
         // the completion box goes out of the Y axis, move it up
         pt.y -= lineHeight;
         pt.y -= rect.GetHeight();
     }
 
     // Check X axis
-    if((pt.x + rect.GetWidth()) > (screenSize.GetX() + screenSize.GetWidth())) {
+    if ((pt.x + rect.GetWidth()) > (screenSize.GetX() + screenSize.GetWidth())) {
         // the completion box goes out of the X axis. Move it to the left
         pt.x = (screenSize.GetX() + screenSize.GetWidth()) - rect.GetWidth();
     }
@@ -599,9 +645,9 @@ void wxCodeCompletionBox::RemoveDuplicateEntries()
 {
     wxStringSet_t matches;
     wxCodeCompletionBoxEntry::Vec_t uniqueList;
-    for(size_t i = 0; i < m_allEntries.size(); ++i) {
+    for (size_t i = 0; i < m_allEntries.size(); ++i) {
         wxCodeCompletionBoxEntry::Ptr_t entry = m_allEntries.at(i);
-        if(matches.count(entry->GetText()) == 0) {
+        if (matches.count(entry->GetText()) == 0) {
             // new entry
             matches.insert(entry->GetText());
             uniqueList.push_back(entry);
@@ -614,14 +660,14 @@ wxBitmap wxCodeCompletionBox::GetBitmap(TagEntryPtr tag)
 {
     InitializeDefaultBitmaps();
     int imgId = GetImageId(tag);
-    if((imgId < 0) || (imgId >= (int)m_defaultBitmaps.size()))
+    if ((imgId < 0) || (imgId >= (int)m_defaultBitmaps.size()))
         return wxNullBitmap;
     return m_defaultBitmaps.at(imgId);
 }
 
 void wxCodeCompletionBox::InitializeDefaultBitmaps()
 {
-    if(m_defaultBitmaps.empty()) {
+    if (m_defaultBitmaps.empty()) {
         BitmapLoader* bmpLoader = clGetManager()->GetStdIcons();
         m_defaultBitmaps.push_back(bmpLoader->LoadBitmap("cc/16/class"));              // 0
         m_defaultBitmaps.push_back(bmpLoader->LoadBitmap("cc/16/struct"));             // 1
@@ -647,7 +693,7 @@ void wxCodeCompletionBox::InitializeDefaultBitmaps()
 
 wxString wxCodeCompletionBox::GetFilter()
 {
-    if(!m_stc)
+    if (!m_stc)
         return "";
     int start = m_startPos;
     int end = m_stc->GetCurrentPos();
@@ -655,29 +701,30 @@ wxString wxCodeCompletionBox::GetFilter()
     return m_stc->GetTextRange(start, end);
 }
 
-void wxCodeCompletionBox::ShowCompletionBox(wxStyledTextCtrl* ctrl, const LSP::CompletionItem::Vec_t& completions)
+void wxCodeCompletionBox::ShowCompletionBox(wxStyledTextCtrl* ctrl, const LSP::CompletionItem::Vec_t& completions,
+                                            const wxSize& control_size)
 {
-    ShowCompletionBox(ctrl, LSPCompletionsToEntries(completions));
+    ShowCompletionBox(ctrl, LSPCompletionsToEntries(completions), control_size);
 }
 
 wxCodeCompletionBoxEntry::Vec_t
 wxCodeCompletionBox::LSPCompletionsToEntries(const LSP::CompletionItem::Vec_t& completions)
 {
     wxCodeCompletionBoxEntry::Vec_t entries;
-    for(size_t i = 0; i < completions.size(); ++i) {
+    for (size_t i = 0; i < completions.size(); ++i) {
         LSP::CompletionItem::Ptr_t completion = completions[i];
         wxString text = completion->GetLabel();
         int imgIndex = GetImageId(completion);
         wxCodeCompletionBoxEntry::Ptr_t entry = wxCodeCompletionBoxEntry::New(text, imgIndex);
 
         wxString comment;
-        if(!completion->GetDetail().IsEmpty()) {
+        if (!completion->GetDetail().IsEmpty()) {
             wxString detail = completion->GetDetail();
             StringUtils::DisableMarkdownStyling(detail);
             comment << detail;
         }
-        if(!completion->GetDocumentation().GetValue().IsEmpty()) {
-            if(!comment.IsEmpty()) {
+        if (!completion->GetDocumentation().GetValue().IsEmpty()) {
+            if (!comment.IsEmpty()) {
                 comment << "\n---\n";
             }
             comment << completion->GetDocumentation().GetValue();
@@ -686,7 +733,7 @@ wxCodeCompletionBox::LSPCompletionsToEntries(const LSP::CompletionItem::Vec_t& c
         // if 'insertText' is provided, use it instead of the label
         wxString insertText;
         insertText = completion->GetInsertText().IsEmpty() ? completion->GetLabel() : completion->GetInsertText();
-        if(completion->HasTextEdit()) {
+        if (completion->HasTextEdit()) {
             // According to the spec: if textEdit exists, we ignore 'insertText'
             insertText = completion->GetTextEdit()->GetNewText();
         }
@@ -695,27 +742,27 @@ wxCodeCompletionBox::LSPCompletionsToEntries(const LSP::CompletionItem::Vec_t& c
         entry->SetInsertText(insertText);
         wxChar ch = text.empty() ? 0 : text[0];
         // Handle special cases
-        if(reTemplateFunction.IsValid() && reTemplateFunction.Matches(text)) {
+        if (reTemplateFunction.IsValid() && reTemplateFunction.Matches(text)) {
             entry->SetInsertText(reTemplateFunction.GetMatch(text, 1) + "<|>");
             entry->SetIsSnippet(true);
-        } else if(text.StartsWith("include <")) {
+        } else if (text.StartsWith("include <")) {
             // include statement
             entry->SetInsertText("include <|");
             entry->SetIsSnippet(true);
-        } else if(text.StartsWith("include \"")) {
+        } else if (text.StartsWith("include \"")) {
             entry->SetInsertText("include \"|");
             entry->SetIsSnippet(true);
-        } else if(ch == L'•') {
+        } else if (ch == L'•') {
             // this completion entry triggers an #include insertion
             entry->SetTriggerInclude(!completion->GetAdditionalText().empty());
-            if(entry->IsTriggerInclude()) {
+            if (entry->IsTriggerInclude()) {
                 const auto& v = completion->GetAdditionalText();
                 comment = v[0]->GetNewText();
                 comment.Trim().Trim(false);
-                if(comment.Contains("\"")) {
+                if (comment.Contains("\"")) {
                     comment = comment.AfterFirst('"');
                     comment.Prepend("\"");
-                } else if(comment.Contains("<")) {
+                } else if (comment.Contains("<")) {
                     comment = comment.AfterFirst('<');
                     comment.Prepend("<");
                 }
@@ -728,7 +775,7 @@ wxCodeCompletionBox::LSPCompletionsToEntries(const LSP::CompletionItem::Vec_t& c
                              completion->GetKind() == LSP::CompletionItem::kKindFunction ||
                              completion->GetKind() == LSP::CompletionItem::kKindMethod);
         entry->SetIsTemplateFunction(completion->GetLabel().Contains("<") && completion->GetLabel().Contains(">"));
-        if(entry->IsFunction()) {
+        if (entry->IsFunction()) {
             // extract the function signature from the label
             wxString label = completion->GetLabel();
             wxString signature = label.AfterFirst('(');
@@ -743,7 +790,7 @@ wxCodeCompletionBox::LSPCompletionsToEntries(const LSP::CompletionItem::Vec_t& c
 
 int wxCodeCompletionBox::GetImageId(LSP::CompletionItem::Ptr_t entry) const
 {
-    if(m_lspCompletionItemImageIndexMap.count(entry->GetKind())) {
+    if (m_lspCompletionItemImageIndexMap.count(entry->GetKind())) {
         return m_lspCompletionItemImageIndexMap.find(entry->GetKind())->second;
     }
     return m_lspCompletionItemImageIndexMap.find(LSP::CompletionItem::kKindText)->second;
@@ -756,7 +803,7 @@ void wxCodeCompletionBox::DoPopulateList()
 
     m_list->Begin();
     wxVector<wxVariant> cols;
-    for(size_t i = 0; i < m_entries.size(); ++i) {
+    for (size_t i = 0; i < m_entries.size(); ++i) {
         wxCodeCompletionBoxEntry::Ptr_t cc_item = m_entries[i];
         cols.clear();
         cols.push_back(::MakeBitmapIndexText(cc_item->GetText(), cc_item->GetImgIndex()));
@@ -764,7 +811,7 @@ void wxCodeCompletionBox::DoPopulateList()
     }
     m_list->Commit();
     // Select the first item
-    if(m_list->GetItemCount()) {
+    if (m_list->GetItemCount()) {
         m_list->Select(m_list->RowToItem(0));
     }
 }
@@ -779,7 +826,7 @@ void wxCodeCompletionBox::OnSelectionActivated(wxDataViewEvent& event)
 void wxCodeCompletionBox::OnSelectionChanged(wxDataViewEvent& event)
 {
     event.Skip();
-    CallAfter(&wxCodeCompletionBox::DoDisplayTipWindow);
+    StartTooltipWindowTimer();
 }
 
 void wxCodeCompletionBox::SetStripHtmlTags(bool strip) { strip_html_tags = strip; }
