@@ -40,10 +40,6 @@ protected:
     wxCodeCompletionBox* m_box;
     wxStyledTextCtrl* m_stc;
 
-private:
-    wxCodeCompletionBoxManager();
-    ~wxCodeCompletionBoxManager();
-
 protected:
     void DestroyCurrent();
     void InsertSelection(wxCodeCompletionBoxEntry::Ptr_t match, bool userTriggered);
@@ -66,6 +62,9 @@ protected:
 public:
     static wxCodeCompletionBoxManager& Get();
 
+    wxCodeCompletionBoxManager();
+    virtual ~wxCodeCompletionBoxManager();
+
     /**
      * @brief uninitialize all event handlers and destroy the CC box manager
      */
@@ -86,7 +85,7 @@ public:
      * as the event object (wxEvent::GetEventObject())
      */
     void ShowCompletionBox(wxStyledTextCtrl* ctrl, const wxCodeCompletionBoxEntry::Vec_t& entries, size_t flags,
-                           int startPos, wxEvtHandler* eventObject = NULL);
+                           int startPos, wxEvtHandler* eventObject = NULL, const wxSize& control_size = wxDefaultSize);
     /**
      * @brief show the completion box
      * @param ctrl the wxSTC control requesting the completion box
@@ -99,7 +98,7 @@ public:
      */
     void ShowCompletionBox(wxStyledTextCtrl* ctrl, const wxCodeCompletionBoxEntry::Vec_t& entries,
                            const wxCodeCompletionBox::BmpVec_t& bitmaps, size_t flags, int startPos,
-                           wxEvtHandler* eventObject = NULL);
+                           wxEvtHandler* eventObject = NULL, const wxSize& control_size = wxDefaultSize);
 
     /**
      * @brief show the completion box
@@ -111,13 +110,14 @@ public:
      * as the event object (wxEvent::GetEventObject())
      */
     void ShowCompletionBox(wxStyledTextCtrl* ctrl, const TagEntryPtrVector_t& tags, size_t flags, int startPos,
-                           wxEvtHandler* eventObject = NULL);
+                           wxEvtHandler* eventObject = NULL, const wxSize& control_size = wxDefaultSize);
 
     /**
      * @brief show the completion box. Language Server Protocol version
      */
     void ShowCompletionBox(wxStyledTextCtrl* ctrl, const LSP::CompletionItem::Vec_t& completions, size_t flags = 0,
-                           int startPos = wxNOT_FOUND, wxEvtHandler* eventObject = NULL);
+                           int startPos = wxNOT_FOUND, wxEvtHandler* eventObject = NULL,
+                           const wxSize& control_size = wxDefaultSize);
 
     /**
      * @brief do we have a completion box shown?
