@@ -27,7 +27,8 @@
 
 #include "codelite_exports.h"
 #include "serialized_object.h"
-#include "wx/xml/xml.h"
+
+#include <wx/xml/xml.h>
 
 /// A collection of XML utils
 class WXDLLIMPEXP_SDK XmlUtils
@@ -46,7 +47,7 @@ public:
 
     /**
      * update node property. If multiple properties with the same name exist, this function updates
-     * the first occurance
+     * the first occurrence
      * \param node
      * \param name property name
      * \param value new value to set
