@@ -1,6 +1,8 @@
 #include "RemotyNewWorkspaceDlg.h"
+
 #include "globals.h"
-#include "ssh_account_info.h"
+#include "ssh/ssh_account_info.h"
+
 RemotyNewWorkspaceDlg::RemotyNewWorkspaceDlg(wxWindow* parent)
     : RemotyNewWorkspaceDlgBase(parent)
 {
@@ -14,7 +16,7 @@ RemotyNewWorkspaceDlg::~RemotyNewWorkspaceDlg() {}
 void RemotyNewWorkspaceDlg::OnBrowse(wxCommandEvent& event)
 {
     auto result = ::clRemoteFileSelector(_("Seelct a folder"));
-    if(result.second.empty() || result.second.empty()) {
+    if(result.first.empty() || result.second.empty()) {
         return;
     }
     m_textCtrlPath->SetEditable(true);
