@@ -1,23 +1,25 @@
 #include "RemotyWorkspace.hpp"
 
+#include "AsyncProcess/asyncprocess.h"
+#include "AsyncProcess/processreaderthread.h"
+#include "Console/clConsoleBase.h"
+#include "Debugger/debuggermanager.h"
+#include "FileSystemWorkspace/clFileSystemWorkspace.hpp"
 #include "JSON.h"
-#include "Platform.hpp"
+#include "Platform/Platform.hpp"
 #include "RemotyConfig.hpp"
 #include "RemotyNewWorkspaceDlg.h"
 #include "RemotySwitchToWorkspaceDlg.h"
 #include "RemotyWorkspaceView.hpp"
 #include "StringUtils.h"
-#include "asyncprocess.h"
 #include "clCodeLiteRemoteProcess.hpp"
-#include "clConsoleBase.h"
-#include "clFileSystemWorkspace.hpp"
 #include "clRemoteFindDialog.h"
+#include "clRemoteHost.hpp"
 #include "clSFTPManager.hpp"
 #include "clTempFile.hpp"
 #include "clWorkspaceManager.h"
 #include "clWorkspaceView.h"
 #include "codelite_events.h"
-#include "debuggermanager.h"
 #include "environmentconfig.h"
 #include "event_notifier.h"
 #include "file_logger.h"
@@ -27,7 +29,6 @@
 #include "imanager.h"
 #include "macros.h"
 #include "open_resource_dialog.h"
-#include "processreaderthread.h"
 #include "sample_codelite_remote_json.cpp"
 #include "shell_command.h"
 #include "wxStringHash.h"
@@ -40,7 +41,7 @@
 
 #define CHECK_EVENT(e)     \
     {                      \
-        if(!IsOpened()) {  \
+        if (!IsOpened()) { \
             e.Skip();      \
             return;        \
         }                  \
@@ -91,7 +92,7 @@ void RemotyWorkspace::GetWorkspaceFiles(wxArrayString& files) const
 {
     files.clear();
     files.reserve(m_workspaceFiles.size());
-    for(const wxString& file : m_workspaceFiles) {
+    for (const wxString& file : m_workspaceFiles) {
         files.Add(file);
     }
 }
@@ -104,7 +105,7 @@ bool RemotyWorkspace::IsProjectSupported() const { return false; }
 
 void RemotyWorkspace::BindEvents()
 {
-    if(m_eventsConnected) {
+    if (m_eventsConnected) {
         return;
     }
 
@@ -137,26 +138,30 @@ void RemotyWorkspace::BindEvents()
 
     // finder
     m_codeliteRemoteFinder.Bind(wxEVT_CODELITE_REMOTE_RESTARTED, &RemotyWorkspace::OnCodeLiteRemoteTerminated, this);
-    m_codeliteRemoteFinder.Bind(wxEVT_CODELITE_REMOTE_FIND_RESULTS, &RemotyWorkspace::OnCodeLiteRemoteFindProgress,
-                                this);
-    m_codeliteRemoteFinder.Bind(wxEVT_CODELITE_REMOTE_FIND_RESULTS_DONE, &RemotyWorkspace::OnCodeLiteRemoteFindDone,
-                                this);
-    m_codeliteRemoteFinder.Bind(wxEVT_CODELITE_REMOTE_LIST_FILES, &RemotyWorkspace::OnCodeLiteRemoteListFilesProgress,
-                                this);
-    m_codeliteRemoteFinder.Bind(wxEVT_CODELITE_REMOTE_LIST_FILES_DONE, &RemotyWorkspace::OnCodeLiteRemoteListFilesDone,
-                                this);
+    m_codeliteRemoteFinder.Bind(
+        wxEVT_CODELITE_REMOTE_FIND_RESULTS, &RemotyWorkspace::OnCodeLiteRemoteFindProgress, this);
+    m_codeliteRemoteFinder.Bind(
+        wxEVT_CODELITE_REMOTE_FIND_RESULTS_DONE, &RemotyWorkspace::OnCodeLiteRemoteFindDone, this);
+    m_codeliteRemoteFinder.Bind(
+        wxEVT_CODELITE_REMOTE_REPLACE_DONE, &RemotyWorkspace::OnCodeLiteRemoteReplaceDone, this);
+    m_codeliteRemoteFinder.Bind(
+        wxEVT_CODELITE_REMOTE_REPLACE_RESULTS, &RemotyWorkspace::OnCodeLiteRemoteReplaceProgress, this);
+    m_codeliteRemoteFinder.Bind(
+        wxEVT_CODELITE_REMOTE_LIST_FILES, &RemotyWorkspace::OnCodeLiteRemoteListFilesProgress, this);
+    m_codeliteRemoteFinder.Bind(
+        wxEVT_CODELITE_REMOTE_LIST_FILES_DONE, &RemotyWorkspace::OnCodeLiteRemoteListFilesDone, this);
 
     // builder
-    m_codeliteRemoteBuilder.Bind(wxEVT_CODELITE_REMOTE_EXEC_OUTPUT, &RemotyWorkspace::OnCodeLiteRemoteBuildOutput,
-                                 this);
-    m_codeliteRemoteBuilder.Bind(wxEVT_CODELITE_REMOTE_EXEC_DONE, &RemotyWorkspace::OnCodeLiteRemoteBuildOutputDone,
-                                 this);
+    m_codeliteRemoteBuilder.Bind(
+        wxEVT_CODELITE_REMOTE_EXEC_OUTPUT, &RemotyWorkspace::OnCodeLiteRemoteBuildOutput, this);
+    m_codeliteRemoteBuilder.Bind(
+        wxEVT_CODELITE_REMOTE_EXEC_DONE, &RemotyWorkspace::OnCodeLiteRemoteBuildOutputDone, this);
     m_codeliteRemoteBuilder.Bind(wxEVT_CODELITE_REMOTE_RESTARTED, &RemotyWorkspace::OnCodeLiteRemoteTerminated, this);
 }
 
 void RemotyWorkspace::UnbindEvents()
 {
-    if(!m_eventsConnected) {
+    if (!m_eventsConnected) {
         return;
     }
     EventNotifier::Get()->Unbind(wxEVT_SWITCHING_TO_WORKSPACE, &RemotyWorkspace::OnOpenWorkspace, this);
@@ -184,28 +189,28 @@ void RemotyWorkspace::UnbindEvents()
     // codelite-remote events
 
     // finder
-    m_codeliteRemoteFinder.Unbind(wxEVT_CODELITE_REMOTE_FIND_RESULTS, &RemotyWorkspace::OnCodeLiteRemoteFindProgress,
-                                  this);
-    m_codeliteRemoteFinder.Unbind(wxEVT_CODELITE_REMOTE_FIND_RESULTS_DONE, &RemotyWorkspace::OnCodeLiteRemoteFindDone,
-                                  this);
+    m_codeliteRemoteFinder.Unbind(
+        wxEVT_CODELITE_REMOTE_FIND_RESULTS, &RemotyWorkspace::OnCodeLiteRemoteFindProgress, this);
+    m_codeliteRemoteFinder.Unbind(
+        wxEVT_CODELITE_REMOTE_FIND_RESULTS_DONE, &RemotyWorkspace::OnCodeLiteRemoteFindDone, this);
     m_codeliteRemoteFinder.Unbind(wxEVT_CODELITE_REMOTE_RESTARTED, &RemotyWorkspace::OnCodeLiteRemoteTerminated, this);
-    m_codeliteRemoteFinder.Unbind(wxEVT_CODELITE_REMOTE_LIST_FILES, &RemotyWorkspace::OnCodeLiteRemoteListFilesProgress,
-                                  this);
-    m_codeliteRemoteFinder.Unbind(wxEVT_CODELITE_REMOTE_LIST_FILES_DONE,
-                                  &RemotyWorkspace::OnCodeLiteRemoteListFilesDone, this);
+    m_codeliteRemoteFinder.Unbind(
+        wxEVT_CODELITE_REMOTE_LIST_FILES, &RemotyWorkspace::OnCodeLiteRemoteListFilesProgress, this);
+    m_codeliteRemoteFinder.Unbind(
+        wxEVT_CODELITE_REMOTE_LIST_FILES_DONE, &RemotyWorkspace::OnCodeLiteRemoteListFilesDone, this);
 
     // builder
-    m_codeliteRemoteBuilder.Unbind(wxEVT_CODELITE_REMOTE_EXEC_OUTPUT, &RemotyWorkspace::OnCodeLiteRemoteBuildOutput,
-                                   this);
-    m_codeliteRemoteBuilder.Unbind(wxEVT_CODELITE_REMOTE_EXEC_DONE, &RemotyWorkspace::OnCodeLiteRemoteBuildOutputDone,
-                                   this);
+    m_codeliteRemoteBuilder.Unbind(
+        wxEVT_CODELITE_REMOTE_EXEC_OUTPUT, &RemotyWorkspace::OnCodeLiteRemoteBuildOutput, this);
+    m_codeliteRemoteBuilder.Unbind(
+        wxEVT_CODELITE_REMOTE_EXEC_DONE, &RemotyWorkspace::OnCodeLiteRemoteBuildOutputDone, this);
     m_codeliteRemoteBuilder.Unbind(wxEVT_CODELITE_REMOTE_RESTARTED, &RemotyWorkspace::OnCodeLiteRemoteTerminated, this);
     m_eventsConnected = false;
 }
 
 void RemotyWorkspace::OnCodeLiteRemoteTerminated(clCommandEvent& event)
 {
-    if(event.GetEventObject() == &m_codeliteRemoteBuilder) {
+    if (event.GetEventObject() == &m_codeliteRemoteBuilder) {
         clWARNING() << "codelite-remote (builder) terminated" << endl;
         m_buildInProgress = false;
     }
@@ -214,11 +219,11 @@ void RemotyWorkspace::OnCodeLiteRemoteTerminated(clCommandEvent& event)
 void RemotyWorkspace::OnOpenWorkspace(clCommandEvent& event)
 {
     RemotySwitchToWorkspaceDlg dlg(EventNotifier::Get()->TopFrame());
-    if(dlg.ShowModal() != wxID_OK) {
+    if (dlg.ShowModal() != wxID_OK) {
         return;
     }
 
-    if(!dlg.IsRemote()) {
+    if (!dlg.IsRemote()) {
         event.Skip();
         event.SetFileName(dlg.GetPath());
 
@@ -230,12 +235,14 @@ void RemotyWorkspace::OnOpenWorkspace(clCommandEvent& event)
 void RemotyWorkspace::OnCloseWorkspace(clCommandEvent& event)
 {
     event.Skip();
+    // we don't fire the `XRCID("close_workspace")` event here
+    // since this is how we got here in the first place
     DoClose(true);
 }
 
 void RemotyWorkspace::Initialise()
 {
-    if(m_eventsConnected) {
+    if (m_eventsConnected) {
         return;
     }
     BindEvents();
@@ -248,7 +255,7 @@ bool RemotyWorkspace::IsOpened() const { return !m_account.GetAccountName().empt
 void RemotyWorkspace::DoClose(bool notify)
 {
     m_listLspOutput.clear();
-    if(!IsOpened()) {
+    if (!IsOpened()) {
         clDEBUG() << "Remoty: DoClose() -> not opened..." << endl;
         return;
     }
@@ -261,15 +268,16 @@ void RemotyWorkspace::DoClose(bool notify)
     m_remoteWorkspaceFile.clear();
     m_localWorkspaceFile.clear();
     m_localUserWorkspaceFile.clear();
+    m_replaceInFilesModifiedFiles.clear();
 
     m_codeliteRemoteBuilder.Stop();
     m_codeliteRemoteFinder.Stop();
 
-    // and restart all the lsp_metadata_arr
-    clLanguageServerEvent restart_event(wxEVT_LSP_RESTART_ALL);
-    EventNotifier::Get()->AddPendingEvent(restart_event);
+    //    // and restart all the lsp_metadata_arr
+    //    clLanguageServerEvent stop_event(wxEVT_LSP_STOP_ALL);
+    //    EventNotifier::Get()->ProcessEvent(stop_event);
 
-    if(notify) {
+    if (notify) {
         // notify codelite to close all opened files
         wxCommandEvent eventClose(wxEVT_MENU, wxID_CLOSE_ALL);
         eventClose.SetEventObject(EventNotifier::Get()->TopFrame());
@@ -283,7 +291,7 @@ void RemotyWorkspace::DoClose(bool notify)
 
 void RemotyWorkspace::SaveSettings()
 {
-    if(m_remoteWorkspaceFile.empty() || m_localWorkspaceFile.empty() || m_account.GetAccountName().empty()) {
+    if (m_remoteWorkspaceFile.empty() || m_localWorkspaceFile.empty() || m_account.GetAccountName().empty()) {
         return;
     }
 
@@ -295,7 +303,7 @@ void RemotyWorkspace::SaveSettings()
 void RemotyWorkspace::OnBuildStarting(clBuildEvent& event)
 {
     event.Skip();
-    if(IsOpened()) {
+    if (IsOpened()) {
         event.Skip(false);
         // before we start the build, save all modified files
         clGetManager()->SaveAll(false);
@@ -305,11 +313,11 @@ void RemotyWorkspace::OnBuildStarting(clBuildEvent& event)
 
 wxString RemotyWorkspace::GetTargetCommand(const wxString& target) const
 {
-    if(!m_settings.GetSelectedConfig()) {
+    if (!m_settings.GetSelectedConfig()) {
         return wxEmptyString;
     }
     const auto& M = m_settings.GetSelectedConfig()->GetBuildTargets();
-    if(M.count(target)) {
+    if (M.count(target)) {
         wxString cmd = M.find(target)->second;
         return cmd;
     }
@@ -320,15 +328,16 @@ void RemotyWorkspace::BuildTarget(const wxString& target)
 {
     wxBusyCursor bc;
     auto conf = m_settings.GetSelectedConfig();
-    if(!conf) {
+    if (!conf) {
         ::wxMessageBox(_("You should have at least one workspace configuration.\n0 found\nOpen the project "
                          "settings and add one"),
-                       "CodeLite", wxICON_ERROR | wxCENTER);
+                       "CodeLite",
+                       wxICON_ERROR | wxCENTER);
         return;
     }
 
     wxString cmd = GetTargetCommand(target);
-    if(cmd.IsEmpty()) {
+    if (cmd.empty()) {
         ::wxMessageBox(_("Don't know how to run '") + target + "'", "CodeLite", wxICON_ERROR | wxCENTER);
         return;
     }
@@ -342,18 +351,18 @@ void RemotyWorkspace::BuildTarget(const wxString& target)
     // we pass the selected compiler in the event
     clBuildEvent e(wxEVT_BUILD_PROCESS_STARTED);
     e.SetToolchain(conf->GetCompiler());
-    EventNotifier::Get()->AddPendingEvent(e);
+    EventNotifier::Get()->ProcessEvent(e);
 
     // Notify about build process started
     clBuildEvent eventStart(wxEVT_BUILD_STARTED);
-    EventNotifier::Get()->AddPendingEvent(eventStart);
+    EventNotifier::Get()->ProcessEvent(eventStart);
 }
 
 void RemotyWorkspace::DoPrintBuildMessage(const wxString& message)
 {
     clBuildEvent e(wxEVT_BUILD_PROCESS_ADDLINE);
     e.SetString(message);
-    EventNotifier::Get()->AddPendingEvent(e);
+    EventNotifier::Get()->ProcessEvent(e);
 }
 
 void RemotyWorkspace::OnIsBuildInProgress(clBuildEvent& event)
@@ -382,7 +391,7 @@ void RemotyWorkspace::OnCustomTargetMenu(clContextMenuEvent& event)
     const auto& targets = m_settings.GetSelectedConfig()->GetBuildTargets();
 
     std::unordered_map<int, wxString> M;
-    for(const auto& vt : targets) {
+    for (const auto& vt : targets) {
         const wxString& name = vt.first;
         int menuId = wxXmlResource::GetXRCID(vt.first);
         M.insert({ menuId, name });
@@ -391,7 +400,7 @@ void RemotyWorkspace::OnCustomTargetMenu(clContextMenuEvent& event)
             wxEVT_MENU,
             [=](wxCommandEvent& e) {
                 auto iter = M.find(e.GetId());
-                if(iter == M.end()) {
+                if (iter == M.end()) {
                     return;
                 }
                 this->CallAfter(&RemotyWorkspace::BuildTarget, iter->second);
@@ -405,37 +414,53 @@ void RemotyWorkspace::OnBuildHotspotClicked(clBuildEvent& event)
     CHECK_EVENT(event);
     wxString filename = event.GetFileName();
     int line_number = event.GetLineNumber();
+    wxString basepath = event.GetBuildDir();
 
     clDEBUG() << "Remoty: attempting to open file:" << filename << endl;
+    clDEBUG() << "Remoty: build directory:" << basepath << endl;
 
     wxFileName fn(filename);
-    if(fn.IsRelative(wxPATH_UNIX)) {
+    if (fn.IsRelative(wxPATH_UNIX)) {
         // attempt to make it absolute
-        fn.MakeAbsolute(GetRemoteWorkingDir(), wxPATH_UNIX);
+        basepath = basepath.empty() ? GetRemoteWorkingDir() : basepath;
+        fn.MakeAbsolute(basepath, wxPATH_UNIX);
         filename = fn.GetFullPath(wxPATH_UNIX);
-        clDEBUG() << "Remoty: file is relative, converting to fullpath:" << filename << endl;
+        LOG_IF_DEBUG
+        {
+            clDEBUG() << "Remoty: using basepath:" << basepath << endl;
+            clDEBUG() << "Remoty: file is relative, converting to fullpath:" << filename << endl;
+        }
     }
 
     // download the file
     wxBusyCursor bc;
     clGetManager()->GetStatusBar()->SetStatusText(_("Downloading file: ") + filename);
     auto editor = clSFTPManager::Get().OpenFile(filename, m_account.GetAccountName());
-    if(editor) {
+    if (editor) {
         // the compiler report line numbers from 1
         // clEditor start counting lines from 0
         // hence the -1
         editor->CenterLine(line_number - 1);
+        CallAfter(&RemotyWorkspace::SetFocusToActiveEditor);
     }
 }
 
+void RemotyWorkspace::SetFocusToActiveEditor()
+{
+    auto editor = clGetManager()->GetActiveEditor();
+    CHECK_PTR_RET(editor);
+
+    editor->SetActive();
+}
+
 void RemotyWorkspace::OnNewWorkspace(clCommandEvent& event)
 {
     event.Skip();
-    if(event.GetString() == GetWorkspaceType()) {
+    if (event.GetString() == GetWorkspaceType()) {
         event.Skip(false);
         // Prompt the user for folder and name
         RemotyNewWorkspaceDlg dlg(EventNotifier::Get()->TopFrame());
-        if(dlg.ShowModal() != wxID_OK) {
+        if (dlg.ShowModal() != wxID_OK) {
             return;
         }
 
@@ -453,8 +478,9 @@ void RemotyWorkspace::OnNewWorkspace(clCommandEvent& event)
         remote_path << "/" << name << ".workspace";
         // upload this file to the remote location
         clDEBUG() << "Writing file: [" << account << "]" << tmpfile.GetFullPath() << "->" << remote_path << endl;
-        if(!clSFTPManager::Get().AwaitSaveFile(tmpfile.GetFullPath(), remote_path, account)) {
-            ::wxMessageBox(wxString() << _("Failed to create new workspace file:\n") << remote_path, "CodeLite",
+        if (!clSFTPManager::Get().AwaitSaveFile(tmpfile.GetFullPath(), remote_path, account)) {
+            ::wxMessageBox(wxString() << _("Failed to create new workspace file:\n") << remote_path,
+                           "CodeLite",
                            wxOK | wxICON_ERROR);
             return;
         }
@@ -471,37 +497,32 @@ void RemotyWorkspace::OnNewWorkspace(clCommandEvent& event)
 void RemotyWorkspace::DoOpen(const wxString& file_path, const wxString& account)
 {
     // Close any opened workspace
-    auto frame = EventNotifier::Get()->TopFrame();
-    wxCommandEvent eventCloseWsp(wxEVT_COMMAND_MENU_SELECTED, XRCID("close_workspace"));
-    eventCloseWsp.SetEventObject(frame);
-    frame->GetEventHandler()->ProcessEvent(eventCloseWsp);
-
-    // close any previously opened workspace
-    DoClose(true);
+    CloseWorkspace();
 
     // Load the account
     auto ssh_account = SSHAccountInfo::LoadAccount(account);
 
-    if(ssh_account.GetAccountName().empty()) {
-        ::wxMessageBox(_("Could not find a matching SSH account to load the workspace!"), "CodeLite",
-                       wxICON_ERROR | wxCENTER);
+    if (ssh_account.GetAccountName().empty()) {
+        ::wxMessageBox(
+            _("Could not find a matching SSH account to load the workspace!"), "CodeLite", wxICON_ERROR | wxCENTER);
         return;
     }
 
     wxBusyCursor bc;
     wxFileName localFile;
-    for(size_t i = 0; i < MAX_LOAD_WORKSPACE_RETRIES; ++i) {
+    for (size_t i = 0; i < MAX_LOAD_WORKSPACE_RETRIES; ++i) {
         // first: attempt to download the workspace file and store it locally
         localFile = clSFTPManager::Get().Download(file_path, account);
-        if(localFile.IsOk()) {
+        if (localFile.IsOk()) {
             break;
         }
 
         // check if we can do another retry
-        if((i + 1) >= MAX_LOAD_WORKSPACE_RETRIES) {
+        if ((i + 1) >= MAX_LOAD_WORKSPACE_RETRIES) {
             // retries exhausted
             ::wxMessageBox(_("Failed to download remote workspace file!\n") + clSFTPManager::Get().GetLastError(),
-                           "CodeLite", wxICON_ERROR | wxCENTER);
+                           "CodeLite",
+                           wxICON_ERROR | wxCENTER);
             return;
         }
         clGetManager()->SetStatusMessage(_("Retrying to load workspace..."));
@@ -512,9 +533,9 @@ void RemotyWorkspace::DoOpen(const wxString& file_path, const wxString& account)
     userSettings.AppendDir("LocalWorkspaces");
     userSettings.Mkdir(wxPATH_MKDIR_FULL);
     clDEBUG() << "User workspace file is set:" << userSettings << endl;
-    if(!m_settings.Load(localFile, userSettings)) {
-        ::wxMessageBox(_("Failed to load workspace file: ") + m_localWorkspaceFile, "CodeLite",
-                       wxICON_ERROR | wxCENTER);
+    if (!m_settings.Load(localFile, userSettings)) {
+        ::wxMessageBox(
+            _("Failed to load workspace file: ") + m_localWorkspaceFile, "CodeLite", wxICON_ERROR | wxCENTER);
         return;
     }
 
@@ -526,7 +547,7 @@ void RemotyWorkspace::DoOpen(const wxString& file_path, const wxString& account)
     wxString fixed_path = file_path;
     fixed_path.Replace("\\", "/");
     wxString workspacePath = GetRemoteWorkingDir();
-    if(workspacePath.empty()) {
+    if (workspacePath.empty()) {
         ::wxMessageBox(_("Invalid empty remote path provided"), "CodeLite", wxICON_ERROR | wxCENTER);
         return;
     }
@@ -539,11 +560,12 @@ void RemotyWorkspace::DoOpen(const wxString& file_path, const wxString& account)
     // wrap the command in ssh
     wxString ssh_exe;
     EnvSetter setter;
-    if(!ThePlatform->Which("ssh", &ssh_exe)) {
+    if (!ThePlatform->Which("ssh", &ssh_exe)) {
         ::wxMessageBox(
             _("Could not locate ssh executable in your PATH!\nUpdate your PATH from 'settings -> environment "
               "variables' to a location that contains your 'ssh' executable"),
-            "CodeLite", wxICON_ERROR | wxOK | wxCENTER);
+            "CodeLite",
+            wxICON_ERROR | wxOK | wxCENTER);
     }
 
     RestartCodeLiteRemote(&m_codeliteRemoteBuilder, CONTEXT_BUILDER);
@@ -557,7 +579,12 @@ void RemotyWorkspace::DoOpen(const wxString& file_path, const wxString& account)
     open_event.SetString(m_remoteWorkspaceFile);
     open_event.SetRemoteAccount(m_account.GetAccountName());
     open_event.SetWorkspaceType(GetWorkspaceType());
-    EventNotifier::Get()->AddPendingEvent(open_event);
+
+    // we need this to be processed first
+    clRemoteHost::Instance()->ProcessEvent(open_event);
+
+    // Fire the `wxEVT_WORKSPACE_LOADED` event
+    EventNotifier::Get()->ProcessEvent(open_event);
 
     // update the remote workspace list
     RemotyConfig config;
@@ -576,13 +603,13 @@ void RemotyWorkspace::OnDebugStarting(clDebugEvent& event)
 
     DebuggerMgr::Get().SetActiveDebugger(conf->GetDebugger());
     IDebugger* dbgr = DebuggerMgr::Get().GetActiveDebugger();
-    if(!dbgr) {
+    if (!dbgr) {
         return;
     }
 
     // if already running, skip this
     // the default behaviour is to "continue"
-    if(dbgr->IsRunning()) {
+    if (dbgr->IsRunning()) {
         event.Skip();
         return;
     }
@@ -615,9 +642,10 @@ void RemotyWorkspace::OnDebugStarting(clDebugEvent& event)
 
     // open new terminal on the remote host
     m_remote_terminal.reset(new clRemoteTerminal(m_account));
-    if(!m_remote_terminal->Start()) {
+    if (!m_remote_terminal->Start()) {
         ::wxMessageBox(_("Failed to start remote terminal process. Do you have `ssh` client installed and in PATH?"),
-                       "CodeLite", wxICON_ERROR | wxOK | wxOK_DEFAULT);
+                       "CodeLite",
+                       wxICON_ERROR | wxOK | wxOK_DEFAULT);
         return;
     }
 
@@ -627,9 +655,9 @@ void RemotyWorkspace::OnDebugStarting(clDebugEvent& event)
     wxString tty;
 
     clDEBUG() << "Waiting for tty..." << endl;
-    while(--count) {
+    while (--count) {
         tty = m_remote_terminal->ReadTty();
-        if(tty.empty()) {
+        if (tty.empty()) {
             wxMilliSleep(100);
         } else {
             break;
@@ -645,7 +673,7 @@ void RemotyWorkspace::OnDebugStarting(clDebugEvent& event)
     envmap.insert(envlist.begin(), envlist.end());
 
     // override the gdb executable with the one provided with the GDB environment variable
-    if(envmap.count("GDB")) {
+    if (envmap.count("GDB")) {
         const wxString& gdbpath = envmap["GDB"];
         sesstion_info.debuggerPath = gdbpath;
     }
@@ -655,7 +683,7 @@ void RemotyWorkspace::OnDebugStarting(clDebugEvent& event)
     sesstion_info.enablePrettyPrinting = true;
 
     clDEBUG() << "Starting gdb:" << sesstion_info.debuggerPath << endl;
-    if(!dbgr->Start(sesstion_info, &envlist)) {
+    if (!dbgr->Start(sesstion_info, &envlist)) {
         // message box about this and cancel the debugge session
         ::wxMessageBox(_("Failed to start debugger!"), "CodeLite", wxICON_ERROR | wxOK | wxOK_DEFAULT);
         clDebugEvent eventStarted(wxEVT_DEBUG_ENDED);
@@ -687,7 +715,7 @@ IProcess* RemotyWorkspace::DoRunSSHProcess(const wxString& scriptContent, bool s
     wxString path = UploadScript(scriptContent);
     std::vector<wxString> args = { "/bin/bash", path };
     size_t flags = IProcessCreateDefault | IProcessCreateSSH;
-    if(sync) {
+    if (sync) {
         flags |= IProcessCreateSync;
     }
     return ::CreateAsyncProcess(this, args, flags, wxEmptyString, nullptr, m_account.GetAccountName());
@@ -709,7 +737,7 @@ void RemotyWorkspace::OnRun(clExecuteEvent& event)
 
     wxString command;
     command = conf->GetExecutable();
-    if(command.empty()) {
+    if (command.empty()) {
         ::wxMessageBox(_("Please specify an executable to run"), "CodeLite", wxICON_ERROR | wxOK | wxOK_DEFAULT);
         return;
     }
@@ -723,7 +751,7 @@ void RemotyWorkspace::OnRun(clExecuteEvent& event)
     auto args_arr = StringUtils::BuildArgv(args);
 
     // append the args
-    for(auto& arg : args_arr) {
+    for (auto& arg : args_arr) {
         arg.Trim().Trim(false);
         // wrap with quotes if required
         ::WrapWithQuotes(arg);
@@ -734,7 +762,7 @@ void RemotyWorkspace::OnRun(clExecuteEvent& event)
     wxString wd = conf->GetWorkingDirectory();
     wd.Trim().Trim(false);
 
-    if(wd.empty()) {
+    if (wd.empty()) {
         wd = GetRemoteWorkingDir();
     }
 
@@ -766,7 +794,7 @@ void RemotyWorkspace::OnRun(clExecuteEvent& event)
 void RemotyWorkspace::OnStop(clExecuteEvent& event)
 {
     CHECK_EVENT(event);
-    if(m_execPID != wxNOT_FOUND) {
+    if (m_execPID != wxNOT_FOUND) {
         ::clKill(m_execPID, wxSIGTERM, true, false);
         m_execPID = wxNOT_FOUND;
     }
@@ -782,7 +810,7 @@ wxString RemotyWorkspace::CreateEnvScriptContent() const
 
     wxString content;
     content << "# prepare the environment variables\n";
-    for(auto& vt : envmap) {
+    for (auto& vt : envmap) {
         content << "export " << vt.first << "=" << ::WrapWithQuotes(vt.second) << "\n";
     }
     return content;
@@ -798,11 +826,11 @@ wxString RemotyWorkspace::UploadScript(const wxString& content, const wxString&
     default_path << "/tmp/codelite-remoty." << clGetUserName() << ".sh";
 
     wxString path = default_path;
-    if(!script_path.empty()) {
+    if (!script_path.empty()) {
         path = script_path;
     }
 
-    if(!clSFTPManager::Get().AwaitWriteFile(script_content, path, m_account.GetAccountName())) {
+    if (!clSFTPManager::Get().AwaitWriteFile(script_content, path, m_account.GetAccountName())) {
         ::wxMessageBox(_("Failed to write remote script on the remote machine!"), "CodeLite", wxICON_ERROR | wxCENTER);
         return wxEmptyString;
     }
@@ -824,11 +852,11 @@ void RemotyWorkspace::OnExecProcessTerminated(clProcessEvent& event)
 void RemotyWorkspace::OnFindSwapped(clFileSystemEvent& event)
 {
     auto editor = clGetManager()->GetActiveEditor();
-    if(!editor) {
+    if (!editor) {
         event.Skip();
         return;
     }
-    if(!editor->IsRemoteFile()) {
+    if (!editor->IsRemoteFile()) {
         event.Skip();
         return;
     }
@@ -837,7 +865,7 @@ void RemotyWorkspace::OnFindSwapped(clFileSystemEvent& event)
 
     // replace the file extension
     auto type = FileExtManager::GetTypeFromExtension(editor->GetFileName().GetFullName());
-    if(type == FileExtManager::TypeSourceC || type == FileExtManager::TypeSourceCpp) {
+    if (type == FileExtManager::TypeSourceC || type == FileExtManager::TypeSourceCpp) {
         // try to find a header file
         exts.push_back("h");
         exts.push_back("hpp");
@@ -854,10 +882,10 @@ void RemotyWorkspace::OnFindSwapped(clFileSystemEvent& event)
     }
 
     wxString remote_path = editor->GetRemotePath();
-    for(const auto& other_ext : exts) {
+    for (const auto& other_ext : exts) {
         remote_path = remote_path.BeforeLast('.');
         remote_path << "." << other_ext;
-        if(clSFTPManager::Get().IsFileExists(remote_path, m_account)) {
+        if (clSFTPManager::Get().IsFileExists(remote_path, m_account)) {
             // open this file
             auto other_editor = clSFTPManager::Get().OpenFile(remote_path, m_account);
             event.SetPath(other_editor->GetFileName().GetFullPath());
@@ -870,13 +898,13 @@ void RemotyWorkspace::RestartCodeLiteRemote(clCodeLiteRemoteProcess* proc, const
     CHECK_PTR_RET(proc);
 
     // if running and restart is true, restart codelite-remote
-    if(proc->IsRunning() && restart) {
+    if (proc->IsRunning() && restart) {
         clDEBUG() << "Stopping codelite-remote..." << endl;
         proc->Stop();
     }
 
     // make sure we are not running
-    if(proc->IsRunning()) {
+    if (proc->IsRunning()) {
         clDEBUG() << "codelite-remote is already running" << endl;
         return;
     }
@@ -908,6 +936,7 @@ void RemotyWorkspace::OnCodeLiteRemoteListFilesDone(clCommandEvent& event)
     // notify that scan is completed
     clDEBUG() << "Sending wxEVT_WORKSPACE_FILES_SCANNED event..." << endl;
     clWorkspaceEvent event_scan{ wxEVT_WORKSPACE_FILES_SCANNED };
+    event_scan.SetIsRemote(true);
     EventNotifier::Get()->ProcessEvent(event_scan);
 }
 
@@ -915,18 +944,17 @@ void RemotyWorkspace::ScanForWorkspaceFiles()
 {
     wxString root_dir = GetRemoteWorkingDir();
     wxString file_extensions = GetSettings().GetSelectedConfig()->GetFileExtensions();
-    file_extensions.Replace("*", "");
 
     auto files_exts = ::wxStringTokenize(file_extensions, ";,", wxTOKEN_STRTOK);
     std::unordered_set<wxString> S{ files_exts.begin(), files_exts.end() };
 
     // common file extensions
-    S.insert(".txt");
-    S.insert(".toml");
+    S.insert("*.txt");
+    S.insert("*.toml");
     S.insert("Rakefile");
 
     file_extensions.clear();
-    for(const auto& s : S) {
+    for (const auto& s : S) {
         file_extensions << s << ";";
     }
     m_workspaceFiles.clear();
@@ -941,7 +969,7 @@ void RemotyWorkspace::OnOpenResourceFile(clCommandEvent& event)
 
     // our event
     auto editor = clSFTPManager::Get().OpenFile(event.GetFileName(), m_account);
-    if(editor) {
+    if (editor) {
         editor->GetCtrl()->GotoLine(event.GetLineNumber());
     }
 }
@@ -954,17 +982,92 @@ void RemotyWorkspace::OnShutdown(clCommandEvent& event)
 
 void RemotyWorkspace::OnInitDone(wxCommandEvent& event) { event.Skip(); }
 
-void RemotyWorkspace::FindInFiles(const wxString& root_dir, const wxString& file_extensions, const wxString& find_what,
-                                  bool whole_word, bool icase)
+void RemotyWorkspace::ReplaceInFiles(const wxString& root_dir,
+                                     const wxString& file_extensions,
+                                     const wxString& find_what,
+                                     const wxString& replace_with,
+                                     bool whole_word,
+                                     bool icase)
+{
+    m_replaceInFilesModifiedFiles.clear();
+    wxString search_folder = root_dir;
+    if (search_folder == "<Workspace Folder>") {
+        search_folder = GetRemoteWorkingDir();
+    }
+
+    wxStandardID answer = ::PromptForYesNoCancelDialogWithCheckbox(
+        _("You are about to execute a remote replace in files\nDo you wish to continue?"),
+        "remoty-prompt-before-replace-in-files");
+    if (answer != wxID_YES) {
+        return;
+    }
+
+    m_codeliteRemoteFinder.Replace(search_folder, file_extensions, find_what, replace_with, whole_word, icase);
+}
+
+void RemotyWorkspace::FindInFiles(
+    const wxString& root_dir, const wxString& file_extensions, const wxString& find_what, bool whole_word, bool icase)
 {
     m_remoteFinder.SetCodeLiteRemote(&m_codeliteRemoteFinder);
     wxString search_folder = root_dir;
-    if(search_folder == "<Workspace Folder>") {
+    if (search_folder == "<Workspace Folder>") {
         search_folder = GetRemoteWorkingDir();
     }
     m_remoteFinder.Search(search_folder, find_what, file_extensions, whole_word, icase);
 }
 
+void RemotyWorkspace::OnCodeLiteRemoteReplaceProgress(clFindInFilesEvent& event)
+{
+    event.Skip();
+    for (const wxString& file : event.GetStrings()) {
+        m_replaceInFilesModifiedFiles.insert(file);
+    }
+}
+
+void RemotyWorkspace::OnCodeLiteRemoteReplaceDone(clFindInFilesEvent& event)
+{
+    event.Skip();
+
+    // prompt the user to load the modified files
+    IEditor::List_t editors;
+    clGetManager()->GetAllEditors(editors);
+
+    std::unordered_set<IEditor*> open_editors;
+    open_editors.reserve(editors.size());
+    for (auto editor : editors) {
+        if (editor->IsRemoteFile() && m_replaceInFilesModifiedFiles.count(editor->GetRemotePath())) {
+            open_editors.insert(editor);
+        }
+    }
+
+    // this event will trigger a git refresh
+    clFileSystemEvent fs_event{ wxEVT_FILES_MODIFIED_REPLACE_IN_FILES };
+    EventNotifier::Get()->AddPendingEvent(fs_event);
+
+    wxString message;
+    message << _("Remote replace in files completed, would you like to reload the following modified files:\n");
+    for (auto editor : editors) {
+        message << editor->GetRemotePath() << "\n";
+    }
+
+    wxStandardID answer =
+        ::PromptForYesNoCancelDialogWithCheckbox(message,
+                                                 "remoty-reload-after-replace-in-files",
+                                                 _("Reload"),
+                                                 _("No"),
+                                                 _("Cancel"),
+                                                 _("Remember my answer and don't ask me again"),
+                                                 wxYES_NO | wxCANCEL | wxICON_QUESTION | wxCANCEL_DEFAULT);
+    if (answer != wxID_YES) {
+        return;
+    }
+
+    wxBusyCursor bc;
+    for (auto editor : editors) {
+        editor->ReloadFromDisk();
+    }
+}
+
 void RemotyWorkspace::OnCodeLiteRemoteFindProgress(clFindInFilesEvent& event)
 {
     m_remoteFinder.ProcessSearchOutput(event, false);
@@ -988,11 +1091,11 @@ void RemotyWorkspace::OnCodeLiteRemoteBuildOutputDone(clProcessEvent& event)
 
 void RemotyWorkspace::DoProcessBuildOutput(const wxString& output, bool is_completed)
 {
-    if(!output.empty()) {
+    if (!output.empty()) {
         DoPrintBuildMessage(output);
     }
 
-    if(is_completed) {
+    if (is_completed) {
         clBuildEvent e(wxEVT_BUILD_PROCESS_ENDED);
         EventNotifier::Get()->AddPendingEvent(e);
 
@@ -1006,11 +1109,11 @@ void RemotyWorkspace::OnLSPOpenFile(LSPEvent& event)
 {
     CHECK_EVENT(event);
     auto editor = clSFTPManager::Get().OpenFile(event.GetFileName(), m_account);
-    if(!editor) {
+    if (!editor) {
         event.Skip();
         return;
     }
-    editor->SelectRange(event.GetLocation().GetRange());
+    editor->SelectRangeAfter(event.GetLocation().GetRange());
 }
 
 wxString RemotyWorkspace::GetName() const { return wxFileName(m_localWorkspaceFile).GetName(); }
@@ -1029,11 +1132,11 @@ void LSPParams::From(const JSONItem& json)
     this->priority = json["priority"].toSize_t(80);
 
     int env_list_size = json["env"].arraySize();
-    for(int i = 0; i < env_list_size; ++i) {
+    for (int i = 0; i < env_list_size; ++i) {
         auto env_entry = json["env"][i];
         wxString name = env_entry["name"].toString();
         wxString value = env_entry["value"].toString();
-        if(!name.empty()) {
+        if (!name.empty()) {
             this->env.push_back({ name, value });
         }
     }
@@ -1046,7 +1149,7 @@ void RemotyWorkspace::OnDownloadFile(clCommandEvent& event)
     clDEBUG() << "Downloading file:" << event.GetFileName() << "using account:" << m_account.GetName() << endl;
     CHECK_EVENT(event);
     auto editor = clSFTPManager::Get().OpenFile(event.GetFileName(), m_account);
-    if(editor) {
+    if (editor) {
         // update the event with the local file's fullpath
         event.SetFileName(editor->GetFileName().GetFullPath());
         event.Skip(false);
@@ -1054,18 +1157,39 @@ void RemotyWorkspace::OnDownloadFile(clCommandEvent& event)
 }
 
 void RemotyWorkspace::OpenWorkspace(const wxString& path, const wxString& account) { DoOpen(path, account); }
+void RemotyWorkspace::CloseWorkspace()
+{
+    if (!clWorkspaceManager::Get().IsWorkspaceOpened()) {
+        // nothing is opened
+        return;
+    }
+
+    // Close any opened workspace
+    auto frame = EventNotifier::Get()->TopFrame();
+    wxCommandEvent eventCloseWsp(wxEVT_COMMAND_MENU_SELECTED, XRCID("close_workspace"));
+    eventCloseWsp.SetEventObject(frame);
+    frame->GetEventHandler()->ProcessEvent(eventCloseWsp);
+
+    // close any previously opened workspace
+    DoClose(true);
+}
 
 void RemotyWorkspace::OnReloadWorkspace(clCommandEvent& event)
 {
     CHECK_EVENT(event);
     wxString filepath = GetRemoteWorkspaceFile();
     wxString account_name = GetAccount().GetAccountName();
+
+    // close the current workspace
+    CloseWorkspace();
+
+    // re-open it
     CallAfter(&RemotyWorkspace::OpenWorkspace, filepath, account_name);
 }
 
 IEditor* RemotyWorkspace::OpenFile(const wxString& remote_file_path)
 {
-    if(!IsOpened())
+    if (!IsOpened())
         return nullptr;
     return clSFTPManager::Get().OpenFile(remote_file_path, m_account);
 }
@@ -1075,29 +1199,30 @@ void RemotyWorkspace::OpenAndEditCodeLiteRemoteJson()
     wxString remote_file_path = GetRemoteWorkingDir();
     remote_file_path << "/.codelite/codelite-remote.json";
     IEditor* editor = OpenFile(remote_file_path);
-    if(editor) {
+    if (editor) {
         return;
     }
     // Could not find the file, prompt the user
-    if(wxMessageBox(_("Could not find codelite-remote.json file\nWould you like to create one?"), "CodeLite",
-                    wxICON_QUESTION | wxYES_NO | wxCANCEL | wxCANCEL_DEFAULT | wxCENTRE) != wxYES) {
+    if (wxMessageBox(_("Could not find codelite-remote.json file\nWould you like to create one?"),
+                     "CodeLite",
+                     wxICON_QUESTION | wxYES_NO | wxCANCEL | wxCANCEL_DEFAULT | wxCENTRE) != wxYES) {
         return;
     }
 
     wxString remote_file_dir = GetRemoteWorkingDir() + "/.codelite";
-    if(!clSFTPManager::Get().NewFolder(remote_file_dir, m_account)) {
+    if (!clSFTPManager::Get().NewFolder(remote_file_dir, m_account)) {
         wxMessageBox(_("Failed to create directory: ") + remote_file_dir, "CodeLite", wxICON_ERROR | wxOK);
         return;
     }
 
     // create a new file
-    if(!clSFTPManager::Get().NewFile(remote_file_path, m_account)) {
+    if (!clSFTPManager::Get().NewFile(remote_file_path, m_account)) {
         wxMessageBox(_("Failed to create file: ") + remote_file_path, "CodeLite", wxICON_ERROR | wxOK);
         return;
     }
 
     editor = OpenFile(remote_file_path);
-    if(!editor) {
+    if (!editor) {
         wxMessageBox(_("Failed to open file: ") + remote_file_path, "CodeLite", wxICON_ERROR | wxOK);
         return;
     }
@@ -1108,7 +1233,7 @@ void RemotyWorkspace::OpenAndEditCodeLiteRemoteJson()
 void RemotyWorkspace::OnStopFindInFiles(clFindInFilesEvent& event)
 {
     event.Skip();
-    if(IsOpened() && m_codeliteRemoteFinder.IsRunning()) {
+    if (IsOpened() && m_codeliteRemoteFinder.IsRunning()) {
         RestartCodeLiteRemote(&m_codeliteRemoteFinder, CONTEXT_FINDER, true);
         // send event notifying that the search has been cancelled
         m_remoteFinder.NotifySearchCancelled();
@@ -1129,7 +1254,7 @@ void RemotyWorkspace::RestoreSession()
 
 wxString RemotyWorkspace::GetDebuggerName() const
 {
-    if(m_settings.GetSelectedConfig()) {
+    if (m_settings.GetSelectedConfig()) {
         return m_settings.GetSelectedConfig()->GetDebugger();
     } else {
         return wxEmptyString;
@@ -1139,16 +1264,27 @@ wxString RemotyWorkspace::GetDebuggerName() const
 void RemotyWorkspace::OnSftpSaveError(clCommandEvent& event)
 {
     event.Skip();
-    if(!IsOpened()) {
+    if (!IsOpened()) {
         return;
     }
-    ::wxMessageBox(_("Failed to save file: ") + event.GetFileName(), "CodeLite", wxICON_WARNING | wxOK | wxCENTRE);
+
+    // Attempt to reconnect
+    wxBusyCursor bc;
+    clGetManager()->SetStatusMessage(wxString() << _("Reconnecting to: ") << event.GetSshAccount());
+    wxYield();
+    if (clSFTPManager::Get().AddConnection(event.GetSshAccount(), true)) {
+        clGetManager()->GetActiveEditor()->Save();
+    } else {
+        ::wxMessageBox(_("Failed to save file: ") + event.GetFileName() + "\n" + event.GetString(),
+                       "CodeLite (Remoty)",
+                       wxICON_WARNING | wxOK | wxCENTRE);
+    }
 }
 
 void RemotyWorkspace::OnSftpSaveSuccess(clCommandEvent& event)
 {
     event.Skip();
-    if(!IsOpened()) {
+    if (!IsOpened()) {
         return;
     }
     clGetManager()->SetStatusMessage(_("Remote file: ") + event.GetFileName() + _(" successfully saved"));
