@@ -1,10 +1,11 @@
 #include "RemotyWorkspaceView.hpp"
 
+#include "AsyncProcess/asyncprocess.h"
+#include "AsyncProcess/processreaderthread.h"
+#include "FileSystemWorkspace/clFileSystemWorkspaceConfig.hpp"
+#include "FileSystemWorkspace/clFileSystemWorkspaceDlg.h"
 #include "RemotyWorkspace.hpp"
 #include "SFTPClientData.hpp"
-#include "asyncprocess.h"
-#include "clFileSystemWorkspaceConfig.hpp"
-#include "clFileSystemWorkspaceDlg.h"
 #include "clRemoteFindDialog.h"
 #include "clSFTPManager.hpp"
 #include "codelite_events.h"
@@ -13,15 +14,14 @@
 #include "globals.h"
 #include "ieditor.h"
 #include "imanager.h"
-#include "processreaderthread.h"
 #include "search_thread.h"
-#include "ssh_account_info.h"
-#include "wx/event.h"
-#include "wx/tokenzr.h"
-#include "wx/wxcrt.h"
+#include "ssh/ssh_account_info.h"
 
 #include <wx/arrstr.h>
+#include <wx/event.h>
 #include <wx/msgdlg.h>
+#include <wx/tokenzr.h>
+#include <wx/wxcrt.h>
 #include <wx/xrc/xmlres.h>
 
 RemotyWorkspaceView::RemotyWorkspaceView(wxWindow* parent, RemotyWorkspace* workspace)
@@ -189,8 +189,13 @@ void RemotyWorkspaceView::OnFindInFilesShowing(clFindInFilesEvent& event)
     }
 
     // start the search
-    m_workspace->FindInFiles(dlg.GetWhere(), dlg.GetFileExtensions(), dlg.GetFindWhat(), dlg.IsWholeWord(),
-                             dlg.IsIcase());
+    if(dlg.IsReplaceAction()) {
+        m_workspace->ReplaceInFiles(dlg.GetWhere(), dlg.GetFileExtensions(), dlg.GetFindWhat(), dlg.GetReplaceWith(),
+                                    dlg.IsWholeWord(), dlg.IsIcase());
+    } else {
+        m_workspace->FindInFiles(dlg.GetWhere(), dlg.GetFileExtensions(), dlg.GetFindWhat(), dlg.IsWholeWord(),
+                                 dlg.IsIcase());
+    }
 }
 
 void RemotyWorkspaceView::OnOpenFindInFilesMatch(clFindInFilesEvent& event)
@@ -213,11 +218,12 @@ void RemotyWorkspaceView::OnOpenFindInFilesMatch(clFindInFilesEvent& event)
     if(editor) {
         // sci is 0 based line numbers
         auto callback = [=](IEditor* peditor) {
+            int editor_line = loc.line - 1;
             peditor->GetCtrl()->ClearSelections();
-            int pos_start = peditor->PosFromLine(loc.line - 1) + loc.column_start;
-            int pos_end = peditor->PosFromLine(loc.line - 1) + loc.column_end;
-            peditor->GetCtrl()->SetSelection(pos_start, pos_end);
-            peditor->CenterLinePreserveSelection(loc.line);
+            int pos = peditor->PosFromLine(editor_line);
+            peditor->SetActive();
+            peditor->SetCaretAt(pos);
+            peditor->CenterLinePreserveSelection(editor_line);
         };
         // load the local file (or make it selected) and then focus on the matched line
         clGetManager()->OpenFileAndAsyncExecute(editor->GetFileName().GetFullPath(), callback);
