@@ -1,6 +1,7 @@
 #include "clRemoteTerminal.hpp"
 
-#include "asyncprocess.h"
+#include "AsyncProcess/asyncprocess.h"
+#include "Platform/Platform.hpp"
 #include "environmentconfig.h"
 #include "file_logger.h"
 #include "globals.h"
@@ -22,9 +23,8 @@ bool clRemoteTerminal::Start()
     }
 
     // wrap the command in ssh
-    wxFileName ssh_exe;
-    EnvSetter setter;
-    if(!FileUtils::FindExe("ssh", ssh_exe)) {
+    wxString ssh_exe;
+    if(!ThePlatform->Which("ssh", &ssh_exe)) {
         clERROR() << "Could not locate ssh executable in your PATH!" << endl;
         return false;
     }
