@@ -8,15 +8,10 @@
 #include <wx/menu.h>
 #include <wx/xrc/xmlres.h>
 
-static SmartCompletion* thePlugin = NULL;
-
 // Define the plugin entry point
 CL_PLUGIN_API IPlugin* CreatePlugin(IManager* manager)
 {
-    if(thePlugin == NULL) {
-        thePlugin = new SmartCompletion(manager);
-    }
-    return thePlugin;
+    return new SmartCompletion(manager);
 }
 
 CL_PLUGIN_API PluginInfo* GetPluginInfo()
