@@ -37,13 +37,21 @@
 #include "file_logger.h"
 #include "globals.h"
 #include "macros.h"
-#include "wx/wxprec.h"
+
+#include <wx/wxprec.h>
+
 #include <wx/log.h>
 
 #ifndef WX_PRECOMP
-#include "wx/wx.h"
+#include <wx/wx.h>
 #endif
 
+#include "CorrectSpellingDlg.h"
+#include "IHunSpell.h"
+#include "ctags_manager.h"
+#include "scGlobals.h"
+#include "spellcheck.h"
+
 #include <wx/arrimpl.cpp>
 #include <wx/filename.h>
 #include <wx/regex.h>
@@ -51,11 +59,114 @@
 #include <wx/textfile.h>
 #include <wx/tokenzr.h>
 
-#include "CorrectSpellingDlg.h"
-#include "IHunSpell.h"
-#include "ctags_manager.h"
-#include "scGlobals.h"
-#include "spellcheck.h"
+namespace
+{
+/// Keep a set of styles per lexer-id that should be checked for spelling
+
+/// Only STRING styles
+std::unordered_map<int, std::unordered_set<int>> ALLOWED_STYLES_STRINGS = {
+    { wxSTC_LEX_ASM, { wxSTC_ASM_STRING } },
+    { wxSTC_LEX_BASH, { wxSTC_SH_STRING } },
+    { wxSTC_LEX_CMAKE, { wxSTC_CMAKE_STRINGDQ, wxSTC_CMAKE_STRINGLQ, wxSTC_CMAKE_STRINGRQ } },
+    { wxSTC_LEX_CSS, { wxSTC_CSS_DOUBLESTRING, wxSTC_CSS_SINGLESTRING } },
+    { wxSTC_LEX_CPP, { wxSTC_C_STRING, wxSTC_C_STRINGRAW, wxSTC_C_STRINGEOL } },
+    { wxSTC_LEX_FORTRAN, { wxSTC_F_STRING1, wxSTC_F_STRING2 } },
+    { wxSTC_LEX_INNOSETUP, { wxSTC_INNO_STRING_DOUBLE, wxSTC_INNO_STRING_SINGLE } },
+    { wxSTC_LEX_JSON, { wxSTC_JSON_STRING, wxSTC_JSON_STRINGEOL } },
+    { wxSTC_LEX_LUA, { wxSTC_LUA_STRING, wxSTC_LUA_LITERALSTRING, wxSTC_LUA_STRINGEOL } },
+    { wxSTC_LEX_MARKDOWN, { wxSTC_MARKDOWN_DEFAULT } },
+    { wxSTC_LEX_HTML,
+      {
+          wxSTC_H_DOUBLESTRING,
+          wxSTC_H_SINGLESTRING,
+          wxSTC_HJ_DOUBLESTRING,
+          wxSTC_HJ_SINGLESTRING,
+          wxSTC_HJ_STRINGEOL,
+          wxSTC_HPHP_HSTRING,
+          wxSTC_HPHP_SIMPLESTRING,
+      } },
+    { wxSTC_LEX_PYTHON,
+      {
+          wxSTC_P_STRING,
+          wxSTC_P_STRINGEOL,
+          wxSTC_P_TRIPLE,
+          wxSTC_P_TRIPLEDOUBLE,
+#if wxCHECK_VERSION(3, 3, 0)
+          wxSTC_P_FSTRING,
+          wxSTC_P_FCHARACTER,
+          wxSTC_P_FTRIPLE,
+          wxSTC_P_FTRIPLEDOUBLE,
+#endif
+      } },
+    { wxSTC_LEX_RUBY,
+      {
+          wxSTC_RB_STRING,
+          wxSTC_RB_STRING_Q,
+          wxSTC_RB_STRING_QQ,
+          wxSTC_RB_STRING_QX,
+          wxSTC_RB_STRING_QR,
+          wxSTC_RB_STRING_QW,
+      } },
+    { wxSTC_LEX_RUST,
+      {
+          wxSTC_RUST_STRING,
+          wxSTC_RUST_STRINGR,
+          wxSTC_RUST_BYTESTRING,
+          wxSTC_RUST_BYTESTRINGR,
+      } },
+    { wxSTC_LEX_NULL, { 0 } },
+};
+
+/// Only COMMENT styles
+std::unordered_map<int, std::unordered_set<int>> ALLOWED_STYLES_COMMENTS = {
+    { wxSTC_LEX_ASM, { wxSTC_ASM_COMMENT, wxSTC_ASM_COMMENTBLOCK, wxSTC_ASM_COMMENTDIRECTIVE } },
+    { wxSTC_LEX_BASH, { wxSTC_SH_COMMENTLINE } },
+    { wxSTC_LEX_BATCH, { wxSTC_BAT_COMMENT } },
+    { wxSTC_LEX_CMAKE, { wxSTC_CMAKE_COMMENT } },
+    { wxSTC_LEX_CSS, { wxSTC_CSS_COMMENT } },
+    { wxSTC_LEX_CPP, { wxSTC_C_COMMENT, wxSTC_C_COMMENTDOC, wxSTC_C_COMMENTLINE, wxSTC_C_COMMENTLINEDOC } },
+    { wxSTC_LEX_DIFF, { wxSTC_DIFF_COMMENT } },
+    { wxSTC_LEX_FORTRAN, { wxSTC_F_COMMENT } },
+    { wxSTC_LEX_PROPERTIES, { wxSTC_PROPS_COMMENT } },
+    { wxSTC_LEX_INNOSETUP, { wxSTC_INNO_COMMENT } },
+    { wxSTC_LEX_JSON, { wxSTC_JSON_LINECOMMENT, wxSTC_JSON_BLOCKCOMMENT } },
+    { wxSTC_LEX_LUA, { wxSTC_LUA_COMMENT, wxSTC_LUA_COMMENTLINE, wxSTC_LUA_COMMENTDOC } },
+    { wxSTC_LEX_MAKEFILE, { wxSTC_MAKE_COMMENT } },
+    { wxSTC_LEX_MARKDOWN, { wxSTC_MARKDOWN_DEFAULT } },
+    { wxSTC_LEX_HTML,
+      {
+          wxSTC_H_COMMENT,
+          wxSTC_HJ_COMMENT,
+          wxSTC_HJ_COMMENTLINE,
+          wxSTC_HJ_COMMENTDOC,
+          wxSTC_HPHP_COMMENTLINE,
+          wxSTC_HPHP_COMMENT,
+      } },
+    { wxSTC_LEX_PYTHON, { wxSTC_P_COMMENTLINE, wxSTC_P_COMMENTBLOCK } },
+    { wxSTC_LEX_RUBY, { wxSTC_RB_COMMENTLINE } },
+    { wxSTC_LEX_RUST,
+      {
+          wxSTC_RUST_COMMENTBLOCK,
+          wxSTC_RUST_COMMENTLINE,
+          wxSTC_RUST_COMMENTBLOCKDOC,
+          wxSTC_RUST_COMMENTLINEDOC,
+      } },
+    { wxSTC_LEX_SQL, { wxSTC_SQL_COMMENT, wxSTC_SQL_COMMENTLINE, wxSTC_SQL_COMMENTDOC } },
+    { wxSTC_LEX_TCL, { wxSTC_TCL_COMMENT, wxSTC_TCL_COMMENTLINE, wxSTC_TCL_BLOCK_COMMENT, wxSTC_TCL_COMMENT_BOX } },
+    { wxSTC_LEX_NULL, { 0 } },
+    { wxSTC_LEX_XML, { wxSTC_H_COMMENT } },
+    { wxSTC_LEX_YAML, { wxSTC_YAML_COMMENT } },
+};
+
+void HighlightWord(IEditor* editor, int pos)
+{
+    int indicator_start = editor->GetCtrl()->WordStartPosition(pos, true);
+    int indicator_end = editor->GetCtrl()->WordEndPosition(pos, true);
+    int len = indicator_end - indicator_start;
+    editor->SetUserIndicator(indicator_start, len);
+}
+
+} // namespace
 
 // ------------------------------------------------------------
 #define MIN_TOKEN_LEN 3
@@ -75,14 +186,14 @@ IHunSpell::~IHunSpell()
 {
     CloseEngine();
 
-    if(m_pSpellDlg != NULL)
+    if (m_pSpellDlg != NULL)
         m_pSpellDlg->Destroy();
 }
 // ------------------------------------------------------------
 bool IHunSpell::InitEngine()
 {
     // check if we are already initialized
-    if(m_pSpell != NULL)
+    if (m_pSpell != NULL)
         return true;
 
     m_ignoreList = CustomDictionary(0, StringHashOptionalCase(m_caseSensitiveUserDictionary),
@@ -91,7 +202,7 @@ bool IHunSpell::InitEngine()
                                   StringCompareOptionalCase(m_caseSensitiveUserDictionary));
 
     // check base path
-    if(!m_dicPath.IsEmpty() && !wxEndsWithPathSeparator(m_dicPath))
+    if (!m_dicPath.IsEmpty() && !wxEndsWithPathSeparator(m_dicPath))
         m_dicPath += wxFILE_SEP_PATH;
     // load user dict
     LoadUserDict(m_userDictPath + s_userDict);
@@ -104,13 +215,13 @@ bool IHunSpell::InitEngine()
 
     wxFileName fna(aff);
 
-    if(!fna.FileExists()) {
+    if (!fna.FileExists()) {
         clLogMessage(_("Could not find aff file!"));
         return false;
     }
     wxFileName fnd(dict);
 
-    if(!fnd.FileExists()) {
+    if (!fnd.FileExists()) {
         clLogMessage(_("Could not find dictionary file!"));
         return false;
     }
@@ -122,7 +233,7 @@ bool IHunSpell::InitEngine()
 // ------------------------------------------------------------
 void IHunSpell::CloseEngine()
 {
-    if(m_pSpell != NULL) {
+    if (m_pSpell != NULL) {
         Hunspell_destroy(m_pSpell);
         SaveUserDict(m_userDictPath + s_userDict);
     }
@@ -134,139 +245,39 @@ bool IHunSpell::CheckWord(const wxString& word) const
     static thread_local wxRegEx rehex(s_dectHex, wxRE_ADVANCED);
 
     // look in ignore list
-    if(m_ignoreList.count(word) != 0)
+    if (m_ignoreList.count(word) != 0)
         return true;
 
     // look in user list
-    if(m_userDict.count(word) != 0)
+    if (m_userDict.count(word) != 0)
         return true;
 
     // see if hex number
-    if(rehex.Matches(word))
+    if (rehex.Matches(word))
         return true;
 
     return Hunspell_spell(m_pSpell, word.ToUTF8()) != 0;
 }
 // ------------------------------------------------------------
-bool IHunSpell::IsTag(const wxString& word) const
-{
-    if(GetIgnoreSymbolsInTagsDatabase()) {
-        std::vector<TagEntryPtr> tags;
-        TagsManagerST::Get()->FindSymbol(word, tags);
-        if(!tags.empty())
-            return true;
-    }
-
-    return false;
-}
-// ------------------------------------------------------------
 wxArrayString IHunSpell::GetSuggestions(const wxString& misspelled)
 {
     wxArrayString suggestions;
     suggestions.Empty();
 
-    if(m_pSpell) {
+    if (m_pSpell) {
         char** wlst;
 
         wxCharBuffer misspelledBuffer = misspelled.mb_str();
         int ns = Hunspell_suggest(m_pSpell, &wlst, misspelledBuffer);
 
-        for(int i = 0; i < ns; i++)
+        for (int i = 0; i < ns; i++)
             suggestions.Add(wxString(wlst[i]));
         Hunspell_free_list(m_pSpell, &wlst, ns);
     }
 
     return suggestions;
 }
-// ------------------------------------------------------------
-void IHunSpell::CheckCppSpelling()
-{
-    // check if engine is initialized, if not do so
-    CHECK_COND_RET(InitEngine());
 
-    IEditor* pEditor = ::clGetManager()->GetActiveEditor();
-    CHECK_PTR_RET(pEditor);
-
-    int retVal = kNoSpellingError;
-    wxString text = pEditor->GetEditorText() + " ";
-
-    m_parseValues.clear();
-    wxStyledTextCtrl* pTextCtrl = pEditor->GetCtrl();
-
-    // check for dialog and create if necessary
-    if(!m_pPlugIn->GetCheckContinuous()) {
-        if(m_pSpellDlg == NULL) {
-            m_pSpellDlg = new CorrectSpellingDlg(NULL);
-        }
-
-        m_pSpellDlg->SetPHs(this);
-    }
-    posLen query;
-
-    for(int i = 0; i < pEditor->GetLength(); i++) {
-        switch(pTextCtrl->GetStyleAt(i)) {
-        case SCT_STRING: {
-            query.first = i;
-
-            while(pTextCtrl->GetStyleAt(i++) == SCT_STRING)
-                ;
-            query.second = i;
-
-            if(IsScannerType(kString))
-                m_parseValues.push_back(make_pair(query, kString));
-        } break;
-        case SCT_CPP_COM: {
-            query.first = i;
-
-            while(pTextCtrl->GetStyleAt(i++) == SCT_CPP_COM)
-                ;
-            query.second = i;
-
-            if(IsScannerType(kCppComment))
-                m_parseValues.push_back(make_pair(query, kCppComment));
-        } break;
-        case SCT_C_COM: {
-            query.first = i;
-
-            while(pTextCtrl->GetStyleAt(i++) == SCT_C_COM)
-                ;
-            query.second = i;
-
-            if(IsScannerType(kCComment))
-                m_parseValues.push_back(make_pair(query, kCComment));
-        } break;
-        case SCT_DOX_1: {
-            query.first = i;
-
-            while(pTextCtrl->GetStyleAt(i++) == SCT_DOX_1)
-                ;
-            query.second = i;
-
-            if(IsScannerType(kDox1))
-                m_parseValues.push_back(make_pair(query, kDox1));
-        } break;
-        case SCT_DOX_2: {
-            query.first = i;
-
-            while(pTextCtrl->GetStyleAt(i++) == SCT_DOX_2)
-                ;
-            query.second = i;
-
-            if(IsScannerType(kDox2))
-                m_parseValues.push_back(make_pair(query, kDox2));
-        } break;
-        }
-    }
-    int errors = 0;
-
-    if(!m_pPlugIn->GetCheckContinuous()) {
-        retVal = CheckCppType(pEditor);
-
-        if(errors == 0 && retVal != kSpellingCanceled)
-            ::wxMessageBox(_("No spelling errors found!"));
-    } else
-        retVal = MarkErrors(pEditor);
-}
 // ------------------------------------------------------------
 void IHunSpell::CheckSpelling()
 {
@@ -275,94 +286,114 @@ void IHunSpell::CheckSpelling()
     CHECK_PTR_RET(pEditor);
     CHECK_COND_RET(InitEngine());
 
-    // special handling for C++ files
-    if(pEditor->GetLexerId() == wxSTC_LEX_CPP) {
-        LOG_IF_TRACE { clDEBUG1() << "SpellChecker: checkSpelling -> C++ is called" << endl; }
-        CheckCppSpelling();
-        return;
-    }
-
-    int offset = 0;
     bool error = false;
     wxString text = pEditor->GetEditorText() + " ";
 
     // check for dialog and create if necessary
-    if(m_pSpellDlg == NULL) {
+    if (m_pSpellDlg == NULL) {
         m_pSpellDlg = new CorrectSpellingDlg(NULL);
     }
     m_pSpellDlg->SetPHs(this);
-    wxStringTokenizer tkz(text, s_defDelimiters);
+    wxArrayString lines = ::wxStringTokenize(text, "\n", wxTOKEN_RET_EMPTY_ALL);
+
+    const std::unordered_set<int>* STRING_STYLES = nullptr;
+    const std::unordered_set<int>* COMMENT_STYLES = nullptr;
+
+    if (ALLOWED_STYLES_STRINGS.count(pEditor->GetLexerId())) {
+        STRING_STYLES = &ALLOWED_STYLES_STRINGS[pEditor->GetLexerId()];
+    }
+
+    if (ALLOWED_STYLES_COMMENTS.count(pEditor->GetLexerId())) {
+        COMMENT_STYLES = &ALLOWED_STYLES_COMMENTS[pEditor->GetLexerId()];
+    }
+
+#define IS_STYLE_ALLOWED(pset, style_id) \
+    (!pset /* no limit */ || (pset && pset->count(style_id) /* we have a set -> it must contain the id*/))
 
     LOG_IF_TRACE { clDEBUG1() << "SpellChecker: checking file:" << pEditor->GetFileName() << endl; }
-    while(tkz.HasMoreTokens()) {
-        wxString token = tkz.GetNextToken();
-        int pos = tkz.GetPosition() - token.Len() - 1;
-        pos += offset;
+    for (size_t line_number = 0; line_number < lines.size(); ++line_number) {
+        // Now parse each line separately
+        wxStringTokenizer tkz(lines[line_number], s_defDelimiters);
+        int offset = 0;
+        while (tkz.HasMoreTokens()) {
+            wxString token = tkz.GetNextToken();
 
-        // ignore token shorter then MIN_TOKEN_LEN
-        if(token.Len() <= MIN_TOKEN_LEN)
-            continue;
+            int line_start_pos = pEditor->PosFromLine(line_number);
+            int pos = tkz.GetPosition() - token.length() + line_start_pos;
+            // incase the current token real length is greater than the normal len
+            // include it in the offset
+            size_t utf8_len = FileUtils::UTF8Length(token.c_str(), token.length());
+            if (utf8_len > token.length()) {
+                offset += (utf8_len - token.length());
+            }
+            pos += offset;
 
-        // process token
-        if(!CheckWord(token)) {
-            pEditor->SetUserIndicator(pos, token.Len());
+            // ignore token shorter then MIN_TOKEN_LEN
+            if (token.length() <= MIN_TOKEN_LEN)
+                continue;
 
-            if(!m_pPlugIn->GetCheckContinuous()) {
-                pEditor->SetCaretAt(pos);
-                pEditor->SelectText(pos, token.Len());
-                // show correct spelling dialog
-                error = true;
-                m_pSpellDlg->SetMisspelled(token);
-                m_pSpellDlg->SetSuggestions(GetSuggestions(token));
-                int ret = m_pSpellDlg->ShowModal();
+            // Check the style at the middle of the token
+            int style_at_pos = pEditor->GetStyleAtPos(pos + token.length() / 2);
+            if (!IS_STYLE_ALLOWED(STRING_STYLES, style_at_pos) && !IS_STYLE_ALLOWED(COMMENT_STYLES, style_at_pos))
+                // skip this token
+                continue;
 
-                switch(ret) {
-                case SC_CHANGE: {
-                    // correct spelling
-                    wxString replace = m_pSpellDlg->GetMisspelled();
-                    offset += replace.Len() - token.Len();
-                    text.replace(pos, token.Len(), replace);
-                    pEditor->ReplaceSelection(replace);
-                } break;
-                case SC_IGNORE:
-                    AddWordToIgnoreList(token);
-                    break;
-                case SC_ADD:
-                    AddWordToUserDict(token);
-                    break;
-                default: {
-                    pEditor->ClearUserIndicators();
-                    return;
-                }
+            // process token
+            if (!CheckWord(token)) {
+                HighlightWord(pEditor, pos + (token.length() / 2));
+                // pEditor->SetUserIndicator(pos, token.length());
+
+                if (!m_pPlugIn->GetCheckContinuous()) {
+                    pEditor->SetCaretAt(pos);
+                    pEditor->SelectText(pos, token.length());
+                    // show correct spelling dialog
+                    error = true;
+                    m_pSpellDlg->SetMisspelled(token);
+                    m_pSpellDlg->SetSuggestions(GetSuggestions(token));
+                    int ret = m_pSpellDlg->ShowModal();
+
+                    switch (ret) {
+                    case SC_CHANGE: {
+                        // correct spelling
+                        wxString replace = m_pSpellDlg->GetMisspelled();
+                        offset += replace.Len() - token.Len();
+                        text.replace(pos, token.Len(), replace);
+                        pEditor->ReplaceSelection(replace);
+                    } break;
+                    case SC_IGNORE:
+                        AddWordToIgnoreList(token);
+                        break;
+                    case SC_ADD:
+                        AddWordToUserDict(token);
+                        break;
+                    default: {
+                        pEditor->ClearUserIndicators();
+                        return;
+                    }
+                    }
                 }
             }
         }
     }
+#undef IS_STYLE_ALLOWED
+
     LOG_IF_TRACE { clDEBUG1() << "SpellChecker:: checking file:" << pEditor->GetFileName() << "is done" << endl; }
-    if(!m_pPlugIn->GetCheckContinuous()) {
+    if (!m_pPlugIn->GetCheckContinuous()) {
         // clean up
         pEditor->ClearUserIndicators();
 
-        if(!error)
+        if (!error)
             ::wxMessageBox(_("No spelling errors found!"));
     }
 }
 // ------------------------------------------------------------
 // tools
 // ------------------------------------------------------------
-wxString IHunSpell::GetCharacterEncoding()
-{
-    if(m_pSpell == NULL)
-        return wxEmptyString;
-
-    wxString encoding(wxConvUTF8.cMB2WC(Hunspell_get_dic_encoding(m_pSpell)), *wxConvCurrent);
-    return encoding;
-}
 
 // ------------------------------------------------------------
 void IHunSpell::AddWordToIgnoreList(const wxString& word)
 {
-    if(word.IsEmpty())
+    if (word.IsEmpty())
         return;
 
     m_ignoreList.insert(word);
@@ -370,7 +401,7 @@ void IHunSpell::AddWordToIgnoreList(const wxString& word)
 // ------------------------------------------------------------
 void IHunSpell::AddWordToUserDict(const wxString& word)
 {
-    if(word.IsEmpty())
+    if (word.IsEmpty())
         return;
 
     m_userDict.insert(word);
@@ -380,14 +411,14 @@ bool IHunSpell::LoadUserDict(const wxString& filename)
 {
     wxTextFile tf(filename);
 
-    if(!tf.Exists())
+    if (!tf.Exists())
         return false;
 
     m_userDict.clear();
 
     tf.Open();
 
-    for(wxUint32 i = 0; i < tf.GetLineCount(); i++) {
+    for (wxUint32 i = 0; i < tf.GetLineCount(); i++) {
         m_userDict.insert(tf.GetLine(i));
     }
     tf.Close();
@@ -400,22 +431,22 @@ bool IHunSpell::SaveUserDict(const wxString& filename)
     wxTextFile tf(filename);
     CustomDictionary fileUserDict(m_userDict);
 
-    if(!tf.Exists()) {
-        if(!tf.Create())
+    if (!tf.Exists()) {
+        if (!tf.Create())
             return false;
     } else {
-        if(!tf.Open())
+        if (!tf.Open())
             return false;
 
         // Re-read contents from disk in case another CodeLite instance has updated the user dictionary.
-        for(wxUint32 i = 0; i < tf.GetLineCount(); i++) {
+        for (wxUint32 i = 0; i < tf.GetLineCount(); i++) {
             fileUserDict.insert(tf.GetLine(i));
         }
 
         tf.Clear();
     }
 
-    for(const auto& word : fileUserDict) {
+    for (const auto& word : fileUserDict) {
         tf.AddLine(word);
     }
     tf.Write();
@@ -426,7 +457,7 @@ bool IHunSpell::SaveUserDict(const wxString& filename)
 // ------------------------------------------------------------
 bool IHunSpell::ChangeLanguage(const wxString& language)
 {
-    if(m_dictionary.Cmp(language) == 0)
+    if (m_dictionary.Cmp(language) == 0)
         return false;
     CloseEngine();
     m_dictionary = language;
@@ -496,23 +527,12 @@ void IHunSpell::InitLanguageList()
     m_languageList[_T( "Zulu (Africa)" )] = _T( "zu_ZA" );
 }
 // ------------------------------------------------------------
-void IHunSpell::GetAllLanguageKeyNames(wxArrayString& lang)
-{
-    lang.Clear();
-    languageMap::iterator itLang;
-
-    for(itLang = m_languageList.begin(); itLang != m_languageList.end(); ++itLang) {
-        wxString key = itLang->first;
-        lang.Add(key);
-    }
-}
-// ------------------------------------------------------------
 void IHunSpell::GetAvailableLanguageKeyNames(const wxString& path, wxArrayString& lang)
 {
     lang.Clear();
     languageMap::iterator itLang;
 
-    for(itLang = m_languageList.begin(); itLang != m_languageList.end(); ++itLang) {
+    for (itLang = m_languageList.begin(); itLang != m_languageList.end(); ++itLang) {
         wxFileName fna(path, "");
         wxFileName fnd(path, "");
 
@@ -522,7 +542,7 @@ void IHunSpell::GetAvailableLanguageKeyNames(const wxString& path, wxArrayString
         fnd.SetName(itLang->second);
         fnd.SetExt("dic");
 
-        if(!fna.FileExists() || !fnd.FileExists())
+        if (!fna.FileExists() || !fnd.FileExists())
             continue;
 
         lang.Add(itLang->first);
@@ -532,144 +552,15 @@ void IHunSpell::GetAvailableLanguageKeyNames(const wxString& path, wxArrayString
 // ------------------------------------------------------------
 void IHunSpell::EnableScannerType(int type, bool state)
 {
-    if(state)
+    if (state)
         m_scanners |= type;
     else
         m_scanners &= ~type;
 }
 // ------------------------------------------------------------
-int IHunSpell::CheckCppType(IEditor* pEditor)
-{
-    wxStringTokenizer tkz;
-
-    int retVal = kNoSpellingError;
-    int offset = 0;
-
-    for(wxUint32 i = 0; i < m_parseValues.size(); i++) {
-        posLen pl = m_parseValues[i].first;
-        wxString text = pEditor->GetTextRange(pl.first, pl.second);
-        wxString del = s_commentDelimiters;
-
-        if(m_parseValues[i].second ==
-           kString) { // replace \n\r\t in strings with blanks to correctly tokenize content like '\nNext line'
-            wxRegEx re(s_wsRegEx, wxRE_ADVANCED);
-            // to ensure that \\n will not get captured by the regex, we temporarily replace it
-            text.Replace(s_DOUBLE_BACKSLASH, s_PLACE_HOLDER);
-
-            if(re.Matches(text)) {
-                re.ReplaceAll(&text, wxT("  "));
-                del = s_cppDelimiters;
-            }
-
-            // restore
-            text.Replace(s_PLACE_HOLDER, s_DOUBLE_BACKSLASH);
-        }
-
-        tkz.SetString(text, del);
-
-        while(tkz.HasMoreTokens()) {
-            wxString token = tkz.GetNextToken();
-            int pos = pl.first + tkz.GetPosition() - token.Len() - 1;
-            pos += offset;
-
-            if(token.Len() <= MIN_TOKEN_LEN)
-                continue;
-
-            if(m_parseValues[i].second == kString) { // ignore filenames in #include
-                wxString line = pEditor->GetCtrl()->GetLine(pEditor->LineFromPos(pl.first));
-
-                if(line.Find(s_include) != wxNOT_FOUND)
-                    continue;
-            }
-
-            // Note checking tags database only in continuous mode.
-            if(!CheckWord(token)) {
-                pEditor->SetUserIndicator(pos, token.Len());
-                pEditor->SetCaretAt(pos);
-                pEditor->SelectText(pos, token.Len());
-                // show correct spelling dialog
-                retVal = kSpellingError;
-                m_pSpellDlg->SetMisspelled(token);
-                m_pSpellDlg->SetSuggestions(GetSuggestions(token));
-                int ret = m_pSpellDlg->ShowModal();
-
-                switch(ret) {
-                case SC_CHANGE: {
-                    // correct spelling
-                    wxString replace = m_pSpellDlg->GetMisspelled();
-                    offset += replace.Len() - token.Len();
-                    text.replace(tkz.GetPosition(), token.Len(), replace);
-                    pEditor->ReplaceSelection(replace);
-                } break;
-                case SC_IGNORE:
-                    AddWordToIgnoreList(token);
-                    break;
-                case SC_ADD:
-                    AddWordToUserDict(token);
-                    break;
-                default: {
-                    pEditor->ClearUserIndicators();
-                    return kSpellingCanceled;
-                }
-                }
-            }
-        }
-    }
-    return retVal;
-}
-// ------------------------------------------------------------
-int IHunSpell::MarkErrors(IEditor* pEditor)
-{
-    wxStringTokenizer tkz;
-
-    int counter = 0;
-    pEditor->ClearUserIndicators();
-
-    for(wxUint32 i = 0; i < m_parseValues.size(); i++) {
-        posLen pl = m_parseValues[i].first;
-        wxString text = pEditor->GetTextRange(pl.first, pl.second);
-        wxString del = s_commentDelimiters;
-
-        if(m_parseValues[i].second ==
-           kString) { // replace \n\r\t in strings with blanks to correctly tokenize content like '\nNext line'
-            wxRegEx re(s_wsRegEx, wxRE_ADVANCED);
-            // to ensure that \\n will not get captured by the regex, we temporarily replace it
-            text.Replace(s_DOUBLE_BACKSLASH, s_PLACE_HOLDER);
-            if(re.Matches(text)) {
-                re.ReplaceAll(&text, wxT("  "));
-                del = s_cppDelimiters;
-            }
-            text.Replace(s_PLACE_HOLDER, s_DOUBLE_BACKSLASH);
-        }
-        tkz.SetString(text, del);
-
-        while(tkz.HasMoreTokens()) {
-            wxString token = tkz.GetNextToken();
-            int pos = pl.first + tkz.GetPosition() - token.Len() - 1;
-
-            if(token.Len() <= MIN_TOKEN_LEN)
-                continue;
-
-            if(m_parseValues[i].second == kString) {
-                wxString line = pEditor->GetCtrl()->GetLine(pEditor->LineFromPos(pl.first));
-
-                if(line.Find(s_include) != wxNOT_FOUND) // ignore filenames
-                    continue;
-            }
-
-            if(!CheckWord(token) && !IsTag(token)) {
-                pEditor->SetUserIndicator(pos, token.Len());
-                counter++;
-            }
-        }
-    }
-
-    return counter;
-}
-
 void IHunSpell::SetCaseSensitiveUserDictionary(const bool caseSensitiveUserDictionary)
 {
-    if(caseSensitiveUserDictionary != m_caseSensitiveUserDictionary) {
+    if (caseSensitiveUserDictionary != m_caseSensitiveUserDictionary) {
         m_caseSensitiveUserDictionary = caseSensitiveUserDictionary;
 
         // Re-order user dictionary and ignores.
@@ -684,14 +575,3 @@ void IHunSpell::SetCaseSensitiveUserDictionary(const bool caseSensitiveUserDicti
         m_ignoreList.swap(ignoreList);
     }
 }
-
-void IHunSpell::AddWord(const wxString& word)
-{
-#if wxUSE_STL
-    // Implicit conversions are disabled when building with wxUSE_STL=1
-    Hunspell_add(m_pSpell, word.mb_str().data());
-#else
-    Hunspell_add(m_pSpell, word);
-#endif
-}
-// ------------------------------------------------------------
