@@ -1,20 +1,17 @@
+#include "tail.h"
+
 #include "TailFrame.h"
 #include "TailPanel.h"
 #include "cl_command_event.h"
 #include "cl_config.h"
 #include "event_notifier.h"
-#include "tail.h"
-#include <wx/xrc/xmlres.h>
 
-static Tail* thePlugin = NULL;
+#include <wx/xrc/xmlres.h>
 
 // Define the plugin entry point
 CL_PLUGIN_API IPlugin* CreatePlugin(IManager* manager)
 {
-    if(thePlugin == NULL) {
-        thePlugin = new Tail(manager);
-    }
-    return thePlugin;
+    return new Tail(manager);
 }
 
 CL_PLUGIN_API PluginInfo* GetPluginInfo()
@@ -37,7 +34,7 @@ Tail::Tail(IManager* manager)
     m_shortName = wxT("Tail");
 
     // Hook our output-pane panel
-    InitTailWindow(m_mgr->GetOutputPaneNotebook(), true, TailData(), false);
+    InitTailWindow(m_mgr->BookGet(PaneId::BOTTOM_BAR), true, TailData(), false);
     EventNotifier::Get()->Bind(wxEVT_INIT_DONE, &Tail::OnInitDone, this);
 }
 
@@ -60,7 +57,7 @@ void Tail::CreatePluginMenu(wxMenu* pluginsMenu) {}
 
 void Tail::UnPlug()
 {
-    m_editEventsHandler.Reset(NULL);
+    m_editEventsHandler = nullptr;
     // Unbind events
     EventNotifier::Get()->Unbind(wxEVT_INIT_DONE, &Tail::OnInitDone, this);
 
@@ -91,19 +88,11 @@ void Tail::DetachTailWindow(const TailData& d)
 
 void Tail::DockTailWindow(const TailData& d)
 {
-    InitTailWindow(m_mgr->GetOutputPaneNotebook(), true, d, true);
+    InitTailWindow(m_mgr->BookGet(PaneId::BOTTOM_BAR), true, d, true);
     m_mgr->GetDockingManager()->Update();
 }
 
-void Tail::DoDetachWindow()
-{
-    for(size_t i = 0; i < m_mgr->GetOutputPaneNotebook()->GetPageCount(); i++) {
-        if(m_view == m_mgr->GetOutputPaneNotebook()->GetPage(i)) {
-            m_mgr->GetOutputPaneNotebook()->RemovePage(i);
-            break;
-        }
-    }
-}
+void Tail::DoDetachWindow() { m_mgr->BookRemovePage(PaneId::BOTTOM_BAR, m_view); }
 
 void Tail::InitTailWindow(wxWindow* parent, bool isNotebook, const TailData& d, bool selectPage)
 {
@@ -118,13 +107,10 @@ void Tail::InitTailWindow(wxWindow* parent, bool isNotebook, const TailData& d,
     }
 
     // Hook our output-pane panel
-    int bmp = m_mgr->GetOutputPaneNotebook()->GetBitmaps()->Add("mime-txt");
     m_view = tmpView;
-    m_editEventsHandler.Reset(new clEditEventsHandler(m_view->GetStc()));
+    m_editEventsHandler = std::make_unique<clEditEventsHandler>(m_view->GetStc());
     if(isNotebook) {
-        m_mgr->GetOutputPaneNotebook()->InsertPage(0, m_view, "Tail", selectPage, bmp);
-        m_tabHelper.reset(new clTabTogglerHelper("Tail", m_view, "", NULL));
-        m_tabHelper->SetOutputTabBmp(bmp);
+        m_mgr->BookAddPage(PaneId::BOTTOM_BAR, m_view, "Tail");
     } else {
         m_tabHelper.reset(NULL);
     }
