@@ -24,9 +24,10 @@
 //////////////////////////////////////////////////////////////////////////////
 #include "unittestpp.h"
 
-#include "asyncprocess.h"
+#include "AsyncProcess/asyncprocess.h"
+#include "AsyncProcess/processreaderthread.h"
+#include "Keyboard/clKeyboardManager.h"
 #include "bitmap_loader.h"
-#include "clKeyboardManager.h"
 #include "codelite_events.h"
 #include "ctags_manager.h"
 #include "dirsaver.h"
@@ -35,7 +36,6 @@
 #include "macros.h"
 #include "newunittestdlg.h"
 #include "pipedprocess.h"
-#include "processreaderthread.h"
 #include "procutils.h"
 #include "project.h"
 #include "testclassdlg.h"
@@ -53,20 +53,15 @@
 #include <wx/xrc/xmlres.h>
 
 #ifdef __WXMSW__
-#include "evnvarlist.h"
+#include "envvarlist.h"
 
 #include <wx/msw/registry.h>
 #endif
 
-static UnitTestPP* thePlugin = NULL;
-
 // Define the plugin entry point
 CL_PLUGIN_API IPlugin* CreatePlugin(IManager* manager)
 {
-    if(thePlugin == 0) {
-        thePlugin = new UnitTestPP(manager);
-    }
-    return thePlugin;
+    return new UnitTestPP(manager);
 }
 
 CL_PLUGIN_API PluginInfo* GetPluginInfo()
@@ -94,12 +89,9 @@ UnitTestPP::UnitTestPP(IManager* manager)
     EventNotifier::Get()->Connect(wxEVT_CMD_EXECUTE_ACTIVE_PROJECT, clExecuteEventHandler(UnitTestPP::OnRunProject),
                                   NULL, this);
 
-    m_outputPage = new UnitTestsPage(m_mgr->GetOutputPaneNotebook(), m_mgr);
-    auto book = m_mgr->GetOutputPaneNotebook();
-    auto images = book->GetBitmaps();
-    book->AddPage(m_outputPage, _("UnitTest++"), false, images->Add("ok"));
+    m_outputPage = new UnitTestsPage(m_mgr->BookGet(PaneId::BOTTOM_BAR), m_mgr);
+    m_mgr->BookAddPage(PaneId::BOTTOM_BAR, m_outputPage, _("UnitTest++"));
     m_tabHelper.reset(new clTabTogglerHelper(_("UnitTest++"), m_outputPage, "", NULL));
-    m_tabHelper->SetOutputTabBmp(images->Add("ok"));
 
     m_longName = _("A Unit test plugin based on the UnitTest++ framework");
     m_shortName = "UnitTestPP";
@@ -524,16 +516,7 @@ void UnitTestPP::OnProcessTerminated(clProcessEvent& e)
     SelectUTPage();
 }
 
-void UnitTestPP::SelectUTPage()
-{
-    size_t pageCount = m_mgr->GetOutputPaneNotebook()->GetPageCount();
-    for(size_t i = 0; i < pageCount; ++i) {
-        if(m_mgr->GetOutputPaneNotebook()->GetPage(i) == m_outputPage) {
-            m_mgr->GetOutputPaneNotebook()->SetSelection(i);
-            break;
-        }
-    }
-}
+void UnitTestPP::SelectUTPage() { m_mgr->BookSelectPage(PaneId::BOTTOM_BAR, m_outputPage); }
 
 void UnitTestPP::OnRunProject(clExecuteEvent& e)
 {
