@@ -1,10 +1,11 @@
+#include "NodeJSWorkspaceView.h"
+
+#include "Console/clConsoleBase.h"
 #include "NodeJSDebuggerDlg.h"
 #include "NodeJSPackageJSON.h"
 #include "NodeJSWorkspaceConfiguration.h"
-#include "NodeJSWorkspaceView.h"
 #include "NoteJSWorkspace.h"
 #include "bitmap_loader.h"
-#include "clConsoleBase.h"
 #include "clNodeJS.h"
 #include "clWorkspaceView.h"
 #include "codelite_events.h"
@@ -15,6 +16,7 @@
 #include "ieditor.h"
 #include "imanager.h"
 #include "macros.h"
+
 #include <wx/filename.h>
 #include <wx/menu.h>
 #include <wx/msgdlg.h>
@@ -295,9 +297,9 @@ void NodeJSWorkspaceView::OnItemExpanding(wxTreeEvent& event)
     wxTreeItemId item = event.GetItem();
     CHECK_ITEM_RET(item);
 
-    clTreeCtrlData* cd = GetItemData(item);
-    CHECK_PTR_RET(cd);
-    CHECK_COND_RET(cd->IsFolder());
+    clTreeCtrlData* itemData = GetItemData(item);
+    CHECK_PTR_RET(itemData);
+    CHECK_COND_RET(itemData->IsFolder());
 
     int imageIndex = clBitmaps::Get().GetLoader()->GetMimeImageId(FileExtManager::TypeProject);
     CHECK_COND_RET(imageIndex != wxNOT_FOUND);
@@ -306,7 +308,7 @@ void NodeJSWorkspaceView::OnItemExpanding(wxTreeEvent& event)
 
     {
         // change the icon for the parent folder as well
-        wxFileName packageJSON(cd->GetPath(), "package.json");
+        wxFileName packageJSON(itemData->GetPath(), "package.json");
         if(packageJSON.FileExists()) {
             GetTreeCtrl()->SetItemImage(item, imageIndex, imageIndexExpanded);
         }
