@@ -26,19 +26,19 @@
 #ifndef XMLCODECOMPLETION_H
 #define XMLCODECOMPLETION_H
 
-#include "ServiceProvider.h"
 #include "cl_command_event.h"
 #include "macros.h"
-#include "smart_ptr.h"
+
+#include <memory>
 #include <vector>
 #include <wx/event.h>
 
 class WebTools;
 class IEditor;
-class XMLCodeCompletion : public ServiceProvider
+class XMLCodeCompletion : public wxEvtHandler
 {
 public:
-    typedef SmartPtr<XMLCodeCompletion> Ptr_t;
+    using Ptr_t = std::unique_ptr<XMLCodeCompletion>;
     struct HtmlCompletion {
         wxString m_tag;
         wxString m_comment;
