@@ -25,9 +25,10 @@
 
 #include "abbreviation.h"
 
+
+#include "Keyboard/clKeyboardManager.h"
 #include "abbreviationentry.h"
 #include "abbreviationssettingsdlg.h"
-#include "clKeyboardManager.h"
 #include "cl_config.h"
 #include "event_notifier.h"
 #include "globals.h"
@@ -45,16 +46,8 @@
 #include <wx/textdlg.h>
 #include <wx/xrc/xmlres.h>
 
-static AbbreviationPlugin* thePlugin = NULL;
-
 // Define the plugin entry point
-CL_PLUGIN_API IPlugin* CreatePlugin(IManager* manager)
-{
-    if(thePlugin == 0) {
-        thePlugin = new AbbreviationPlugin(manager);
-    }
-    return thePlugin;
-}
+CL_PLUGIN_API IPlugin* CreatePlugin(IManager* manager) { return new AbbreviationPlugin(manager); }
 
 CL_PLUGIN_API PluginInfo* GetPluginInfo()
 {
@@ -70,34 +63,26 @@ CL_PLUGIN_API int GetPluginInterfaceVersion() { return PLUGIN_INTERFACE_VERSION;
 
 class AbbreviationClientData : public wxClientData
 {
-public:
-    AbbreviationClientData() {}
-    virtual ~AbbreviationClientData() {}
 };
 
 AbbreviationPlugin::AbbreviationPlugin(IManager* manager)
     : IPlugin(manager)
-    , m_topWindow(NULL)
     , m_config("abbreviations.conf")
 {
     m_longName = _("Abbreviation plugin");
     m_shortName = "Abbreviation";
     m_topWindow = m_mgr->GetTheApp();
     EventNotifier::Get()->Bind(wxEVT_CCBOX_SELECTION_MADE, &AbbreviationPlugin::OnAbbrevSelected, this);
-
     EventNotifier::Get()->Bind(wxEVT_CCBOX_SHOWING, &AbbreviationPlugin::OnCompletionBoxShowing, this);
-    // m_helper = new AbbreviationServiceProvider(this);
     InitDefaults();
 }
 
-AbbreviationPlugin::~AbbreviationPlugin() {}
-
 void AbbreviationPlugin::CreateToolBar(clToolBarGeneric* toolbar) { wxUnusedVar(toolbar); }
 
 void AbbreviationPlugin::CreatePluginMenu(wxMenu* pluginsMenu)
 {
     wxMenu* menu = new wxMenu();
-    wxMenuItem* item(NULL);
+    wxMenuItem* item(nullptr);
 
     item = new wxMenuItem(menu, XRCID("abbrev_insert"), _("Show abbreviations completion box"),
                           _("Show abbreviations completion box"), wxITEM_NORMAL);
@@ -133,12 +118,12 @@ void AbbreviationPlugin::OnSettings(wxCommandEvent& e)
     m_config.Reload();
 }
 
-void AbbreviationPlugin::GetAbbreviations(wxCodeCompletionBoxEntry::Vec_t& V, const wxString& filter)
+wxCodeCompletionBoxEntry::Vec_t AbbreviationPlugin::GetAbbreviations(const wxString& filter)
 {
     wxString lcFilter = filter.Lower();
 
     AbbreviationJSONEntry jsonData;
-    if(!m_config.ReadItem(&jsonData)) {
+    if (!m_config.ReadItem(&jsonData)) {
         // merge the data from the old configuration
         AbbreviationEntry data;
         m_mgr->GetConfigTool()->ReadObject("AbbreviationsData", &data);
@@ -148,32 +133,33 @@ void AbbreviationPlugin::GetAbbreviations(wxCodeCompletionBoxEntry::Vec_t& V, co
         m_config.WriteItem(&jsonData);
     }
 
+    wxCodeCompletionBoxEntry::Vec_t V;
     wxBitmap bmp = clGetManager()->GetStdIcons()->LoadBitmap("replace-blue");
-    if(bmp.IsOk()) {
+    if (bmp.IsOk()) {
         // search for the old item
-        const wxStringMap_t& entries = jsonData.GetEntries();
-        std::for_each(entries.begin(), entries.end(), [&](const wxStringMap_t::value_type& vt) {
+        for (const auto& vt : jsonData.GetEntries()) {
             // Only add matching entries (entries that "starts_with")
             wxString lcAbbv = vt.first.Lower();
-            if(lcAbbv.StartsWith(lcFilter)) {
+            if (lcAbbv.StartsWith(lcFilter)) {
                 // Append our entries
                 wxString textHelp;
                 textHelp << "**Abbreviation entry**\n===```" << vt.second << "```";
                 V.push_back(wxCodeCompletionBoxEntry::New(vt.first, textHelp, bmp, new AbbreviationClientData()));
             }
-        });
+        }
     }
+    return V;
 }
 
 void AbbreviationPlugin::OnAbbrevSelected(clCodeCompletionEvent& e)
 {
-    if(!e.GetEntry()) {
+    if (!e.GetEntry()) {
         e.Skip();
         return;
     }
 
     AbbreviationClientData* cd = dynamic_cast<AbbreviationClientData*>(e.GetEntry()->GetClientData());
-    if(!cd) {
+    if (!cd) {
         e.Skip();
         return;
     }
@@ -184,7 +170,7 @@ void AbbreviationPlugin::InitDefaults()
 {
     // check to see if there are any abbreviations configured
     AbbreviationJSONEntry jsonData;
-    if(!m_config.ReadItem(&jsonData)) {
+    if (!m_config.ReadItem(&jsonData)) {
         // merge the data from the old configuration
         AbbreviationEntry data;
         m_mgr->GetConfigTool()->ReadObject("AbbreviationsData", &data);
@@ -195,7 +181,7 @@ void AbbreviationPlugin::InitDefaults()
     }
 
     // search for the old item
-    if(jsonData.GetEntries().empty()) {
+    if (jsonData.GetEntries().empty()) {
         // fill some default abbreviations
         wxStringMap_t entries;
         entries["main"] = "int main(int argc, char **argv) {\n    |\n}\n";
@@ -215,14 +201,14 @@ bool AbbreviationPlugin::InsertExpansion(const wxString& abbreviation)
 {
     // get the active editor
     IEditor* editor = m_mgr->GetActiveEditor();
-    if(!editor || abbreviation.IsEmpty()) {
+    if (!editor || abbreviation.IsEmpty()) {
         return false;
     }
 
     // search for abbreviation that matches str
     // prepate list of abbreviations
     AbbreviationJSONEntry jsonData;
-    if(!m_config.ReadItem(&jsonData)) {
+    if (!m_config.ReadItem(&jsonData)) {
         // merge the data from the old configuration
         AbbreviationEntry data;
         m_mgr->GetConfigTool()->ReadObject("AbbreviationsData", &data);
@@ -236,7 +222,7 @@ bool AbbreviationPlugin::InsertExpansion(const wxString& abbreviation)
     const wxStringMap_t& entries = jsonData.GetEntries();
     wxStringMap_t::const_iterator iter = entries.find(abbreviation);
 
-    if(iter != entries.end()) {
+    if (iter != entries.end()) {
 
         wxString text = iter->second;
         int selStart = editor->WordStartPos(editor->GetCurrentPosition(), true);
@@ -246,13 +232,13 @@ bool AbbreviationPlugin::InsertExpansion(const wxString& abbreviation)
         wxString textOrig;
         wxString textLeadingSpaces;
 
-        if(typedWordLen < 0) {
+        if (typedWordLen < 0) {
             typedWordLen = 0;
         }
 
         // format the text to insert
         bool appendEol(false);
-        if(text.EndsWith("\r") || text.EndsWith("\n")) {
+        if (text.EndsWith("\r") || text.EndsWith("\n")) {
             appendEol = true;
         }
 
@@ -262,13 +248,13 @@ bool AbbreviationPlugin::InsertExpansion(const wxString& abbreviation)
 
         text = editor->FormatTextKeepIndent(text, selStart, Format_Text_Save_Empty_Lines);
 
-        // remove the first line indenation that might have been placed by CL
+        // remove the first line indentation that might have been placed by CL
         text.Trim(false).Trim();
         text = textLeadingSpaces + text;
 
-        if(appendEol) {
+        if (appendEol) {
             wxString eol;
-            switch(editor->GetEOL()) {
+            switch (editor->GetEOL()) {
             case 1:
                 eol = "\r";
                 break;
@@ -291,7 +277,7 @@ bool AbbreviationPlugin::InsertExpansion(const wxString& abbreviation)
         // locate the caret(s)
         std::vector<int> carets;
         int where = text.Find("|");
-        while(where != wxNOT_FOUND) {
+        while (where != wxNOT_FOUND) {
             carets.push_back(where);
             where = text.find('|', where + 1);
         }
@@ -299,7 +285,7 @@ bool AbbreviationPlugin::InsertExpansion(const wxString& abbreviation)
         // remove the pipe (|) character
         text.Replace("|", " ");
 
-        if(selEnd - selStart >= 0) {
+        if (selEnd - selStart >= 0) {
             editor->SelectText(selStart, selEnd - selStart);
             editor->ReplaceSelection(text);
             editor->GetCtrl()->ClearSelections();
@@ -307,7 +293,7 @@ bool AbbreviationPlugin::InsertExpansion(const wxString& abbreviation)
             bool first = true;
             std::for_each(carets.begin(), carets.end(), [&](int where) {
                 int caretPos = curPos + where - typedWordLen;
-                if(first) {
+                if (first) {
                     editor->GetCtrl()->SetSelection(caretPos, caretPos + 1);
                     first = false;
                 } else {
@@ -329,33 +315,9 @@ void AbbreviationPlugin::OnShowAbbvreviations(wxCommandEvent& e)
     CHECK_PTR_RET(editor);
 
     wxStyledTextCtrl* ctrl = editor->GetCtrl();
-    wxCodeCompletionBoxEntry::Vec_t V;
-    GetAbbreviations(V, editor->GetWordAtPosition(editor->GetCurrentPosition()));
-    if(!V.empty()) {
+    const auto V = GetAbbreviations(editor->GetWordAtPosition(editor->GetCurrentPosition()));
+    if (!V.empty()) {
         wxCodeCompletionBoxManager::Get().ShowCompletionBox(ctrl, V, wxCodeCompletionBox::kRefreshOnKeyType,
                                                             wxNOT_FOUND);
     }
 }
-
-// Helper
-// AbbreviationServiceProvider::AbbreviationServiceProvider(AbbreviationPlugin* plugin)
-//    : ServiceProvider("Abbreviations", eServiceType::kCodeCompletion)
-//    , m_plugin(plugin)
-//{
-//    SetPriority(10);
-//    Bind(wxEVT_CC_WORD_COMPLETE, &AbbreviationServiceProvider::OnWordComplete, this);
-//}
-//
-// AbbreviationServiceProvider::~AbbreviationServiceProvider()
-//{
-//    Unbind(wxEVT_CC_WORD_COMPLETE, &AbbreviationServiceProvider::OnWordComplete, this);
-//}
-//
-// void AbbreviationServiceProvider::OnWordComplete(clCodeCompletionEvent& event)
-//{
-//    event.Skip();
-//    if(event.GetTriggerKind() == LSP::CompletionItem::kTriggerUser) {
-//        // user used Ctr-SPACE
-//        m_plugin->AddAbbreviations(event);
-//    }
-//}
