@@ -3,19 +3,19 @@
 #include "ColoursAndFontsManager.h"
 #include "LSP/LSPEvent.h"
 #include "LSP/basic_types.h"
-#include "PHPEntityBase.h"
-#include "PHPEntityClass.h"
-#include "PHPEntityFunction.h"
-#include "PHPEntityFunctionAlias.h"
-#include "PHPEntityKeyword.h"
-#include "PHPEntityVariable.h"
-#include "PHPExpression.h"
+#include "PHP/PHPEntityBase.h"
+#include "PHP/PHPEntityClass.h"
+#include "PHP/PHPEntityFunction.h"
+#include "PHP/PHPEntityFunctionAlias.h"
+#include "PHP/PHPEntityKeyword.h"
+#include "PHP/PHPEntityVariable.h"
+#include "PHP/PHPExpression.h"
 #include "clEditorBar.h"
 #include "clSelectSymbolDialog.h"
 #include "cl_command_event.h"
 #include "cl_config.h"
+#include "database/entry.h"
 #include "editor_config.h"
-#include "entry.h"
 #include "event_notifier.h"
 #include "globals.h"
 #include "imanager.h"
@@ -47,13 +47,6 @@ struct PHPCCUserData : public wxClientData {
 };
 
 /// Ascending sorting function
-struct _SDescendingSort {
-    bool operator()(const TagEntryPtr& rStart, const TagEntryPtr& rEnd)
-    {
-        return rStart->GetName().Cmp(rEnd->GetName()) > 0;
-    }
-};
-
 struct _SAscendingSort {
     bool operator()(const TagEntryPtr& rStart, const TagEntryPtr& rEnd)
     {
@@ -65,59 +58,48 @@ struct _SAscendingSort {
 PHPCodeCompletion* PHPCodeCompletion::m_instance = NULL;
 
 PHPCodeCompletion::PHPCodeCompletion()
-    : ServiceProvider("PHP Plugin", eServiceType::kCodeCompletion)
-    , m_manager(NULL)
+    : m_manager(NULL)
     , m_typeInfoTooltip(NULL)
 {
-    EventNotifier::Get()->Connect(wxEVT_CMD_RETAG_WORKSPACE, wxCommandEventHandler(PHPCodeCompletion::OnRetagWorkspace),
-                                  NULL, this);
-    EventNotifier::Get()->Connect(wxEVT_CMD_RETAG_WORKSPACE_FULL,
-                                  wxCommandEventHandler(PHPCodeCompletion::OnRetagWorkspace), NULL, this);
+    EventNotifier::Get()->Bind(wxEVT_CMD_RETAG_WORKSPACE, &PHPCodeCompletion::OnRetagWorkspace, this);
+    EventNotifier::Get()->Bind(wxEVT_CMD_RETAG_WORKSPACE_FULL, &PHPCodeCompletion::OnRetagWorkspace, this);
 
     EventNotifier::Get()->Bind(wxEVT_FILE_SAVED, clCommandEventHandler(PHPCodeCompletion::OnFileSaved), this);
     EventNotifier::Get()->Bind(wxEVT_ACTIVE_EDITOR_CHANGED, &PHPCodeCompletion::OnActiveEditorChanged, this);
-    EventNotifier::Get()->Connect(wxEVT_CC_CODE_COMPLETE_LANG_KEYWORD,
-                                  clCodeCompletionEventHandler(PHPCodeCompletion::OnCodeCompleteLangKeywords), NULL,
-                                  this);
-    EventNotifier::Get()->Connect(wxEVT_CC_CODE_COMPLETE_BOX_DISMISSED,
-                                  clCodeCompletionEventHandler(PHPCodeCompletion::OnCodeCompletionBoxDismissed), NULL,
-                                  this);
-    EventNotifier::Get()->Connect(wxEVT_CC_GENERATE_DOXY_BLOCK,
-                                  clCodeCompletionEventHandler(PHPCodeCompletion::OnInsertDoxyBlock), NULL, this);
+    EventNotifier::Get()->Bind(wxEVT_CC_CODE_COMPLETE_LANG_KEYWORD, &PHPCodeCompletion::OnCodeCompleteLangKeywords,
+                               this);
+    EventNotifier::Get()->Bind(wxEVT_CC_CODE_COMPLETE_BOX_DISMISSED, &PHPCodeCompletion::OnCodeCompletionBoxDismissed,
+                               this);
+    EventNotifier::Get()->Bind(wxEVT_CC_GENERATE_DOXY_BLOCK, &PHPCodeCompletion::OnInsertDoxyBlock, this);
     EventNotifier::Get()->Bind(wxPHP_PARSE_ENDED, &PHPCodeCompletion::OnParseEnded, this);
 
     // code completion events
-    Bind(wxEVT_CC_CODE_COMPLETE, &PHPCodeCompletion::OnCodeComplete, this);
-    Bind(wxEVT_CC_CODE_COMPLETE_FUNCTION_CALLTIP, &PHPCodeCompletion::OnFunctionCallTip, this);
-    Bind(wxEVT_CC_TYPEINFO_TIP, &PHPCodeCompletion::OnTypeinfoTip, this);
-    Bind(wxEVT_CC_FIND_SYMBOL, &PHPCodeCompletion::OnFindSymbol, this);
-    Bind(wxEVT_CC_JUMP_HYPER_LINK, &PHPCodeCompletion::OnQuickJump, this);
+    EventNotifier::Get()->Bind(wxEVT_CC_CODE_COMPLETE, &PHPCodeCompletion::OnCodeComplete, this);
+    EventNotifier::Get()->Bind(wxEVT_CC_CODE_COMPLETE_FUNCTION_CALLTIP, &PHPCodeCompletion::OnFunctionCallTip, this);
+    EventNotifier::Get()->Bind(wxEVT_CC_TYPEINFO_TIP, &PHPCodeCompletion::OnTypeinfoTip, this);
+    EventNotifier::Get()->Bind(wxEVT_CC_FIND_SYMBOL, &PHPCodeCompletion::OnFindSymbol, this);
+    EventNotifier::Get()->Bind(wxEVT_CC_JUMP_HYPER_LINK, &PHPCodeCompletion::OnQuickJump, this);
 }
 
 PHPCodeCompletion::~PHPCodeCompletion()
 {
     EventNotifier::Get()->Unbind(wxEVT_ACTIVE_EDITOR_CHANGED, &PHPCodeCompletion::OnActiveEditorChanged, this);
-    EventNotifier::Get()->Disconnect(wxEVT_CMD_RETAG_WORKSPACE,
-                                     wxCommandEventHandler(PHPCodeCompletion::OnRetagWorkspace), NULL, this);
-    EventNotifier::Get()->Disconnect(wxEVT_CMD_RETAG_WORKSPACE_FULL,
-                                     wxCommandEventHandler(PHPCodeCompletion::OnRetagWorkspace), NULL, this);
+    EventNotifier::Get()->Unbind(wxEVT_CMD_RETAG_WORKSPACE, &PHPCodeCompletion::OnRetagWorkspace, this);
+    EventNotifier::Get()->Unbind(wxEVT_CMD_RETAG_WORKSPACE_FULL, &PHPCodeCompletion::OnRetagWorkspace, this);
 
     EventNotifier::Get()->Unbind(wxEVT_FILE_SAVED, clCommandEventHandler(PHPCodeCompletion::OnFileSaved), this);
-    EventNotifier::Get()->Disconnect(wxEVT_CC_CODE_COMPLETE_LANG_KEYWORD,
-                                     clCodeCompletionEventHandler(PHPCodeCompletion::OnCodeCompleteLangKeywords), NULL,
-                                     this);
-    EventNotifier::Get()->Disconnect(wxEVT_CC_CODE_COMPLETE_BOX_DISMISSED,
-                                     clCodeCompletionEventHandler(PHPCodeCompletion::OnCodeCompletionBoxDismissed),
-                                     NULL, this);
-    EventNotifier::Get()->Disconnect(wxEVT_CC_GENERATE_DOXY_BLOCK,
-                                     clCodeCompletionEventHandler(PHPCodeCompletion::OnInsertDoxyBlock), NULL, this);
+    EventNotifier::Get()->Unbind(wxEVT_CC_CODE_COMPLETE_LANG_KEYWORD, &PHPCodeCompletion::OnCodeCompleteLangKeywords,
+                                 this);
+    EventNotifier::Get()->Unbind(wxEVT_CC_CODE_COMPLETE_BOX_DISMISSED, &PHPCodeCompletion::OnCodeCompletionBoxDismissed,
+                                 this);
+    EventNotifier::Get()->Unbind(wxEVT_CC_GENERATE_DOXY_BLOCK, &PHPCodeCompletion::OnInsertDoxyBlock, this);
     EventNotifier::Get()->Unbind(wxPHP_PARSE_ENDED, &PHPCodeCompletion::OnParseEnded, this);
     // code completion events
-    Unbind(wxEVT_CC_CODE_COMPLETE, &PHPCodeCompletion::OnCodeComplete, this);
-    Unbind(wxEVT_CC_CODE_COMPLETE_FUNCTION_CALLTIP, &PHPCodeCompletion::OnFunctionCallTip, this);
-    Unbind(wxEVT_CC_TYPEINFO_TIP, &PHPCodeCompletion::OnTypeinfoTip, this);
-    Unbind(wxEVT_CC_FIND_SYMBOL, &PHPCodeCompletion::OnFindSymbol, this);
-    Unbind(wxEVT_CC_JUMP_HYPER_LINK, &PHPCodeCompletion::OnQuickJump, this);
+    EventNotifier::Get()->Unbind(wxEVT_CC_CODE_COMPLETE, &PHPCodeCompletion::OnCodeComplete, this);
+    EventNotifier::Get()->Unbind(wxEVT_CC_CODE_COMPLETE_FUNCTION_CALLTIP, &PHPCodeCompletion::OnFunctionCallTip, this);
+    EventNotifier::Get()->Unbind(wxEVT_CC_TYPEINFO_TIP, &PHPCodeCompletion::OnTypeinfoTip, this);
+    EventNotifier::Get()->Unbind(wxEVT_CC_FIND_SYMBOL, &PHPCodeCompletion::OnFindSymbol, this);
+    EventNotifier::Get()->Unbind(wxEVT_CC_JUMP_HYPER_LINK, &PHPCodeCompletion::OnQuickJump, this);
 }
 
 PHPCodeCompletion* PHPCodeCompletion::Instance()
@@ -266,7 +248,7 @@ void PHPCodeCompletion::OnCodeComplete(clCodeCompletionEvent& e)
     e.Skip(true);
     if(PHPWorkspace::Get()->IsOpen()) {
         IEditor* editor = GetEditor(e.GetFileName());
-        if(editor && IsPHPFile(editor)) {
+        if(editor && wxWindow::FindFocus() == editor->GetCtrl() && IsPHPFile(editor)) {
             e.Skip(false);
 
             // Update the settings
@@ -436,7 +418,7 @@ PHPLocation::Ptr_t PHPCodeCompletion::FindDefinition(IEditor* editor, int pos)
                 // use the internal function
                 resolved = resolved->Cast<PHPEntityFunctionAlias>()->GetFunc();
             }
-            loc = new PHPLocation;
+            loc = std::make_shared<PHPLocation>();
             loc->filename = resolved->GetFilename().GetFullPath();
             loc->linenumber = resolved->GetLine();
             loc->what = resolved->GetShortName();
@@ -650,10 +632,6 @@ void PHPCodeCompletion::OnInsertDoxyBlock(clCodeCompletionEvent& e)
     }
 }
 
-void PHPCodeCompletion::OnSymbolsCached() { clLogMessage("PHP Symbols cached into OS cache"); }
-
-void PHPCodeCompletion::OnSymbolsCacheError() { clLogMessage("Error encountered while caching PHP symbols"); }
-
 void PHPCodeCompletion::OnQuickJump(clCodeCompletionEvent& e)
 {
     // this is identical to "Find Symbol"
@@ -773,7 +751,7 @@ int PHPCodeCompletion::GetLocationForSettersGetters(const wxString& filecontent,
     phpLexerToken token;
     bool isOK = false;
     while(::phpLexerNext(scanner, token)) {
-        if(token.type != kPHP_T_CLASS) {
+        if(token.type != kPHP_T_CLASS && token.type != kPHP_T_ENUM) {
             continue;
         }
 
