@@ -26,18 +26,17 @@
 #ifndef PHPCODECOMPLETION_H
 #define PHPCODECOMPLETION_H
 
-#include "PHPEntityBase.h"
-#include "PHPExpression.h"
-#include "PHPLookupTable.h"
-#include "ServiceProvider.h"
+#include "PHP/PHPEntityBase.h"
+#include "PHP/PHPExpression.h"
+#include "PHP/PHPLookupTable.h"
+#include "cc_box_tip_window.h"
 #include "cl_command_event.h"
 #include "ieditor.h"
 #include "php_event.h"
 #include "precompiled_header.h"
 #include "wxStringHash.h"
-#include <cc_box_tip_window.h>
-#include <cl_command_event.h>
-#include <smart_ptr.h>
+
+#include <memory>
 #include <vector>
 
 struct PHPLocation {
@@ -45,12 +44,12 @@ struct PHPLocation {
     wxString filename; // file name (absolute path)
     int linenumber;    // line number within filename
     PHPEntityBase::Ptr_t entity;
-    typedef SmartPtr<PHPLocation> Ptr_t;
+    using Ptr_t = std::shared_ptr<PHPLocation>;
 };
 
 class IManager;
 struct ResourceItem;
-class PHPCodeCompletion : public ServiceProvider
+class PHPCodeCompletion : public wxEvtHandler
 {
 public:
     enum {
@@ -141,17 +140,6 @@ public:
      */
     void Close();
 
-    /**
-     * @brief called by the PHP symbols cache job.
-     * This is to optimize the searching the database (loading the symbols into the
-     * memory forces a kernel caching)
-     */
-    void OnSymbolsCached();
-
-    /**
-     * @brief same as the above function, but the caching went bad...
-     */
-    void OnSymbolsCacheError();
     /**
      * @brief expand 'require_once' line (or any require) by replacing __file__ etc with the proper
      * values and appending everything
