@@ -26,11 +26,12 @@
 #ifndef PHPPROJECTSETTINGSDATA_H
 #define PHPPROJECTSETTINGSDATA_H
 
-#include <wx/string.h>
-#include <wx/arrstr.h>
 #include "JSON.h"
-#include <macros.h>
 #include "XDebugBreakpoint.h"
+#include "macros.h"
+
+#include <wx/arrstr.h>
+#include <wx/string.h>
 
 class PHPProjectSettingsData
 {
@@ -113,7 +114,6 @@ public:
     const wxString& GetIncludePath() const { return m_includePath; }
     wxArrayString GetIncludePathAsArray() const;
     wxArrayString GetCCIncludePathAsArray() const;
-    static wxArrayString GetAllIncludePaths();
 
     const wxString& GetIndexFile() const { return m_indexFile; }
     const wxString& GetPhpExe() const { return m_phpExe; }
