@@ -2,21 +2,20 @@
 
 #include "clWorkspaceManager.h"
 #include "cl_command_event.h"
+#include "dirtraverser.h"
+#include "event_notifier.h"
 #include "file_logger.h"
+#include "globals.h"
+#include "macros.h"
 #include "php_code_completion.h"
 #include "php_configuration_data.h"
 #include "php_event.h"
 #include "php_parser_thread.h"
 #include "php_strings.h"
+#include "plugin.h"
 #include "wxCodeCompletionBox.h"
 
 #include <algorithm>
-#include <cl_command_event.h>
-#include <dirtraverser.h>
-#include <event_notifier.h>
-#include <globals.h>
-#include <macros.h>
-#include <plugin.h>
 #include <wx/busyinfo.h>
 #include <wx/msgdlg.h>
 #include <wx/progdlg.h>
@@ -219,8 +218,6 @@ void PHPWorkspace::CreateProject(const PHPProject::CreateData& createData)
     ParseWorkspace(false);
 }
 
-bool PHPWorkspace::IsProjectExists(const wxString& project) { return HasProject(project); }
-
 const PHPProject::Map_t& PHPWorkspace::GetProjects() const { return m_projects; }
 
 void PHPWorkspace::DeleteProject(const wxString& project)
@@ -271,34 +268,6 @@ void PHPWorkspace::GetWorkspaceFiles(wxStringSet_t& workspaceFiles, wxProgressDi
     }
 }
 
-void PHPWorkspace::GetWorkspaceFiles(wxStringSet_t& workspaceFiles, const wxString& filter) const
-{
-    wxStringSet_t all_files;
-    GetWorkspaceFiles(all_files);
-    if(filter.IsEmpty()) {
-        workspaceFiles.swap(all_files);
-
-    } else {
-        wxStringSet_t::iterator iter = all_files.begin();
-        for(; iter != all_files.end(); ++iter) {
-            wxFileName fn(*iter);
-            if(fn.GetName().Contains(filter)) {
-                workspaceFiles.insert(*iter);
-            }
-        }
-    }
-}
-
-void PHPWorkspace::DoNotifyFilesRemoved(const wxArrayString& files)
-{
-    if(!files.IsEmpty()) {
-
-        wxBusyInfo info(_("Updating workspace..."));
-        wxYieldIfNeeded();
-        EventNotifier::Get()->PostFileRemovedEvent(files);
-    }
-}
-
 wxString PHPWorkspace::GetActiveProjectName() const
 {
     PHPProject::Map_t::const_iterator iter = m_projects.begin();
@@ -310,16 +279,6 @@ wxString PHPWorkspace::GetActiveProjectName() const
     return "";
 }
 
-void PHPWorkspace::DelFile(const wxString& project, const wxString& filename)
-{
-    PHPProject::Ptr_t proj = GetProject(project);
-    CHECK_PTR_RET(proj);
-
-    wxArrayString files;
-    files.Add(filename);
-    proj->FilesDeleted(files, true);
-}
-
 bool PHPWorkspace::RunProject(bool debugging, const wxString& urlOrFilePath, const wxString& projectName,
                               const wxString& xdebugSessionName)
 {
@@ -483,30 +442,6 @@ void PHPWorkspace::Rename(const wxString& newname)
     EventNotifier::Get()->AddPendingEvent(evtRetag);
 }
 
-void PHPWorkspace::DoPromptWorkspaceModifiedDialog()
-{
-    wxMessageDialog dlg(FRAME, _("Workspace file modified externally. Would you like to reload the workspace?"),
-                        "CodeLite", wxYES_NO | wxCENTER);
-    dlg.SetYesNoLabels(_("Reload Workspace"), _("Ignore"));
-
-    int answer = dlg.ShowModal();
-    if(answer == wxID_YES) {
-        wxCommandEvent evtReload(wxEVT_COMMAND_MENU_SELECTED, XRCID("reload_workspace"));
-        FRAME->GetEventHandler()->AddPendingEvent(evtReload);
-    }
-}
-
-void PHPWorkspace::GetWorkspaceFiles(wxArrayString& workspaceFiles, wxProgressDialog* progress) const
-{
-    wxStringSet_t files;
-    GetWorkspaceFiles(files, progress);
-    workspaceFiles.clear();
-    wxStringSet_t::const_iterator iter = files.begin();
-    for(; iter != files.end(); ++iter) {
-        workspaceFiles.Add(*iter);
-    }
-}
-
 void PHPWorkspace::ParseWorkspace(bool full)
 {
     // Request for parsing
