@@ -31,11 +31,11 @@
 #include "PHPWrokspaceStorageInterface.h"
 #include "XDebugBreakpoint.h"
 #include "imanager.h"
+#include "macros.h"
 #include "php_project.h"
 #include "php_project_settings_data.h"
 #include "phpexecutor.h"
 
-#include <macros.h>
 #include <map>
 #include <set>
 #include <vector>
@@ -96,8 +96,6 @@ public:
     virtual ~PHPWorkspace();
 
 protected:
-    void DoNotifyFilesRemoved(const wxArrayString& files);
-    void DoPromptWorkspaceModifiedDialog();
     void OnProjectSyncEnd(clCommandEvent& event);
 
 public:
@@ -194,14 +192,6 @@ public:
      */
     void Rename(const wxString& newname);
 
-    /////////////////////////////////////
-    // Sanity
-    /////////////////////////////////////
-    /**
-     * @brief synonym to HasProject()
-     */
-    bool IsProjectExists(const wxString& project);
-
     /////////////////////////////////////
     // Workspace construction
     /////////////////////////////////////
@@ -214,29 +204,15 @@ public:
      */
     bool AddProject(const wxFileName& projectFile, wxString& errmsg);
 
-    /**
-     * @brief delete a file from a project/folder
-     */
-    void DelFile(const wxString& project, const wxString& filename);
-
     /**
      * @brief return map with all projects
      */
     const PHPProject::Map_t& GetProjects() const;
-    /**
-     * @brief return list of files from the entire workspace that matches given filter (Contains())
-     * note that files are returned as fullpath
-     */
-    void GetWorkspaceFiles(wxStringSet_t& workspaceFiles, const wxString& filter) const;
     /**
      * @brief return list of files from the entire workspace
      * note that files are returned as fullpath
      */
     void GetWorkspaceFiles(wxStringSet_t& workspaceFiles, wxProgressDialog* progress = NULL) const;
-    /**
-     * @brief same as above, but return the files in the form of an array
-     */
-    void GetWorkspaceFiles(wxArrayString& workspaceFiles, wxProgressDialog* progress) const;
     /**
      * @brief return the active project name
      */
