@@ -1,15 +1,16 @@
 #include "PHPDebugPane.h"
+
 #include "ColoursAndFontsManager.h"
 #include "XDebugManager.h"
+#include "editor_config.h"
+#include "event_notifier.h"
+#include "globals.h"
 #include "lexer_configuration.h"
 #include "php_event.h"
 #include "php_utils.h"
 #include "php_workspace.h"
 #include "xdebugevent.h"
-#include <editor_config.h>
-#include <event_notifier.h>
-#include <globals.h>
-#include <lexer_configuration.h>
+
 #include <wx/tokenzr.h>
 
 PHPDebugPane::PHPDebugPane(wxWindow* parent)
@@ -30,10 +31,12 @@ PHPDebugPane::PHPDebugPane(wxWindow* parent)
     if(phpLexer) {
         phpLexer->Apply(m_console->GetTerminalOutputWindow());
     }
-    m_tbBreakpoints->AddTool(wxID_DELETE, _("Delete"), clGetManager()->GetStdIcons()->LoadBitmap("minus"),
+    m_tbBreakpoints->AddTool(wxID_DELETE, _("Delete"),
+                            wxBitmapBundle(clGetManager()->GetStdIcons()->LoadBitmap("minus")),
                              _("Delete the selected breakpoints"));
     m_tbBreakpoints->AddTool(wxID_CLEAR, _("Delete all breakpoints"),
-                             clGetManager()->GetStdIcons()->LoadBitmap("clean"), _("Delete all breakpoints"));
+                             wxBitmapBundle(clGetManager()->GetStdIcons()->LoadBitmap("clean")),
+                             _("Delete all breakpoints"));
     m_tbBreakpoints->Bind(wxEVT_TOOL, &PHPDebugPane::OnDeleteBreakpoint, this, wxID_DELETE);
     m_tbBreakpoints->Bind(wxEVT_UPDATE_UI, &PHPDebugPane::OnDeleteBreakpointUI, this, wxID_DELETE);
     m_tbBreakpoints->Bind(wxEVT_TOOL, &PHPDebugPane::OnClearAll, this, wxID_CLEAR);
