@@ -4,14 +4,20 @@
 #include "PHPDebugPane.h"
 #include "PHPXDebugSetupWizard.h"
 #include "XDebugTester.h"
+#include "Zip/clZipReader.h"
 #include "bookmark_manager.h"
 #include "clSFTPEvent.h"
 #include "clWorkspaceManager.h"
 #include "clWorkspaceView.h"
-#include "clZipReader.h"
+#include "cl_config.h"
 #include "cl_standard_paths.h"
+#include "ctags_manager.h"
+#include "detachedpanesinfo.h"
+#include "dockablepane.h"
 #include "editor_config.h"
 #include "evalpane.h"
+#include "event_notifier.h"
+#include "file_logger.h"
 #include "globals.h"
 #include "localsview.h"
 #include "new_php_workspace_dlg.h"
@@ -25,34 +31,22 @@
 #include "php_utils.h"
 #include "php_workspace.h"
 #include "php_workspace_view.h"
+#include "plugin.h"
 #include "quick_outline_dlg.h"
 #include "ssh_workspace_settings.h"
 #include "wxCodeCompletionBox.h"
 #include "xdebugevent.h"
 
-#include <cl_config.h>
-#include <cl_standard_paths.h>
-#include <ctags_manager.h>
-#include <detachedpanesinfo.h>
-#include <dockablepane.h>
-#include <event_notifier.h>
-#include <file_logger.h>
-#include <plugin.h>
 #include <wx/app.h>
 #include <wx/filedlg.h>
 #include <wx/regex.h>
 #include <wx/richmsgdlg.h>
 #include <wx/xrc/xmlres.h>
 
-static PhpPlugin* thePlugin = NULL;
-
 // Define the plugin entry point
 CL_PLUGIN_API IPlugin* CreatePlugin(IManager* manager)
 {
-    if(thePlugin == 0) {
-        thePlugin = new PhpPlugin(manager);
-    }
-    return thePlugin;
+    return new PhpPlugin(manager);
 }
 
 CL_PLUGIN_API PluginInfo* GetPluginInfo()
@@ -152,13 +146,15 @@ PhpPlugin::PhpPlugin(IManager* manager)
         targetDir.AppendDir("php-plugin");
 
         // Don't extract the zip if one of the files on disk is newer or equal to the zip timestamp
-        wxFileName fnSampleFile(targetDir.GetPath(), "basic.php");
+        wxFileName fnSampleFile(targetDir.GetPath(), "version");
         fnSampleFile.AppendDir("cc");
         PHPConfigurationData config;
         if(!fnSampleFile.Exists() || // the sample file does not exists
                                      // Or the resource file (PHP.zip) is newer than the sample file
            (phpResources.GetModificationTime().GetTicks() > fnSampleFile.GetModificationTime().GetTicks())) {
-
+            if(targetDir.DirExists()) {
+                targetDir.Rmdir(wxPATH_RMDIR_RECURSIVE);
+            }
             targetDir.Mkdir(wxS_DIR_DEFAULT, wxPATH_MKDIR_FULL);
             zipReader.Extract("*", targetDir.GetPath());
 
@@ -188,14 +184,6 @@ PhpPlugin::PhpPlugin(IManager* manager)
 
 PhpPlugin::~PhpPlugin() {}
 
-bool PhpPlugin::IsWorkspaceViewDetached()
-{
-    DetachedPanesInfo dpi;
-    m_mgr->GetConfigTool()->ReadObject(wxT("DetachedPanesList"), &dpi);
-    wxArrayString detachedPanes = dpi.GetPanes();
-    return detachedPanes.Index(PHPStrings::PHP_WORKSPACE_VIEW_TITLE) != wxNOT_FOUND;
-}
-
 void PhpPlugin::CreateToolBar(clToolBarGeneric* toolbar) { wxUnusedVar(toolbar); }
 
 void PhpPlugin::CreatePluginMenu(wxMenu* pluginsMenu)
@@ -575,8 +563,6 @@ void PhpPlugin::OnXDebugDeleteAllBreakpoints(clDebugEvent& e)
     EventNotifier::Get()->AddPendingEvent(eventDelAllBP);
 }
 
-void PhpPlugin::OnXDebugShowBreakpointsWindow(wxCommandEvent& e) { DoEnsureXDebugPanesVisible(_("Breakpoints")); }
-
 void PhpPlugin::DoEnsureXDebugPanesVisible(const wxString& selectWindow)
 {
     // Save the current layout to be the normal layout
@@ -653,8 +639,6 @@ void PhpPlugin::OnNewProjectFinish(clNewProjectEvent& e)
     }
 }
 
-void PhpPlugin::OnXDebugSettings(wxCommandEvent& e) {}
-
 void PhpPlugin::OnAllEditorsClosed(wxCommandEvent& e)
 {
     e.Skip();
