@@ -1,12 +1,14 @@
 #include "php_file_layout_tree.h"
-#include <imanager.h>
-#include <ieditor.h>
-#include <algorithm>
-#include <globals.h>
-#include "PHPEntityFunction.h"
-#include "PHPEntityVariable.h"
-#include "PHPSourceFile.h"
+
+#include "PHP/PHPEntityFunction.h"
+#include "PHP/PHPEntityVariable.h"
+#include "PHP/PHPSourceFile.h"
 #include "fileutils.h"
+#include "globals.h"
+#include "ieditor.h"
+#include "imanager.h"
+
+#include <algorithm>
 
 #ifndef __WXMSW__
 #include <wx/imaglist.h>
@@ -117,27 +119,6 @@ int PHPFileLayoutTree::GetImageId(PHPEntityBase::Ptr_t entry)
     return -1; // Unknown
 }
 
-wxTreeItemId PHPFileLayoutTree::FindItemIdByName(const wxTreeItemId& parent, const wxString& name)
-{
-    if(parent.IsOk() == false) return wxTreeItemId();
-
-    if(!ItemHasChildren(parent)) {
-        return AppendItem(parent, name, 7, 7, NULL);
-    }
-
-    wxTreeItemIdValue cookie;
-    wxTreeItemId child = GetFirstChild(parent, cookie);
-    while(child.IsOk()) {
-        if(GetItemText(child) == name) {
-            return child;
-        }
-        child = GetNextChild(parent, cookie);
-    }
-
-    // No match? add it
-    return AppendItem(parent, name, 7, 7, NULL);
-}
-
 wxTreeItemId PHPFileLayoutTree::RecurseSearch(const wxTreeItemId& item, const wxString& word)
 {
     if(!item.IsOk()) return wxTreeItemId();
@@ -162,41 +143,6 @@ wxTreeItemId PHPFileLayoutTree::RecurseSearch(const wxTreeItemId& item, const wx
     return wxTreeItemId();
 }
 
-void PHPFileLayoutTree::FindWord(const wxString& word)
-{
-    wxString lcword = word;
-    lcword.MakeLower();
-
-    wxTreeItemId item = RecurseSearch(GetRootItem(), lcword);
-    if(item.IsOk()) {
-        SelectItem(item);
-        EnsureVisible(item);
-        ScrollTo(item);
-    }
-}
-
-void PHPFileLayoutTree::AdvanceSelection(bool forward)
-{
-    wxTreeItemId item = GetSelection();
-    if(!item.IsOk()) {
-        return;
-    }
-
-    wxTreeItemId nextItem;
-    if(forward) {
-        // Item is visible, scroll to it to make sure GetNextVisible() wont
-        // fail
-        ScrollTo(item);
-        nextItem = GetNextVisible(item);
-    } else {
-        nextItem = TryGetPrevItem(item);
-    }
-
-    if(nextItem.IsOk()) {
-        SelectItem(nextItem);
-    }
-}
-
 wxTreeItemId PHPFileLayoutTree::TryGetPrevItem(wxTreeItemId item)
 {
     wxCHECK_MSG(item.IsOk(), wxTreeItemId(), wxT("invalid tree item"));
