@@ -2,37 +2,35 @@
 
 #include "FilesCollector.h"
 #include "NewPHPClass.h"
+#include "PHP/PHPLookupTable.h"
 #include "PHPDebugStartDlg.h"
-#include "PHPLookupTable.h"
+#include "SFTPBrowserDlg.h"
+#include "SSHAccountManagerDlg.h"
 #include "XDebugManager.h"
+#include "bitmap_loader.h"
 #include "clFileOrFolderDropTarget.h"
 #include "clFileSystemEvent.h"
 #include "clWorkspaceView.h"
 #include "cl_aui_tool_stickness.h"
+#include "cl_command_event.h"
+#include "editor_config.h"
 #include "event_notifier.h"
 #include "file_logger.h"
+#include "fileextmanager.h"
 #include "fileutils.h"
-#include "new_file_dlg.h"
+#include "globals.h"
+#include "imanager.h"
+#include "macros.h"
 #include "php_configuration_data.h"
 #include "php_project_settings_dlg.h"
 #include "php_strings.h"
 #include "php_workspace.h"
+#include "plugin.h"
+#include "sftp_settings.h"
+#include "ssh/ssh_account_info.h"
 #include "ssh_workspace_settings.h"
 #include "tree_item_data.h"
 
-#include <SFTPBrowserDlg.h>
-#include <SSHAccountManagerDlg.h>
-#include <bitmap_loader.h>
-#include <cl_command_event.h>
-#include <editor_config.h>
-#include <event_notifier.h>
-#include <fileextmanager.h>
-#include <globals.h>
-#include <imanager.h>
-#include <macros.h>
-#include <plugin.h>
-#include <sftp_settings.h>
-#include <ssh_account_info.h>
 #include <wx/busyinfo.h>
 #include <wx/filedlg.h>
 #include <wx/imaglist.h>
@@ -550,18 +548,18 @@ void PHPWorkspaceView::OnNewFolder(wxCommandEvent& e)
     wxTreeItemId parent = m_treeCtrlView->GetFocusedItem();
     CHECK_ITEM_RET(parent);
 
-    ItemData* itemData = DoGetItemData(parent);
-    CHECK_PTR_RET(itemData);
+    ItemData* parentItemData = DoGetItemData(parent);
+    CHECK_PTR_RET(parentItemData);
 
-    if(!itemData->IsFolder() && !itemData->IsProject())
+    if (!parentItemData->IsFolder() && !parentItemData->IsProject())
         return;
 
     PHPProject::Ptr_t proj = PHPWorkspace::Get()->GetProject(project);
     CHECK_PTR_RET(proj);
 
     wxString base;
-    if(itemData->IsFolder()) {
-        base = itemData->GetFolderPath();
+    if (parentItemData->IsFolder()) {
+        base = parentItemData->GetFolderPath();
     } else {
         base = proj->GetFilename().GetPath();
     }
@@ -1039,8 +1037,6 @@ void PHPWorkspaceView::OnNewClass(wxCommandEvent& e)
     }
 }
 
-void PHPWorkspaceView::OnWorkspaceOpenUI(wxUpdateUIEvent& event) { event.Enable(PHPWorkspace::Get()->IsOpen()); }
-
 void PHPWorkspaceView::OnRenameWorkspace(wxCommandEvent& e)
 {
     wxString new_name = ::wxGetTextFromUser(_("New workspace name:"), _("Rename workspace"));
@@ -1122,8 +1118,8 @@ void PHPWorkspaceView::ReportParseThreadProgress(size_t curIndex, size_t total)
     }
 
     if(total) {
-        int precent = (curIndex * 100) / total;
-        m_gaugeParseProgress->SetValue(precent);
+        int percent = (curIndex * 100) / total;
+        m_gaugeParseProgress->SetValue(percent);
     }
 }
 
@@ -1161,8 +1157,6 @@ void PHPWorkspaceView::OnPhpParserProgress(clParseEvent& event)
     ReportParseThreadProgress(event.GetCurfileIndex(), event.GetTotalFiles());
 }
 
-void PHPWorkspaceView::OnPhpParserStarted(clParseEvent& event) { event.Skip(); }
-
 void PHPWorkspaceView::OnSyncWorkspaceWithFileSystem(wxCommandEvent& e)
 {
     PHPWorkspace::Get()->SyncWithFileSystemAsync(this);
