@@ -25,9 +25,9 @@
 #include "cscope.h"
 
 #include "CScopeSettingsDlg.h"
+#include "FileSystemWorkspace/clFileSystemWorkspace.hpp"
+#include "Keyboard/clKeyboardManager.h"
 #include "bitmap_loader.h"
-#include "clFileSystemWorkspace.hpp"
-#include "clKeyboardManager.h"
 #include "cscopedbbuilderthread.h"
 #include "cscopestatusmessage.h"
 #include "cscopetab.h"
@@ -51,17 +51,12 @@
 #include <wx/textdlg.h>
 #include <wx/xrc/xmlres.h>
 
-static Cscope* thePlugin = NULL;
-
 static const wxString CSCOPE_NAME = _("CScope");
 
 // Define the plugin entry point
 CL_PLUGIN_API IPlugin* CreatePlugin(IManager* manager)
 {
-    if(thePlugin == 0) {
-        thePlugin = new Cscope(manager);
-    }
-    return thePlugin;
+    return new Cscope(manager);
 }
 
 CL_PLUGIN_API PluginInfo* GetPluginInfo()
@@ -84,12 +79,10 @@ Cscope::Cscope(IManager* manager)
     m_shortName = CSCOPE_NAME;
     m_topWindow = m_mgr->GetTheApp();
 
-    m_cscopeWin = new CscopeTab(m_mgr->GetOutputPaneNotebook(), m_mgr);
-    auto book = m_mgr->GetOutputPaneNotebook();
-    auto images = book->GetBitmaps();
-    book->AddPage(m_cscopeWin, CSCOPE_NAME, false, images->Add("cscope"));
+    auto book = m_mgr->BookGet(PaneId::BOTTOM_BAR);
+    m_cscopeWin = new CscopeTab(book, m_mgr);
+    m_mgr->BookAddPage(PaneId::BOTTOM_BAR, m_cscopeWin, CSCOPE_NAME);
     m_tabHelper.reset(new clTabTogglerHelper(CSCOPE_NAME, m_cscopeWin, "", NULL));
-    m_tabHelper->SetOutputTabBmp(images->Add("cscope"));
 
     Connect(wxEVT_CSCOPE_THREAD_DONE, wxCommandEventHandler(Cscope::OnCScopeThreadEnded), NULL, this);
     Connect(wxEVT_CSCOPE_THREAD_UPDATE_STATUS, wxCommandEventHandler(Cscope::OnCScopeThreadUpdateStatus), NULL, this);
@@ -242,13 +235,11 @@ void Cscope::UnPlug()
                             wxCommandEventHandler(Cscope::OnCreateDB), NULL, (wxEvtHandler*)this);
 
     // before this plugin is un-plugged we must remove the tab we added
-    for(size_t i = 0; i < m_mgr->GetOutputPaneNotebook()->GetPageCount(); i++) {
-        if(m_cscopeWin == m_mgr->GetOutputPaneNotebook()->GetPage(i)) {
-            m_mgr->GetOutputPaneNotebook()->RemovePage(i);
-            m_cscopeWin->Destroy();
-            break;
-        }
+    if(!m_mgr->BookDeletePage(PaneId::BOTTOM_BAR, m_cscopeWin)) {
+        m_cscopeWin->Destroy();
     }
+    m_cscopeWin = nullptr;
+
     EventNotifier::Get()->Unbind(wxEVT_CONTEXT_MENU_EDITOR, &Cscope::OnEditorContentMenu, this);
     CScopeThreadST::Get()->Stop();
     CScopeThreadST::Free();
@@ -384,7 +375,6 @@ void Cscope::DoCscopeCommand(const wxString& command, const wxString& findWhat,
     }
 
     // set the focus to the cscope tab
-    Notebook* book = m_mgr->GetOutputPaneNotebook();
 
     // make sure that the Output pane is visible
     wxAuiManager* aui = m_mgr->GetDockingManager();
@@ -396,15 +386,7 @@ void Cscope::DoCscopeCommand(const wxString& command, const wxString& findWhat,
         }
     }
 
-    wxString curSel = book->GetPageText((size_t)book->GetSelection());
-    if(curSel != CSCOPE_NAME) {
-        for(size_t i = 0; i < (size_t)book->GetPageCount(); i++) {
-            if(book->GetPageText(i) == CSCOPE_NAME) {
-                book->SetSelection(i);
-                break;
-            }
-        }
-    }
+    m_mgr->BookSelectPage(PaneId::BOTTOM_BAR, CSCOPE_NAME);
 
     // create the search thread and return
     CscopeRequest* req = new CscopeRequest();
