@@ -22,9 +22,12 @@
 //
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
+
+#include "cscopetab.h"
+
+#include "FileSystemWorkspace/clFileSystemWorkspace.hpp"
 #include "bitmap_loader.h"
 #include "cscopedbbuilderthread.h"
-#include "cscopetab.h"
 #include "csscopeconfdata.h"
 #include "drawingutils.h"
 #include "event_notifier.h"
@@ -34,6 +37,7 @@
 #include "imanager.h"
 #include "plugin.h"
 #include "workspace.h"
+
 #include <set>
 #include <wx/app.h>
 #include <wx/imaglist.h>
@@ -45,7 +49,7 @@ CscopeTab::CscopeTab(wxWindow* parent, IManager* mgr)
     , m_table(NULL)
     , m_mgr(mgr)
 {
-    m_styler.Reset(new clFindResultsStyler(m_stc));
+    m_styler = std::make_unique<clFindResultsStyler>(m_stc);
 
     CScopeConfData data;
     m_mgr->GetConfigTool()->ReadObject(wxT("CscopeSettings"), &data);
@@ -173,7 +177,7 @@ void CscopeTab::OnCreateDB(wxCommandEvent& e)
 void CscopeTab::OnWorkspaceOpenUI(wxUpdateUIEvent& e)
 {
     CHECK_CL_SHUTDOWN();
-    e.Enable(m_mgr->IsWorkspaceOpen());
+    e.Enable(IsWorkspaceOpen());
 }
 
 void CscopeTab::OnThemeChanged(wxCommandEvent& e)
@@ -206,8 +210,8 @@ void CscopeTab::AddFile(const wxString& filename)
 
 void CscopeTab::OnHotspotClicked(wxStyledTextEvent& e)
 {
-    CHECK_PTR_RET(clCxxWorkspaceST::Get()->IsOpen());
-
+    if(!IsWorkspaceOpen()) { return; }
+    
     int clickedLine;
     int style = m_styler->HitTest(e, clickedLine);
     if(style == clFindResultsStyler::LEX_FIF_FILE || style == clFindResultsStyler::LEX_FIF_HEADER) {
@@ -217,7 +221,7 @@ void CscopeTab::OnHotspotClicked(wxStyledTextEvent& e)
         // Open the match
         std::map<int, CscopeEntryData>::const_iterator iter = m_matchesInStc.find(clickedLine);
         if(iter != m_matchesInStc.end()) {
-            wxString wsp_path = clCxxWorkspaceST::Get()->GetPrivateFolder();
+            wxString wsp_path = GetWorkingDirectory();
             wxFileName fn(iter->second.GetFile());
             if(!fn.MakeAbsolute(wsp_path)) {
                 clLogMessage(wxT("CScope: failed to convert file to absolute path"));
@@ -238,3 +242,21 @@ void CscopeTab::CenterEditorLine(int lineno)
     IEditor* editor = m_mgr->GetActiveEditor();
     if(editor) { editor->CenterLine(lineno); }
 }
+
+wxString CscopeTab::GetWorkingDirectory() const
+{
+    if(!IsWorkspaceOpen()) { return wxEmptyString; }
+
+    if(clFileSystemWorkspace::Get().IsOpen()) {
+        wxFileName fn = clFileSystemWorkspace::Get().GetFileName();
+        fn.AppendDir(".codelite");
+        return fn.GetPath();
+    } else {
+        return clCxxWorkspaceST::Get()->GetPrivateFolder();
+    }
+}
+
+bool CscopeTab::IsWorkspaceOpen() const
+{
+    return clFileSystemWorkspace::Get().IsOpen() || clCxxWorkspaceST::Get()->IsOpen();
+}
