@@ -19,12 +19,12 @@ ChannelSocket::~ChannelSocket() {}
 
 eReadSome ChannelSocket::read_some()
 {
-    wxString buffer;
     client->SelectRead();
-
-    switch(client->Read(buffer)) {
+    char buffer[1024 * 4];
+    size_t bytes_read = 0;
+    switch(client->Read(buffer, sizeof(buffer), bytes_read)) {
     case clSocketBase::kSuccess:
-        m_buffer.Append(buffer);
+        m_buffer.append(buffer, bytes_read);
         return eReadSome::kSuccess;
     case clSocketBase::kTimeout:
         return eReadSome::kTimeout;
