@@ -4,7 +4,7 @@
 #include "LSP/CompletionItem.h"
 #include "LSP/basic_types.h"
 #include "SimpleTokenizer.hpp"
-#include "entry.h"
+#include "database/entry.h"
 
 #include <unordered_set>
 #include <vector>
@@ -35,8 +35,6 @@ public:
     static LSP::CompletionItem::eCompletionItemKind get_completion_kind(const TagEntry* tag);
     static std::vector<LSP::SymbolInformation> to_symbol_information_array(const std::vector<TagEntryPtr>& tags,
                                                                            bool for_tree_view);
-    static std::vector<LSP::SymbolInformation> to_symbol_information_array(const std::vector<TagEntry>& tags,
-                                                                           bool for_tree_view);
 };
 
 #endif // LSPUTILS_HPP
