@@ -2,12 +2,11 @@
 
 #include "CTags.hpp"
 #include "CompletionHelper.hpp"
-#include "CxxCodeCompletion.hpp"
-#include "CxxPreProcessor.h"
-#include "CxxScannerTokens.h"
-#include "CxxTokenizer.h"
-#include "CxxUsingNamespaceCollector.h"
-#include "CxxVariableScanner.h"
+#include "Cxx/CxxCodeCompletion.hpp"
+#include "Cxx/CxxPreProcessor.h"
+#include "Cxx/CxxScannerTokens.h"
+#include "Cxx/CxxTokenizer.h"
+#include "Cxx/CxxVariableScanner.h"
 #include "LSP/LSPEvent.h"
 #include "LSP/basic_types.h"
 #include "LSPUtils.hpp"
@@ -17,13 +16,11 @@
 #include "clFilesCollector.h"
 #include "clTempFile.hpp"
 #include "cl_calltip.h"
-#include "crawler_include.h"
 #include "ctags_manager.h"
-#include "fc_fileopener.h"
+#include "database/tags_storage_sqlite3.h"
 #include "file_logger.h"
 #include "fileextmanager.h"
 #include "tags_options_data.h"
-#include "tags_storage_sqlite3.h"
 
 #include <deque>
 #include <iostream>
@@ -39,7 +36,7 @@ FileLogger& operator<<(FileLogger& logger, const TagEntry& tag)
 {
     wxString s;
     s << tag.GetKind() << ", " << tag.GetDisplayName() << ", " << tag.GetPatternClean();
-    logger.Append(s, logger.GetRequestedLogLevel());
+    logger.Append(s, logger.GetLogEntryVerbosity());
     return logger;
 }
 
@@ -59,7 +56,7 @@ void remove_db_if_needed(const wxString& dbpath)
         clSYSTEM() << "DB version schema upgrade is required" << endl;
         clSYSTEM() << "New schema version is:" << db->GetVersion() << endl;
         clSYSTEM() << "Current schema version is:" << db->GetSchemaVersion() << endl;
-        db.Reset(nullptr);
+        db = nullptr;
         FileUtils::RemoveFile(dbpath);
     } else {
         clDEBUG() << "No schema changes detected" << endl;
@@ -318,8 +315,7 @@ std::vector<wxString> ProtocolHandler::update_additional_scopes_for_file(const w
         while(!Q.empty()) {
             // pop the front of queue
             wxString file = Q.front();
-            Q.front() = Q.back();
-            Q.pop_back();
+            Q.erase(Q.begin());
 
             // sanity
             if(m_parsed_files_info.count(file) == 0 // no info for this file
@@ -796,7 +792,7 @@ void ProtocolHandler::on_completion(std::unique_ptr<JSON>&& msg, Channel::ptr_t
             // word completion
             // ----------------------------------
             wxStringSet_t visible_files;
-            get_includes_recrusively(filepath, &visible_files);
+            get_includes_recursively(filepath, &visible_files);
             m_completer->word_complete(filepath, line, expression, minimized_buffer, visible_scopes, false, candidates,
                                        visible_files);
         }
@@ -844,7 +840,7 @@ void ProtocolHandler::on_completion(std::unique_ptr<JSON>&& msg, Channel::ptr_t
             item.addProperty("detail", tag->GetTypename());
 
             // set the kind
-            CompletionItem::eCompletionItemKind kind = LSPUtils::get_completion_kind(tag.Get());
+            CompletionItem::eCompletionItemKind kind = LSPUtils::get_completion_kind(tag.get());
             item.addProperty("kind", static_cast<int>(kind));
             counter++;
         }
@@ -1197,7 +1193,7 @@ void ProtocolHandler::on_document_signature_help(std::unique_ptr<JSON>&& msg, Ch
     candidates.clear();
     m_completer->sort_tags(matches, candidates, true, {});
 
-    clCallTipPtr tip(new clCallTip(candidates));
+    clCallTipPtr tip = std::make_shared<clCallTip>(candidates);
     LSP::SignatureHelp sh;
     if(tip) {
         CompletionHelper helper;
@@ -1489,22 +1485,6 @@ void ProtocolHandler::on_definition(std::unique_ptr<JSON>&& msg, Channel::ptr_t
     do_definition(std::move(msg), channel, true);
 }
 
-wxArrayString ProtocolHandler::FilterNonWantedNamespaces(const wxArrayString& namespace_arr) const
-{
-    wxArrayString scopes;
-    scopes.reserve(namespace_arr.size());
-
-    for(const wxString& scope : namespace_arr) {
-        // filter internal scopes from std
-        if(!scope.StartsWith("std::_")) {
-            scopes.Add(scope);
-        }
-    }
-    // the global namespace is **always** last
-    scopes.Add("<global>"); // always include the global namespace
-    return scopes;
-}
-
 void ProtocolHandler::build_search_path()
 {
     // build the workspace file list
@@ -1598,7 +1578,7 @@ wxArrayString ProtocolHandler::get_first_level_includes(const wxString& filepath
     return files;
 }
 
-size_t ProtocolHandler::get_includes_recrusively(const wxString& filepath, wxStringSet_t* output)
+size_t ProtocolHandler::get_includes_recursively(const wxString& filepath, wxStringSet_t* output)
 {
     std::deque<wxString> Q;
     Q.push_back(filepath);
