@@ -25,12 +25,14 @@
 
 #include "GitConsole.h"
 
+#include "AsyncProcess/clCommandProcessor.h"
 #include "ColoursAndFontsManager.h"
 #include "GitResetDlg.h"
+#include "StdToWX.h"
+#include "StringUtils.h"
 #include "bitmap_loader.h"
 #include "clAnsiEscapeCodeColourBuilder.hpp"
-#include "clBitmap.h"
-#include "clCommandProcessor.h"
+#include "clStrings.h"
 #include "clToolBar.h"
 #include "cl_aui_tool_stickness.h"
 #include "cl_config.h"
@@ -52,7 +54,6 @@
 
 #define GIT_MESSAGE(...) AddText(wxString::Format(__VA_ARGS__));
 #define GIT_MESSAGE1(...)
-
 #define GIT_ITEM_DATA(viewItem) reinterpret_cast<GitClientData*>(m_dvListCtrl->GetItemData(viewItem))
 
 namespace
@@ -79,7 +80,6 @@ public:
     }
     virtual ~GitClientData() {}
 
-    void SetPath(const wxString& path) { this->m_path = path; }
     const wxString& GetPath() const { return m_path; }
     eGitFile GetKind() const { return m_kind; }
 };
@@ -102,23 +102,24 @@ struct ToolBarItem {
 // ---------------------------------------------------------------------
 void PopulateToolbarOverflow(clToolBar* toolbar)
 {
-    std::vector<ToolBarItem> items = { { wxTRANSLATE("Create local branch"), XRCID("git_create_branch"), "file_new" },
-                                       { wxTRANSLATE("Switch to local branch"), XRCID("git_switch_branch"), "split" },
-                                       { wxTRANSLATE("Switch to remote branch"), XRCID("git_switch_to_remote_branch"),
-                                         "remote-folder" },
-                                       { wxEmptyString, wxID_SEPARATOR, wxEmptyString },
-                                       { wxTRANSLATE("Refresh"), XRCID("git_refresh"), "file_reload" },
-                                       { wxTRANSLATE("Apply Patch"), XRCID("git_apply_patch"), "patch" },
-                                       { wxEmptyString, wxID_SEPARATOR, wxEmptyString },
-                                       { wxTRANSLATE("Start gitk"), XRCID("git_start_gitk"), "debugger_start" },
-                                       { wxTRANSLATE("Garbage collect"), XRCID("git_garbage_collection"), "clean" },
-                                       { wxEmptyString, wxID_SEPARATOR, wxEmptyString },
-                                       { wxTRANSLATE("Plugin settings"), XRCID("git_settings"), "cog" },
-                                       { wxTRANSLATE("Clone a git repository"), XRCID("git_clone"), "copy" } };
+    std::vector<ToolBarItem> items = {
+        { wxTRANSLATE("Create local branch"), XRCID("git_create_branch"), "file_new" },
+        { wxTRANSLATE("Switch to local branch"), XRCID("git_switch_branch"), "split" },
+        { wxTRANSLATE("Switch to remote branch"), XRCID("git_switch_to_remote_branch"), "remote-folder" },
+        { wxEmptyString, wxID_SEPARATOR, wxEmptyString },
+        { wxTRANSLATE("Refresh"), XRCID("git_refresh"), "file_reload" },
+        { wxTRANSLATE("Apply Patch"), XRCID("git_apply_patch"), "patch" },
+        { wxEmptyString, wxID_SEPARATOR, wxEmptyString },
+        { wxTRANSLATE("Start gitk"), XRCID("git_start_gitk"), "debugger_start" },
+        { wxTRANSLATE("Garbage collect"), XRCID("git_garbage_collection"), "clean" },
+        { wxEmptyString, wxID_SEPARATOR, wxEmptyString },
+        { wxTRANSLATE("Plugin settings"), XRCID("git_settings"), "cog" },
+        { wxTRANSLATE("Clone a git repository"), XRCID("git_clone"), "copy" }
+    };
 
     auto images = toolbar->GetBitmapsCreateIfNeeded();
-    for(auto item : items) {
-        if(item.id == wxID_SEPARATOR) {
+    for (auto item : items) {
+        if (item.id == wxID_SEPARATOR) {
             toolbar->AddSeparator();
         } else {
             toolbar->AddTool(item.id, wxGetTranslation(item.label), images->Add(item.bmp));
@@ -174,19 +175,19 @@ GitConsole::GitConsole(wxWindow* parent, GitPlugin* git)
     m_newBmp = m_bitmapLoader->LoadBitmap("plus");
     m_deleteBmp = m_bitmapLoader->LoadBitmap("minus");
 
-    EventNotifier::Get()->Connect(wxEVT_GIT_CONFIG_CHANGED, wxCommandEventHandler(GitConsole::OnConfigurationChanged),
-                                  NULL, this);
+    EventNotifier::Get()->Connect(
+        wxEVT_GIT_CONFIG_CHANGED, wxCommandEventHandler(GitConsole::OnConfigurationChanged), NULL, this);
     EventNotifier::Get()->Bind(wxEVT_WORKSPACE_CLOSED, &GitConsole::OnWorkspaceClosed, this);
     clConfig conf("git.conf");
     GitEntry data;
     conf.ReadItem(&data);
-    m_isVerbose = (data.GetFlags() & GitEntry::Git_Verbose_Log);
+    m_isVerbose = (data.GetFlags() & GitEntry::VerboseLog);
 
     // Toolbar
     auto images = m_toolbar->GetBitmapsCreateIfNeeded();
     m_toolbar->AddTool(XRCID("git_clear_log"), _("Clear Git Log"), images->Add("clear"), _("Clear Git Log"));
-    m_toolbar->AddTool(XRCID("git_stop_process"), _("Terminate Git Process"), images->Add("execute_stop"),
-                       _("Terminate Git Process"));
+    m_toolbar->AddTool(
+        XRCID("git_stop_process"), _("Terminate Git Process"), images->Add("execute_stop"), _("Terminate Git Process"));
     m_toolbar->AddSeparator();
     m_toolbar->AddTool(XRCID("git_console_add_file"), _("Add File"), images->Add("plus"), _("Add File"));
     m_toolbar->AddTool(XRCID("git_console_reset_file"), _("Reset File"), images->Add("undo"), _("Reset File"));
@@ -206,7 +207,9 @@ GitConsole::GitConsole(wxWindow* parent, GitPlugin* git)
 
 #ifdef __WXMSW__
     m_toolbar->AddSeparator();
-    m_toolbar->AddTool(XRCID("git_msysgit"), _("Open MSYS Git"), images->Add("console"),
+    m_toolbar->AddTool(XRCID("git_msysgit"),
+                       _("Open MSYS Git"),
+                       images->Add("console"),
                        _("Open MSYS Git at the current file location"));
 #endif
 
@@ -214,7 +217,10 @@ GitConsole::GitConsole(wxWindow* parent, GitPlugin* git)
     m_toolbar->Bind(wxEVT_MENU, &GitConsole::OnClearGitLog, this, XRCID("git_clear_log"));
     m_toolbar->Bind(wxEVT_UPDATE_UI, &GitConsole::OnClearGitLogUI, this, XRCID("git_clear_log"));
     m_toolbar->Bind(wxEVT_MENU, &GitConsole::OnResetFile, this, XRCID("git_console_reset_file"));
+    m_toolbar->Bind(wxEVT_MENU, &GitConsole::OnAddUnversionedFiles, this, XRCID("git_console_add_file"));
     m_toolbar->Bind(wxEVT_MENU, &GitConsole::OnStopGitProcess, this, XRCID("git_stop_process"));
+    m_toolbar->Bind(wxEVT_UPDATE_UI, &GitConsole::OnAddUnversionedFilesUI, this, XRCID("git_console_add_file"));
+    m_toolbar->Bind(wxEVT_UPDATE_UI, &GitConsole::OnResetFileUI, this, XRCID("git_console_reset_file"));
     m_toolbar->Bind(wxEVT_UPDATE_UI, &GitConsole::OnStopGitProcessUI, this, XRCID("git_stop_process"));
 
     PopulateToolbarOverflow(m_toolbar);
@@ -235,6 +241,9 @@ GitConsole::GitConsole(wxWindow* parent, GitPlugin* git)
     });
 
     EventNotifier::Get()->Bind(wxEVT_SYS_COLOURS_CHANGED, &GitConsole::OnSysColoursChanged, this);
+    EventNotifier::Get()->Bind(wxEVT_OUTPUT_VIEW_TAB_CHANGED, &GitConsole::OnOutputViewTabChanged, this);
+
+    m_dvListCtrlLog->Bind(wxEVT_CONTEXT_MENU, &GitConsole::OnLogMenu, this);
 
     // force font/colours udpate
     clCommandEvent dummy;
@@ -243,12 +252,13 @@ GitConsole::GitConsole(wxWindow* parent, GitPlugin* git)
 
 GitConsole::~GitConsole()
 {
-    EventNotifier::Get()->Disconnect(wxEVT_GIT_CONFIG_CHANGED,
-                                     wxCommandEventHandler(GitConsole::OnConfigurationChanged), NULL, this);
+    EventNotifier::Get()->Disconnect(
+        wxEVT_GIT_CONFIG_CHANGED, wxCommandEventHandler(GitConsole::OnConfigurationChanged), NULL, this);
     EventNotifier::Get()->Unbind(wxEVT_WORKSPACE_CLOSED, &GitConsole::OnWorkspaceClosed, this);
     m_toolbar->Unbind(wxEVT_TOOL_DROPDOWN, &GitConsole::OnGitPullDropdown, this, XRCID("git_pull"));
     m_toolbar->Unbind(wxEVT_TOOL_DROPDOWN, &GitConsole::OnGitRebaseDropdown, this, XRCID("git_rebase"));
     EventNotifier::Get()->Unbind(wxEVT_SYS_COLOURS_CHANGED, &GitConsole::OnSysColoursChanged, this);
+    EventNotifier::Get()->Unbind(wxEVT_OUTPUT_VIEW_TAB_CHANGED, &GitConsole::OnOutputViewTabChanged, this);
 }
 
 void GitConsole::OnClearGitLog(wxCommandEvent& event)
@@ -259,11 +269,11 @@ void GitConsole::OnClearGitLog(wxCommandEvent& event)
 
 void GitConsole::OnStopGitProcess(wxCommandEvent& event)
 {
-    if(m_git->GetProcess()) {
+    if (m_git->GetProcess()) {
         m_git->GetProcess()->Terminate();
     }
 
-    if(m_git->GetFolderProcess()) {
+    if (m_git->GetFolderProcess()) {
         m_git->GetFolderProcess()->Terminate();
     }
 }
@@ -278,8 +288,8 @@ void GitConsole::OnClearGitLogUI(wxUpdateUIEvent& event) { event.Enable(!m_dvLis
 bool GitConsole::IsPatternFound(const wxString& buffer, const std::unordered_set<wxString>& m) const
 {
     wxString lc = buffer.Lower();
-    for(const auto& s : m) {
-        if(lc.Contains(s)) {
+    for (const auto& s : m) {
+        if (lc.Contains(s)) {
             return true;
         }
     }
@@ -295,7 +305,7 @@ bool GitConsole::HasAnsiEscapeSequences(const wxString& buffer) const
 void GitConsole::AddText(const wxString& text)
 {
     auto lines = ::wxStringTokenize(text, "\n", wxTOKEN_STRTOK);
-    for(const auto& line : lines) {
+    for (const auto& line : lines) {
         AddLine(line);
     }
 }
@@ -308,7 +318,7 @@ void GitConsole::OnConfigurationChanged(wxCommandEvent& e)
     clConfig conf("git.conf");
     GitEntry data;
     conf.ReadItem(&data);
-    m_isVerbose = (data.GetFlags() & GitEntry::Git_Verbose_Log);
+    m_isVerbose = (data.GetFlags() & GitEntry::VerboseLog);
 }
 
 void GitConsole::UpdateTreeView(const wxString& output)
@@ -321,7 +331,7 @@ void GitConsole::UpdateTreeView(const wxString& output)
     std::vector<GitFileEntry> lines;
     lines.reserve(files.size());
 
-    for(wxString& filename : files) {
+    for (wxString& filename : files) {
 
         filename.Trim().Trim(false);
         filename.Replace("\t", " ");
@@ -331,7 +341,7 @@ void GitConsole::UpdateTreeView(const wxString& output)
         filename = filename.AfterFirst(' ');
 
         filename.Trim().Trim(false);
-        if(filename.EndsWith("/"))
+        if (filename.EndsWith("/"))
             // a directory
             continue;
 
@@ -346,13 +356,13 @@ void GitConsole::UpdateTreeView(const wxString& output)
     };
     std::sort(lines.begin(), lines.end(), std::move(sort_cb));
 
-    for(const auto& d : lines) {
+    for (const auto& d : lines) {
         wxString filename = d.fullname;
         wxChar chX = d.prefix[0];
 
         wxBitmap statusBmp;
         eGitFile kind = eGitFile::kUntrackedFile;
-        switch(chX) {
+        switch (chX) {
         case 'M':
             statusBmp = m_modifiedBmp;
             kind = eGitFile::kModifiedFile;
@@ -375,7 +385,7 @@ void GitConsole::UpdateTreeView(const wxString& output)
             break;
         }
 
-        if(kind == eGitFile::kUntrackedFile) {
+        if (kind == eGitFile::kUntrackedFile) {
             // untracked
             cols.clear();
             cols.push_back(MakeFileBitmapLabel(d.path));
@@ -393,7 +403,7 @@ void GitConsole::UpdateTreeView(const wxString& output)
 void GitConsole::OnContextMenu(wxDataViewEvent& event)
 {
     bool hasSelection = (m_dvListCtrl->GetSelectedItemsCount() > 0);
-    if(!hasSelection) {
+    if (!hasSelection) {
         return;
     }
 
@@ -413,34 +423,35 @@ void GitConsole::OnResetFile(wxCommandEvent& event)
     m_dvListCtrl->GetSelections(items);
     wxArrayString filesToRevert, filesToRemove;
 
-    for(size_t i = 0; i < items.GetCount(); ++i) {
+    for (size_t i = 0; i < items.GetCount(); ++i) {
         GitClientData* gcd = GIT_ITEM_DATA(items.Item(i));
-        if(gcd) {
-            if(gcd->GetKind() == eGitFile::kNewFile) {
+        if (gcd) {
+            if (gcd->GetKind() == eGitFile::kNewFile) {
                 filesToRemove.push_back(gcd->GetPath());
 
-            } else if((gcd->GetKind() == eGitFile::kModifiedFile) || (gcd->GetKind() == eGitFile::kRenamedFile)) {
+            } else if ((gcd->GetKind() == eGitFile::kModifiedFile) || (gcd->GetKind() == eGitFile::kRenamedFile) ||
+                       (gcd->GetKind() == eGitFile::kDeletedFile)) {
                 filesToRevert.push_back(gcd->GetPath());
             }
         }
     }
-    if(filesToRevert.IsEmpty() && filesToRemove.IsEmpty()) {
+    if (filesToRevert.IsEmpty() && filesToRemove.IsEmpty()) {
         return;
     }
 
     GitResetDlg dlg(EventNotifier::Get()->TopFrame(), filesToRevert, filesToRemove);
-    if(dlg.ShowModal() != wxID_OK) {
+    if (dlg.ShowModal() != wxID_OK) {
         return;
     }
 
     filesToRevert = dlg.GetItemsToRevert();
     filesToRemove = dlg.GetItemsToRemove();
 
-    if(!filesToRevert.IsEmpty()) {
+    if (!filesToRevert.IsEmpty()) {
         m_git->ResetFiles(filesToRevert);
     }
 
-    if(!filesToRemove.IsEmpty()) {
+    if (!filesToRemove.IsEmpty()) {
         m_git->UndoAddFiles(filesToRemove);
     }
 }
@@ -460,12 +471,38 @@ void GitConsole::OnFileActivated(wxDataViewEvent& event)
 {
     CHECK_ITEM_RET(event.GetItem());
 
-    wxArrayString files;
     GitClientData* gcd = GIT_ITEM_DATA(event.GetItem());
-    if(gcd) {
-        GIT_MESSAGE("Showing diff for: %s", gcd->GetPath().c_str());
+    CHECK_PTR_RET(gcd);
+
+    clConfig conf("git.conf");
+    GitEntry data;
+    conf.ReadItem(&data);
+
+    wxString difftool = data.GetDifftool();
+    if (difftool.empty()) {
+        const wxArrayString wx_options =
+            StdToWX::ToArrayString({ "built-in", "vimdiff", "vimdiff1", "vimdiff2", "vimdiff3", "winmerge" });
+        difftool = ::wxGetSingleChoice(_("Choose a tool to use:"), "CodeLite", wx_options, 0);
+        if (difftool.empty()) {
+            // user hit cancel
+            return;
+        }
+
+        data.SetDifftool(difftool);
+        data.Save();
+
+        wxString message;
+        message << _("Your diff tool is set to: ") << difftool << "\n"
+                << _("You can change this from the menu bar: Plugins > Git > GIT plugin settings > Tools");
+        ::wxMessageBox(message);
+    }
+
+    if (difftool == "built-in") {
+        wxArrayString files;
         files.push_back(gcd->GetPath());
         m_git->ShowDiff(files);
+    } else {
+        m_git->ShowExternalDiff(gcd->GetPath(), difftool);
     }
 }
 
@@ -474,20 +511,20 @@ void GitConsole::OnOpenFile(wxCommandEvent& e)
     wxDataViewItemArray items;
     m_dvListCtrl->GetSelections(items);
     wxArrayString files;
-    for(size_t i = 0; i < items.GetCount(); ++i) {
+    for (size_t i = 0; i < items.GetCount(); ++i) {
         GitClientData* gcd = GIT_ITEM_DATA(items.Item(i));
-        if(gcd) {
+        if (gcd) {
             files.push_back(gcd->GetPath());
         }
     }
 
-    if(files.IsEmpty()) {
+    if (files.IsEmpty()) {
         e.Skip();
         return;
     }
 
     // open the files
-    for(size_t i = 0; i < files.GetCount(); ++i) {
+    for (size_t i = 0; i < files.GetCount(); ++i) {
         GIT_MESSAGE("Opening file: %s", files.Item(i).c_str());
         m_git->OpenFile(files.Item(i));
     }
@@ -520,16 +557,24 @@ void GitConsole::DoOnDropdown(const wxString& commandName, int id)
 
     wxArrayString arr;
     wxMenu menu;
-    for(size_t n = 0; n < entries.size(); ++n) {
+    for (size_t n = 0; n < entries.size(); ++n) {
         wxMenuItem* item = menu.AppendRadioItem(n, entries.at(n).label);
         item->Check(n == (size_t)lastUsed);
         arr.Add(entries.at(n).command);
     }
-    menu.Bind(wxEVT_MENU, wxCommandEventHandler(GitConsole::OnDropDownMenuEvent), this, 0, arr.GetCount(),
+    menu.Bind(wxEVT_MENU,
+              wxCommandEventHandler(GitConsole::OnDropDownMenuEvent),
+              this,
+              0,
+              arr.GetCount(),
               new GitCommandData(arr, commandName, id));
 
     m_toolbar->ShowMenuForButton(id, &menu);
-    menu.Unbind(wxEVT_MENU, wxCommandEventHandler(GitConsole::OnDropDownMenuEvent), this, 0, arr.GetCount(),
+    menu.Unbind(wxEVT_MENU,
+                wxCommandEventHandler(GitConsole::OnDropDownMenuEvent),
+                this,
+                0,
+                arr.GetCount(),
                 new GitCommandData(arr, commandName, id));
 }
 
@@ -554,7 +599,7 @@ void GitConsole::OnDropDownMenuEvent(wxCommandEvent& event)
 
 void GitConsole::HideProgress()
 {
-    if(m_gauge->IsShown()) {
+    if (m_gauge->IsShown()) {
         m_gauge->SetValue(0);
         m_gauge->Hide();
         GetSizer()->Layout();
@@ -563,12 +608,12 @@ void GitConsole::HideProgress()
 
 void GitConsole::ShowProgress(const wxString& message, bool pulse)
 {
-    if(!m_gauge->IsShown()) {
+    if (!m_gauge->IsShown()) {
         m_gauge->Show();
         GetSizer()->Layout();
     }
 
-    if(pulse) {
+    if (pulse) {
         m_gauge->Pulse();
         m_gauge->Update();
 
@@ -597,20 +642,20 @@ void GitConsole::Clear()
 {
     m_dvListCtrl->DeleteAllItems([](wxUIntPtr d) {
         GitClientData* cd = reinterpret_cast<GitClientData*>(d);
-        if(cd) {
+        if (cd) {
             wxDELETE(cd);
         }
     });
 
     m_dvListCtrlUnversioned->DeleteAllItems([](wxUIntPtr d) {
         GitClientData* cd = reinterpret_cast<GitClientData*>(d);
-        if(cd) {
+        if (cd) {
             wxDELETE(cd);
         }
     });
 }
 
-void GitConsole::OnUpdateUI(wxUpdateUIEvent& event) { event.Enable(!m_git->GetRepositoryPath().IsEmpty()); }
+void GitConsole::OnUpdateUI(wxUpdateUIEvent& event) { event.Enable(m_git->IsGitEnabled()); }
 
 void GitConsole::OnUnversionedFileActivated(wxDataViewEvent& event)
 {
@@ -630,22 +675,47 @@ void GitConsole::OnUnversionedFileContextMenu(wxDataViewEvent& event)
     m_dvListCtrlUnversioned->PopupMenu(&menu);
 }
 
+wxArrayString GitConsole::GetSelectedModifiedFiles() const
+{
+    if (m_dvListCtrl->GetSelectedItemsCount() == 0) {
+        return {};
+    }
+
+    wxArrayString paths;
+    wxDataViewItemArray items;
+    int count = m_dvListCtrl->GetSelections(items);
+    paths.reserve(count);
+    for (int i = 0; i < count; i++) {
+        wxDataViewItem item = items.Item(i);
+        if (item.IsOk() == false) {
+            continue;
+        }
+
+        GitClientData* cd = reinterpret_cast<GitClientData*>(m_dvListCtrl->GetItemData(item));
+        if (cd && cd->GetKind() == eGitFile::kModifiedFile) {
+            paths.Add(cd->GetPath());
+        }
+    }
+    return paths;
+}
+
 wxArrayString GitConsole::GetSelectedUnversionedFiles() const
 {
-    if(m_dvListCtrlUnversioned->GetSelectedItemsCount() == 0) {
+    if (m_dvListCtrlUnversioned->GetSelectedItemsCount() == 0) {
         return wxArrayString();
     }
     wxArrayString paths;
     wxDataViewItemArray items;
     int count = m_dvListCtrlUnversioned->GetSelections(items);
-    for(int i = 0; i < count; i++) {
+    paths.reserve(count);
+    for (int i = 0; i < count; i++) {
         wxDataViewItem item = items.Item(i);
-        if(item.IsOk() == false) {
+        if (item.IsOk() == false) {
             continue;
         }
 
         GitClientData* cd = reinterpret_cast<GitClientData*>(m_dvListCtrlUnversioned->GetItemData(item));
-        if(cd && cd->GetKind() == eGitFile::kUntrackedFile) {
+        if (cd && cd->GetKind() == eGitFile::kUntrackedFile) {
             paths.Add(cd->GetPath());
         }
     }
@@ -656,12 +726,12 @@ void GitConsole::OnOpenUnversionedFiles(wxCommandEvent& event)
 {
     wxUnusedVar(event);
     wxArrayString paths = GetSelectedUnversionedFiles();
-    if(paths.IsEmpty()) {
+    if (paths.IsEmpty()) {
         return;
     }
 
-    for(const wxString& filepath : paths) {
-        if(!filepath.EndsWith("/")) {
+    for (const wxString& filepath : paths) {
+        if (!filepath.EndsWith("/")) {
             m_git->OpenFile(filepath);
         }
     }
@@ -684,7 +754,7 @@ wxString GitConsole::GetPrompt() const
     wxString prompt_str = m_git->GetRepositoryPath();
 #ifndef __WXMSW__
     wxString home_dir = ::wxGetHomeDir();
-    if(prompt_str.StartsWith(home_dir)) {
+    if (prompt_str.StartsWith(home_dir)) {
         prompt_str.Replace(home_dir, "~", false);
     }
 #endif
@@ -701,17 +771,17 @@ void GitConsole::AddLine(const wxString& line)
     auto& builder = m_dvListCtrlLog->GetBuilder();
     builder.Clear();
 
-    if(HasAnsiEscapeSequences(tmp)) {
-        builder.Add(tmp, eAsciiColours::NORMAL_TEXT);
+    if (HasAnsiEscapeSequences(tmp)) {
+        builder.Add(tmp, AnsiColours::NormalText());
     } else {
-        if(IsPatternFound(tmp, m_errorPatterns)) {
-            builder.Add(tmp, eAsciiColours::RED);
-        } else if(IsPatternFound(tmp, m_warningPatterns)) {
-            builder.Add(tmp, eAsciiColours::YELLOW);
-        } else if(IsPatternFound(tmp, m_successPatterns)) {
-            builder.Add(tmp, eAsciiColours::GREEN);
+        if (IsPatternFound(tmp, m_errorPatterns)) {
+            builder.Add(tmp, AnsiColours::Red());
+        } else if (IsPatternFound(tmp, m_warningPatterns)) {
+            builder.Add(tmp, AnsiColours::Yellow());
+        } else if (IsPatternFound(tmp, m_successPatterns)) {
+            builder.Add(tmp, AnsiColours::Green());
         } else {
-            builder.Add(tmp, eAsciiColours::NORMAL_TEXT);
+            builder.Add(tmp, AnsiColours::NormalText());
         }
     }
     m_dvListCtrlLog->AddLine(builder.GetString(), text_ends_with_cr);
@@ -721,11 +791,54 @@ void GitConsole::PrintPrompt()
 {
     auto& builder = m_dvListCtrlLog->GetBuilder();
     builder.Clear();
-    builder.Add(GetPrompt(), eAsciiColours::GREEN, true);
+    builder.Add(GetPrompt(), AnsiColours::Green(), true);
     m_dvListCtrlLog->AddLine(builder.GetString(), false);
     builder.Clear();
 }
 
+void GitConsole::OnLogMenu(wxContextMenuEvent& event)
+{
+    wxUnusedVar(event);
+    wxDataViewItemArray selected_items;
+    m_dvListCtrlLog->GetSelections(selected_items);
+
+    wxMenu menu;
+    menu.Append(XRCID("git-console-log-copy"), _("Copy"));
+    menu.Append(XRCID("git-console-log-clear"), _("Clear"));
+
+    menu.Bind(
+        wxEVT_MENU,
+        [this](wxCommandEvent& e) {
+            wxUnusedVar(e);
+            wxDataViewItemArray selected_items;
+            m_dvListCtrlLog->GetSelections(selected_items);
+
+            wxArrayString lines;
+            for (auto item : selected_items) {
+                wxString line = m_dvListCtrlLog->GetItemText(item);
+                line.Trim();
+                wxString mod_buffer;
+                StringUtils::StripTerminalColouring(line, mod_buffer);
+                lines.Add(mod_buffer);
+            }
+
+            ::CopyToClipboard(wxJoin(lines, '\n'));
+        },
+        XRCID("git-console-log-copy"));
+
+    menu.Enable(XRCID("git-console-log-copy"), !selected_items.empty());
+    menu.Enable(XRCID("git-console-log-clear"), !selected_items.empty());
+
+    menu.Bind(
+        wxEVT_MENU,
+        [this](wxCommandEvent& e) {
+            wxUnusedVar(e);
+            m_dvListCtrlLog->DeleteAllItems();
+        },
+        XRCID("git-console-log-clear"));
+    m_dvListCtrlLog->PopupMenu(&menu);
+}
+
 void GitConsole::OnSysColoursChanged(clCommandEvent& event)
 {
     event.Skip();
@@ -734,3 +847,27 @@ void GitConsole::OnSysColoursChanged(clCommandEvent& event)
     m_dvListCtrlLog->SetDefaultFont(font);
     m_dvListCtrlUnversioned->SetDefaultFont(font);
 }
+
+void GitConsole::OnAddUnversionedFilesUI(wxUpdateUIEvent& event)
+{
+    bool has_unversioned_files = !GetSelectedUnversionedFiles().empty();
+    event.Enable(m_git->IsGitEnabled() && has_unversioned_files);
+}
+
+void GitConsole::OnResetFileUI(wxUpdateUIEvent& event)
+{
+    bool has_modified_files = !GetSelectedModifiedFiles().empty();
+    event.Enable(m_git->IsGitEnabled() && has_modified_files);
+}
+
+void GitConsole::OnOutputViewTabChanged(clCommandEvent& event)
+{
+    event.Skip();
+    // Avoid auto refreshing the view on a remote workspace, this could lead to non responsive UI
+    if (m_git->m_isRemoteWorkspace || !clGetManager()->IsPaneShown(PANE_OUTPUT, GIT_TAB_NAME)) {
+        return;
+    }
+    if (m_git && event.GetString() == GIT_TAB_NAME) {
+        m_git->DoRefreshView(false);
+    }
+}
