@@ -37,20 +37,6 @@
 class GitPlugin;
 class GitConsole : public GitConsoleBase
 {
-    GitPlugin* m_git;
-    bool m_isVerbose;
-    BitmapLoader* m_bitmapLoader;
-    wxBitmap m_modifiedBmp;
-    wxBitmap m_untrackedBmp;
-    wxBitmap m_folderBmp;
-    wxBitmap m_newBmp;
-    wxBitmap m_deleteBmp;
-    size_t m_indent = 0;
-    std::unordered_set<wxString> m_errorPatterns;
-    std::unordered_set<wxString> m_successPatterns;
-    std::unordered_set<wxString> m_warningPatterns;
-    wxString m_buffer;
-
 public:
     GitConsole(wxWindow* parent, GitPlugin* git);
     virtual ~GitConsole();
@@ -82,6 +68,8 @@ protected:
     virtual void OnUnversionedFileActivated(wxDataViewEvent& event);
     virtual void OnUnversionedFileContextMenu(wxDataViewEvent& event);
     virtual void OnUpdateUI(wxUpdateUIEvent& event);
+    virtual void OnAddUnversionedFilesUI(wxUpdateUIEvent& event);
+    virtual void OnResetFileUI(wxUpdateUIEvent& event);
     virtual void OnStclogStcChange(wxStyledTextEvent& event);
     virtual void OnApplyPatch(wxCommandEvent& event);
     virtual void OnFileActivated(wxDataViewEvent& event);
@@ -95,6 +83,7 @@ protected:
     virtual void OnOpenUnversionedFiles(wxCommandEvent& event);
     virtual void OnAddUnversionedFiles(wxCommandEvent& event);
     void OnSysColoursChanged(clCommandEvent& event);
+    void OnLogMenu(wxContextMenuEvent& event);
 
     void OnOpenFile(wxCommandEvent& e);
     void OnWorkspaceClosed(clWorkspaceEvent& e);
@@ -109,6 +98,24 @@ protected:
     void DoOnDropdown(const wxString& commandName, int id);
     void OnDropDownMenuEvent(wxCommandEvent& e);
     void Clear();
+    void OnOutputViewTabChanged(clCommandEvent& event);
+
+private:
     wxArrayString GetSelectedUnversionedFiles() const;
+    wxArrayString GetSelectedModifiedFiles() const;
+
+    GitPlugin* m_git = nullptr;
+    bool m_isVerbose = false;
+    BitmapLoader* m_bitmapLoader = nullptr;
+    wxBitmap m_modifiedBmp;
+    wxBitmap m_untrackedBmp;
+    wxBitmap m_folderBmp;
+    wxBitmap m_newBmp;
+    wxBitmap m_deleteBmp;
+    size_t m_indent = 0;
+    std::unordered_set<wxString> m_errorPatterns;
+    std::unordered_set<wxString> m_successPatterns;
+    std::unordered_set<wxString> m_warningPatterns;
+    wxString m_buffer;
 };
 #endif // GITCONSOLE_H
