@@ -33,9 +33,8 @@
 #ifndef __git__
 #define __git__
 
-#include <wx/progdlg.h>
-
-#include "asyncprocess.h"
+#include "AsyncProcess/asyncprocess.h"
+#include "AsyncProcess/processreaderthread.h"
 #include "clCodeLiteRemoteProcess.hpp"
 #include "clTabTogglerHelper.h"
 #include "cl_command_event.h"
@@ -44,32 +43,31 @@
 #include "ieditor.h"
 #include "overlaytool.h"
 #include "plugin.h"
-#include "processreaderthread.h"
 #include "project.h" // wxStringSet_t
+
 #include <map>
 #include <queue>
 #include <set>
 #include <vector>
 #include <wx/progdlg.h>
+#if USE_SFTP
+#include "cl_ssh.h"
+#endif
 
 class clTreeCtrl;
 class clCommandProcessor;
-class GitBlameDlg;
+
+#define GIT_TAB_NAME "Git"
 
 class gitAction
 {
 public:
-    int action;
+    int action = 0;
     wxString arguments;
     wxString workingDirectory;
 
 public:
-    gitAction()
-        : action(0)
-        , arguments("")
-        , workingDirectory("")
-    {
-    }
+    gitAction() {}
     gitAction(int act, const wxString& args)
         : action(act)
         , arguments(args)
@@ -113,6 +111,7 @@ class GitPlugin : public IPlugin
         gitAddFile,
         gitDeleteFile,
         gitDiffFile,
+        gitDiffFileExternal,
         gitDiffRepoCommit,
         gitDiffRepoShow,
         gitResetFile,
@@ -174,7 +173,6 @@ class GitPlugin : public IPlugin
     wxString m_selectedFolder;
     clCommandProcessor* m_commandProcessor;
     clTabTogglerHelper::Ptr_t m_tabToggler;
-    GitBlameDlg* m_gitBlameDlg;
     std::unordered_map<wxString, std::vector<wxString>>
         m_blameMap; // contains file: comment per line (extracted from the 'git blame' info)
     size_t m_configFlags = 0;
@@ -183,15 +181,19 @@ class GitPlugin : public IPlugin
     wxString m_remoteWorkspaceAccount;
     clCodeLiteRemoteProcess m_remoteProcess;
     wxString m_codeliteRemoteScriptPath;
+    bool m_isEnabled = false;
+    bool m_commitDialogIsShown = false;
+#if USE_SFTP
+    clSSH::Ptr_t m_ssh;
+#endif
 
 private:
     void StartCodeLiteRemote();
     void ClearCodeLiteRemoteInfo();
-    void DoCreateTreeImages();
     void DoShowDiffViewer(const wxString& headFile, const wxString& fileName);
     void DoExecuteCommands(const GitCmd::Vec_t& commands, const wxString& workingDir);
-    bool DoExecuteCommandSync(const wxString& command, wxString* commandOutput,
-                              const wxString& workingDir = wxEmptyString);
+    bool
+    DoExecuteCommandSync(const wxString& command, wxString* commandOutput, const wxString& workingDir = wxEmptyString);
 
     void DoSetTreeItemImage(clTreeCtrl* ctrl, const wxTreeItemId& item, OverlayTool::BmpType bmpType) const;
     void InitDefaults();
@@ -217,7 +219,6 @@ private:
     void DoCleanup();
     void DoAddFiles(const wxArrayString& files);
     void DoResetFiles(const wxArrayString& files);
-    void DoGetFileViewSelectedFiles(wxArrayString& files, bool relativeToRepo);
     void DoShowDiffsForFiles(const wxArrayString& files, bool useFileAsBase = false);
     void DoSetRepoPath(const wxString& repo_path = wxEmptyString);
     void DoRecoverFromGitCommandError(bool clear_queue = true);
@@ -244,12 +245,10 @@ private:
     void OnWorkspaceClosed(clWorkspaceEvent& e);
     void OnWorkspaceConfigurationChanged(wxCommandEvent& e);
     void OnMainFrameTitle(clCommandEvent& e);
-    void OnSetGitRepoPath(wxCommandEvent& e);
     void OnSettings(wxCommandEvent& e);
     void OnFileDiffSelected(wxCommandEvent& e);
     void OnFileResetSelected(wxCommandEvent& e);
     void OnFileAddSelected(wxCommandEvent& e);
-    void OnFileDeleteSelected(wxCommandEvent& e);
     void OnSwitchLocalBranch(wxCommandEvent& e);
     void OnSwitchRemoteBranch(wxCommandEvent& e);
     void OnCreateBranch(wxCommandEvent& e);
@@ -276,7 +275,6 @@ private:
     void OnEditorClosed(wxCommandEvent& event);
     void OnEnableGitRepoExists(wxUpdateUIEvent& e);
     void OnClone(wxCommandEvent& e);
-    void OnSftpFileSaved(clCommandEvent& event);
 
     // Event handlers from folder context menu
     void OnFolderPullRebase(wxCommandEvent& event);
@@ -292,6 +290,7 @@ private:
 
     // Remote callbacks
     void OnFindPath(clCommandEvent& event);
+    void OpenURLInBrowser(const wxString& url);
 
 public:
     GitPlugin(IManager* manager);
@@ -305,13 +304,19 @@ public:
     /**
      * @brief create git process and return the process handle
      */
-    IProcess* AsyncRunGit(wxEvtHandler* handler, const wxString& git_args, size_t create_flags,
-                          const wxString& working_directory, bool logMessage = false);
+    IProcess* AsyncRunGit(wxEvtHandler* handler,
+                          const wxString& git_args,
+                          size_t create_flags,
+                          const wxString& working_directory,
+                          bool logMessage = false);
     /**
      * @brief create a git process and direct the output to a callback
      */
-    void AsyncRunGitWithCallback(const wxString& git_args, std::function<void(const wxString&)> callback,
-                                 size_t create_flags, const wxString& working_directory, bool logMessage = false);
+    void AsyncRunGitWithCallback(const wxString& git_args,
+                                 std::function<void(const wxString&)> callback,
+                                 size_t create_flags,
+                                 const wxString& working_directory,
+                                 bool logMessage = false);
     /**
      * @brief is git enabled for the current workspace?
      */
@@ -336,6 +341,7 @@ public:
     IManager* GetManager() { return m_mgr; }
 
     void ShowDiff(const wxArrayString& files) { DoShowDiffsForFiles(files); }
+    void ShowExternalDiff(const wxString& file, const wxString& tool);
 
     void ApplyPatch(const wxString& filename, const wxString& extraFlags);
     void AddFiles(const wxArrayString& files) { DoAddFiles(files); }
@@ -356,8 +362,6 @@ public:
 
     void DoGitBlame(const wxString& args);      // Called by OnGitBlame or the git blame dialog
     wxString GetEditorRelativeFilepath() const; // Called by OnGitBlame or the git blame dialog
-    void OnGitBlameRevList(const wxString& arg, const wxString& filepath,
-                           const wxString& commit = ""); // Called by the git blame dialog
 
     /**
      * @brief simple git command executioin completed. Display its output etc
