@@ -38,6 +38,14 @@
 
 #include <wx/tokenzr.h>
 
+namespace
+{
+wxString GetTempCommitFile()
+{
+    return wxFileName{ clStandardPaths::Get().GetTempDir(), "commit-message.tmp" }.GetFullPath();
+}
+} // namespace
+
 GitCommitDlg::GitCommitDlg(wxWindow* parent, GitPlugin* plugin, const wxString& workingDir)
     : GitCommitDlgBase(parent)
     , m_plugin(plugin)
@@ -45,15 +53,17 @@ GitCommitDlg::GitCommitDlg(wxWindow* parent, GitPlugin* plugin, const wxString&
     , m_toggleChecks(false)
 {
     m_dvListCtrlFiles->SetBitmaps(clGetManager()->GetStdIcons()->GetStandardMimeBitmapListPtr());
-    // read the configuration
+
+    // Load persistent settings
     clConfig conf("git.conf");
     GitEntry data;
     conf.ReadItem(&data);
     m_splitterInner->CallAfter(&wxSplitterWindow::SetSashPosition, data.GetGitCommitDlgHSashPos(), true);
     m_splitterMain->CallAfter(&wxSplitterWindow::SetSashPosition, data.GetGitCommitDlgVSashPos(), true);
+    m_checkBoxSignedOff->SetValue(data.GetFlags() & GitEntry::CheckSignedOffBy);
 
     LexerConf::Ptr_t diffLexer = ColoursAndFontsManager::Get().GetLexer("diff");
-    if(diffLexer) {
+    if (diffLexer) {
         diffLexer->Apply(m_stcDiff);
     }
 
@@ -63,10 +73,16 @@ GitCommitDlg::GitCommitDlg(wxWindow* parent, GitPlugin* plugin, const wxString&
     m_toolbar->Realize();
     m_toolbar->Bind(wxEVT_TOOL, &GitCommitDlg::OnToggleCheckAll, this, XRCID("ID_CHECKALL"));
     m_toolbar->Bind(wxEVT_TOOL, &GitCommitDlg::OnCommitHistory, this, XRCID("ID_HISTORY"));
-    m_editEventsHandlerDiffStc.Reset(new clEditEventsHandler(m_stcDiff));
-    ::clSetDialogBestSizeAndPosition(this);
+    ::clSetTLWindowBestSizeAndPosition(this);
     CentreOnParent();
 
+    wxFileName temp_commit = GetTempCommitFile();
+    if (temp_commit.FileExists()) {
+        wxString content;
+        FileUtils::ReadFileContent(temp_commit, content);
+        m_stcCommitMessage->SetText(content);
+    }
+
     // set the focus to the text control
     m_stcCommitMessage->CallAfter(&wxStyledTextCtrl::SetFocus);
 }
@@ -81,7 +97,16 @@ GitCommitDlg::~GitCommitDlg()
 
     data.SetGitCommitDlgHSashPos(m_splitterInner->GetSashPosition());
     data.SetGitCommitDlgVSashPos(m_splitterMain->GetSashPosition());
+    data.EnableFlag(GitEntry::CheckSignedOffBy, m_checkBoxSignedOff->IsChecked());
     conf.WriteItem(&data);
+
+    // if the dialog was dimissed with "OK", remove the commit file
+    if (m_dismissedWithOk) {
+        FileUtils::RemoveFile(GetTempCommitFile());
+    } else if (!m_stcCommitMessage->IsEmpty()) {
+        // otherwise, write the content to the file, we will load it later
+        FileUtils::WriteFileContent(GetTempCommitFile(), m_stcCommitMessage->GetText());
+    }
 }
 
 /*******************************************************************************/
@@ -94,19 +119,19 @@ void GitCommitDlg::AppendDiff(const wxString& diff)
     BitmapLoader* bitmaps = clGetManager()->GetStdIcons();
     std::vector<wxString> names;
     names.reserve(m_diffMap.size());
-    for(const wxStringMap_t::value_type& vt : m_diffMap) {
+    for (const wxStringMap_t::value_type& vt : m_diffMap) {
         names.push_back(vt.first);
     }
 
     std::sort(names.begin(), names.end(), [](const wxString& a, const wxString& b) { return a.CmpNoCase(b) < 0; });
 
-    for(const wxString& filename : names) {
+    for (const wxString& filename : names) {
         cols.clear();
         cols.push_back(::MakeCheckboxVariant(filename, true, bitmaps->GetMimeImageId(filename)));
         m_dvListCtrlFiles->AppendItem(cols);
     }
 
-    if(!names.empty()) {
+    if (!names.empty()) {
         m_dvListCtrlFiles->Select(m_dvListCtrlFiles->RowToItem(0));
         wxStringMap_t::iterator it = m_diffMap.begin();
         m_stcDiff->SetText((*it).second);
@@ -118,9 +143,9 @@ void GitCommitDlg::AppendDiff(const wxString& diff)
 wxArrayString GitCommitDlg::GetSelectedFiles()
 {
     wxArrayString ret;
-    for(size_t i = 0; i < m_dvListCtrlFiles->GetItemCount(); ++i) {
+    for (size_t i = 0; i < m_dvListCtrlFiles->GetItemCount(); ++i) {
         wxDataViewItem item = m_dvListCtrlFiles->RowToItem(i);
-        if(m_dvListCtrlFiles->IsItemChecked(item, 0)) {
+        if (m_dvListCtrlFiles->IsItemChecked(item, 0)) {
             ret.Add(m_dvListCtrlFiles->GetItemText(item, 0));
         }
     }
@@ -146,17 +171,18 @@ void GitCommitDlg::OnChangeFile(wxDataViewEvent& e)
 
 void GitCommitDlg::OnCommitOK(wxCommandEvent& event)
 {
-    if(m_stcCommitMessage->GetText().IsEmpty() && !IsAmending()) {
+    if (m_stcCommitMessage->GetText().IsEmpty() && !IsAmending()) {
         ::wxMessageBox(_("Git requires a commit message"), "codelite", wxICON_WARNING | wxOK | wxCENTER);
         return;
     }
+    m_dismissedWithOk = true;
     EndModal(wxID_OK);
 }
 
 /*******************************************************************************/
 void GitCommitDlg::OnToggleCheckAll(wxCommandEvent& event)
 {
-    for(size_t i = 0; i < m_dvListCtrlFiles->GetItemCount(); ++i) {
+    for (size_t i = 0; i < m_dvListCtrlFiles->GetItemCount(); ++i) {
         m_dvListCtrlFiles->SetItemChecked(m_dvListCtrlFiles->RowToItem(i), m_toggleChecks, 0);
     }
     m_toggleChecks = !m_toggleChecks;
@@ -166,30 +192,28 @@ void GitCommitDlg::OnCommitHistory(wxCommandEvent& event)
 {
     clSingleChoiceDialog dlg(this, m_history);
     dlg.SetLabel(_("Choose a commit"));
-    if(dlg.ShowModal() != wxID_OK)
+    if (dlg.ShowModal() != wxID_OK)
         return;
 
     wxString commitHash = dlg.GetSelection().BeforeFirst(' ');
-    if(!commitHash.empty()) {
+    if (!commitHash.empty()) {
         wxString selectedCommit;
         m_plugin->DoExecuteCommandSync("log -1 --pretty=format:\"%B\" " + commitHash, &selectedCommit);
-        if(!selectedCommit.empty()) {
+        if (!selectedCommit.empty()) {
             m_stcCommitMessage->SetText(selectedCommit);
         }
     }
 }
 
-void GitCommitDlg::OnCommitHistoryUI(wxUpdateUIEvent& event) { event.Enable(!m_history.IsEmpty()); }
-
 void GitCommitDlg::OnAmendClicked(wxCommandEvent& event)
 {
-    if(event.IsChecked()) {
-        if(!m_previousCommitMessage.empty()) {
+    if (event.IsChecked()) {
+        if (!m_previousCommitMessage.empty()) {
             m_stashedMessage = m_stcCommitMessage->GetText();
             m_stcCommitMessage->SetText(m_previousCommitMessage);
         }
     } else {
-        if(!m_stashedMessage.empty()) {
+        if (!m_stashedMessage.empty()) {
             m_stcCommitMessage->SetText(m_stashedMessage);
         }
     }
