@@ -90,7 +90,7 @@ public:
     const wxString GetDefaultCommand() const
     {
         wxString str;
-        if(m_lastUsed >= 0 && m_lastUsed < (int)m_commands.size()) {
+        if (m_lastUsed >= 0 && m_lastUsed < (int)m_commands.size()) {
             str = m_commands.at(m_lastUsed).command;
         }
         return str;
@@ -147,20 +147,21 @@ class GitEntry : public clConfigItem
     int m_gitConsoleSashPos;
     int m_gitCommitDlgHSashPos;
     int m_gitCommitDlgVSashPos;
-    wxArrayString m_recentCommits;
     wxString m_gitShellCommand;
     bool m_gitBlameShowLogControls;
     bool m_gitBlameShowParentCommit;
     int m_gitBlameDlgMainSashPos;
     int m_gitBlameDlgHSashPos;
     int m_gitBlameDlgVSashPos;
+    wxString m_difftool;
 
 public:
     enum {
-        Git_Verbose_Log = (1 << 0),
-        Git_Show_Terminal = (1 << 1),
-        Git_Colour_Tree_View = (1 << 2),
-        Git_Show_Commit_Info = (1 << 4),
+        VerboseLog = (1 << 0),
+        ShowTerminal = (1 << 1),
+        ColourTreeView = (1 << 2),
+        ShowCommitInfo = (1 << 4),
+        CheckSignedOffBy = (1 << 5),
     };
 
     struct GitProperties {
@@ -180,7 +181,7 @@ public:
 
     void EnableFlag(size_t flag, bool b)
     {
-        if(b) {
+        if (b) {
             m_flags |= flag;
         } else {
             m_flags &= ~flag;
@@ -189,8 +190,6 @@ public:
 
     void Save();
     GitEntry& Load();
-    wxArrayString& GetRecentCommit() { return m_recentCommits; }
-    void AddRecentCommit(const wxString& commitMessage);
 
     void SetGitShellCommand(const wxString& gitShellCommand) { this->m_gitShellCommand = gitShellCommand; }
     const wxString& GetGitShellCommand() const { return m_gitShellCommand; }
@@ -213,7 +212,6 @@ public:
     const wxStringMap_t& GetEntries() const { return m_entries; }
     size_t GetFlags() const { return m_flags; }
     void SetEntry(const wxString& workspace, const wxString& repo) { this->m_entries[workspace] = repo; }
-    void DeleteEntry(const wxString& workspace);
 
     GitCommandsEntriesMap_t GetCommandsMap() const { return m_commandsMap; }
     void SetTrackedFileColour(const wxColour& colour) { this->m_colourTrackedFile = colour; }
@@ -255,6 +253,8 @@ public:
     virtual void FromJSON(const JSONItem& json);
     virtual JSONItem ToJSON() const;
 
-    bool IsShowBlameInfoInStatusBar() const { return m_flags & Git_Show_Commit_Info; }
+    bool IsShowBlameInfoInStatusBar() const { return m_flags & ShowCommitInfo; }
+    void SetDifftool(const wxString& difftool) { this->m_difftool = difftool; }
+    const wxString& GetDifftool() const { return m_difftool; }
 };
 #endif
