@@ -1,9 +1,9 @@
 #ifndef EVENTSEDITORDLG_H
 #define EVENTSEDITORDLG_H
 
+#include "database/entry.h"
 #include "events_database.h"
 #include "wxcrafter.h"
-#include <entry.h>
 
 class wxcWidget;
 class wxCrafterPlugin;
@@ -29,7 +29,6 @@ protected:
 public:
     EventsEditorPane(wxWindow* parent, wxcWidget* control, wxCrafterPlugin* plugin);
     virtual ~EventsEditorPane();
-    void OpenFunction(const wxString& kind, const wxString& fooname);
     void Save();
     void InitEventsForWidget(wxcWidget* control);
     void Clear();
